Class: IntersightClient::AdapterHostEthInterfaceAllOf

Inherits:
Object
  • Object
show all
Defined in:
lib/intersight_client/models/adapter_host_eth_interface_all_of.rb

Overview

Definition of the list of properties defined in ‘adapter.HostEthInterface’, excluding properties defined in parent classes.

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ AdapterHostEthInterfaceAllOf

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
# File 'lib/intersight_client/models/adapter_host_eth_interface_all_of.rb', line 158

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `IntersightClient::AdapterHostEthInterfaceAllOf` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `#{self.class.name}`. Please check the name to make sure it's valid. List of attributes: " + self.class.acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'class_id')
    self.class_id = attributes[:'class_id']
  else
    self.class_id = 'adapter.HostEthInterface'
  end

  if attributes.key?(:'object_type')
    self.object_type = attributes[:'object_type']
  else
    self.object_type = 'adapter.HostEthInterface'
  end

  if attributes.key?(:'admin_state')
    self.admin_state = attributes[:'admin_state']
  end

  if attributes.key?(:'ep_dn')
    self.ep_dn = attributes[:'ep_dn']
  end

  if attributes.key?(:'host_eth_interface_id')
    self.host_eth_interface_id = attributes[:'host_eth_interface_id']
  end

  if attributes.key?(:'interface_type')
    self.interface_type = attributes[:'interface_type']
  end

  if attributes.key?(:'mac_address')
    self.mac_address = attributes[:'mac_address']
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  end

  if attributes.key?(:'oper_reason')
    if (value = attributes[:'oper_reason']).is_a?(Array)
      self.oper_reason = value
    end
  end

  if attributes.key?(:'operability')
    self.operability = attributes[:'operability']
  end

  if attributes.key?(:'original_mac_address')
    self.original_mac_address = attributes[:'original_mac_address']
  end

  if attributes.key?(:'pci_addr')
    self.pci_addr = attributes[:'pci_addr']
  end

  if attributes.key?(:'peer_dn')
    self.peer_dn = attributes[:'peer_dn']
  end

  if attributes.key?(:'virtualization_preference')
    self.virtualization_preference = attributes[:'virtualization_preference']
  end

  if attributes.key?(:'vnic_dn')
    self.vnic_dn = attributes[:'vnic_dn']
  end

  if attributes.key?(:'adapter_unit')
    self.adapter_unit = attributes[:'adapter_unit']
  end

  if attributes.key?(:'inventory_device_info')
    self.inventory_device_info = attributes[:'inventory_device_info']
  end

  if attributes.key?(:'registered_device')
    self.registered_device = attributes[:'registered_device']
  end
end

Instance Attribute Details

#adapter_unitObject

Returns the value of attribute adapter_unit.



63
64
65
# File 'lib/intersight_client/models/adapter_host_eth_interface_all_of.rb', line 63

def adapter_unit
  @adapter_unit
end

#admin_stateObject

Admin state of the Host Ethernet Interface.



26
27
28
# File 'lib/intersight_client/models/adapter_host_eth_interface_all_of.rb', line 26

def admin_state
  @admin_state
end

#class_idObject

The fully-qualified name of the instantiated, concrete type. This property is used as a discriminator to identify the type of the payload when marshaling and unmarshaling data.



20
21
22
# File 'lib/intersight_client/models/adapter_host_eth_interface_all_of.rb', line 20

def class_id
  @class_id
end

#ep_dnObject

The Endpoint Config Dn of the Host Ethernet Interface.



29
30
31
# File 'lib/intersight_client/models/adapter_host_eth_interface_all_of.rb', line 29

def ep_dn
  @ep_dn
end

#host_eth_interface_idObject

Unique Identifier for an Host Ethernet Interface within the adapter object.



32
33
34
# File 'lib/intersight_client/models/adapter_host_eth_interface_all_of.rb', line 32

def host_eth_interface_id
  @host_eth_interface_id
end

#interface_typeObject

Type of External Ethernet Interface.



35
36
37
# File 'lib/intersight_client/models/adapter_host_eth_interface_all_of.rb', line 35

def interface_type
  @interface_type
end

#inventory_device_infoObject

Returns the value of attribute inventory_device_info.



65
66
67
# File 'lib/intersight_client/models/adapter_host_eth_interface_all_of.rb', line 65

def inventory_device_info
  @inventory_device_info
end

#mac_addressObject

Mac address of the Host Ethernet Interface.



38
39
40
# File 'lib/intersight_client/models/adapter_host_eth_interface_all_of.rb', line 38

def mac_address
  @mac_address
end

#nameObject

Name of Host Ethernet Interface.



41
42
43
# File 'lib/intersight_client/models/adapter_host_eth_interface_all_of.rb', line 41

def name
  @name
end

#object_typeObject

The fully-qualified name of the instantiated, concrete type. The value should be the same as the ‘ClassId’ property.



23
24
25
# File 'lib/intersight_client/models/adapter_host_eth_interface_all_of.rb', line 23

def object_type
  @object_type
end

#oper_reasonObject

Returns the value of attribute oper_reason.



43
44
45
# File 'lib/intersight_client/models/adapter_host_eth_interface_all_of.rb', line 43

def oper_reason
  @oper_reason
end

#operabilityObject

Operability status of Host Ethernet Channel Interface.



46
47
48
# File 'lib/intersight_client/models/adapter_host_eth_interface_all_of.rb', line 46

def operability
  @operability
end

#original_mac_addressObject

The factory default Mac address of the Host Ethernet Interface.



49
50
51
# File 'lib/intersight_client/models/adapter_host_eth_interface_all_of.rb', line 49

def original_mac_address
  @original_mac_address
end

#pci_addrObject

The PCI address of the Host Ethernet Interface.



52
53
54
# File 'lib/intersight_client/models/adapter_host_eth_interface_all_of.rb', line 52

def pci_addr
  @pci_addr
end

#peer_dnObject

The distinguished name of the peer endpoint connected to the Host Ethernet interface.



55
56
57
# File 'lib/intersight_client/models/adapter_host_eth_interface_all_of.rb', line 55

def peer_dn
  @peer_dn
end

#registered_deviceObject

Returns the value of attribute registered_device.



67
68
69
# File 'lib/intersight_client/models/adapter_host_eth_interface_all_of.rb', line 67

def registered_device
  @registered_device
end

#virtualization_preferenceObject

Virtualization Preference of the Host Ethernet Interface indicating if virtualization is enabled or not.



58
59
60
# File 'lib/intersight_client/models/adapter_host_eth_interface_all_of.rb', line 58

def virtualization_preference
  @virtualization_preference
end

#vnic_dnObject

The Virtual Ethernet Interface DN connected to the Host Ethernet Interface.



61
62
63
# File 'lib/intersight_client/models/adapter_host_eth_interface_all_of.rb', line 61

def vnic_dn
  @vnic_dn
end

Class Method Details

.acceptable_attribute_mapObject

Returns the key-value map of all the JSON attributes this model knows about



121
122
123
# File 'lib/intersight_client/models/adapter_host_eth_interface_all_of.rb', line 121

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



116
117
118
# File 'lib/intersight_client/models/adapter_host_eth_interface_all_of.rb', line 116

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
# File 'lib/intersight_client/models/adapter_host_eth_interface_all_of.rb', line 92

def self.attribute_map
  {
    :'class_id' => :'ClassId',
    :'object_type' => :'ObjectType',
    :'admin_state' => :'AdminState',
    :'ep_dn' => :'EpDn',
    :'host_eth_interface_id' => :'HostEthInterfaceId',
    :'interface_type' => :'InterfaceType',
    :'mac_address' => :'MacAddress',
    :'name' => :'Name',
    :'oper_reason' => :'OperReason',
    :'operability' => :'Operability',
    :'original_mac_address' => :'OriginalMacAddress',
    :'pci_addr' => :'PciAddr',
    :'peer_dn' => :'PeerDn',
    :'virtualization_preference' => :'VirtualizationPreference',
    :'vnic_dn' => :'VnicDn',
    :'adapter_unit' => :'AdapterUnit',
    :'inventory_device_info' => :'InventoryDeviceInfo',
    :'registered_device' => :'RegisteredDevice'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



337
338
339
# File 'lib/intersight_client/models/adapter_host_eth_interface_all_of.rb', line 337

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_nullableObject

List of attributes with nullable: true



150
151
152
153
154
# File 'lib/intersight_client/models/adapter_host_eth_interface_all_of.rb', line 150

def self.openapi_nullable
  Set.new([
    :'oper_reason',
  ])
end

.openapi_typesObject

Attribute type mapping.



126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
# File 'lib/intersight_client/models/adapter_host_eth_interface_all_of.rb', line 126

def self.openapi_types
  {
    :'class_id' => :'String',
    :'object_type' => :'String',
    :'admin_state' => :'String',
    :'ep_dn' => :'String',
    :'host_eth_interface_id' => :'Integer',
    :'interface_type' => :'String',
    :'mac_address' => :'String',
    :'name' => :'String',
    :'oper_reason' => :'Array<String>',
    :'operability' => :'String',
    :'original_mac_address' => :'String',
    :'pci_addr' => :'String',
    :'peer_dn' => :'String',
    :'virtualization_preference' => :'String',
    :'vnic_dn' => :'String',
    :'adapter_unit' => :'AdapterUnitRelationship',
    :'inventory_device_info' => :'InventoryDeviceInfoRelationship',
    :'registered_device' => :'AssetDeviceRegistrationRelationship'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
# File 'lib/intersight_client/models/adapter_host_eth_interface_all_of.rb', line 299

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      class_id == o.class_id &&
      object_type == o.object_type &&
      admin_state == o.admin_state &&
      ep_dn == o.ep_dn &&
      host_eth_interface_id == o.host_eth_interface_id &&
      interface_type == o.interface_type &&
      mac_address == o.mac_address &&
      name == o.name &&
      oper_reason == o.oper_reason &&
      operability == o.operability &&
      original_mac_address == o.original_mac_address &&
      pci_addr == o.pci_addr &&
      peer_dn == o.peer_dn &&
      virtualization_preference == o.virtualization_preference &&
      vnic_dn == o.vnic_dn &&
      adapter_unit == o.adapter_unit &&
      inventory_device_info == o.inventory_device_info &&
      registered_device == o.registered_device
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
# File 'lib/intersight_client/models/adapter_host_eth_interface_all_of.rb', line 367

def _deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = IntersightClient.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



438
439
440
441
442
443
444
445
446
447
448
449
450
# File 'lib/intersight_client/models/adapter_host_eth_interface_all_of.rb', line 438

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
# File 'lib/intersight_client/models/adapter_host_eth_interface_all_of.rb', line 344

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  AdapterHostEthInterfaceAllOf.openapi_types.each_pair do |key, type|
    if attributes[AdapterHostEthInterfaceAllOf.attribute_map[key]].nil? && AdapterHostEthInterfaceAllOf.openapi_nullable.include?(key)
      self.send("#{key}=", nil)
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[AdapterHostEthInterfaceAllOf.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[AdapterHostEthInterfaceAllOf.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[AdapterHostEthInterfaceAllOf.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[AdapterHostEthInterfaceAllOf.attribute_map[key]]))
    end
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


324
325
326
# File 'lib/intersight_client/models/adapter_host_eth_interface_all_of.rb', line 324

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



330
331
332
# File 'lib/intersight_client/models/adapter_host_eth_interface_all_of.rb', line 330

def hash
  [class_id, object_type, admin_state, ep_dn, host_eth_interface_id, interface_type, mac_address, name, oper_reason, operability, original_mac_address, pci_addr, peer_dn, virtualization_preference, vnic_dn, adapter_unit, inventory_device_info, registered_device].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



252
253
254
255
256
257
258
259
260
261
262
263
# File 'lib/intersight_client/models/adapter_host_eth_interface_all_of.rb', line 252

def list_invalid_properties
  invalid_properties = Array.new
  if @class_id.nil?
    invalid_properties.push('invalid value for "class_id", class_id cannot be nil.')
  end

  if @object_type.nil?
    invalid_properties.push('invalid value for "object_type", object_type cannot be nil.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



414
415
416
# File 'lib/intersight_client/models/adapter_host_eth_interface_all_of.rb', line 414

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



420
421
422
423
424
425
426
427
428
429
430
431
432
# File 'lib/intersight_client/models/adapter_host_eth_interface_all_of.rb', line 420

def to_hash
  hash = {}
  AdapterHostEthInterfaceAllOf.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = AdapterHostEthInterfaceAllOf.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



408
409
410
# File 'lib/intersight_client/models/adapter_host_eth_interface_all_of.rb', line 408

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



267
268
269
270
271
272
273
274
275
# File 'lib/intersight_client/models/adapter_host_eth_interface_all_of.rb', line 267

def valid?
  return false if @class_id.nil?
  class_id_validator = EnumAttributeValidator.new('String', ["adapter.HostEthInterface"])
  return false unless class_id_validator.valid?(@class_id)
  return false if @object_type.nil?
  object_type_validator = EnumAttributeValidator.new('String', ["adapter.HostEthInterface"])
  return false unless object_type_validator.valid?(@object_type)
  true
end