Class: IntersightClient::AdapterHostFcInterface

Inherits:
EquipmentBase show all
Defined in:
lib/intersight_client/models/adapter_host_fc_interface.rb

Overview

Host facing fibre channel interface on a server adapter.

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Attributes inherited from EquipmentBase

#model, #presence, #previous_fru, #revision, #serial, #vendor

Attributes inherited from InventoryBase

#device_mo_id, #dn, #rn

Attributes inherited from MoBaseMo

#account_moid, #ancestors, #create_time, #display_names, #domain_group_moid, #mod_time, #moid, #owners, #parent, #permission_resources, #shared_scope, #tags, #version_context

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ AdapterHostFcInterface

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
# File 'lib/intersight_client/models/adapter_host_fc_interface.rb', line 166

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `IntersightClient::AdapterHostFcInterface` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `#{self.class.name}`. Please check the name to make sure it's valid. List of attributes: " + self.class.acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  # call parent's initialize
  super(attributes)

  if attributes.key?(:'class_id')
    self.class_id = attributes[:'class_id']
  else
    self.class_id = 'adapter.HostFcInterface'
  end

  if attributes.key?(:'object_type')
    self.object_type = attributes[:'object_type']
  else
    self.object_type = 'adapter.HostFcInterface'
  end

  if attributes.key?(:'admin_state')
    self.admin_state = attributes[:'admin_state']
  end

  if attributes.key?(:'ep_dn')
    self.ep_dn = attributes[:'ep_dn']
  end

  if attributes.key?(:'host_fc_interface_id')
    self.host_fc_interface_id = attributes[:'host_fc_interface_id']
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  end

  if attributes.key?(:'oper_reason')
    if (value = attributes[:'oper_reason']).is_a?(Array)
      self.oper_reason = value
    end
  end

  if attributes.key?(:'oper_state')
    self.oper_state = attributes[:'oper_state']
  end

  if attributes.key?(:'operability')
    self.operability = attributes[:'operability']
  end

  if attributes.key?(:'original_wwnn')
    self.original_wwnn = attributes[:'original_wwnn']
  end

  if attributes.key?(:'original_wwpn')
    self.original_wwpn = attributes[:'original_wwpn']
  end

  if attributes.key?(:'peer_dn')
    self.peer_dn = attributes[:'peer_dn']
  end

  if attributes.key?(:'wwnn')
    self.wwnn = attributes[:'wwnn']
  end

  if attributes.key?(:'wwpn')
    self.wwpn = attributes[:'wwpn']
  end

  if attributes.key?(:'adapter_unit')
    self.adapter_unit = attributes[:'adapter_unit']
  end

  if attributes.key?(:'inventory_device_info')
    self.inventory_device_info = attributes[:'inventory_device_info']
  end

  if attributes.key?(:'registered_device')
    self.registered_device = attributes[:'registered_device']
  end
end

Instance Attribute Details

#adapter_unitObject

Returns the value of attribute adapter_unit.



60
61
62
# File 'lib/intersight_client/models/adapter_host_fc_interface.rb', line 60

def adapter_unit
  @adapter_unit
end

#admin_stateObject

Admin Configured State of Host Fibre Channel Interface.



26
27
28
# File 'lib/intersight_client/models/adapter_host_fc_interface.rb', line 26

def admin_state
  @admin_state
end

#class_idObject

The fully-qualified name of the instantiated, concrete type. This property is used as a discriminator to identify the type of the payload when marshaling and unmarshaling data.



20
21
22
# File 'lib/intersight_client/models/adapter_host_fc_interface.rb', line 20

def class_id
  @class_id
end

#ep_dnObject

The Endpoint Config Dn of the Host Fibre Channel Interface.



29
30
31
# File 'lib/intersight_client/models/adapter_host_fc_interface.rb', line 29

def ep_dn
  @ep_dn
end

#host_fc_interface_idObject

Identifier of Host Fibre Channel Interface.



32
33
34
# File 'lib/intersight_client/models/adapter_host_fc_interface.rb', line 32

def host_fc_interface_id
  @host_fc_interface_id
end

#inventory_device_infoObject

Returns the value of attribute inventory_device_info.



62
63
64
# File 'lib/intersight_client/models/adapter_host_fc_interface.rb', line 62

def inventory_device_info
  @inventory_device_info
end

#nameObject

Name of Host Fibre Channel Interface.



35
36
37
# File 'lib/intersight_client/models/adapter_host_fc_interface.rb', line 35

def name
  @name
end

#object_typeObject

The fully-qualified name of the instantiated, concrete type. The value should be the same as the ‘ClassId’ property.



23
24
25
# File 'lib/intersight_client/models/adapter_host_fc_interface.rb', line 23

def object_type
  @object_type
end

#oper_reasonObject

Returns the value of attribute oper_reason.



37
38
39
# File 'lib/intersight_client/models/adapter_host_fc_interface.rb', line 37

def oper_reason
  @oper_reason
end

#oper_stateObject

Operational State of Host Fibre Channel Interface.



40
41
42
# File 'lib/intersight_client/models/adapter_host_fc_interface.rb', line 40

def oper_state
  @oper_state
end

#operabilityObject

Operability status of Host Fibre Channel Interface.



43
44
45
# File 'lib/intersight_client/models/adapter_host_fc_interface.rb', line 43

def operability
  @operability
end

#original_wwnnObject

The uniquely distinguishable factory default World Wide Node Name of the Host.



46
47
48
# File 'lib/intersight_client/models/adapter_host_fc_interface.rb', line 46

def original_wwnn
  @original_wwnn
end

#original_wwpnObject

The uniquely distinguishable factory default World Wide Port Name of the Host Fibre Channel Interface.



49
50
51
# File 'lib/intersight_client/models/adapter_host_fc_interface.rb', line 49

def original_wwpn
  @original_wwpn
end

#peer_dnObject

PeerPort Dn of Host Fibre Channel Interface.



52
53
54
# File 'lib/intersight_client/models/adapter_host_fc_interface.rb', line 52

def peer_dn
  @peer_dn
end

#registered_deviceObject

Returns the value of attribute registered_device.



64
65
66
# File 'lib/intersight_client/models/adapter_host_fc_interface.rb', line 64

def registered_device
  @registered_device
end

#wwnnObject

The uniquely distinguishable user configured World Wide Node Name of the Host.



55
56
57
# File 'lib/intersight_client/models/adapter_host_fc_interface.rb', line 55

def wwnn
  @wwnn
end

#wwpnObject

The uniquely distinguishable user configured World Wide Port Name of the Host Fibre Channel Interface.



58
59
60
# File 'lib/intersight_client/models/adapter_host_fc_interface.rb', line 58

def wwpn
  @wwpn
end

Class Method Details

.acceptable_attribute_mapObject

Returns the key-value map of all the JSON attributes this model knows about, including the ones defined in its parent(s)



117
118
119
# File 'lib/intersight_client/models/adapter_host_fc_interface.rb', line 117

def self.acceptable_attribute_map
  attribute_map.merge(superclass.acceptable_attribute_map)
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about, including the ones defined in its parent(s)



112
113
114
# File 'lib/intersight_client/models/adapter_host_fc_interface.rb', line 112

def self.acceptable_attributes
  attribute_map.values.concat(superclass.acceptable_attributes)
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
# File 'lib/intersight_client/models/adapter_host_fc_interface.rb', line 89

def self.attribute_map
  {
    :'class_id' => :'ClassId',
    :'object_type' => :'ObjectType',
    :'admin_state' => :'AdminState',
    :'ep_dn' => :'EpDn',
    :'host_fc_interface_id' => :'HostFcInterfaceId',
    :'name' => :'Name',
    :'oper_reason' => :'OperReason',
    :'oper_state' => :'OperState',
    :'operability' => :'Operability',
    :'original_wwnn' => :'OriginalWwnn',
    :'original_wwpn' => :'OriginalWwpn',
    :'peer_dn' => :'PeerDn',
    :'wwnn' => :'Wwnn',
    :'wwpn' => :'Wwpn',
    :'adapter_unit' => :'AdapterUnit',
    :'inventory_device_info' => :'InventoryDeviceInfo',
    :'registered_device' => :'RegisteredDevice'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



343
344
345
# File 'lib/intersight_client/models/adapter_host_fc_interface.rb', line 343

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_all_ofObject

List of class defined in allOf (OpenAPI v3)



152
153
154
155
156
157
# File 'lib/intersight_client/models/adapter_host_fc_interface.rb', line 152

def self.openapi_all_of
  [
  :'AdapterHostFcInterfaceAllOf',
  :'EquipmentBase'
  ]
end

.openapi_discriminator_nameObject

discriminator’s property name in OpenAPI v3



160
161
162
# File 'lib/intersight_client/models/adapter_host_fc_interface.rb', line 160

def self.openapi_discriminator_name
  :'ClassId'
end

.openapi_nullableObject

List of attributes with nullable: true



145
146
147
148
149
# File 'lib/intersight_client/models/adapter_host_fc_interface.rb', line 145

def self.openapi_nullable
  Set.new([
    :'oper_reason',
  ])
end

.openapi_typesObject

Attribute type mapping.



122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
# File 'lib/intersight_client/models/adapter_host_fc_interface.rb', line 122

def self.openapi_types
  {
    :'class_id' => :'String',
    :'object_type' => :'String',
    :'admin_state' => :'String',
    :'ep_dn' => :'String',
    :'host_fc_interface_id' => :'Integer',
    :'name' => :'String',
    :'oper_reason' => :'Array<String>',
    :'oper_state' => :'String',
    :'operability' => :'String',
    :'original_wwnn' => :'String',
    :'original_wwpn' => :'String',
    :'peer_dn' => :'String',
    :'wwnn' => :'String',
    :'wwpn' => :'String',
    :'adapter_unit' => :'AdapterUnitRelationship',
    :'inventory_device_info' => :'InventoryDeviceInfoRelationship',
    :'registered_device' => :'AssetDeviceRegistrationRelationship'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
# File 'lib/intersight_client/models/adapter_host_fc_interface.rb', line 306

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      class_id == o.class_id &&
      object_type == o.object_type &&
      admin_state == o.admin_state &&
      ep_dn == o.ep_dn &&
      host_fc_interface_id == o.host_fc_interface_id &&
      name == o.name &&
      oper_reason == o.oper_reason &&
      oper_state == o.oper_state &&
      operability == o.operability &&
      original_wwnn == o.original_wwnn &&
      original_wwpn == o.original_wwpn &&
      peer_dn == o.peer_dn &&
      wwnn == o.wwnn &&
      wwpn == o.wwpn &&
      adapter_unit == o.adapter_unit &&
      inventory_device_info == o.inventory_device_info &&
      registered_device == o.registered_device && super(o)
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
410
411
# File 'lib/intersight_client/models/adapter_host_fc_interface.rb', line 374

def _deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = IntersightClient.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



445
446
447
448
449
450
451
452
453
454
455
456
457
# File 'lib/intersight_client/models/adapter_host_fc_interface.rb', line 445

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
# File 'lib/intersight_client/models/adapter_host_fc_interface.rb', line 350

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  super(attributes)
  AdapterHostFcInterface.openapi_types.each_pair do |key, type|
    if attributes[AdapterHostFcInterface.attribute_map[key]].nil? && AdapterHostFcInterface.openapi_nullable.include?(key)
      self.send("#{key}=", nil)
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[AdapterHostFcInterface.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[AdapterHostFcInterface.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[AdapterHostFcInterface.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[AdapterHostFcInterface.attribute_map[key]]))
    end
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


330
331
332
# File 'lib/intersight_client/models/adapter_host_fc_interface.rb', line 330

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



336
337
338
# File 'lib/intersight_client/models/adapter_host_fc_interface.rb', line 336

def hash
  [class_id, object_type, admin_state, ep_dn, host_fc_interface_id, name, oper_reason, oper_state, operability, original_wwnn, original_wwpn, peer_dn, wwnn, wwpn, adapter_unit, inventory_device_info, registered_device].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



259
260
261
262
263
264
265
266
267
268
269
270
# File 'lib/intersight_client/models/adapter_host_fc_interface.rb', line 259

def list_invalid_properties
  invalid_properties = super
  if @class_id.nil?
    invalid_properties.push('invalid value for "class_id", class_id cannot be nil.')
  end

  if @object_type.nil?
    invalid_properties.push('invalid value for "object_type", object_type cannot be nil.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



421
422
423
# File 'lib/intersight_client/models/adapter_host_fc_interface.rb', line 421

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



427
428
429
430
431
432
433
434
435
436
437
438
439
# File 'lib/intersight_client/models/adapter_host_fc_interface.rb', line 427

def to_hash
  hash = super
  AdapterHostFcInterface.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = AdapterHostFcInterface.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



415
416
417
# File 'lib/intersight_client/models/adapter_host_fc_interface.rb', line 415

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



274
275
276
277
278
279
280
281
282
# File 'lib/intersight_client/models/adapter_host_fc_interface.rb', line 274

def valid?
  return false if @class_id.nil?
  class_id_validator = EnumAttributeValidator.new('String', ["adapter.HostFcInterface"])
  return false unless class_id_validator.valid?(@class_id)
  return false if @object_type.nil?
  object_type_validator = EnumAttributeValidator.new('String', ["adapter.HostFcInterface"])
  return false unless object_type_validator.valid?(@object_type)
  true && super
end