Class: IntersightClient::AdapterHostIscsiInterfaceAllOf

Inherits:
Object
  • Object
show all
Defined in:
lib/intersight_client/models/adapter_host_iscsi_interface_all_of.rb

Overview

Definition of the list of properties defined in ‘adapter.HostIscsiInterface’, excluding properties defined in parent classes.

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ AdapterHostIscsiInterfaceAllOf

Initializes the object



138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
# File 'lib/intersight_client/models/adapter_host_iscsi_interface_all_of.rb', line 138

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `IntersightClient::AdapterHostIscsiInterfaceAllOf` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `#{self.class.name}`. Please check the name to make sure it's valid. List of attributes: " + self.class.acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'class_id')
    self.class_id = attributes[:'class_id']
  else
    self.class_id = 'adapter.HostIscsiInterface'
  end

  if attributes.key?(:'object_type')
    self.object_type = attributes[:'object_type']
  else
    self.object_type = 'adapter.HostIscsiInterface'
  end

  if attributes.key?(:'admin_state')
    self.admin_state = attributes[:'admin_state']
  end

  if attributes.key?(:'ep_dn')
    self.ep_dn = attributes[:'ep_dn']
  end

  if attributes.key?(:'host_iscsi_interface_id')
    self.host_iscsi_interface_id = attributes[:'host_iscsi_interface_id']
  end

  if attributes.key?(:'host_visible')
    self.host_visible = attributes[:'host_visible']
  end

  if attributes.key?(:'mac_address')
    self.mac_address = attributes[:'mac_address']
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  end

  if attributes.key?(:'oper_state')
    self.oper_state = attributes[:'oper_state']
  end

  if attributes.key?(:'operability')
    self.operability = attributes[:'operability']
  end

  if attributes.key?(:'peer_dn')
    self.peer_dn = attributes[:'peer_dn']
  end

  if attributes.key?(:'adapter_unit')
    self.adapter_unit = attributes[:'adapter_unit']
  end

  if attributes.key?(:'inventory_device_info')
    self.inventory_device_info = attributes[:'inventory_device_info']
  end

  if attributes.key?(:'registered_device')
    self.registered_device = attributes[:'registered_device']
  end
end

Instance Attribute Details

#adapter_unitObject

Returns the value of attribute adapter_unit.



52
53
54
# File 'lib/intersight_client/models/adapter_host_iscsi_interface_all_of.rb', line 52

def adapter_unit
  @adapter_unit
end

#admin_stateObject

Admin Configured State of Host ISCSI Interface.



26
27
28
# File 'lib/intersight_client/models/adapter_host_iscsi_interface_all_of.rb', line 26

def admin_state
  @admin_state
end

#class_idObject

The fully-qualified name of the instantiated, concrete type. This property is used as a discriminator to identify the type of the payload when marshaling and unmarshaling data.



20
21
22
# File 'lib/intersight_client/models/adapter_host_iscsi_interface_all_of.rb', line 20

def class_id
  @class_id
end

#ep_dnObject

The Endpoint Config Dn of the Host ISCSI Interface.



29
30
31
# File 'lib/intersight_client/models/adapter_host_iscsi_interface_all_of.rb', line 29

def ep_dn
  @ep_dn
end

#host_iscsi_interface_idObject

Identifier of the Host ISCSI Interface.



32
33
34
# File 'lib/intersight_client/models/adapter_host_iscsi_interface_all_of.rb', line 32

def host_iscsi_interface_id
  @host_iscsi_interface_id
end

#host_visibleObject

The visibility of the Host to the endpoint.



35
36
37
# File 'lib/intersight_client/models/adapter_host_iscsi_interface_all_of.rb', line 35

def host_visible
  @host_visible
end

#inventory_device_infoObject

Returns the value of attribute inventory_device_info.



54
55
56
# File 'lib/intersight_client/models/adapter_host_iscsi_interface_all_of.rb', line 54

def inventory_device_info
  @inventory_device_info
end

#mac_addressObject

MAC address of Host ISCSI Interface.



38
39
40
# File 'lib/intersight_client/models/adapter_host_iscsi_interface_all_of.rb', line 38

def mac_address
  @mac_address
end

#nameObject

Name of the Host ISCSI Interface.



41
42
43
# File 'lib/intersight_client/models/adapter_host_iscsi_interface_all_of.rb', line 41

def name
  @name
end

#object_typeObject

The fully-qualified name of the instantiated, concrete type. The value should be the same as the ‘ClassId’ property.



23
24
25
# File 'lib/intersight_client/models/adapter_host_iscsi_interface_all_of.rb', line 23

def object_type
  @object_type
end

#oper_stateObject

Operational State of Host ISCSI Interface.



44
45
46
# File 'lib/intersight_client/models/adapter_host_iscsi_interface_all_of.rb', line 44

def oper_state
  @oper_state
end

#operabilityObject

Operability status of Host ISCSI Interface.



47
48
49
# File 'lib/intersight_client/models/adapter_host_iscsi_interface_all_of.rb', line 47

def operability
  @operability
end

#peer_dnObject

PeerPort Dn of Host ISCSI Interface.



50
51
52
# File 'lib/intersight_client/models/adapter_host_iscsi_interface_all_of.rb', line 50

def peer_dn
  @peer_dn
end

#registered_deviceObject

Returns the value of attribute registered_device.



56
57
58
# File 'lib/intersight_client/models/adapter_host_iscsi_interface_all_of.rb', line 56

def registered_device
  @registered_device
end

Class Method Details

.acceptable_attribute_mapObject

Returns the key-value map of all the JSON attributes this model knows about



106
107
108
# File 'lib/intersight_client/models/adapter_host_iscsi_interface_all_of.rb', line 106

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



101
102
103
# File 'lib/intersight_client/models/adapter_host_iscsi_interface_all_of.rb', line 101

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
# File 'lib/intersight_client/models/adapter_host_iscsi_interface_all_of.rb', line 81

def self.attribute_map
  {
    :'class_id' => :'ClassId',
    :'object_type' => :'ObjectType',
    :'admin_state' => :'AdminState',
    :'ep_dn' => :'EpDn',
    :'host_iscsi_interface_id' => :'HostIscsiInterfaceId',
    :'host_visible' => :'HostVisible',
    :'mac_address' => :'MacAddress',
    :'name' => :'Name',
    :'oper_state' => :'OperState',
    :'operability' => :'Operability',
    :'peer_dn' => :'PeerDn',
    :'adapter_unit' => :'AdapterUnit',
    :'inventory_device_info' => :'InventoryDeviceInfo',
    :'registered_device' => :'RegisteredDevice'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash



295
296
297
# File 'lib/intersight_client/models/adapter_host_iscsi_interface_all_of.rb', line 295

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_nullableObject

List of attributes with nullable: true



131
132
133
134
# File 'lib/intersight_client/models/adapter_host_iscsi_interface_all_of.rb', line 131

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
# File 'lib/intersight_client/models/adapter_host_iscsi_interface_all_of.rb', line 111

def self.openapi_types
  {
    :'class_id' => :'String',
    :'object_type' => :'String',
    :'admin_state' => :'String',
    :'ep_dn' => :'String',
    :'host_iscsi_interface_id' => :'Integer',
    :'host_visible' => :'String',
    :'mac_address' => :'String',
    :'name' => :'String',
    :'oper_state' => :'String',
    :'operability' => :'String',
    :'peer_dn' => :'String',
    :'adapter_unit' => :'AdapterUnitRelationship',
    :'inventory_device_info' => :'InventoryDeviceInfoRelationship',
    :'registered_device' => :'AssetDeviceRegistrationRelationship'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.



261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
# File 'lib/intersight_client/models/adapter_host_iscsi_interface_all_of.rb', line 261

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      class_id == o.class_id &&
      object_type == o.object_type &&
      admin_state == o.admin_state &&
      ep_dn == o.ep_dn &&
      host_iscsi_interface_id == o.host_iscsi_interface_id &&
      host_visible == o.host_visible &&
      mac_address == o.mac_address &&
      name == o.name &&
      oper_state == o.oper_state &&
      operability == o.operability &&
      peer_dn == o.peer_dn &&
      adapter_unit == o.adapter_unit &&
      inventory_device_info == o.inventory_device_info &&
      registered_device == o.registered_device
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type



325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
# File 'lib/intersight_client/models/adapter_host_iscsi_interface_all_of.rb', line 325

def _deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = IntersightClient.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value



396
397
398
399
400
401
402
403
404
405
406
407
408
# File 'lib/intersight_client/models/adapter_host_iscsi_interface_all_of.rb', line 396

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash



302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
# File 'lib/intersight_client/models/adapter_host_iscsi_interface_all_of.rb', line 302

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  AdapterHostIscsiInterfaceAllOf.openapi_types.each_pair do |key, type|
    if attributes[AdapterHostIscsiInterfaceAllOf.attribute_map[key]].nil? && AdapterHostIscsiInterfaceAllOf.openapi_nullable.include?(key)
      self.send("#{key}=", nil)
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[AdapterHostIscsiInterfaceAllOf.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[AdapterHostIscsiInterfaceAllOf.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[AdapterHostIscsiInterfaceAllOf.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[AdapterHostIscsiInterfaceAllOf.attribute_map[key]]))
    end
  end

  self
end

#eql?(o) ⇒ Boolean

See Also:

  • `==` method


282
283
284
# File 'lib/intersight_client/models/adapter_host_iscsi_interface_all_of.rb', line 282

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.



288
289
290
# File 'lib/intersight_client/models/adapter_host_iscsi_interface_all_of.rb', line 288

def hash
  [class_id, object_type, admin_state, ep_dn, host_iscsi_interface_id, host_visible, mac_address, name, oper_state, operability, peer_dn, adapter_unit, inventory_device_info, registered_device].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?



214
215
216
217
218
219
220
221
222
223
224
225
# File 'lib/intersight_client/models/adapter_host_iscsi_interface_all_of.rb', line 214

def list_invalid_properties
  invalid_properties = Array.new
  if @class_id.nil?
    invalid_properties.push('invalid value for "class_id", class_id cannot be nil.')
  end

  if @object_type.nil?
    invalid_properties.push('invalid value for "object_type", object_type cannot be nil.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)



372
373
374
# File 'lib/intersight_client/models/adapter_host_iscsi_interface_all_of.rb', line 372

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash



378
379
380
381
382
383
384
385
386
387
388
389
390
# File 'lib/intersight_client/models/adapter_host_iscsi_interface_all_of.rb', line 378

def to_hash
  hash = {}
  AdapterHostIscsiInterfaceAllOf.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = AdapterHostIscsiInterfaceAllOf.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object



366
367
368
# File 'lib/intersight_client/models/adapter_host_iscsi_interface_all_of.rb', line 366

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid



229
230
231
232
233
234
235
236
237
# File 'lib/intersight_client/models/adapter_host_iscsi_interface_all_of.rb', line 229

def valid?
  return false if @class_id.nil?
  class_id_validator = EnumAttributeValidator.new('String', ["adapter.HostIscsiInterface"])
  return false unless class_id_validator.valid?(@class_id)
  return false if @object_type.nil?
  object_type_validator = EnumAttributeValidator.new('String', ["adapter.HostIscsiInterface"])
  return false unless object_type_validator.valid?(@object_type)
  true
end