Class: IntersightClient::ApplianceBackupBase

Inherits:
MoBaseMo
  • Object
show all
Defined in:
lib/intersight_client/models/appliance_backup_base.rb

Overview

BackupBase is the parent type of Backup, Restore, and BackupPolicy managed objects. BackupBase holds the common information required for copying the file from the Intersight Appliance to the remote file server and vice versa.

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Attributes inherited from MoBaseMo

#account_moid, #ancestors, #create_time, #display_names, #domain_group_moid, #mod_time, #moid, #owners, #parent, #permission_resources, #shared_scope, #tags, #version_context

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ ApplianceBackupBase

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
# File 'lib/intersight_client/models/appliance_backup_base.rb', line 124

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `IntersightClient::ApplianceBackupBase` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `#{self.class.name}`. Please check the name to make sure it's valid. List of attributes: " + self.class.acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  # call parent's initialize
  super(attributes)

  if attributes.key?(:'class_id')
    self.class_id = attributes[:'class_id']
  end

  if attributes.key?(:'object_type')
    self.object_type = attributes[:'object_type']
  end

  if attributes.key?(:'filename')
    self.filename = attributes[:'filename']
  end

  if attributes.key?(:'protocol')
    self.protocol = attributes[:'protocol']
  else
    self.protocol = 'scp'
  end

  if attributes.key?(:'remote_host')
    self.remote_host = attributes[:'remote_host']
  end

  if attributes.key?(:'remote_path')
    self.remote_path = attributes[:'remote_path']
  end

  if attributes.key?(:'remote_port')
    self.remote_port = attributes[:'remote_port']
  end

  if attributes.key?(:'username')
    self.username = attributes[:'username']
  end
end

Instance Attribute Details

#class_idObject

The fully-qualified name of the instantiated, concrete type. This property is used as a discriminator to identify the type of the payload when marshaling and unmarshaling data. The enum values provides the list of concrete types that can be instantiated from this abstract type.



20
21
22
# File 'lib/intersight_client/models/appliance_backup_base.rb', line 20

def class_id
  @class_id
end

#filenameObject

Backup filename to backup or restore.



26
27
28
# File 'lib/intersight_client/models/appliance_backup_base.rb', line 26

def filename
  @filename
end

#object_typeObject

The fully-qualified name of the instantiated, concrete type. The value should be the same as the ‘ClassId’ property. The enum values provides the list of concrete types that can be instantiated from this abstract type.



23
24
25
# File 'lib/intersight_client/models/appliance_backup_base.rb', line 23

def object_type
  @object_type
end

#protocolObject

Communication protocol used by the file server (e.g. scp or sftp). * scp - Secure Copy Protocol (SCP) to access the file server. * sftp - SSH File Transfer Protocol (SFTP) to access file server.



29
30
31
# File 'lib/intersight_client/models/appliance_backup_base.rb', line 29

def protocol
  @protocol
end

#remote_hostObject

Hostname of the remote file server.



32
33
34
# File 'lib/intersight_client/models/appliance_backup_base.rb', line 32

def remote_host
  @remote_host
end

#remote_pathObject

File server directory to copy the file.



35
36
37
# File 'lib/intersight_client/models/appliance_backup_base.rb', line 35

def remote_path
  @remote_path
end

#remote_portObject

Remote TCP port on the file server (e.g. 22 for scp).



38
39
40
# File 'lib/intersight_client/models/appliance_backup_base.rb', line 38

def remote_port
  @remote_port
end

#usernameObject

Username to authenticate the fileserver.



41
42
43
# File 'lib/intersight_client/models/appliance_backup_base.rb', line 41

def username
  @username
end

Class Method Details

.acceptable_attribute_mapObject

Returns the key-value map of all the JSON attributes this model knows about, including the ones defined in its parent(s)



85
86
87
# File 'lib/intersight_client/models/appliance_backup_base.rb', line 85

def self.acceptable_attribute_map
  attribute_map.merge(superclass.acceptable_attribute_map)
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about, including the ones defined in its parent(s)



80
81
82
# File 'lib/intersight_client/models/appliance_backup_base.rb', line 80

def self.acceptable_attributes
  attribute_map.values.concat(superclass.acceptable_attributes)
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



66
67
68
69
70
71
72
73
74
75
76
77
# File 'lib/intersight_client/models/appliance_backup_base.rb', line 66

def self.attribute_map
  {
    :'class_id' => :'ClassId',
    :'object_type' => :'ObjectType',
    :'filename' => :'Filename',
    :'protocol' => :'Protocol',
    :'remote_host' => :'RemoteHost',
    :'remote_path' => :'RemotePath',
    :'remote_port' => :'RemotePort',
    :'username' => :'Username'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



315
316
317
# File 'lib/intersight_client/models/appliance_backup_base.rb', line 315

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_all_ofObject

List of class defined in allOf (OpenAPI v3)



110
111
112
113
114
115
# File 'lib/intersight_client/models/appliance_backup_base.rb', line 110

def self.openapi_all_of
  [
  :'ApplianceBackupBaseAllOf',
  :'MoBaseMo'
  ]
end

.openapi_discriminator_nameObject

discriminator’s property name in OpenAPI v3



118
119
120
# File 'lib/intersight_client/models/appliance_backup_base.rb', line 118

def self.openapi_discriminator_name
  :'ClassId'
end

.openapi_nullableObject

List of attributes with nullable: true



104
105
106
107
# File 'lib/intersight_client/models/appliance_backup_base.rb', line 104

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



90
91
92
93
94
95
96
97
98
99
100
101
# File 'lib/intersight_client/models/appliance_backup_base.rb', line 90

def self.openapi_types
  {
    :'class_id' => :'String',
    :'object_type' => :'String',
    :'filename' => :'String',
    :'protocol' => :'String',
    :'remote_host' => :'String',
    :'remote_path' => :'String',
    :'remote_port' => :'Integer',
    :'username' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



287
288
289
290
291
292
293
294
295
296
297
298
# File 'lib/intersight_client/models/appliance_backup_base.rb', line 287

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      class_id == o.class_id &&
      object_type == o.object_type &&
      filename == o.filename &&
      protocol == o.protocol &&
      remote_host == o.remote_host &&
      remote_path == o.remote_path &&
      remote_port == o.remote_port &&
      username == o.username && super(o)
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
# File 'lib/intersight_client/models/appliance_backup_base.rb', line 346

def _deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = IntersightClient.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



417
418
419
420
421
422
423
424
425
426
427
428
429
# File 'lib/intersight_client/models/appliance_backup_base.rb', line 417

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
# File 'lib/intersight_client/models/appliance_backup_base.rb', line 322

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  super(attributes)
  ApplianceBackupBase.openapi_types.each_pair do |key, type|
    if attributes[ApplianceBackupBase.attribute_map[key]].nil? && ApplianceBackupBase.openapi_nullable.include?(key)
      self.send("#{key}=", nil)
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[ApplianceBackupBase.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[ApplianceBackupBase.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[ApplianceBackupBase.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[ApplianceBackupBase.attribute_map[key]]))
    end
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


302
303
304
# File 'lib/intersight_client/models/appliance_backup_base.rb', line 302

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



308
309
310
# File 'lib/intersight_client/models/appliance_backup_base.rb', line 308

def hash
  [class_id, object_type, filename, protocol, remote_host, remote_path, remote_port, username].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
# File 'lib/intersight_client/models/appliance_backup_base.rb', line 177

def list_invalid_properties
  invalid_properties = super
  if @class_id.nil?
    invalid_properties.push('invalid value for "class_id", class_id cannot be nil.')
  end

  if @object_type.nil?
    invalid_properties.push('invalid value for "object_type", object_type cannot be nil.')
  end

  pattern = Regexp.new(/^$|^[a-zA-Z0-9][a-zA-Z0-9_\.\-\+]*$/)
  if !@filename.nil? && @filename !~ pattern
    invalid_properties.push("invalid value for \"filename\", must conform to the pattern #{pattern}.")
  end

  pattern = Regexp.new(/^$|^(\/[^\/ ]*)+\/?$/)
  if !@remote_path.nil? && @remote_path !~ pattern
    invalid_properties.push("invalid value for \"remote_path\", must conform to the pattern #{pattern}.")
  end

  pattern = Regexp.new(/^$|^[a-zA-Z0-9_][a-zA-Z0-9_\.\-\+]*$/)
  if !@username.nil? && @username !~ pattern
    invalid_properties.push("invalid value for \"username\", must conform to the pattern #{pattern}.")
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



393
394
395
# File 'lib/intersight_client/models/appliance_backup_base.rb', line 393

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



399
400
401
402
403
404
405
406
407
408
409
410
411
# File 'lib/intersight_client/models/appliance_backup_base.rb', line 399

def to_hash
  hash = super
  ApplianceBackupBase.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = ApplianceBackupBase.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



387
388
389
# File 'lib/intersight_client/models/appliance_backup_base.rb', line 387

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



207
208
209
210
211
212
213
214
215
216
217
218
219
220
# File 'lib/intersight_client/models/appliance_backup_base.rb', line 207

def valid?
  return false if @class_id.nil?
  class_id_validator = EnumAttributeValidator.new('String', ["appliance.Backup", "appliance.BackupPolicy", "appliance.Restore"])
  return false unless class_id_validator.valid?(@class_id)
  return false if @object_type.nil?
  object_type_validator = EnumAttributeValidator.new('String', ["appliance.Backup", "appliance.BackupPolicy", "appliance.Restore"])
  return false unless object_type_validator.valid?(@object_type)
  return false if !@filename.nil? && @filename !~ Regexp.new(/^$|^[a-zA-Z0-9][a-zA-Z0-9_\.\-\+]*$/)
  protocol_validator = EnumAttributeValidator.new('String', ["scp", "sftp"])
  return false unless protocol_validator.valid?(@protocol)
  return false if !@remote_path.nil? && @remote_path !~ Regexp.new(/^$|^(\/[^\/ ]*)+\/?$/)
  return false if !@username.nil? && @username !~ Regexp.new(/^$|^[a-zA-Z0-9_][a-zA-Z0-9_\.\-\+]*$/)
  true && super
end