Class: IntersightClient::ApplianceFileSystemStatusAllOf

Inherits:
Object
  • Object
show all
Defined in:
lib/intersight_client/models/appliance_file_system_status_all_of.rb

Overview

Definition of the list of properties defined in ‘appliance.FileSystemStatus’, excluding properties defined in parent classes.

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ ApplianceFileSystemStatusAllOf

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
# File 'lib/intersight_client/models/appliance_file_system_status_all_of.rb', line 110

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `IntersightClient::ApplianceFileSystemStatusAllOf` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `#{self.class.name}`. Please check the name to make sure it's valid. List of attributes: " + self.class.acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'class_id')
    self.class_id = attributes[:'class_id']
  else
    self.class_id = 'appliance.FileSystemStatus'
  end

  if attributes.key?(:'object_type')
    self.object_type = attributes[:'object_type']
  else
    self.object_type = 'appliance.FileSystemStatus'
  end

  if attributes.key?(:'capacity')
    self.capacity = attributes[:'capacity']
  end

  if attributes.key?(:'mountpoint')
    self.mountpoint = attributes[:'mountpoint']
  end

  if attributes.key?(:'operational_status')
    self.operational_status = attributes[:'operational_status']
  else
    self.operational_status = 'Unknown'
  end

  if attributes.key?(:'status_checks')
    if (value = attributes[:'status_checks']).is_a?(Array)
      self.status_checks = value
    end
  end

  if attributes.key?(:'usage')
    self.usage = attributes[:'usage']
  end

  if attributes.key?(:'node_status')
    self.node_status = attributes[:'node_status']
  end
end

Instance Attribute Details

#capacityObject

Capacity of the file system in bytes.



26
27
28
# File 'lib/intersight_client/models/appliance_file_system_status_all_of.rb', line 26

def capacity
  @capacity
end

#class_idObject

The fully-qualified name of the instantiated, concrete type. This property is used as a discriminator to identify the type of the payload when marshaling and unmarshaling data.



20
21
22
# File 'lib/intersight_client/models/appliance_file_system_status_all_of.rb', line 20

def class_id
  @class_id
end

#mountpointObject

Mount point of this file system.



29
30
31
# File 'lib/intersight_client/models/appliance_file_system_status_all_of.rb', line 29

def mountpoint
  @mountpoint
end

#node_statusObject

Returns the value of attribute node_status.



39
40
41
# File 'lib/intersight_client/models/appliance_file_system_status_all_of.rb', line 39

def node_status
  @node_status
end

#object_typeObject

The fully-qualified name of the instantiated, concrete type. The value should be the same as the ‘ClassId’ property.



23
24
25
# File 'lib/intersight_client/models/appliance_file_system_status_all_of.rb', line 23

def object_type
  @object_type
end

#operational_statusObject

Operational status of the file system. Operational status is based on the result of the status checks. If result of any check is Critical, then its value is Impaired. Otherwise, if result of any check is Warning, then its value is AttentionNeeded. If all checks are OK, then its value is Operational. * Unknown - Operational status of the Intersight Appliance entity is Unknown. * Operational - Operational status of the Intersight Appliance entity is Operational. * Impaired - Operational status of the Intersight Appliance entity is Impaired. * AttentionNeeded - Operational status of the Intersight Appliance entity is AttentionNeeded.



32
33
34
# File 'lib/intersight_client/models/appliance_file_system_status_all_of.rb', line 32

def operational_status
  @operational_status
end

#status_checksObject

Returns the value of attribute status_checks.



34
35
36
# File 'lib/intersight_client/models/appliance_file_system_status_all_of.rb', line 34

def status_checks
  @status_checks
end

#usageObject

Percentage of the file system capacity currently in use.



37
38
39
# File 'lib/intersight_client/models/appliance_file_system_status_all_of.rb', line 37

def usage
  @usage
end

Class Method Details

.acceptable_attribute_mapObject

Returns the key-value map of all the JSON attributes this model knows about



83
84
85
# File 'lib/intersight_client/models/appliance_file_system_status_all_of.rb', line 83

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



78
79
80
# File 'lib/intersight_client/models/appliance_file_system_status_all_of.rb', line 78

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



64
65
66
67
68
69
70
71
72
73
74
75
# File 'lib/intersight_client/models/appliance_file_system_status_all_of.rb', line 64

def self.attribute_map
  {
    :'class_id' => :'ClassId',
    :'object_type' => :'ObjectType',
    :'capacity' => :'Capacity',
    :'mountpoint' => :'Mountpoint',
    :'operational_status' => :'OperationalStatus',
    :'status_checks' => :'StatusChecks',
    :'usage' => :'Usage',
    :'node_status' => :'NodeStatus'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



253
254
255
# File 'lib/intersight_client/models/appliance_file_system_status_all_of.rb', line 253

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_nullableObject

List of attributes with nullable: true



102
103
104
105
106
# File 'lib/intersight_client/models/appliance_file_system_status_all_of.rb', line 102

def self.openapi_nullable
  Set.new([
    :'status_checks',
  ])
end

.openapi_typesObject

Attribute type mapping.



88
89
90
91
92
93
94
95
96
97
98
99
# File 'lib/intersight_client/models/appliance_file_system_status_all_of.rb', line 88

def self.openapi_types
  {
    :'class_id' => :'String',
    :'object_type' => :'String',
    :'capacity' => :'Integer',
    :'mountpoint' => :'String',
    :'operational_status' => :'String',
    :'status_checks' => :'Array<ApplianceStatusCheck>',
    :'usage' => :'Float',
    :'node_status' => :'ApplianceNodeStatusRelationship'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



225
226
227
228
229
230
231
232
233
234
235
236
# File 'lib/intersight_client/models/appliance_file_system_status_all_of.rb', line 225

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      class_id == o.class_id &&
      object_type == o.object_type &&
      capacity == o.capacity &&
      mountpoint == o.mountpoint &&
      operational_status == o.operational_status &&
      status_checks == o.status_checks &&
      usage == o.usage &&
      node_status == o.node_status
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
# File 'lib/intersight_client/models/appliance_file_system_status_all_of.rb', line 283

def _deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = IntersightClient.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



354
355
356
357
358
359
360
361
362
363
364
365
366
# File 'lib/intersight_client/models/appliance_file_system_status_all_of.rb', line 354

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
# File 'lib/intersight_client/models/appliance_file_system_status_all_of.rb', line 260

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  ApplianceFileSystemStatusAllOf.openapi_types.each_pair do |key, type|
    if attributes[ApplianceFileSystemStatusAllOf.attribute_map[key]].nil? && ApplianceFileSystemStatusAllOf.openapi_nullable.include?(key)
      self.send("#{key}=", nil)
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[ApplianceFileSystemStatusAllOf.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[ApplianceFileSystemStatusAllOf.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[ApplianceFileSystemStatusAllOf.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[ApplianceFileSystemStatusAllOf.attribute_map[key]]))
    end
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


240
241
242
# File 'lib/intersight_client/models/appliance_file_system_status_all_of.rb', line 240

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



246
247
248
# File 'lib/intersight_client/models/appliance_file_system_status_all_of.rb', line 246

def hash
  [class_id, object_type, capacity, mountpoint, operational_status, status_checks, usage, node_status].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



166
167
168
169
170
171
172
173
174
175
176
177
# File 'lib/intersight_client/models/appliance_file_system_status_all_of.rb', line 166

def list_invalid_properties
  invalid_properties = Array.new
  if @class_id.nil?
    invalid_properties.push('invalid value for "class_id", class_id cannot be nil.')
  end

  if @object_type.nil?
    invalid_properties.push('invalid value for "object_type", object_type cannot be nil.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



330
331
332
# File 'lib/intersight_client/models/appliance_file_system_status_all_of.rb', line 330

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



336
337
338
339
340
341
342
343
344
345
346
347
348
# File 'lib/intersight_client/models/appliance_file_system_status_all_of.rb', line 336

def to_hash
  hash = {}
  ApplianceFileSystemStatusAllOf.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = ApplianceFileSystemStatusAllOf.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



324
325
326
# File 'lib/intersight_client/models/appliance_file_system_status_all_of.rb', line 324

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



181
182
183
184
185
186
187
188
189
190
191
# File 'lib/intersight_client/models/appliance_file_system_status_all_of.rb', line 181

def valid?
  return false if @class_id.nil?
  class_id_validator = EnumAttributeValidator.new('String', ["appliance.FileSystemStatus"])
  return false unless class_id_validator.valid?(@class_id)
  return false if @object_type.nil?
  object_type_validator = EnumAttributeValidator.new('String', ["appliance.FileSystemStatus"])
  return false unless object_type_validator.valid?(@object_type)
  operational_status_validator = EnumAttributeValidator.new('String', ["Unknown", "Operational", "Impaired", "AttentionNeeded"])
  return false unless operational_status_validator.valid?(@operational_status)
  true
end