Class: IntersightClient::ApplianceSystemInfoAllOf

Inherits:
Object
  • Object
show all
Defined in:
lib/intersight_client/models/appliance_system_info_all_of.rb

Overview

Definition of the list of properties defined in ‘appliance.SystemInfo’, excluding properties defined in parent classes.

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ ApplianceSystemInfoAllOf

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
# File 'lib/intersight_client/models/appliance_system_info_all_of.rb', line 121

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `IntersightClient::ApplianceSystemInfoAllOf` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `#{self.class.name}`. Please check the name to make sure it's valid. List of attributes: " + self.class.acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'class_id')
    self.class_id = attributes[:'class_id']
  else
    self.class_id = 'appliance.SystemInfo'
  end

  if attributes.key?(:'object_type')
    self.object_type = attributes[:'object_type']
  else
    self.object_type = 'appliance.SystemInfo'
  end

  if attributes.key?(:'cloud_conn_status')
    self.cloud_conn_status = attributes[:'cloud_conn_status']
  else
    self.cloud_conn_status = ''
  end

  if attributes.key?(:'deployment_size')
    self.deployment_size = attributes[:'deployment_size']
  end

  if attributes.key?(:'hostname')
    self.hostname = attributes[:'hostname']
  end

  if attributes.key?(:'init_done')
    self.init_done = attributes[:'init_done']
  end

  if attributes.key?(:'operational_status')
    self.operational_status = attributes[:'operational_status']
  else
    self.operational_status = 'Unknown'
  end

  if attributes.key?(:'serial_id')
    self.serial_id = attributes[:'serial_id']
  end

  if attributes.key?(:'time_zone')
    self.time_zone = attributes[:'time_zone']
  else
    self.time_zone = 'Pacific/Niue'
  end

  if attributes.key?(:'version')
    self.version = attributes[:'version']
  end
end

Instance Attribute Details

#class_idObject

The fully-qualified name of the instantiated, concrete type. This property is used as a discriminator to identify the type of the payload when marshaling and unmarshaling data.



20
21
22
# File 'lib/intersight_client/models/appliance_system_info_all_of.rb', line 20

def class_id
  @class_id
end

#cloud_conn_statusObject

Connection state of the Intersight Appliance to the Intersight. * “ - The target details have been persisted but Intersight has not yet attempted to connect to the target. * Connected - Intersight is able to establish a connection to the target and initiate management activities. * NotConnected - Intersight is unable to establish a connection to the target. * ClaimInProgress - Claim of the target is in progress. A connection to the target has not been fully established. * Unclaimed - The device was un-claimed from the users account by an Administrator of the device. Also indicates the failure to claim Targets of type HTTP Endpoint in Intersight. * Claimed - Target of type HTTP Endpoint is successfully claimed in Intersight. Currently no validation is performed to verify the Target connectivity from Intersight at the time of creation. However invoking API from Intersight Orchestrator fails if this Target is not reachable from Intersight or if Target API credentials are incorrect.



26
27
28
# File 'lib/intersight_client/models/appliance_system_info_all_of.rb', line 26

def cloud_conn_status
  @cloud_conn_status
end

#deployment_sizeObject

Current running deployment size for the Intersight Appliance cluster. Eg. small, medium, large etc.



29
30
31
# File 'lib/intersight_client/models/appliance_system_info_all_of.rb', line 29

def deployment_size
  @deployment_size
end

#hostnameObject

Publicly accessible FQDN or IP address of the Intersight Appliance.



32
33
34
# File 'lib/intersight_client/models/appliance_system_info_all_of.rb', line 32

def hostname
  @hostname
end

#init_doneObject

Indicates that the setup initialization process has been completed.



35
36
37
# File 'lib/intersight_client/models/appliance_system_info_all_of.rb', line 35

def init_done
  @init_done
end

#object_typeObject

The fully-qualified name of the instantiated, concrete type. The value should be the same as the ‘ClassId’ property.



23
24
25
# File 'lib/intersight_client/models/appliance_system_info_all_of.rb', line 23

def object_type
  @object_type
end

#operational_statusObject

Operational status of the Intersight Appliance cluster. * Unknown - Operational status of the Intersight Appliance entity is Unknown. * Operational - Operational status of the Intersight Appliance entity is Operational. * Impaired - Operational status of the Intersight Appliance entity is Impaired. * AttentionNeeded - Operational status of the Intersight Appliance entity is AttentionNeeded.



38
39
40
# File 'lib/intersight_client/models/appliance_system_info_all_of.rb', line 38

def operational_status
  @operational_status
end

#serial_idObject

SerialId of the Intersight Appliance. SerialId is generated when the Intersight Appliance is setup. It is a unique UUID string, and serialId will not change for the life time of the Intersight Appliance.



41
42
43
# File 'lib/intersight_client/models/appliance_system_info_all_of.rb', line 41

def serial_id
  @serial_id
end

#time_zoneObject

Timezone of the Intersight Appliance. * Pacific/Niue - * Pacific/Pago_Pago - * Pacific/Honolulu - * Pacific/Rarotonga - * Pacific/Tahiti - * Pacific/Marquesas - * America/Anchorage - * Pacific/Gambier - * America/Los_Angeles - * America/Tijuana - * America/Vancouver - * America/Whitehorse - * Pacific/Pitcairn - * America/Dawson_Creek - * America/Denver - * America/Edmonton - * America/Hermosillo - * America/Mazatlan - * America/Phoenix - * America/Yellowknife - * America/Belize - * America/Chicago - * America/Costa_Rica - * America/El_Salvador - * America/Guatemala - * America/Managua - * America/Mexico_City - * America/Regina - * America/Tegucigalpa - * America/Winnipeg - * Pacific/Galapagos - * America/Bogota - * America/Cancun - * America/Cayman - * America/Guayaquil - * America/Havana - * America/Iqaluit - * America/Jamaica - * America/Lima - * America/Nassau - * America/New_York - * America/Panama - * America/Port-au-Prince - * America/Rio_Branco - * America/Toronto - * Pacific/Easter - * America/Caracas - * America/Asuncion - * America/Barbados - * America/Boa_Vista - * America/Campo_Grande - * America/Cuiaba - * America/Curacao - * America/Grand_Turk - * America/Guyana - * America/Halifax - * America/La_Paz - * America/Manaus - * America/Martinique - * America/Port_of_Spain - * America/Porto_Velho - * America/Puerto_Rico - * America/Santo_Domingo - * America/Thule - * Atlantic/Bermuda - * America/St_Johns - * America/Araguaina - * America/Argentina/Buenos_Aires - * America/Bahia - * America/Belem - * America/Cayenne - * America/Fortaleza - * America/Godthab - * America/Maceio - * America/Miquelon - * America/Montevideo - * America/Paramaribo - * America/Recife - * America/Santiago - * America/Sao_Paulo - * Antarctica/Palmer - * Antarctica/Rothera - * Atlantic/Stanley - * America/Noronha - * Atlantic/South_Georgia - * America/Scoresbysund - * Atlantic/Azores - * Atlantic/Cape_Verde - * Africa/Abidjan - * Africa/Accra - * Africa/Bissau - * Africa/Casablanca - * Africa/El_Aaiun - * Africa/Monrovia - * America/Danmarkshavn - * Atlantic/Canary - * Atlantic/Faroe - * Atlantic/Reykjavik - * Etc/GMT - * Europe/Dublin - * Europe/Lisbon - * Europe/London - * Africa/Algiers - * Africa/Ceuta - * Africa/Lagos - * Africa/Ndjamena - * Africa/Tunis - * Africa/Windhoek - * Europe/Amsterdam - * Europe/Andorra - * Europe/Belgrade - * Europe/Berlin - * Europe/Brussels - * Europe/Budapest - * Europe/Copenhagen - * Europe/Gibraltar - * Europe/Luxembourg - * Europe/Madrid - * Europe/Malta - * Europe/Monaco - * Europe/Oslo - * Europe/Paris - * Europe/Prague - * Europe/Rome - * Europe/Stockholm - * Europe/Tirane - * Europe/Vienna - * Europe/Warsaw - * Europe/Zurich - * Africa/Cairo - * Africa/Johannesburg - * Africa/Maputo - * Africa/Tripoli - * Asia/Amman - * Asia/Beirut - * Asia/Damascus - * Asia/Gaza - * Asia/Jerusalem - * Asia/Nicosia - * Europe/Athens - * Europe/Bucharest - * Europe/Chisinau - * Europe/Helsinki - * Europe/Istanbul - * Europe/Kaliningrad - * Europe/Kiev - * Europe/Riga - * Europe/Sofia - * Europe/Tallinn - * Europe/Vilnius - * Africa/Khartoum - * Africa/Nairobi - * Antarctica/Syowa - * Asia/Baghdad - * Asia/Qatar - * Asia/Riyadh - * Europe/Minsk - * Europe/Moscow - * Asia/Tehran - * Asia/Baku - * Asia/Dubai - * Asia/Tbilisi - * Asia/Yerevan - * Europe/Samara - * Indian/Mahe - * Indian/Mauritius - * Indian/Reunion - * Asia/Kabul - * Antarctica/Mawson - * Asia/Aqtau - * Asia/Aqtobe - * Asia/Ashgabat - * Asia/Dushanbe - * Asia/Karachi - * Asia/Tashkent - * Asia/Yekaterinburg - * Indian/Kerguelen - * Indian/Maldives - * Asia/Calcutta - * Asia/Kolkata - * Asia/Colombo - * Asia/Katmandu - * Antarctica/Vostok - * Asia/Almaty - * Asia/Bishkek - * Asia/Dhaka - * Asia/Omsk - * Asia/Thimphu - * Indian/Chagos - * Asia/Rangoon - * Indian/Cocos - * Antarctica/Davis - * Asia/Bangkok - * Asia/Hovd - * Asia/Jakarta - * Asia/Krasnoyarsk - * Asia/Saigon - * Indian/Christmas - * Antarctica/Casey - * Asia/Brunei - * Asia/Choibalsan - * Asia/Hong_Kong - * Asia/Irkutsk - * Asia/Kuala_Lumpur - * Asia/Macau - * Asia/Makassar - * Asia/Manila - * Asia/Shanghai - * Asia/Singapore - * Asia/Taipei - * Asia/Ulaanbaatar - * Australia/Perth - * Asia/Pyongyang - * Asia/Dili - * Asia/Jayapura - * Asia/Seoul - * Asia/Tokyo - * Asia/Yakutsk - * Pacific/Palau - * Australia/Adelaide - * Australia/Darwin - * Antarctica/DumontDUrville - * Asia/Magadan - * Asia/Vladivostok - * Australia/Brisbane - * Australia/Hobart - * Australia/Sydney - * Pacific/Chuuk - * Pacific/Guam - * Pacific/Port_Moresby - * Pacific/Efate - * Pacific/Guadalcanal - * Pacific/Kosrae - * Pacific/Norfolk - * Pacific/Noumea - * Pacific/Pohnpei - * Asia/Kamchatka - * Pacific/Auckland - * Pacific/Fiji - * Pacific/Funafuti - * Pacific/Kwajalein - * Pacific/Majuro - * Pacific/Nauru - * Pacific/Tarawa - * Pacific/Wake - * Pacific/Wallis - * Pacific/Apia - * Pacific/Enderbury - * Pacific/Fakaofo - * Pacific/Tongatapu - * Pacific/Kiritimati -



44
45
46
# File 'lib/intersight_client/models/appliance_system_info_all_of.rb', line 44

def time_zone
  @time_zone
end

#versionObject

Current software version of the Intersight Appliance.



47
48
49
# File 'lib/intersight_client/models/appliance_system_info_all_of.rb', line 47

def version
  @version
end

Class Method Details

.acceptable_attribute_mapObject

Returns the key-value map of all the JSON attributes this model knows about



93
94
95
# File 'lib/intersight_client/models/appliance_system_info_all_of.rb', line 93

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



88
89
90
# File 'lib/intersight_client/models/appliance_system_info_all_of.rb', line 88

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



72
73
74
75
76
77
78
79
80
81
82
83
84
85
# File 'lib/intersight_client/models/appliance_system_info_all_of.rb', line 72

def self.attribute_map
  {
    :'class_id' => :'ClassId',
    :'object_type' => :'ObjectType',
    :'cloud_conn_status' => :'CloudConnStatus',
    :'deployment_size' => :'DeploymentSize',
    :'hostname' => :'Hostname',
    :'init_done' => :'InitDone',
    :'operational_status' => :'OperationalStatus',
    :'serial_id' => :'SerialId',
    :'time_zone' => :'TimeZone',
    :'version' => :'Version'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



300
301
302
# File 'lib/intersight_client/models/appliance_system_info_all_of.rb', line 300

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_nullableObject

List of attributes with nullable: true



114
115
116
117
# File 'lib/intersight_client/models/appliance_system_info_all_of.rb', line 114

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



98
99
100
101
102
103
104
105
106
107
108
109
110
111
# File 'lib/intersight_client/models/appliance_system_info_all_of.rb', line 98

def self.openapi_types
  {
    :'class_id' => :'String',
    :'object_type' => :'String',
    :'cloud_conn_status' => :'String',
    :'deployment_size' => :'String',
    :'hostname' => :'String',
    :'init_done' => :'Boolean',
    :'operational_status' => :'String',
    :'serial_id' => :'String',
    :'time_zone' => :'String',
    :'version' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



270
271
272
273
274
275
276
277
278
279
280
281
282
283
# File 'lib/intersight_client/models/appliance_system_info_all_of.rb', line 270

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      class_id == o.class_id &&
      object_type == o.object_type &&
      cloud_conn_status == o.cloud_conn_status &&
      deployment_size == o.deployment_size &&
      hostname == o.hostname &&
      init_done == o.init_done &&
      operational_status == o.operational_status &&
      serial_id == o.serial_id &&
      time_zone == o.time_zone &&
      version == o.version
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
# File 'lib/intersight_client/models/appliance_system_info_all_of.rb', line 330

def _deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = IntersightClient.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



401
402
403
404
405
406
407
408
409
410
411
412
413
# File 'lib/intersight_client/models/appliance_system_info_all_of.rb', line 401

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
# File 'lib/intersight_client/models/appliance_system_info_all_of.rb', line 307

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  ApplianceSystemInfoAllOf.openapi_types.each_pair do |key, type|
    if attributes[ApplianceSystemInfoAllOf.attribute_map[key]].nil? && ApplianceSystemInfoAllOf.openapi_nullable.include?(key)
      self.send("#{key}=", nil)
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[ApplianceSystemInfoAllOf.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[ApplianceSystemInfoAllOf.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[ApplianceSystemInfoAllOf.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[ApplianceSystemInfoAllOf.attribute_map[key]]))
    end
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


287
288
289
# File 'lib/intersight_client/models/appliance_system_info_all_of.rb', line 287

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



293
294
295
# File 'lib/intersight_client/models/appliance_system_info_all_of.rb', line 293

def hash
  [class_id, object_type, cloud_conn_status, deployment_size, hostname, init_done, operational_status, serial_id, time_zone, version].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



187
188
189
190
191
192
193
194
195
196
197
198
# File 'lib/intersight_client/models/appliance_system_info_all_of.rb', line 187

def list_invalid_properties
  invalid_properties = Array.new
  if @class_id.nil?
    invalid_properties.push('invalid value for "class_id", class_id cannot be nil.')
  end

  if @object_type.nil?
    invalid_properties.push('invalid value for "object_type", object_type cannot be nil.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



377
378
379
# File 'lib/intersight_client/models/appliance_system_info_all_of.rb', line 377

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



383
384
385
386
387
388
389
390
391
392
393
394
395
# File 'lib/intersight_client/models/appliance_system_info_all_of.rb', line 383

def to_hash
  hash = {}
  ApplianceSystemInfoAllOf.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = ApplianceSystemInfoAllOf.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



371
372
373
# File 'lib/intersight_client/models/appliance_system_info_all_of.rb', line 371

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
# File 'lib/intersight_client/models/appliance_system_info_all_of.rb', line 202

def valid?
  return false if @class_id.nil?
  class_id_validator = EnumAttributeValidator.new('String', ["appliance.SystemInfo"])
  return false unless class_id_validator.valid?(@class_id)
  return false if @object_type.nil?
  object_type_validator = EnumAttributeValidator.new('String', ["appliance.SystemInfo"])
  return false unless object_type_validator.valid?(@object_type)
  cloud_conn_status_validator = EnumAttributeValidator.new('String', ["", "Connected", "NotConnected", "ClaimInProgress", "Unclaimed", "Claimed"])
  return false unless cloud_conn_status_validator.valid?(@cloud_conn_status)
  operational_status_validator = EnumAttributeValidator.new('String', ["Unknown", "Operational", "Impaired", "AttentionNeeded"])
  return false unless operational_status_validator.valid?(@operational_status)
  time_zone_validator = EnumAttributeValidator.new('String', ["Pacific/Niue", "Pacific/Pago_Pago", "Pacific/Honolulu", "Pacific/Rarotonga", "Pacific/Tahiti", "Pacific/Marquesas", "America/Anchorage", "Pacific/Gambier", "America/Los_Angeles", "America/Tijuana", "America/Vancouver", "America/Whitehorse", "Pacific/Pitcairn", "America/Dawson_Creek", "America/Denver", "America/Edmonton", "America/Hermosillo", "America/Mazatlan", "America/Phoenix", "America/Yellowknife", "America/Belize", "America/Chicago", "America/Costa_Rica", "America/El_Salvador", "America/Guatemala", "America/Managua", "America/Mexico_City", "America/Regina", "America/Tegucigalpa", "America/Winnipeg", "Pacific/Galapagos", "America/Bogota", "America/Cancun", "America/Cayman", "America/Guayaquil", "America/Havana", "America/Iqaluit", "America/Jamaica", "America/Lima", "America/Nassau", "America/New_York", "America/Panama", "America/Port-au-Prince", "America/Rio_Branco", "America/Toronto", "Pacific/Easter", "America/Caracas", "America/Asuncion", "America/Barbados", "America/Boa_Vista", "America/Campo_Grande", "America/Cuiaba", "America/Curacao", "America/Grand_Turk", "America/Guyana", "America/Halifax", "America/La_Paz", "America/Manaus", "America/Martinique", "America/Port_of_Spain", "America/Porto_Velho", "America/Puerto_Rico", "America/Santo_Domingo", "America/Thule", "Atlantic/Bermuda", "America/St_Johns", "America/Araguaina", "America/Argentina/Buenos_Aires", "America/Bahia", "America/Belem", "America/Cayenne", "America/Fortaleza", "America/Godthab", "America/Maceio", "America/Miquelon", "America/Montevideo", "America/Paramaribo", "America/Recife", "America/Santiago", "America/Sao_Paulo", "Antarctica/Palmer", "Antarctica/Rothera", "Atlantic/Stanley", "America/Noronha", "Atlantic/South_Georgia", "America/Scoresbysund", "Atlantic/Azores", "Atlantic/Cape_Verde", "Africa/Abidjan", "Africa/Accra", "Africa/Bissau", "Africa/Casablanca", "Africa/El_Aaiun", "Africa/Monrovia", "America/Danmarkshavn", "Atlantic/Canary", "Atlantic/Faroe", "Atlantic/Reykjavik", "Etc/GMT", "Europe/Dublin", "Europe/Lisbon", "Europe/London", "Africa/Algiers", "Africa/Ceuta", "Africa/Lagos", "Africa/Ndjamena", "Africa/Tunis", "Africa/Windhoek", "Europe/Amsterdam", "Europe/Andorra", "Europe/Belgrade", "Europe/Berlin", "Europe/Brussels", "Europe/Budapest", "Europe/Copenhagen", "Europe/Gibraltar", "Europe/Luxembourg", "Europe/Madrid", "Europe/Malta", "Europe/Monaco", "Europe/Oslo", "Europe/Paris", "Europe/Prague", "Europe/Rome", "Europe/Stockholm", "Europe/Tirane", "Europe/Vienna", "Europe/Warsaw", "Europe/Zurich", "Africa/Cairo", "Africa/Johannesburg", "Africa/Maputo", "Africa/Tripoli", "Asia/Amman", "Asia/Beirut", "Asia/Damascus", "Asia/Gaza", "Asia/Jerusalem", "Asia/Nicosia", "Europe/Athens", "Europe/Bucharest", "Europe/Chisinau", "Europe/Helsinki", "Europe/Istanbul", "Europe/Kaliningrad", "Europe/Kiev", "Europe/Riga", "Europe/Sofia", "Europe/Tallinn", "Europe/Vilnius", "Africa/Khartoum", "Africa/Nairobi", "Antarctica/Syowa", "Asia/Baghdad", "Asia/Qatar", "Asia/Riyadh", "Europe/Minsk", "Europe/Moscow", "Asia/Tehran", "Asia/Baku", "Asia/Dubai", "Asia/Tbilisi", "Asia/Yerevan", "Europe/Samara", "Indian/Mahe", "Indian/Mauritius", "Indian/Reunion", "Asia/Kabul", "Antarctica/Mawson", "Asia/Aqtau", "Asia/Aqtobe", "Asia/Ashgabat", "Asia/Dushanbe", "Asia/Karachi", "Asia/Tashkent", "Asia/Yekaterinburg", "Indian/Kerguelen", "Indian/Maldives", "Asia/Calcutta", "Asia/Kolkata", "Asia/Colombo", "Asia/Katmandu", "Antarctica/Vostok", "Asia/Almaty", "Asia/Bishkek", "Asia/Dhaka", "Asia/Omsk", "Asia/Thimphu", "Indian/Chagos", "Asia/Rangoon", "Indian/Cocos", "Antarctica/Davis", "Asia/Bangkok", "Asia/Hovd", "Asia/Jakarta", "Asia/Krasnoyarsk", "Asia/Saigon", "Indian/Christmas", "Antarctica/Casey", "Asia/Brunei", "Asia/Choibalsan", "Asia/Hong_Kong", "Asia/Irkutsk", "Asia/Kuala_Lumpur", "Asia/Macau", "Asia/Makassar", "Asia/Manila", "Asia/Shanghai", "Asia/Singapore", "Asia/Taipei", "Asia/Ulaanbaatar", "Australia/Perth", "Asia/Pyongyang", "Asia/Dili", "Asia/Jayapura", "Asia/Seoul", "Asia/Tokyo", "Asia/Yakutsk", "Pacific/Palau", "Australia/Adelaide", "Australia/Darwin", "Antarctica/DumontDUrville", "Asia/Magadan", "Asia/Vladivostok", "Australia/Brisbane", "Australia/Hobart", "Australia/Sydney", "Pacific/Chuuk", "Pacific/Guam", "Pacific/Port_Moresby", "Pacific/Efate", "Pacific/Guadalcanal", "Pacific/Kosrae", "Pacific/Norfolk", "Pacific/Noumea", "Pacific/Pohnpei", "Asia/Kamchatka", "Pacific/Auckland", "Pacific/Fiji", "Pacific/Funafuti", "Pacific/Kwajalein", "Pacific/Majuro", "Pacific/Nauru", "Pacific/Tarawa", "Pacific/Wake", "Pacific/Wallis", "Pacific/Apia", "Pacific/Enderbury", "Pacific/Fakaofo", "Pacific/Tongatapu", "Pacific/Kiritimati"])
  return false unless time_zone_validator.valid?(@time_zone)
  true
end