Class: IntersightClient::AssetDeploymentDeviceAllOf

Inherits:
Object
  • Object
show all
Defined in:
lib/intersight_client/models/asset_deployment_device_all_of.rb

Overview

Definition of the list of properties defined in ‘asset.DeploymentDevice’, excluding properties defined in parent classes.

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ AssetDeploymentDeviceAllOf

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
# File 'lib/intersight_client/models/asset_deployment_device_all_of.rb', line 151

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `IntersightClient::AssetDeploymentDeviceAllOf` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `#{self.class.name}`. Please check the name to make sure it's valid. List of attributes: " + self.class.acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'class_id')
    self.class_id = attributes[:'class_id']
  else
    self.class_id = 'asset.DeploymentDevice'
  end

  if attributes.key?(:'object_type')
    self.object_type = attributes[:'object_type']
  else
    self.object_type = 'asset.DeploymentDevice'
  end

  if attributes.key?(:'alarm_info')
    self.alarm_info = attributes[:'alarm_info']
  end

  if attributes.key?(:'device_id')
    self.device_id = attributes[:'device_id']
  end

  if attributes.key?(:'device_information')
    self.device_information = attributes[:'device_information']
  end

  if attributes.key?(:'device_pid')
    self.device_pid = attributes[:'device_pid']
  end

  if attributes.key?(:'device_statistics')
    self.device_statistics = attributes[:'device_statistics']
  end

  if attributes.key?(:'product_subgroup')
    self.product_subgroup = attributes[:'product_subgroup']
  end

  if attributes.key?(:'product_type')
    self.product_type = attributes[:'product_type']
  end

  if attributes.key?(:'unit_of_measure')
    if (value = attributes[:'unit_of_measure']).is_a?(Array)
      self.unit_of_measure = value
    end
  end

  if attributes.key?(:'virtualization_platform')
    self.virtualization_platform = attributes[:'virtualization_platform']
  end

  if attributes.key?(:'workload')
    self.workload = attributes[:'workload']
  end

  if attributes.key?(:'deployment')
    self.deployment = attributes[:'deployment']
  end

  if attributes.key?(:'device_contract_information')
    self.device_contract_information = attributes[:'device_contract_information']
  end

  if attributes.key?(:'registered_device')
    self.registered_device = attributes[:'registered_device']
  end

  if attributes.key?(:'subscription')
    self.subscription = attributes[:'subscription']
  end

  if attributes.key?(:'subscription_account')
    self. = attributes[:'subscription_account']
  end
end

Instance Attribute Details

#alarm_infoObject

Returns the value of attribute alarm_info.



25
26
27
# File 'lib/intersight_client/models/asset_deployment_device_all_of.rb', line 25

def alarm_info
  @alarm_info
end

#class_idObject

The fully-qualified name of the instantiated, concrete type. This property is used as a discriminator to identify the type of the payload when marshaling and unmarshaling data.



20
21
22
# File 'lib/intersight_client/models/asset_deployment_device_all_of.rb', line 20

def class_id
  @class_id
end

#deploymentObject

Returns the value of attribute deployment.



51
52
53
# File 'lib/intersight_client/models/asset_deployment_device_all_of.rb', line 51

def deployment
  @deployment
end

#device_contract_informationObject

Returns the value of attribute device_contract_information.



53
54
55
# File 'lib/intersight_client/models/asset_deployment_device_all_of.rb', line 53

def device_contract_information
  @device_contract_information
end

#device_idObject

Unique identifier of the Cisco device.



28
29
30
# File 'lib/intersight_client/models/asset_deployment_device_all_of.rb', line 28

def device_id
  @device_id
end

#device_informationObject

Returns the value of attribute device_information.



30
31
32
# File 'lib/intersight_client/models/asset_deployment_device_all_of.rb', line 30

def device_information
  @device_information
end

#device_pidObject

Product identifier for the specified Cisco device. It is used to distinguish between HyperFlex and UCS devices.



33
34
35
# File 'lib/intersight_client/models/asset_deployment_device_all_of.rb', line 33

def device_pid
  @device_pid
end

#device_statisticsObject

Returns the value of attribute device_statistics.



35
36
37
# File 'lib/intersight_client/models/asset_deployment_device_all_of.rb', line 35

def device_statistics
  @device_statistics
end

#object_typeObject

The fully-qualified name of the instantiated, concrete type. The value should be the same as the ‘ClassId’ property.



23
24
25
# File 'lib/intersight_client/models/asset_deployment_device_all_of.rb', line 23

def object_type
  @object_type
end

#product_subgroupObject

Product Subgroup type helps to determine if device subgroup within Product type has to be billed using consumption metering. example \“N9300 Series\” in Product type \“SWITCH\”.



38
39
40
# File 'lib/intersight_client/models/asset_deployment_device_all_of.rb', line 38

def product_subgroup
  @product_subgroup
end

#product_typeObject

Product type helps to determine if device has to be billed using consumption metering. example \“SERVER\”.



41
42
43
# File 'lib/intersight_client/models/asset_deployment_device_all_of.rb', line 41

def product_type
  @product_type
end

#registered_deviceObject

Returns the value of attribute registered_device.



55
56
57
# File 'lib/intersight_client/models/asset_deployment_device_all_of.rb', line 55

def registered_device
  @registered_device
end

#subscriptionObject

Returns the value of attribute subscription.



57
58
59
# File 'lib/intersight_client/models/asset_deployment_device_all_of.rb', line 57

def subscription
  @subscription
end

#subscription_accountObject

Returns the value of attribute subscription_account.



59
60
61
# File 'lib/intersight_client/models/asset_deployment_device_all_of.rb', line 59

def 
  
end

#unit_of_measureObject

Returns the value of attribute unit_of_measure.



43
44
45
# File 'lib/intersight_client/models/asset_deployment_device_all_of.rb', line 43

def unit_of_measure
  @unit_of_measure
end

#virtualization_platformObject

Virtualization platform is used to identify the hypervisor type. example \“ESXi\”.



46
47
48
# File 'lib/intersight_client/models/asset_deployment_device_all_of.rb', line 46

def virtualization_platform
  @virtualization_platform
end

#workloadObject

Workload/Usecase running on the device.



49
50
51
# File 'lib/intersight_client/models/asset_deployment_device_all_of.rb', line 49

def workload
  @workload
end

Class Method Details

.acceptable_attribute_mapObject

Returns the key-value map of all the JSON attributes this model knows about



112
113
114
# File 'lib/intersight_client/models/asset_deployment_device_all_of.rb', line 112

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



107
108
109
# File 'lib/intersight_client/models/asset_deployment_device_all_of.rb', line 107

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
# File 'lib/intersight_client/models/asset_deployment_device_all_of.rb', line 84

def self.attribute_map
  {
    :'class_id' => :'ClassId',
    :'object_type' => :'ObjectType',
    :'alarm_info' => :'AlarmInfo',
    :'device_id' => :'DeviceId',
    :'device_information' => :'DeviceInformation',
    :'device_pid' => :'DevicePid',
    :'device_statistics' => :'DeviceStatistics',
    :'product_subgroup' => :'ProductSubgroup',
    :'product_type' => :'ProductType',
    :'unit_of_measure' => :'UnitOfMeasure',
    :'virtualization_platform' => :'VirtualizationPlatform',
    :'workload' => :'Workload',
    :'deployment' => :'Deployment',
    :'device_contract_information' => :'DeviceContractInformation',
    :'registered_device' => :'RegisteredDevice',
    :'subscription' => :'Subscription',
    :'subscription_account' => :'SubscriptionAccount'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



325
326
327
# File 'lib/intersight_client/models/asset_deployment_device_all_of.rb', line 325

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_nullableObject

List of attributes with nullable: true



140
141
142
143
144
145
146
147
# File 'lib/intersight_client/models/asset_deployment_device_all_of.rb', line 140

def self.openapi_nullable
  Set.new([
    :'alarm_info',
    :'device_information',
    :'device_statistics',
    :'unit_of_measure',
  ])
end

.openapi_typesObject

Attribute type mapping.



117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
# File 'lib/intersight_client/models/asset_deployment_device_all_of.rb', line 117

def self.openapi_types
  {
    :'class_id' => :'String',
    :'object_type' => :'String',
    :'alarm_info' => :'AssetDeploymentDeviceAlarmInfo',
    :'device_id' => :'String',
    :'device_information' => :'AssetDeploymentDeviceInformation',
    :'device_pid' => :'String',
    :'device_statistics' => :'AssetDeviceStatistics',
    :'product_subgroup' => :'String',
    :'product_type' => :'String',
    :'unit_of_measure' => :'Array<AssetMeteringType>',
    :'virtualization_platform' => :'String',
    :'workload' => :'String',
    :'deployment' => :'AssetDeploymentRelationship',
    :'device_contract_information' => :'AssetDeviceContractInformationRelationship',
    :'registered_device' => :'AssetDeviceRegistrationRelationship',
    :'subscription' => :'AssetSubscriptionRelationship',
    :'subscription_account' => :'AssetSubscriptionAccountRelationship'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
# File 'lib/intersight_client/models/asset_deployment_device_all_of.rb', line 288

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      class_id == o.class_id &&
      object_type == o.object_type &&
      alarm_info == o.alarm_info &&
      device_id == o.device_id &&
      device_information == o.device_information &&
      device_pid == o.device_pid &&
      device_statistics == o.device_statistics &&
      product_subgroup == o.product_subgroup &&
      product_type == o.product_type &&
      unit_of_measure == o.unit_of_measure &&
      virtualization_platform == o.virtualization_platform &&
      workload == o.workload &&
      deployment == o.deployment &&
      device_contract_information == o.device_contract_information &&
      registered_device == o.registered_device &&
      subscription == o.subscription &&
       == o.
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
# File 'lib/intersight_client/models/asset_deployment_device_all_of.rb', line 355

def _deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = IntersightClient.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



426
427
428
429
430
431
432
433
434
435
436
437
438
# File 'lib/intersight_client/models/asset_deployment_device_all_of.rb', line 426

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
# File 'lib/intersight_client/models/asset_deployment_device_all_of.rb', line 332

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  AssetDeploymentDeviceAllOf.openapi_types.each_pair do |key, type|
    if attributes[AssetDeploymentDeviceAllOf.attribute_map[key]].nil? && AssetDeploymentDeviceAllOf.openapi_nullable.include?(key)
      self.send("#{key}=", nil)
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[AssetDeploymentDeviceAllOf.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[AssetDeploymentDeviceAllOf.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[AssetDeploymentDeviceAllOf.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[AssetDeploymentDeviceAllOf.attribute_map[key]]))
    end
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


312
313
314
# File 'lib/intersight_client/models/asset_deployment_device_all_of.rb', line 312

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



318
319
320
# File 'lib/intersight_client/models/asset_deployment_device_all_of.rb', line 318

def hash
  [class_id, object_type, alarm_info, device_id, device_information, device_pid, device_statistics, product_subgroup, product_type, unit_of_measure, virtualization_platform, workload, deployment, device_contract_information, registered_device, subscription, ].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



241
242
243
244
245
246
247
248
249
250
251
252
# File 'lib/intersight_client/models/asset_deployment_device_all_of.rb', line 241

def list_invalid_properties
  invalid_properties = Array.new
  if @class_id.nil?
    invalid_properties.push('invalid value for "class_id", class_id cannot be nil.')
  end

  if @object_type.nil?
    invalid_properties.push('invalid value for "object_type", object_type cannot be nil.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



402
403
404
# File 'lib/intersight_client/models/asset_deployment_device_all_of.rb', line 402

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



408
409
410
411
412
413
414
415
416
417
418
419
420
# File 'lib/intersight_client/models/asset_deployment_device_all_of.rb', line 408

def to_hash
  hash = {}
  AssetDeploymentDeviceAllOf.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = AssetDeploymentDeviceAllOf.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



396
397
398
# File 'lib/intersight_client/models/asset_deployment_device_all_of.rb', line 396

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



256
257
258
259
260
261
262
263
264
# File 'lib/intersight_client/models/asset_deployment_device_all_of.rb', line 256

def valid?
  return false if @class_id.nil?
  class_id_validator = EnumAttributeValidator.new('String', ["asset.DeploymentDevice"])
  return false unless class_id_validator.valid?(@class_id)
  return false if @object_type.nil?
  object_type_validator = EnumAttributeValidator.new('String', ["asset.DeploymentDevice"])
  return false unless object_type_validator.valid?(@object_type)
  true
end