Class: IntersightClient::AssetTargetAllOf

Inherits:
Object
  • Object
show all
Defined in:
lib/intersight_client/models/asset_target_all_of.rb

Overview

Definition of the list of properties defined in ‘asset.Target’, excluding properties defined in parent classes.

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ AssetTargetAllOf

Initializes the object

Parameters:

  • (defaults to: {})

    Model attributes in the form of hash



163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
# File 'lib/intersight_client/models/asset_target_all_of.rb', line 163

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `IntersightClient::AssetTargetAllOf` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `#{self.class.name}`. Please check the name to make sure it's valid. List of attributes: " + self.class.acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'class_id')
    self.class_id = attributes[:'class_id']
  else
    self.class_id = 'asset.Target'
  end

  if attributes.key?(:'object_type')
    self.object_type = attributes[:'object_type']
  else
    self.object_type = 'asset.Target'
  end

  if attributes.key?(:'claimed_by_user_name')
    self.claimed_by_user_name = attributes[:'claimed_by_user_name']
  end

  if attributes.key?(:'connections')
    if (value = attributes[:'connections']).is_a?(Array)
      self.connections = value
    end
  end

  if attributes.key?(:'connector_version')
    self.connector_version = attributes[:'connector_version']
  end

  if attributes.key?(:'external_ip_address')
    self.external_ip_address = attributes[:'external_ip_address']
  end

  if attributes.key?(:'ip_address')
    if (value = attributes[:'ip_address']).is_a?(Array)
      self.ip_address = value
    end
  end

  if attributes.key?(:'management_location')
    self.management_location = attributes[:'management_location']
  else
    self.management_location = 'Unknown'
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  end

  if attributes.key?(:'product_id')
    if (value = attributes[:'product_id']).is_a?(Array)
      self.product_id = value
    end
  end

  if attributes.key?(:'read_only')
    self.read_only = attributes[:'read_only']
  end

  if attributes.key?(:'services')
    if (value = attributes[:'services']).is_a?(Array)
      self.services = value
    end
  end

  if attributes.key?(:'status')
    self.status = attributes[:'status']
  else
    self.status = ''
  end

  if attributes.key?(:'status_error_reason')
    self.status_error_reason = attributes[:'status_error_reason']
  end

  if attributes.key?(:'target_id')
    if (value = attributes[:'target_id']).is_a?(Array)
      self.target_id = value
    end
  end

  if attributes.key?(:'target_type')
    self.target_type = attributes[:'target_type']
  else
    self.target_type = ''
  end

  if attributes.key?(:'account')
    self. = attributes[:'account']
  end

  if attributes.key?(:'assist')
    self.assist = attributes[:'assist']
  end

  if attributes.key?(:'registered_device')
    self.registered_device = attributes[:'registered_device']
  end
end

Instance Attribute Details

#accountObject

Returns the value of attribute account.



62
63
64
# File 'lib/intersight_client/models/asset_target_all_of.rb', line 62

def 
  @account
end

#assistObject

Returns the value of attribute assist.



64
65
66
# File 'lib/intersight_client/models/asset_target_all_of.rb', line 64

def assist
  @assist
end

#claimed_by_user_nameObject

The name or email id of the user who claimed the target.



26
27
28
# File 'lib/intersight_client/models/asset_target_all_of.rb', line 26

def claimed_by_user_name
  @claimed_by_user_name
end

#class_idObject

The fully-qualified name of the instantiated, concrete type. This property is used as a discriminator to identify the type of the payload when marshaling and unmarshaling data.



20
21
22
# File 'lib/intersight_client/models/asset_target_all_of.rb', line 20

def class_id
  @class_id
end

#connectionsObject

Returns the value of attribute connections.



28
29
30
# File 'lib/intersight_client/models/asset_target_all_of.rb', line 28

def connections
  @connections
end

#connector_versionObject

The Device Connector version for target types which are managed by via embedded Device Connector.



31
32
33
# File 'lib/intersight_client/models/asset_target_all_of.rb', line 31

def connector_version
  @connector_version
end

#external_ip_addressObject

ExternalIpAddress is applicable for targets which are managed via an Intersight Device Connector. The value is the IP Address of the target as seen from Intersight. It is either the IP Address of the managed target’s interface which has a route to the internet or a NAT IP Addresss when the target is deployed in a private network.



34
35
36
# File 'lib/intersight_client/models/asset_target_all_of.rb', line 34

def external_ip_address
  @external_ip_address
end

#ip_addressObject

Returns the value of attribute ip_address.



36
37
38
# File 'lib/intersight_client/models/asset_target_all_of.rb', line 36

def ip_address
  @ip_address
end

#management_locationObject

The location from which Intersight manages the target. * Unknown - The management mechanism is not detected. Unknown is used as a default by the implementation and is not an allowed user input. * Intersight - Management of a target is performed directly from Intersight. Network connections are established from Intersight to a management interface of the Target and authenticated using user provided credentials. * IntersightAssist - Management of a target is performed via a selected Intersight Assist. Network connections are established from the Intersight Assist to a management interface of the Target. * DeviceConnector - An Intersight Device Connector running within the Target establishes a connection to Intersight and management of the target is performed via this connection.



39
40
41
# File 'lib/intersight_client/models/asset_target_all_of.rb', line 39

def management_location
  @management_location
end

#nameObject

A user provided name for the managed target.



42
43
44
# File 'lib/intersight_client/models/asset_target_all_of.rb', line 42

def name
  @name
end

#object_typeObject

The fully-qualified name of the instantiated, concrete type. The value should be the same as the ‘ClassId’ property.



23
24
25
# File 'lib/intersight_client/models/asset_target_all_of.rb', line 23

def object_type
  @object_type
end

#product_idObject

Returns the value of attribute product_id.



44
45
46
# File 'lib/intersight_client/models/asset_target_all_of.rb', line 44

def product_id
  @product_id
end

#read_onlyObject

For targets which are managed by an embedded Intersight Device Connector, this field indicates that an administrator of the target has disabled management operations of the Device Connector and only monitoring is permitted.



47
48
49
# File 'lib/intersight_client/models/asset_target_all_of.rb', line 47

def read_only
  @read_only
end

#registered_deviceObject

Returns the value of attribute registered_device.



66
67
68
# File 'lib/intersight_client/models/asset_target_all_of.rb', line 66

def registered_device
  @registered_device
end

#servicesObject

Returns the value of attribute services.



49
50
51
# File 'lib/intersight_client/models/asset_target_all_of.rb', line 49

def services
  @services
end

#statusObject

Status indicates if Intersight can establish a connection and authenticate with the managed target. Status does not include information about the functional health of the target. * “ - The target details have been persisted but Intersight has not yet attempted to connect to the target. * Connected - Intersight is able to establish a connection to the target and initiate management activities. * NotConnected - Intersight is unable to establish a connection to the target. * ClaimInProgress - Claim of the target is in progress. A connection to the target has not been fully established. * Unclaimed - The device was un-claimed from the users account by an Administrator of the device. Also indicates the failure to claim Targets of type HTTP Endpoint in Intersight. * Claimed - Target of type HTTP Endpoint is successfully claimed in Intersight. Currently no validation is performed to verify the Target connectivity from Intersight at the time of creation. However invoking API from Intersight Orchestrator fails if this Target is not reachable from Intersight or if Target API credentials are incorrect.



52
53
54
# File 'lib/intersight_client/models/asset_target_all_of.rb', line 52

def status
  @status
end

#status_error_reasonObject

StatusErrorReason provides additional context for the Status.



55
56
57
# File 'lib/intersight_client/models/asset_target_all_of.rb', line 55

def status_error_reason
  @status_error_reason
end

#target_idObject

Returns the value of attribute target_id.



57
58
59
# File 'lib/intersight_client/models/asset_target_all_of.rb', line 57

def target_id
  @target_id
end

#target_typeObject

The type of the managed target. For example a UCS Server or VMware Vcenter target. * “ - The device reported an empty or unrecognized platform type. * APIC - An Application Policy Infrastructure Controller cluster. * DCNM - A Data Center Network Manager instance. Data Center Network Manager (DCNM) is the network management platform for all NX-OS-enabled deployments, spanning new fabric architectures, IP Fabric for Media, and storage networking deployments for the Cisco Nexus-powered data center. * UCSFI - A UCS Fabric Interconnect in HA or standalone mode, which is being managed by UCS Manager (UCSM). * UCSFIISM - A UCS Fabric Interconnect in HA or standalone mode, managed directly by Intersight. * IMC - A standalone UCS Server Integrated Management Controller. * IMCM4 - A standalone UCS M4 Server. * IMCM5 - A standalone UCS M5 server. * IMCRack - A standalone UCS M6 and above server. * UCSIOM - An UCS Chassis IO module. * HX - A HyperFlex storage controller. * HyperFlexAP - A HyperFlex Application Platform. * IWE - An Intersight Workload Engine. * UCSD - A UCS Director virtual appliance. Cisco UCS Director automates, orchestrates, and manages Cisco and third-party hardware. * IntersightAppliance - A Cisco Intersight Connected Virtual Appliance. * IntersightAssist - A Cisco Intersight Assist. * PureStorageFlashArray - A Pure Storage FlashArray device. * UCSC890 - A standalone Cisco UCSC890 server. * NetAppOntap - A NetApp ONTAP storage system. * NetAppActiveIqUnifiedManager - A NetApp Active IQ Unified Manager. * EmcScaleIo - An EMC ScaleIO storage system. * EmcVmax - An EMC VMAX storage system. * EmcVplex - An EMC VPLEX storage system. * EmcXtremIo - An EMC XtremIO storage system. * VmwareVcenter - A VMware vCenter device that manages Virtual Machines. * MicrosoftHyperV - A Microsoft Hyper-V system that manages Virtual Machines. * AppDynamics - An AppDynamics controller that monitors applications. * Dynatrace - A software-intelligence monitoring platform that simplifies enterprise cloud complexity and accelerates digital transformation. * NewRelic - A software-intelligence monitoring platform that simplifies enterprise cloud complexity and accelerates digital transformation. * ServiceNow - A cloud-based workflow automation platform that enables enterprise organizations to improve operational efficiencies by streamlining and automating routine work tasks. * ReadHatOpenStack - An OpenStack target manages Virtual Machines, Physical Machines, Datacenters and Virtual Datacenters using different OpenStack services as administrative endpoints. * CloudFoundry - An open source cloud platform on which developers can build, deploy, run and scale applications. * MicrosoftAzureApplicationInsights - A feature of Azure Monitor, is an extensible Application Performance Management service for developers and DevOps professionals to monitor their live applications. * OpenStack - An OpenStack target manages Virtual Machines, Physical Machines, Datacenters and Virtual Datacenters using different OpenStack services as administrative endpoints. * MicrosoftSqlServer - A Microsoft SQL database server. * Kubernetes - A Kubernetes cluster that runs containerized applications. * AmazonWebService - A Amazon web service target that discovers and monitors different services like EC2. It discovers entities like VMs, Volumes, regions etc. and monitors attributes like Mem, CPU, cost. * AmazonWebServiceBilling - A Amazon web service billing target to retrieve billing information stored in S3 bucket. * MicrosoftAzureServicePrincipal - A Microsoft Azure Service Principal target that discovers all the associated Azure subscriptions. * MicrosoftAzureEnterpriseAgreement - A Microsoft Azure Enterprise Agreement target that discovers cost, billing and RIs. * DellCompellent - A Dell Compellent storage system. * HPE3Par - A HPE 3PAR storage system. * RedHatEnterpriseVirtualization - A Red Hat Enterprise Virtualization Hypervisor system that manages Virtual Machines. * NutanixAcropolis - A Nutanix Acropolis system that combines servers and storage into a distributed infrastructure platform. * HPEOneView - A HPE Oneview management system that manages compute, storage, and networking. * ServiceEngine - Cisco Application Services Engine. Cisco Application Services Engine is a platform to deploy and manage applications. * HitachiVirtualStoragePlatform - A Hitachi Virtual Storage Platform also referred to as Hitachi VSP. It includes various storage systems designed for data centers. * IMCBlade - An Intersight managed UCS Blade Server. * TerraformCloud - A Terraform Cloud account. * TerraformAgent - A Terraform Cloud Agent that Intersight will deploy in datacenter. The agent will execute Terraform plan for Terraform Cloud workspace configured to use the agent. * CustomTarget - An external endpoint added as Target that can be accessed through its HTTP API interface in Intersight Orchestrator automation workflow.Standard HTTP authentication scheme supported: Basic. * AnsibleEndpoint - An external endpoint added as Target that can be accessed through Ansible in Intersight Cloud Orchestrator automation workflow. * HTTPEndpoint - An external endpoint added as Target that can be accessed through its HTTP API interface in Intersight Orchestrator automation workflow.Standard HTTP authentication scheme supported: Basic, Bearer Token. * SSHEndpoint - An external endpoint added as Target that can be accessed through SSH in Intersight Cloud Orchestrator automation workflow. * CiscoCatalyst - A Cisco Catalyst networking switch device.



60
61
62
# File 'lib/intersight_client/models/asset_target_all_of.rb', line 60

def target_type
  @target_type
end

Class Method Details

.acceptable_attribute_mapObject

Returns the key-value map of all the JSON attributes this model knows about



121
122
123
# File 'lib/intersight_client/models/asset_target_all_of.rb', line 121

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



116
117
118
# File 'lib/intersight_client/models/asset_target_all_of.rb', line 116

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
# File 'lib/intersight_client/models/asset_target_all_of.rb', line 91

def self.attribute_map
  {
    :'class_id' => :'ClassId',
    :'object_type' => :'ObjectType',
    :'claimed_by_user_name' => :'ClaimedByUserName',
    :'connections' => :'Connections',
    :'connector_version' => :'ConnectorVersion',
    :'external_ip_address' => :'ExternalIpAddress',
    :'ip_address' => :'IpAddress',
    :'management_location' => :'ManagementLocation',
    :'name' => :'Name',
    :'product_id' => :'ProductId',
    :'read_only' => :'ReadOnly',
    :'services' => :'Services',
    :'status' => :'Status',
    :'status_error_reason' => :'StatusErrorReason',
    :'target_id' => :'TargetId',
    :'target_type' => :'TargetType',
    :'account' => :'Account',
    :'assist' => :'Assist',
    :'registered_device' => :'RegisteredDevice'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • Model attributes in the form of hash

Returns:

  • Returns the model itself



421
422
423
# File 'lib/intersight_client/models/asset_target_all_of.rb', line 421

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_nullableObject

List of attributes with nullable: true



151
152
153
154
155
156
157
158
159
# File 'lib/intersight_client/models/asset_target_all_of.rb', line 151

def self.openapi_nullable
  Set.new([
    :'connections',
    :'ip_address',
    :'product_id',
    :'services',
    :'target_id',
  ])
end

.openapi_typesObject

Attribute type mapping.



126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
# File 'lib/intersight_client/models/asset_target_all_of.rb', line 126

def self.openapi_types
  {
    :'class_id' => :'String',
    :'object_type' => :'String',
    :'claimed_by_user_name' => :'String',
    :'connections' => :'Array<AssetConnection>',
    :'connector_version' => :'String',
    :'external_ip_address' => :'String',
    :'ip_address' => :'Array<String>',
    :'management_location' => :'String',
    :'name' => :'String',
    :'product_id' => :'Array<String>',
    :'read_only' => :'Boolean',
    :'services' => :'Array<AssetService>',
    :'status' => :'String',
    :'status_error_reason' => :'String',
    :'target_id' => :'Array<String>',
    :'target_type' => :'String',
    :'account' => :'IamAccountRelationship',
    :'assist' => :'AssetTargetRelationship',
    :'registered_device' => :'AssetDeviceRegistrationRelationship'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • to be compared



382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
# File 'lib/intersight_client/models/asset_target_all_of.rb', line 382

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      class_id == o.class_id &&
      object_type == o.object_type &&
      claimed_by_user_name == o.claimed_by_user_name &&
      connections == o.connections &&
      connector_version == o.connector_version &&
      external_ip_address == o.external_ip_address &&
      ip_address == o.ip_address &&
      management_location == o.management_location &&
      name == o.name &&
      product_id == o.product_id &&
      read_only == o.read_only &&
      services == o.services &&
      status == o.status &&
      status_error_reason == o.status_error_reason &&
      target_id == o.target_id &&
      target_type == o.target_type &&
       == o. &&
      assist == o.assist &&
      registered_device == o.registered_device
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • type Data type

  • value Value to be deserialized

Returns:

  • Deserialized data



451
452
453
454
455
456
457
458
459
460
461
462
463
464
465
466
467
468
469
470
471
472
473
474
475
476
477
478
479
480
481
482
483
484
485
486
487
488
# File 'lib/intersight_client/models/asset_target_all_of.rb', line 451

def _deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = IntersightClient.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • Any valid value

Returns:

  • Returns the value in the form of hash



522
523
524
525
526
527
528
529
530
531
532
533
534
# File 'lib/intersight_client/models/asset_target_all_of.rb', line 522

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • Model attributes in the form of hash

Returns:

  • Returns the model itself



428
429
430
431
432
433
434
435
436
437
438
439
440
441
442
443
444
445
# File 'lib/intersight_client/models/asset_target_all_of.rb', line 428

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  AssetTargetAllOf.openapi_types.each_pair do |key, type|
    if attributes[AssetTargetAllOf.attribute_map[key]].nil? && AssetTargetAllOf.openapi_nullable.include?(key)
      self.send("#{key}=", nil)
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[AssetTargetAllOf.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[AssetTargetAllOf.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[AssetTargetAllOf.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[AssetTargetAllOf.attribute_map[key]]))
    end
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • to be compared

Returns:

See Also:

  • `==` method


408
409
410
# File 'lib/intersight_client/models/asset_target_all_of.rb', line 408

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • Hash code



414
415
416
# File 'lib/intersight_client/models/asset_target_all_of.rb', line 414

def hash
  [class_id, object_type, claimed_by_user_name, connections, connector_version, external_ip_address, ip_address, management_location, name, product_id, read_only, services, status, status_error_reason, target_id, target_type, , assist, registered_device].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
# File 'lib/intersight_client/models/asset_target_all_of.rb', line 275

def list_invalid_properties
  invalid_properties = Array.new
  if @class_id.nil?
    invalid_properties.push('invalid value for "class_id", class_id cannot be nil.')
  end

  if @object_type.nil?
    invalid_properties.push('invalid value for "object_type", object_type cannot be nil.')
  end

  if !@connections.nil? && @connections.length > 1
    invalid_properties.push('invalid value for "connections", number of items must be less than or equal to 1.')
  end

  if !@connections.nil? && @connections.length < 1
    invalid_properties.push('invalid value for "connections", number of items must be greater than or equal to 1.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • Returns the object in the form of hash



498
499
500
# File 'lib/intersight_client/models/asset_target_all_of.rb', line 498

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • Returns the object in the form of hash



504
505
506
507
508
509
510
511
512
513
514
515
516
# File 'lib/intersight_client/models/asset_target_all_of.rb', line 504

def to_hash
  hash = {}
  AssetTargetAllOf.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = AssetTargetAllOf.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • String presentation of the object



492
493
494
# File 'lib/intersight_client/models/asset_target_all_of.rb', line 492

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • true if the model is valid



298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
# File 'lib/intersight_client/models/asset_target_all_of.rb', line 298

def valid?
  return false if @class_id.nil?
  class_id_validator = EnumAttributeValidator.new('String', ["asset.Target"])
  return false unless class_id_validator.valid?(@class_id)
  return false if @object_type.nil?
  object_type_validator = EnumAttributeValidator.new('String', ["asset.Target"])
  return false unless object_type_validator.valid?(@object_type)
  return false if !@connections.nil? && @connections.length > 1
  return false if !@connections.nil? && @connections.length < 1
  management_location_validator = EnumAttributeValidator.new('String', ["Unknown", "Intersight", "IntersightAssist", "DeviceConnector"])
  return false unless management_location_validator.valid?(@management_location)
  status_validator = EnumAttributeValidator.new('String', ["", "Connected", "NotConnected", "ClaimInProgress", "Unclaimed", "Claimed"])
  return false unless status_validator.valid?(@status)
  target_type_validator = EnumAttributeValidator.new('String', ["", "APIC", "DCNM", "UCSFI", "UCSFIISM", "IMC", "IMCM4", "IMCM5", "IMCRack", "UCSIOM", "HX", "HyperFlexAP", "IWE", "UCSD", "IntersightAppliance", "IntersightAssist", "PureStorageFlashArray", "UCSC890", "NetAppOntap", "NetAppActiveIqUnifiedManager", "EmcScaleIo", "EmcVmax", "EmcVplex", "EmcXtremIo", "VmwareVcenter", "MicrosoftHyperV", "AppDynamics", "Dynatrace", "NewRelic", "ServiceNow", "ReadHatOpenStack", "CloudFoundry", "MicrosoftAzureApplicationInsights", "OpenStack", "MicrosoftSqlServer", "Kubernetes", "AmazonWebService", "AmazonWebServiceBilling", "MicrosoftAzureServicePrincipal", "MicrosoftAzureEnterpriseAgreement", "DellCompellent", "HPE3Par", "RedHatEnterpriseVirtualization", "NutanixAcropolis", "HPEOneView", "ServiceEngine", "HitachiVirtualStoragePlatform", "IMCBlade", "TerraformCloud", "TerraformAgent", "CustomTarget", "AnsibleEndpoint", "HTTPEndpoint", "SSHEndpoint", "CiscoCatalyst"])
  return false unless target_type_validator.valid?(@target_type)
  true
end