Class: IntersightClient::BulkExportAllOf

Inherits:
Object
  • Object
show all
Defined in:
lib/intersight_client/models/bulk_export_all_of.rb

Overview

Definition of the list of properties defined in ‘bulk.Export’, excluding properties defined in parent classes.

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ BulkExportAllOf

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
# File 'lib/intersight_client/models/bulk_export_all_of.rb', line 132

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `IntersightClient::BulkExportAllOf` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `#{self.class.name}`. Please check the name to make sure it's valid. List of attributes: " + self.class.acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'class_id')
    self.class_id = attributes[:'class_id']
  else
    self.class_id = 'bulk.Export'
  end

  if attributes.key?(:'object_type')
    self.object_type = attributes[:'object_type']
  else
    self.object_type = 'bulk.Export'
  end

  if attributes.key?(:'action')
    self.action = attributes[:'action']
  else
    self.action = 'Start'
  end

  if attributes.key?(:'export_tags')
    self.export_tags = attributes[:'export_tags']
  else
    self.export_tags = true
  end

  if attributes.key?(:'exported_objects')
    if (value = attributes[:'exported_objects']).is_a?(Array)
      self.exported_objects = value
    end
  end

  if attributes.key?(:'import_order')
    self.import_order = attributes[:'import_order']
  end

  if attributes.key?(:'items')
    if (value = attributes[:'items']).is_a?(Array)
      self.items = value
    end
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  end

  if attributes.key?(:'status')
    self.status = attributes[:'status']
  else
    self.status = ''
  end

  if attributes.key?(:'status_message')
    self.status_message = attributes[:'status_message']
  end

  if attributes.key?(:'exported_items')
    if (value = attributes[:'exported_items']).is_a?(Array)
      self.exported_items = value
    end
  end

  if attributes.key?(:'organization')
    self.organization = attributes[:'organization']
  end
end

Instance Attribute Details

#actionObject

Action to be performed on the export operation. * Start - Starts the export operation. * Cancel - Cancels the export operation that is in progress.



26
27
28
# File 'lib/intersight_client/models/bulk_export_all_of.rb', line 26

def action
  @action
end

#class_idObject

The fully-qualified name of the instantiated, concrete type. This property is used as a discriminator to identify the type of the payload when marshaling and unmarshaling data.



20
21
22
# File 'lib/intersight_client/models/bulk_export_all_of.rb', line 20

def class_id
  @class_id
end

#export_tagsObject

Specifies whether tags must be exported and will be considered for all the items MOs.



29
30
31
# File 'lib/intersight_client/models/bulk_export_all_of.rb', line 29

def export_tags
  @export_tags
end

#exported_itemsObject

An array of relationships to bulkExportedItem resources.



48
49
50
# File 'lib/intersight_client/models/bulk_export_all_of.rb', line 48

def exported_items
  @exported_items
end

#exported_objectsObject

Returns the value of attribute exported_objects.



31
32
33
# File 'lib/intersight_client/models/bulk_export_all_of.rb', line 31

def exported_objects
  @exported_objects
end

#import_orderObject

Contains the list of import order.



34
35
36
# File 'lib/intersight_client/models/bulk_export_all_of.rb', line 34

def import_order
  @import_order
end

#itemsObject

Returns the value of attribute items.



36
37
38
# File 'lib/intersight_client/models/bulk_export_all_of.rb', line 36

def items
  @items
end

#nameObject

An identifier for the export instance. Name can only contain letters (a-z, A-Z), numbers (0-9), hyphen (-) or an underscore (_).



39
40
41
# File 'lib/intersight_client/models/bulk_export_all_of.rb', line 39

def name
  @name
end

#object_typeObject

The fully-qualified name of the instantiated, concrete type. The value should be the same as the ‘ClassId’ property.



23
24
25
# File 'lib/intersight_client/models/bulk_export_all_of.rb', line 23

def object_type
  @object_type
end

#organizationObject

Returns the value of attribute organization.



50
51
52
# File 'lib/intersight_client/models/bulk_export_all_of.rb', line 50

def organization
  @organization
end

#statusObject

Status of the export operation. * “ - The operation has not started. * InProgress - The operation is in progress. * OrderInProgress - The archive operation is in progress. * Success - The operation has succeeded. * Failed - The operation has failed. * OperationTimedOut - The operation has timed out. * OperationCancelled - The operation has been cancelled. * CancelInProgress - The operation is being cancelled.



42
43
44
# File 'lib/intersight_client/models/bulk_export_all_of.rb', line 42

def status
  @status
end

#status_messageObject

Status message associated with failures or progress indication.



45
46
47
# File 'lib/intersight_client/models/bulk_export_all_of.rb', line 45

def status_message
  @status_message
end

Class Method Details

.acceptable_attribute_mapObject

Returns the key-value map of all the JSON attributes this model knows about



98
99
100
# File 'lib/intersight_client/models/bulk_export_all_of.rb', line 98

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



93
94
95
# File 'lib/intersight_client/models/bulk_export_all_of.rb', line 93

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
# File 'lib/intersight_client/models/bulk_export_all_of.rb', line 75

def self.attribute_map
  {
    :'class_id' => :'ClassId',
    :'object_type' => :'ObjectType',
    :'action' => :'Action',
    :'export_tags' => :'ExportTags',
    :'exported_objects' => :'ExportedObjects',
    :'import_order' => :'ImportOrder',
    :'items' => :'Items',
    :'name' => :'Name',
    :'status' => :'Status',
    :'status_message' => :'StatusMessage',
    :'exported_items' => :'ExportedItems',
    :'organization' => :'Organization'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



332
333
334
# File 'lib/intersight_client/models/bulk_export_all_of.rb', line 332

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_nullableObject

List of attributes with nullable: true



121
122
123
124
125
126
127
128
# File 'lib/intersight_client/models/bulk_export_all_of.rb', line 121

def self.openapi_nullable
  Set.new([
    :'exported_objects',
    :'import_order',
    :'items',
    :'exported_items',
  ])
end

.openapi_typesObject

Attribute type mapping.



103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
# File 'lib/intersight_client/models/bulk_export_all_of.rb', line 103

def self.openapi_types
  {
    :'class_id' => :'String',
    :'object_type' => :'String',
    :'action' => :'String',
    :'export_tags' => :'Boolean',
    :'exported_objects' => :'Array<BulkSubRequest>',
    :'import_order' => :'Object',
    :'items' => :'Array<MoMoRef>',
    :'name' => :'String',
    :'status' => :'String',
    :'status_message' => :'String',
    :'exported_items' => :'Array<BulkExportedItemRelationship>',
    :'organization' => :'OrganizationOrganizationRelationship'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
# File 'lib/intersight_client/models/bulk_export_all_of.rb', line 300

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      class_id == o.class_id &&
      object_type == o.object_type &&
      action == o.action &&
      export_tags == o.export_tags &&
      exported_objects == o.exported_objects &&
      import_order == o.import_order &&
      items == o.items &&
      name == o.name &&
      status == o.status &&
      status_message == o.status_message &&
      exported_items == o.exported_items &&
      organization == o.organization
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
# File 'lib/intersight_client/models/bulk_export_all_of.rb', line 362

def _deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = IntersightClient.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



433
434
435
436
437
438
439
440
441
442
443
444
445
# File 'lib/intersight_client/models/bulk_export_all_of.rb', line 433

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
# File 'lib/intersight_client/models/bulk_export_all_of.rb', line 339

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  BulkExportAllOf.openapi_types.each_pair do |key, type|
    if attributes[BulkExportAllOf.attribute_map[key]].nil? && BulkExportAllOf.openapi_nullable.include?(key)
      self.send("#{key}=", nil)
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[BulkExportAllOf.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[BulkExportAllOf.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[BulkExportAllOf.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[BulkExportAllOf.attribute_map[key]]))
    end
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


319
320
321
# File 'lib/intersight_client/models/bulk_export_all_of.rb', line 319

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



325
326
327
# File 'lib/intersight_client/models/bulk_export_all_of.rb', line 325

def hash
  [class_id, object_type, action, export_tags, exported_objects, import_order, items, name, status, status_message, exported_items, organization].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
# File 'lib/intersight_client/models/bulk_export_all_of.rb', line 212

def list_invalid_properties
  invalid_properties = Array.new
  if @class_id.nil?
    invalid_properties.push('invalid value for "class_id", class_id cannot be nil.')
  end

  if @object_type.nil?
    invalid_properties.push('invalid value for "object_type", object_type cannot be nil.')
  end

  pattern = Regexp.new(/^[a-zA-Z0-9][a-zA-Z0-9_-]{1,92}$/)
  if !@name.nil? && @name !~ pattern
    invalid_properties.push("invalid value for \"name\", must conform to the pattern #{pattern}.")
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



409
410
411
# File 'lib/intersight_client/models/bulk_export_all_of.rb', line 409

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



415
416
417
418
419
420
421
422
423
424
425
426
427
# File 'lib/intersight_client/models/bulk_export_all_of.rb', line 415

def to_hash
  hash = {}
  BulkExportAllOf.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = BulkExportAllOf.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



403
404
405
# File 'lib/intersight_client/models/bulk_export_all_of.rb', line 403

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



232
233
234
235
236
237
238
239
240
241
242
243
244
245
# File 'lib/intersight_client/models/bulk_export_all_of.rb', line 232

def valid?
  return false if @class_id.nil?
  class_id_validator = EnumAttributeValidator.new('String', ["bulk.Export"])
  return false unless class_id_validator.valid?(@class_id)
  return false if @object_type.nil?
  object_type_validator = EnumAttributeValidator.new('String', ["bulk.Export"])
  return false unless object_type_validator.valid?(@object_type)
  action_validator = EnumAttributeValidator.new('String', ["Start", "Cancel"])
  return false unless action_validator.valid?(@action)
  return false if !@name.nil? && @name !~ Regexp.new(/^[a-zA-Z0-9][a-zA-Z0-9_-]{1,92}$/)
  status_validator = EnumAttributeValidator.new('String', ["", "InProgress", "OrderInProgress", "Success", "Failed", "OperationTimedOut", "OperationCancelled", "CancelInProgress"])
  return false unless status_validator.valid?(@status)
  true
end