Class: IntersightClient::CloudRegionsAllOf

Inherits:
Object
  • Object
show all
Defined in:
lib/intersight_client/models/cloud_regions_all_of.rb

Overview

Definition of the list of properties defined in 'cloud.Regions', excluding properties defined in parent classes.

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ CloudRegionsAllOf

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {}) —

    Model attributes in the form of hash



135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
# File 'lib/intersight_client/models/cloud_regions_all_of.rb', line 135

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `IntersightClient::CloudRegionsAllOf` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `#{self.class.name}`. Please check the name to make sure it's valid. List of attributes: " + self.class.acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'class_id')
    self.class_id = attributes[:'class_id']
  else
    self.class_id = 'cloud.Regions'
  end

  if attributes.key?(:'object_type')
    self.object_type = attributes[:'object_type']
  else
    self.object_type = 'cloud.Regions'
  end

  if attributes.key?(:'alternate_names')
    if (value = attributes[:'alternate_names']).is_a?(Array)
      self.alternate_names = value
    end
  end

  if attributes.key?(:'default_zone')
    self.default_zone = attributes[:'default_zone']
  end

  if attributes.key?(:'group')
    self.group = attributes[:'group']
  end

  if attributes.key?(:'is_active')
    self.is_active = attributes[:'is_active']
  else
    self.is_active = true
  end

  if attributes.key?(:'is_billing_only')
    self.is_billing_only = attributes[:'is_billing_only']
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  end

  if attributes.key?(:'platform_type')
    self.platform_type = attributes[:'platform_type']
  else
    self.platform_type = ''
  end

  if attributes.key?(:'region_end_point')
    self.region_end_point = attributes[:'region_end_point']
  end

  if attributes.key?(:'region_id')
    self.region_id = attributes[:'region_id']
  end

  if attributes.key?(:'zones')
    if (value = attributes[:'zones']).is_a?(Array)
      self.zones = value
    end
  end

  if attributes.key?(:'target')
    self.target = attributes[:'target']
  end
end

Instance Attribute Details

#alternate_names ⇒ Object

Returns the value of attribute alternate_names.



25
26
27
# File 'lib/intersight_client/models/cloud_regions_all_of.rb', line 25

def alternate_names
  @alternate_names
end

#class_id ⇒ Object

The fully-qualified name of the instantiated, concrete type. This property is used as a discriminator to identify the type of the payload when marshaling and unmarshaling data.



20
21
22
# File 'lib/intersight_client/models/cloud_regions_all_of.rb', line 20

def class_id
  @class_id
end

#default_zone ⇒ Object

The default zone for this region.



28
29
30
# File 'lib/intersight_client/models/cloud_regions_all_of.rb', line 28

def default_zone
  @default_zone
end

#group ⇒ Object

Property to identify regions in same category which shares credentials. For e.g. AWS Govcloud Vs AWS Global Vs AWS China.



31
32
33
# File 'lib/intersight_client/models/cloud_regions_all_of.rb', line 31

def group
  @group
end

#is_active ⇒ Object

Flag to indicate of this region is active or not.



34
35
36
# File 'lib/intersight_client/models/cloud_regions_all_of.rb', line 34

def is_active
  @is_active
end

#is_billing_only ⇒ Object

Property to pick regions for orchestration.



37
38
39
# File 'lib/intersight_client/models/cloud_regions_all_of.rb', line 37

def is_billing_only
  @is_billing_only
end

#name ⇒ Object

The display name of the region.



40
41
42
# File 'lib/intersight_client/models/cloud_regions_all_of.rb', line 40

def name
  @name
end

#object_type ⇒ Object

The fully-qualified name of the instantiated, concrete type. The value should be the same as the 'ClassId' property.



23
24
25
# File 'lib/intersight_client/models/cloud_regions_all_of.rb', line 23

def object_type
  @object_type
end

#platform_type ⇒ Object

The platform type for this region. For e.g. AmazonWebService. * `` - The device reported an empty or unrecognized platform type. * APIC - An Application Policy Infrastructure Controller cluster. * DCNM - A Data Center Network Manager instance. Data Center Network Manager (DCNM) is the network management platform for all NX-OS-enabled deployments, spanning new fabric architectures, IP Fabric for Media, and storage networking deployments for the Cisco Nexus-powered data center. * UCSFI - A UCS Fabric Interconnect in HA or standalone mode, which is being managed by UCS Manager (UCSM). * UCSFIISM - A UCS Fabric Interconnect in HA or standalone mode, managed directly by Intersight. * IMC - A standalone UCS Server Integrated Management Controller. * IMCM4 - A standalone UCS M4 Server. * IMCM5 - A standalone UCS M5 server. * IMCRack - A standalone UCS M6 and above server. * UCSIOM - An UCS Chassis IO module. * HX - A HyperFlex storage controller. * HyperFlexAP - A HyperFlex Application Platform. * IWE - An Intersight Workload Engine. * UCSD - A UCS Director virtual appliance. Cisco UCS Director automates, orchestrates, and manages Cisco and third-party hardware. * IntersightAppliance - A Cisco Intersight Connected Virtual Appliance. * IntersightAssist - A Cisco Intersight Assist. * PureStorageFlashArray - A Pure Storage FlashArray device. * UCSC890 - A standalone Cisco UCSC890 server. * NetAppOntap - A NetApp ONTAP storage system. * NetAppActiveIqUnifiedManager - A NetApp Active IQ Unified Manager. * EmcScaleIo - An EMC ScaleIO storage system. * EmcVmax - An EMC VMAX storage system. * EmcVplex - An EMC VPLEX storage system. * EmcXtremIo - An EMC XtremIO storage system. * VmwareVcenter - A VMware vCenter device that manages Virtual Machines. * MicrosoftHyperV - A Microsoft Hyper-V system that manages Virtual Machines. * AppDynamics - An AppDynamics controller that monitors applications. * Dynatrace - A software-intelligence monitoring platform that simplifies enterprise cloud complexity and accelerates digital transformation. * NewRelic - A software-intelligence monitoring platform that simplifies enterprise cloud complexity and accelerates digital transformation. * ServiceNow - A cloud-based workflow automation platform that enables enterprise organizations to improve operational efficiencies by streamlining and automating routine work tasks. * ReadHatOpenStack - An OpenStack target manages Virtual Machines, Physical Machines, Datacenters and Virtual Datacenters using different OpenStack services as administrative endpoints. * CloudFoundry - An open source cloud platform on which developers can build, deploy, run and scale applications. * MicrosoftAzureApplicationInsights - A feature of Azure Monitor, is an extensible Application Performance Management service for developers and DevOps professionals to monitor their live applications. * OpenStack - An OpenStack target manages Virtual Machines, Physical Machines, Datacenters and Virtual Datacenters using different OpenStack services as administrative endpoints. * MicrosoftSqlServer - A Microsoft SQL database server. * Kubernetes - A Kubernetes cluster that runs containerized applications. * AmazonWebService - A Amazon web service target that discovers and monitors different services like EC2. It discovers entities like VMs, Volumes, regions etc. and monitors attributes like Mem, CPU, cost. * AmazonWebServiceBilling - A Amazon web service billing target to retrieve billing information stored in S3 bucket. * MicrosoftAzureServicePrincipal - A Microsoft Azure Service Principal target that discovers all the associated Azure subscriptions. * MicrosoftAzureEnterpriseAgreement - A Microsoft Azure Enterprise Agreement target that discovers cost, billing and RIs. * DellCompellent - A Dell Compellent storage system. * HPE3Par - A HPE 3PAR storage system. * RedHatEnterpriseVirtualization - A Red Hat Enterprise Virtualization Hypervisor system that manages Virtual Machines. * NutanixAcropolis - A Nutanix Acropolis system that combines servers and storage into a distributed infrastructure platform. * HPEOneView - A HPE Oneview management system that manages compute, storage, and networking. * ServiceEngine - Cisco Application Services Engine. Cisco Application Services Engine is a platform to deploy and manage applications. * HitachiVirtualStoragePlatform - A Hitachi Virtual Storage Platform also referred to as Hitachi VSP. It includes various storage systems designed for data centers. * IMCBlade - An Intersight managed UCS Blade Server. * TerraformCloud - A Terraform Cloud account. * TerraformAgent - A Terraform Cloud Agent that Intersight will deploy in datacenter. The agent will execute Terraform plan for Terraform Cloud workspace configured to use the agent. * CustomTarget - An external endpoint added as Target that can be accessed through its HTTP API interface in Intersight Orchestrator automation workflow.Standard HTTP authentication scheme supported: Basic. * AnsibleEndpoint - An external endpoint added as Target that can be accessed through Ansible in Intersight Cloud Orchestrator automation workflow. * HTTPEndpoint - An external endpoint added as Target that can be accessed through its HTTP API interface in Intersight Orchestrator automation workflow.Standard HTTP authentication scheme supported: Basic, Bearer Token. * SSHEndpoint - An external endpoint added as Target that can be accessed through SSH in Intersight Cloud Orchestrator automation workflow. * CiscoCatalyst - A Cisco Catalyst networking switch device.



43
44
45
# File 'lib/intersight_client/models/cloud_regions_all_of.rb', line 43

def platform_type
  @platform_type
end

#region_end_point ⇒ Object

HTTP endpoint of the region. For example https://ec2.us-east-2.amazonaws.com.



46
47
48
# File 'lib/intersight_client/models/cloud_regions_all_of.rb', line 46

def region_end_point
  @region_end_point
end

#region_id ⇒ Object

The region Id which is assigned by the cloud provider. For e.g. us-east-1.



49
50
51
# File 'lib/intersight_client/models/cloud_regions_all_of.rb', line 49

def region_id
  @region_id
end

#target ⇒ Object

Returns the value of attribute target.



53
54
55
# File 'lib/intersight_client/models/cloud_regions_all_of.rb', line 53

def target
  @target
end

#zones ⇒ Object

Returns the value of attribute zones.



51
52
53
# File 'lib/intersight_client/models/cloud_regions_all_of.rb', line 51

def zones
  @zones
end

Class Method Details

.acceptable_attribute_map ⇒ Object

Returns the key-value map of all the JSON attributes this model knows about



102
103
104
# File 'lib/intersight_client/models/cloud_regions_all_of.rb', line 102

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributes ⇒ Object

Returns all the JSON keys this model knows about



97
98
99
# File 'lib/intersight_client/models/cloud_regions_all_of.rb', line 97

def self.acceptable_attributes
  attribute_map.values
end

.attribute_map ⇒ Object

Attribute mapping from ruby-style variable name to JSON key.



78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
# File 'lib/intersight_client/models/cloud_regions_all_of.rb', line 78

def self.attribute_map
  {
    :'class_id' => :'ClassId',
    :'object_type' => :'ObjectType',
    :'alternate_names' => :'AlternateNames',
    :'default_zone' => :'DefaultZone',
    :'group' => :'Group',
    :'is_active' => :'IsActive',
    :'is_billing_only' => :'IsBillingOnly',
    :'name' => :'Name',
    :'platform_type' => :'PlatformType',
    :'region_end_point' => :'RegionEndPoint',
    :'region_id' => :'RegionId',
    :'zones' => :'Zones',
    :'target' => :'Target'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash) —

    Model attributes in the form of hash

Returns:

  • (Object) —

    Returns the model itself



307
308
309
# File 'lib/intersight_client/models/cloud_regions_all_of.rb', line 307

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_nullable ⇒ Object

List of attributes with nullable: true



126
127
128
129
130
131
# File 'lib/intersight_client/models/cloud_regions_all_of.rb', line 126

def self.openapi_nullable
  Set.new([
    :'alternate_names',
    :'zones',
  ])
end

.openapi_types ⇒ Object

Attribute type mapping.



107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
# File 'lib/intersight_client/models/cloud_regions_all_of.rb', line 107

def self.openapi_types
  {
    :'class_id' => :'String',
    :'object_type' => :'String',
    :'alternate_names' => :'Array<String>',
    :'default_zone' => :'String',
    :'group' => :'String',
    :'is_active' => :'Boolean',
    :'is_billing_only' => :'Boolean',
    :'name' => :'String',
    :'platform_type' => :'String',
    :'region_end_point' => :'String',
    :'region_id' => :'String',
    :'zones' => :'Array<String>',
    :'target' => :'AssetTargetRelationship'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object) —

    to be compared



274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
# File 'lib/intersight_client/models/cloud_regions_all_of.rb', line 274

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      class_id == o.class_id &&
      object_type == o.object_type &&
      alternate_names == o.alternate_names &&
      default_zone == o.default_zone &&
      group == o.group &&
      is_active == o.is_active &&
      is_billing_only == o.is_billing_only &&
      name == o.name &&
      platform_type == o.platform_type &&
      region_end_point == o.region_end_point &&
      region_id == o.region_id &&
      zones == o.zones &&
      target == o.target
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string —

    type Data type

  • string —

    value Value to be deserialized

Returns:

  • (Object) —

    Deserialized data



337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
# File 'lib/intersight_client/models/cloud_regions_all_of.rb', line 337

def _deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = IntersightClient.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object) —

    Any valid value

Returns:

  • (Hash) —

    Returns the value in the form of hash



408
409
410
411
412
413
414
415
416
417
418
419
420
# File 'lib/intersight_client/models/cloud_regions_all_of.rb', line 408

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash) —

    Model attributes in the form of hash

Returns:

  • (Object) —

    Returns the model itself



314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
# File 'lib/intersight_client/models/cloud_regions_all_of.rb', line 314

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  CloudRegionsAllOf.openapi_types.each_pair do |key, type|
    if attributes[CloudRegionsAllOf.attribute_map[key]].nil? && CloudRegionsAllOf.openapi_nullable.include?(key)
      self.send("#{key}=", nil)
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[CloudRegionsAllOf.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[CloudRegionsAllOf.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[CloudRegionsAllOf.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[CloudRegionsAllOf.attribute_map[key]]))
    end
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object) —

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


294
295
296
# File 'lib/intersight_client/models/cloud_regions_all_of.rb', line 294

def eql?(o)
  self == o
end

#hash ⇒ Integer

Calculates hash code according to all attributes.

Returns:

  • (Integer) —

    Hash code



300
301
302
# File 'lib/intersight_client/models/cloud_regions_all_of.rb', line 300

def hash
  [class_id, object_type, alternate_names, default_zone, group, is_active, is_billing_only, name, platform_type, region_end_point, region_id, zones, target].hash
end

#list_invalid_properties ⇒ Object

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



215
216
217
218
219
220
221
222
223
224
225
226
# File 'lib/intersight_client/models/cloud_regions_all_of.rb', line 215

def list_invalid_properties
  invalid_properties = Array.new
  if @class_id.nil?
    invalid_properties.push('invalid value for "class_id", class_id cannot be nil.')
  end

  if @object_type.nil?
    invalid_properties.push('invalid value for "object_type", object_type cannot be nil.')
  end

  invalid_properties
end

#to_body ⇒ Hash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash) —

    Returns the object in the form of hash



384
385
386
# File 'lib/intersight_client/models/cloud_regions_all_of.rb', line 384

def to_body
  to_hash
end

#to_hash ⇒ Hash

Returns the object in the form of hash

Returns:

  • (Hash) —

    Returns the object in the form of hash



390
391
392
393
394
395
396
397
398
399
400
401
402
# File 'lib/intersight_client/models/cloud_regions_all_of.rb', line 390

def to_hash
  hash = {}
  CloudRegionsAllOf.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = CloudRegionsAllOf.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_s ⇒ String

Returns the string representation of the object

Returns:

  • (String) —

    String presentation of the object



378
379
380
# File 'lib/intersight_client/models/cloud_regions_all_of.rb', line 378

def to_s
  to_hash.to_s
end

#valid? ⇒ Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean) —

    true if the model is valid



230
231
232
233
234
235
236
237
238
239
240
# File 'lib/intersight_client/models/cloud_regions_all_of.rb', line 230

def valid?
  return false if @class_id.nil?
  class_id_validator = EnumAttributeValidator.new('String', ["cloud.Regions"])
  return false unless class_id_validator.valid?(@class_id)
  return false if @object_type.nil?
  object_type_validator = EnumAttributeValidator.new('String', ["cloud.Regions"])
  return false unless object_type_validator.valid?(@object_type)
  platform_type_validator = EnumAttributeValidator.new('String', ["", "APIC", "DCNM", "UCSFI", "UCSFIISM", "IMC", "IMCM4", "IMCM5", "IMCRack", "UCSIOM", "HX", "HyperFlexAP", "IWE", "UCSD", "IntersightAppliance", "IntersightAssist", "PureStorageFlashArray", "UCSC890", "NetAppOntap", "NetAppActiveIqUnifiedManager", "EmcScaleIo", "EmcVmax", "EmcVplex", "EmcXtremIo", "VmwareVcenter", "MicrosoftHyperV", "AppDynamics", "Dynatrace", "NewRelic", "ServiceNow", "ReadHatOpenStack", "CloudFoundry", "MicrosoftAzureApplicationInsights", "OpenStack", "MicrosoftSqlServer", "Kubernetes", "AmazonWebService", "AmazonWebServiceBilling", "MicrosoftAzureServicePrincipal", "MicrosoftAzureEnterpriseAgreement", "DellCompellent", "HPE3Par", "RedHatEnterpriseVirtualization", "NutanixAcropolis", "HPEOneView", "ServiceEngine", "HitachiVirtualStoragePlatform", "IMCBlade", "TerraformCloud", "TerraformAgent", "CustomTarget", "AnsibleEndpoint", "HTTPEndpoint", "SSHEndpoint", "CiscoCatalyst"])
  return false unless platform_type_validator.valid?(@platform_type)
  true
end