Class: IntersightClient::CloudSkuInstanceTypeAllOf

Inherits:
Object
  • Object
show all
Defined in:
lib/intersight_client/models/cloud_sku_instance_type_all_of.rb

Overview

Definition of the list of properties defined in ‘cloud.SkuInstanceType’, excluding properties defined in parent classes.

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ CloudSkuInstanceTypeAllOf

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
# File 'lib/intersight_client/models/cloud_sku_instance_type_all_of.rb', line 131

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `IntersightClient::CloudSkuInstanceTypeAllOf` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `#{self.class.name}`. Please check the name to make sure it's valid. List of attributes: " + self.class.acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'class_id')
    self.class_id = attributes[:'class_id']
  else
    self.class_id = 'cloud.SkuInstanceType'
  end

  if attributes.key?(:'object_type')
    self.object_type = attributes[:'object_type']
  else
    self.object_type = 'cloud.SkuInstanceType'
  end

  if attributes.key?(:'architecture_type')
    self.architecture_type = attributes[:'architecture_type']
  else
    self.architecture_type = '64Bit'
  end

  if attributes.key?(:'cpu_unit')
    self.cpu_unit = attributes[:'cpu_unit']
  else
    self.cpu_unit = 'VIRTUAL_CPU'
  end

  if attributes.key?(:'cuda_support')
    self.cuda_support = attributes[:'cuda_support']
  end

  if attributes.key?(:'local_storage_size')
    self.local_storage_size = attributes[:'local_storage_size']
  end

  if attributes.key?(:'local_storage_size_unit')
    self.local_storage_size_unit = attributes[:'local_storage_size_unit']
  else
    self.local_storage_size_unit = 'MB'
  end

  if attributes.key?(:'memory_size')
    self.memory_size = attributes[:'memory_size']
  end

  if attributes.key?(:'memory_size_unit')
    self.memory_size_unit = attributes[:'memory_size_unit']
  else
    self.memory_size_unit = 'MB'
  end

  if attributes.key?(:'network_performance')
    self.network_performance = attributes[:'network_performance']
  end

  if attributes.key?(:'num_of_cpus')
    self.num_of_cpus = attributes[:'num_of_cpus']
  end

  if attributes.key?(:'num_of_nics')
    self.num_of_nics = attributes[:'num_of_nics']
  end
end

Instance Attribute Details

#architecture_typeObject

Indicates if the instance type supports 32 or 64 bit or both. * 64Bit - Enum to indicate that the instance type suppports only 64 bit architecture. * 32Bit - Enum to indicate that the instance type supports only 32 bit architecture. * both - Enum to indicate that the instance type supports both 32 and 64 bit architecture.



26
27
28
# File 'lib/intersight_client/models/cloud_sku_instance_type_all_of.rb', line 26

def architecture_type
  @architecture_type
end

#class_idObject

The fully-qualified name of the instantiated, concrete type. This property is used as a discriminator to identify the type of the payload when marshaling and unmarshaling data.



20
21
22
# File 'lib/intersight_client/models/cloud_sku_instance_type_all_of.rb', line 20

def class_id
  @class_id
end

#cpu_unitObject

The cpu unit for this instance type. * VIRTUAL_CPU - The CPU unit used for virtual machines. * MILLI_CPU - The CPU unit used by containers.



29
30
31
# File 'lib/intersight_client/models/cloud_sku_instance_type_all_of.rb', line 29

def cpu_unit
  @cpu_unit
end

#cuda_supportObject

Does the instanceType support CUDA architecture.



32
33
34
# File 'lib/intersight_client/models/cloud_sku_instance_type_all_of.rb', line 32

def cuda_support
  @cuda_support
end

#local_storage_sizeObject

Total size of local storage for this instance type.



35
36
37
# File 'lib/intersight_client/models/cloud_sku_instance_type_all_of.rb', line 35

def local_storage_size
  @local_storage_size
end

#local_storage_size_unitObject

The units for this storage. For e.g. MB or GB or TB. * MB - Enum to represent mega byte storage unit. * GB - Enum to represent Giga byte storage unit. * TB - Enum to represent Tera byte storage unit.



38
39
40
# File 'lib/intersight_client/models/cloud_sku_instance_type_all_of.rb', line 38

def local_storage_size_unit
  @local_storage_size_unit
end

#memory_sizeObject

The RAM size for this instance type.



41
42
43
# File 'lib/intersight_client/models/cloud_sku_instance_type_all_of.rb', line 41

def memory_size
  @memory_size
end

#memory_size_unitObject

Units to represent memory, for e.g. MB or GB. * MB - Enum to represent mega byte storage unit. * GB - Enum to represent Giga byte storage unit. * TB - Enum to represent Tera byte storage unit.



44
45
46
# File 'lib/intersight_client/models/cloud_sku_instance_type_all_of.rb', line 44

def memory_size_unit
  @memory_size_unit
end

#network_performanceObject

Network performance of this instance type.



47
48
49
# File 'lib/intersight_client/models/cloud_sku_instance_type_all_of.rb', line 47

def network_performance
  @network_performance
end

#num_of_cpusObject

The number of CPUs in this instance type.



50
51
52
# File 'lib/intersight_client/models/cloud_sku_instance_type_all_of.rb', line 50

def num_of_cpus
  @num_of_cpus
end

#num_of_nicsObject

Maximum number of NICs supported by this instance type.



53
54
55
# File 'lib/intersight_client/models/cloud_sku_instance_type_all_of.rb', line 53

def num_of_nics
  @num_of_nics
end

#object_typeObject

The fully-qualified name of the instantiated, concrete type. The value should be the same as the ‘ClassId’ property.



23
24
25
# File 'lib/intersight_client/models/cloud_sku_instance_type_all_of.rb', line 23

def object_type
  @object_type
end

Class Method Details

.acceptable_attribute_mapObject

Returns the key-value map of all the JSON attributes this model knows about



101
102
103
# File 'lib/intersight_client/models/cloud_sku_instance_type_all_of.rb', line 101

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



96
97
98
# File 'lib/intersight_client/models/cloud_sku_instance_type_all_of.rb', line 96

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
# File 'lib/intersight_client/models/cloud_sku_instance_type_all_of.rb', line 78

def self.attribute_map
  {
    :'class_id' => :'ClassId',
    :'object_type' => :'ObjectType',
    :'architecture_type' => :'ArchitectureType',
    :'cpu_unit' => :'CpuUnit',
    :'cuda_support' => :'CudaSupport',
    :'local_storage_size' => :'LocalStorageSize',
    :'local_storage_size_unit' => :'LocalStorageSizeUnit',
    :'memory_size' => :'MemorySize',
    :'memory_size_unit' => :'MemorySizeUnit',
    :'network_performance' => :'NetworkPerformance',
    :'num_of_cpus' => :'NumOfCpus',
    :'num_of_nics' => :'NumOfNics'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



334
335
336
# File 'lib/intersight_client/models/cloud_sku_instance_type_all_of.rb', line 334

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_nullableObject

List of attributes with nullable: true



124
125
126
127
# File 'lib/intersight_client/models/cloud_sku_instance_type_all_of.rb', line 124

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
# File 'lib/intersight_client/models/cloud_sku_instance_type_all_of.rb', line 106

def self.openapi_types
  {
    :'class_id' => :'String',
    :'object_type' => :'String',
    :'architecture_type' => :'String',
    :'cpu_unit' => :'String',
    :'cuda_support' => :'Boolean',
    :'local_storage_size' => :'Float',
    :'local_storage_size_unit' => :'String',
    :'memory_size' => :'Float',
    :'memory_size_unit' => :'String',
    :'network_performance' => :'String',
    :'num_of_cpus' => :'Integer',
    :'num_of_nics' => :'Integer'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
# File 'lib/intersight_client/models/cloud_sku_instance_type_all_of.rb', line 302

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      class_id == o.class_id &&
      object_type == o.object_type &&
      architecture_type == o.architecture_type &&
      cpu_unit == o.cpu_unit &&
      cuda_support == o.cuda_support &&
      local_storage_size == o.local_storage_size &&
      local_storage_size_unit == o.local_storage_size_unit &&
      memory_size == o.memory_size &&
      memory_size_unit == o.memory_size_unit &&
      network_performance == o.network_performance &&
      num_of_cpus == o.num_of_cpus &&
      num_of_nics == o.num_of_nics
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
# File 'lib/intersight_client/models/cloud_sku_instance_type_all_of.rb', line 364

def _deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = IntersightClient.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



435
436
437
438
439
440
441
442
443
444
445
446
447
# File 'lib/intersight_client/models/cloud_sku_instance_type_all_of.rb', line 435

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
# File 'lib/intersight_client/models/cloud_sku_instance_type_all_of.rb', line 341

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  CloudSkuInstanceTypeAllOf.openapi_types.each_pair do |key, type|
    if attributes[CloudSkuInstanceTypeAllOf.attribute_map[key]].nil? && CloudSkuInstanceTypeAllOf.openapi_nullable.include?(key)
      self.send("#{key}=", nil)
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[CloudSkuInstanceTypeAllOf.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[CloudSkuInstanceTypeAllOf.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[CloudSkuInstanceTypeAllOf.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[CloudSkuInstanceTypeAllOf.attribute_map[key]]))
    end
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


321
322
323
# File 'lib/intersight_client/models/cloud_sku_instance_type_all_of.rb', line 321

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



327
328
329
# File 'lib/intersight_client/models/cloud_sku_instance_type_all_of.rb', line 327

def hash
  [class_id, object_type, architecture_type, cpu_unit, cuda_support, local_storage_size, local_storage_size_unit, memory_size, memory_size_unit, network_performance, num_of_cpus, num_of_nics].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



207
208
209
210
211
212
213
214
215
216
217
218
# File 'lib/intersight_client/models/cloud_sku_instance_type_all_of.rb', line 207

def list_invalid_properties
  invalid_properties = Array.new
  if @class_id.nil?
    invalid_properties.push('invalid value for "class_id", class_id cannot be nil.')
  end

  if @object_type.nil?
    invalid_properties.push('invalid value for "object_type", object_type cannot be nil.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



411
412
413
# File 'lib/intersight_client/models/cloud_sku_instance_type_all_of.rb', line 411

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



417
418
419
420
421
422
423
424
425
426
427
428
429
# File 'lib/intersight_client/models/cloud_sku_instance_type_all_of.rb', line 417

def to_hash
  hash = {}
  CloudSkuInstanceTypeAllOf.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = CloudSkuInstanceTypeAllOf.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



405
406
407
# File 'lib/intersight_client/models/cloud_sku_instance_type_all_of.rb', line 405

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
# File 'lib/intersight_client/models/cloud_sku_instance_type_all_of.rb', line 222

def valid?
  return false if @class_id.nil?
  class_id_validator = EnumAttributeValidator.new('String', ["cloud.SkuInstanceType"])
  return false unless class_id_validator.valid?(@class_id)
  return false if @object_type.nil?
  object_type_validator = EnumAttributeValidator.new('String', ["cloud.SkuInstanceType"])
  return false unless object_type_validator.valid?(@object_type)
  architecture_type_validator = EnumAttributeValidator.new('String', ["64Bit", "32Bit", "both"])
  return false unless architecture_type_validator.valid?(@architecture_type)
  cpu_unit_validator = EnumAttributeValidator.new('String', ["VIRTUAL_CPU", "MILLI_CPU"])
  return false unless cpu_unit_validator.valid?(@cpu_unit)
  local_storage_size_unit_validator = EnumAttributeValidator.new('String', ["MB", "GB", "TB"])
  return false unless local_storage_size_unit_validator.valid?(@local_storage_size_unit)
  memory_size_unit_validator = EnumAttributeValidator.new('String', ["MB", "GB", "TB"])
  return false unless memory_size_unit_validator.valid?(@memory_size_unit)
  true
end