Class: IntersightClient::CloudSkuVolumeType
- Inherits:
-
CloudBaseSku
- Object
- MoBaseMo
- CloudBaseSku
- IntersightClient::CloudSkuVolumeType
- Defined in:
- lib/intersight_client/models/cloud_sku_volume_type.rb
Overview
Stores information about the volume types.
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#class_id ⇒ Object
The fully-qualified name of the instantiated, concrete type.
-
#iops_unit ⇒ Object
The units to measure IOPS.
-
#is_bootable ⇒ Object
Indicates if this volume can be used as a boot volume.
-
#is_default ⇒ Object
Flag to indicate if this is a default volume.
-
#is_provisioned_iops ⇒ Object
Indicates if this volume type supports provisioned IOPS.
-
#max_iops ⇒ Object
The max I/O operations per second that this volume type supports.
-
#max_read_iops ⇒ Object
The maximum read IOPS that this volume type supports.
-
#max_read_throughput ⇒ Object
The maximum read throughput limit for this volume type.
-
#max_throughput ⇒ Object
The maximum throughput limit for this volume type.
-
#max_volume_size ⇒ Object
The maximum storage size that this volume type supports.
-
#max_write_iops ⇒ Object
The maximum write IOPS that this volume type supports.
-
#max_write_throughput ⇒ Object
The maximum write throughput limit for this volume type.
-
#min_volume_size ⇒ Object
The minimum storage size that this volume type supports.
-
#object_type ⇒ Object
The fully-qualified name of the instantiated, concrete type.
-
#throughput_unit ⇒ Object
The units for measuring throughput.
-
#type ⇒ Object
The volume type like gp2 or st1.
-
#volume_size_unit ⇒ Object
The units for measuring volume size.
Attributes inherited from CloudBaseSku
#custom_attributes, #description, #is_active, #is_auto_discovered, #name, #platform_type, #service_category, #service_family, #service_name, #target
Attributes inherited from MoBaseMo
#account_moid, #ancestors, #create_time, #display_names, #domain_group_moid, #mod_time, #moid, #owners, #parent, #permission_resources, #shared_scope, #tags, #version_context
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns the key-value map of all the JSON attributes this model knows about, including the ones defined in its parent(s).
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about, including the ones defined in its parent(s).
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_all_of ⇒ Object
List of class defined in allOf (OpenAPI v3).
-
.openapi_discriminator_name ⇒ Object
discriminator’s property name in OpenAPI v3.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CloudSkuVolumeType
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ CloudSkuVolumeType
Initializes the object
169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 |
# File 'lib/intersight_client/models/cloud_sku_volume_type.rb', line 169 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `IntersightClient::CloudSkuVolumeType` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `#{self.class.name}`. Please check the name to make sure it's valid. List of attributes: " + self.class.acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } # call parent's initialize super(attributes) if attributes.key?(:'class_id') self.class_id = attributes[:'class_id'] else self.class_id = 'cloud.SkuVolumeType' end if attributes.key?(:'object_type') self.object_type = attributes[:'object_type'] else self.object_type = 'cloud.SkuVolumeType' end if attributes.key?(:'iops_unit') self.iops_unit = attributes[:'iops_unit'] end if attributes.key?(:'is_bootable') self.is_bootable = attributes[:'is_bootable'] end if attributes.key?(:'is_default') self.is_default = attributes[:'is_default'] end if attributes.key?(:'is_provisioned_iops') self.is_provisioned_iops = attributes[:'is_provisioned_iops'] end if attributes.key?(:'max_iops') self.max_iops = attributes[:'max_iops'] end if attributes.key?(:'max_read_iops') self.max_read_iops = attributes[:'max_read_iops'] end if attributes.key?(:'max_read_throughput') self.max_read_throughput = attributes[:'max_read_throughput'] end if attributes.key?(:'max_throughput') self.max_throughput = attributes[:'max_throughput'] end if attributes.key?(:'max_volume_size') self.max_volume_size = attributes[:'max_volume_size'] end if attributes.key?(:'max_write_iops') self.max_write_iops = attributes[:'max_write_iops'] end if attributes.key?(:'max_write_throughput') self.max_write_throughput = attributes[:'max_write_throughput'] end if attributes.key?(:'min_volume_size') self.min_volume_size = attributes[:'min_volume_size'] end if attributes.key?(:'throughput_unit') self.throughput_unit = attributes[:'throughput_unit'] end if attributes.key?(:'type') self.type = attributes[:'type'] end if attributes.key?(:'volume_size_unit') self.volume_size_unit = attributes[:'volume_size_unit'] end end |
Instance Attribute Details
#class_id ⇒ Object
The fully-qualified name of the instantiated, concrete type. This property is used as a discriminator to identify the type of the payload when marshaling and unmarshaling data.
20 21 22 |
# File 'lib/intersight_client/models/cloud_sku_volume_type.rb', line 20 def class_id @class_id end |
#iops_unit ⇒ Object
The units to measure IOPS.
26 27 28 |
# File 'lib/intersight_client/models/cloud_sku_volume_type.rb', line 26 def iops_unit @iops_unit end |
#is_bootable ⇒ Object
Indicates if this volume can be used as a boot volume.
29 30 31 |
# File 'lib/intersight_client/models/cloud_sku_volume_type.rb', line 29 def is_bootable @is_bootable end |
#is_default ⇒ Object
Flag to indicate if this is a default volume. Default volumes will be used when an instance type is launched unless another volume type is specified.
32 33 34 |
# File 'lib/intersight_client/models/cloud_sku_volume_type.rb', line 32 def is_default @is_default end |
#is_provisioned_iops ⇒ Object
Indicates if this volume type supports provisioned IOPS.
35 36 37 |
# File 'lib/intersight_client/models/cloud_sku_volume_type.rb', line 35 def is_provisioned_iops @is_provisioned_iops end |
#max_iops ⇒ Object
The max I/O operations per second that this volume type supports. Read or write numbers does not go beyond this value.
38 39 40 |
# File 'lib/intersight_client/models/cloud_sku_volume_type.rb', line 38 def max_iops @max_iops end |
#max_read_iops ⇒ Object
The maximum read IOPS that this volume type supports.
41 42 43 |
# File 'lib/intersight_client/models/cloud_sku_volume_type.rb', line 41 def max_read_iops @max_read_iops end |
#max_read_throughput ⇒ Object
The maximum read throughput limit for this volume type.
44 45 46 |
# File 'lib/intersight_client/models/cloud_sku_volume_type.rb', line 44 def max_read_throughput @max_read_throughput end |
#max_throughput ⇒ Object
The maximum throughput limit for this volume type.
47 48 49 |
# File 'lib/intersight_client/models/cloud_sku_volume_type.rb', line 47 def max_throughput @max_throughput end |
#max_volume_size ⇒ Object
The maximum storage size that this volume type supports.
50 51 52 |
# File 'lib/intersight_client/models/cloud_sku_volume_type.rb', line 50 def max_volume_size @max_volume_size end |
#max_write_iops ⇒ Object
The maximum write IOPS that this volume type supports.
53 54 55 |
# File 'lib/intersight_client/models/cloud_sku_volume_type.rb', line 53 def max_write_iops @max_write_iops end |
#max_write_throughput ⇒ Object
The maximum write throughput limit for this volume type.
56 57 58 |
# File 'lib/intersight_client/models/cloud_sku_volume_type.rb', line 56 def max_write_throughput @max_write_throughput end |
#min_volume_size ⇒ Object
The minimum storage size that this volume type supports.
59 60 61 |
# File 'lib/intersight_client/models/cloud_sku_volume_type.rb', line 59 def min_volume_size @min_volume_size end |
#object_type ⇒ Object
The fully-qualified name of the instantiated, concrete type. The value should be the same as the ‘ClassId’ property.
23 24 25 |
# File 'lib/intersight_client/models/cloud_sku_volume_type.rb', line 23 def object_type @object_type end |
#throughput_unit ⇒ Object
The units for measuring throughput.
62 63 64 |
# File 'lib/intersight_client/models/cloud_sku_volume_type.rb', line 62 def throughput_unit @throughput_unit end |
#type ⇒ Object
The volume type like gp2 or st1.
65 66 67 |
# File 'lib/intersight_client/models/cloud_sku_volume_type.rb', line 65 def type @type end |
#volume_size_unit ⇒ Object
The units for measuring volume size.
68 69 70 |
# File 'lib/intersight_client/models/cloud_sku_volume_type.rb', line 68 def volume_size_unit @volume_size_unit end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns the key-value map of all the JSON attributes this model knows about, including the ones defined in its parent(s)
121 122 123 |
# File 'lib/intersight_client/models/cloud_sku_volume_type.rb', line 121 def self.acceptable_attribute_map attribute_map.merge(superclass.acceptable_attribute_map) end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about, including the ones defined in its parent(s)
116 117 118 |
# File 'lib/intersight_client/models/cloud_sku_volume_type.rb', line 116 def self.acceptable_attributes attribute_map.values.concat(superclass.acceptable_attributes) end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 |
# File 'lib/intersight_client/models/cloud_sku_volume_type.rb', line 93 def self.attribute_map { :'class_id' => :'ClassId', :'object_type' => :'ObjectType', :'iops_unit' => :'IopsUnit', :'is_bootable' => :'IsBootable', :'is_default' => :'IsDefault', :'is_provisioned_iops' => :'IsProvisionedIops', :'max_iops' => :'MaxIops', :'max_read_iops' => :'MaxReadIops', :'max_read_throughput' => :'MaxReadThroughput', :'max_throughput' => :'MaxThroughput', :'max_volume_size' => :'MaxVolumeSize', :'max_write_iops' => :'MaxWriteIops', :'max_write_throughput' => :'MaxWriteThroughput', :'min_volume_size' => :'MinVolumeSize', :'throughput_unit' => :'ThroughputUnit', :'type' => :'Type', :'volume_size_unit' => :'VolumeSizeUnit' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
344 345 346 |
# File 'lib/intersight_client/models/cloud_sku_volume_type.rb', line 344 def self.build_from_hash(attributes) new.build_from_hash(attributes) end |
.openapi_all_of ⇒ Object
List of class defined in allOf (OpenAPI v3)
155 156 157 158 159 160 |
# File 'lib/intersight_client/models/cloud_sku_volume_type.rb', line 155 def self.openapi_all_of [ :'CloudBaseSku', :'CloudSkuVolumeTypeAllOf' ] end |
.openapi_discriminator_name ⇒ Object
discriminator’s property name in OpenAPI v3
163 164 165 |
# File 'lib/intersight_client/models/cloud_sku_volume_type.rb', line 163 def self.openapi_discriminator_name :'ClassId' end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
149 150 151 152 |
# File 'lib/intersight_client/models/cloud_sku_volume_type.rb', line 149 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 |
# File 'lib/intersight_client/models/cloud_sku_volume_type.rb', line 126 def self.openapi_types { :'class_id' => :'String', :'object_type' => :'String', :'iops_unit' => :'String', :'is_bootable' => :'Boolean', :'is_default' => :'Boolean', :'is_provisioned_iops' => :'Boolean', :'max_iops' => :'Float', :'max_read_iops' => :'Float', :'max_read_throughput' => :'Float', :'max_throughput' => :'Float', :'max_volume_size' => :'Float', :'max_write_iops' => :'Float', :'max_write_throughput' => :'Float', :'min_volume_size' => :'Float', :'throughput_unit' => :'String', :'type' => :'String', :'volume_size_unit' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 |
# File 'lib/intersight_client/models/cloud_sku_volume_type.rb', line 307 def ==(o) return true if self.equal?(o) self.class == o.class && class_id == o.class_id && object_type == o.object_type && iops_unit == o.iops_unit && is_bootable == o.is_bootable && is_default == o.is_default && is_provisioned_iops == o.is_provisioned_iops && max_iops == o.max_iops && max_read_iops == o.max_read_iops && max_read_throughput == o.max_read_throughput && max_throughput == o.max_throughput && max_volume_size == o.max_volume_size && max_write_iops == o.max_write_iops && max_write_throughput == o.max_write_throughput && min_volume_size == o.min_volume_size && throughput_unit == o.throughput_unit && type == o.type && volume_size_unit == o.volume_size_unit && super(o) end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 |
# File 'lib/intersight_client/models/cloud_sku_volume_type.rb', line 375 def _deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = IntersightClient.const_get(type) klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
446 447 448 449 450 451 452 453 454 455 456 457 458 |
# File 'lib/intersight_client/models/cloud_sku_volume_type.rb', line 446 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 |
# File 'lib/intersight_client/models/cloud_sku_volume_type.rb', line 351 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) super(attributes) CloudSkuVolumeType.openapi_types.each_pair do |key, type| if attributes[CloudSkuVolumeType.attribute_map[key]].nil? && CloudSkuVolumeType.openapi_nullable.include?(key) self.send("#{key}=", nil) elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[CloudSkuVolumeType.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[CloudSkuVolumeType.attribute_map[key]].map { |v| _deserialize($1, v) }) end elsif !attributes[CloudSkuVolumeType.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[CloudSkuVolumeType.attribute_map[key]])) end end self end |
#eql?(o) ⇒ Boolean
331 332 333 |
# File 'lib/intersight_client/models/cloud_sku_volume_type.rb', line 331 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
337 338 339 |
# File 'lib/intersight_client/models/cloud_sku_volume_type.rb', line 337 def hash [class_id, object_type, iops_unit, is_bootable, is_default, is_provisioned_iops, max_iops, max_read_iops, max_read_throughput, max_throughput, max_volume_size, max_write_iops, max_write_throughput, min_volume_size, throughput_unit, type, volume_size_unit].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
260 261 262 263 264 265 266 267 268 269 270 271 |
# File 'lib/intersight_client/models/cloud_sku_volume_type.rb', line 260 def list_invalid_properties invalid_properties = super if @class_id.nil? invalid_properties.push('invalid value for "class_id", class_id cannot be nil.') end if @object_type.nil? invalid_properties.push('invalid value for "object_type", object_type cannot be nil.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
422 423 424 |
# File 'lib/intersight_client/models/cloud_sku_volume_type.rb', line 422 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
428 429 430 431 432 433 434 435 436 437 438 439 440 |
# File 'lib/intersight_client/models/cloud_sku_volume_type.rb', line 428 def to_hash hash = super CloudSkuVolumeType.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = CloudSkuVolumeType.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
416 417 418 |
# File 'lib/intersight_client/models/cloud_sku_volume_type.rb', line 416 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
275 276 277 278 279 280 281 282 283 |
# File 'lib/intersight_client/models/cloud_sku_volume_type.rb', line 275 def valid? return false if @class_id.nil? class_id_validator = EnumAttributeValidator.new('String', ["cloud.SkuVolumeType"]) return false unless class_id_validator.valid?(@class_id) return false if @object_type.nil? object_type_validator = EnumAttributeValidator.new('String', ["cloud.SkuVolumeType"]) return false unless object_type_validator.valid?(@object_type) true && super end |