Class: IntersightClient::ComputePhysicalSummary
- Defined in:
- lib/intersight_client/models/compute_physical_summary.rb
Overview
Consolidated view of Blades and RackUnits.
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#admin_power_state ⇒ Object
The desired power state of the server.
-
#alarm_summary ⇒ Object
Returns the value of attribute alarm_summary.
-
#asset_tag ⇒ Object
The user defined asset tag assigned to the server.
-
#available_memory ⇒ Object
The amount of memory available on the server.
-
#bios_post_complete ⇒ Object
The BIOS POST completion status of the server.
-
#chassis_id ⇒ Object
The id of the chassis that the blade is discovered in.
-
#class_id ⇒ Object
The fully-qualified name of the instantiated, concrete type.
-
#connection_status ⇒ Object
Connectivity Status of RackUnit to Switch - A or B or AB.
-
#cpu_capacity ⇒ Object
CPU Capacity = Number of CPU Sockets x Enabled Cores x Speed (GHz).
-
#device_mo_id ⇒ Object
The database identifier of the registered device of an object.
-
#dn ⇒ Object
The Distinguished Name unambiguously identifies an object in the system.
-
#equipment_chassis ⇒ Object
Returns the value of attribute equipment_chassis.
-
#fault_summary ⇒ Object
The fault summary for the server.
-
#firmware ⇒ Object
The firmware version of the Cisco Integrated Management Controller (CIMC) for this server.
-
#hardware_uuid ⇒ Object
The universally unique hardware identity of the server provided by the manufacturer.
-
#inventory_device_info ⇒ Object
Returns the value of attribute inventory_device_info.
-
#ipv4_address ⇒ Object
The IPv4 address configured on the management interface of the Integrated Management Controller.
-
#kvm_ip_addresses ⇒ Object
Returns the value of attribute kvm_ip_addresses.
-
#management_mode ⇒ Object
The management mode of the server.
-
#memory_speed ⇒ Object
The maximum memory speed in MHz available on the server.
-
#mgmt_ip_address ⇒ Object
Management address of the server.
-
#model ⇒ Object
This field identifies the model of the given component.
-
#name ⇒ Object
The name of the UCS Fabric Interconnect cluster or Cisco Integrated Management Controller (CIMC).
-
#num_adaptors ⇒ Object
The total number of network adapters present on the server.
-
#num_cpu_cores ⇒ Object
The total number of CPU cores present on the server.
-
#num_cpu_cores_enabled ⇒ Object
The total number of CPU cores enabled on the server.
-
#num_cpus ⇒ Object
The total number of CPUs present on the server.
-
#num_eth_host_interfaces ⇒ Object
The total number of vNICs which are visible to a host on the server.
-
#num_fc_host_interfaces ⇒ Object
The total number of vHBAs which are visible to a host on the server.
-
#num_threads ⇒ Object
The total number of threads the server is capable of handling.
-
#object_type ⇒ Object
The fully-qualified name of the instantiated, concrete type.
-
#oper_power_state ⇒ Object
The actual power state of the server.
-
#oper_reason ⇒ Object
Returns the value of attribute oper_reason.
-
#oper_state ⇒ Object
The operational state of the server.
-
#operability ⇒ Object
The operability of the server.
-
#personality ⇒ Object
The Rack unit software Personality.
-
#platform_type ⇒ Object
The platform type of the registered device - whether managed by UCSM or operating in standalone mode.
-
#presence ⇒ Object
This field identifies the presence (equipped) or absence of the given component.
-
#registered_device ⇒ Object
Returns the value of attribute registered_device.
-
#revision ⇒ Object
This field identifies the revision of the given component.
-
#rn ⇒ Object
The Relative Name uniquely identifies an object within a given context.
-
#scaled_mode ⇒ Object
The mode of the server that determines it is scaled.
-
#serial ⇒ Object
This field identifies the serial of the given component.
-
#server_id ⇒ Object
RackUnit ID that uniquely identifies the server.
-
#service_profile ⇒ Object
The distinguished name of the service profile to which the server is associated to.
-
#slot_id ⇒ Object
The slot number in the chassis that the blade is discovered in.
-
#source_object_type ⇒ Object
The source object type of this view MO.
-
#topology_scan_status ⇒ Object
To maintain the Topology workflow run status.
-
#total_memory ⇒ Object
The total memory available on the server.
-
#user_label ⇒ Object
The user defined label assigned to the server.
-
#uuid ⇒ Object
The universally unique identity of the server.
-
#vendor ⇒ Object
This field identifies the vendor of the given component.
Attributes inherited from MoBaseMo
#account_moid, #ancestors, #create_time, #display_names, #domain_group_moid, #mod_time, #moid, #owners, #parent, #permission_resources, #shared_scope, #tags, #version_context
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns the key-value map of all the JSON attributes this model knows about, including the ones defined in its parent(s).
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about, including the ones defined in its parent(s).
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_all_of ⇒ Object
List of class defined in allOf (OpenAPI v3).
-
.openapi_discriminator_name ⇒ Object
discriminator’s property name in OpenAPI v3.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ComputePhysicalSummary
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ ComputePhysicalSummary
Initializes the object
341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 463 464 465 466 467 468 469 470 471 472 473 474 475 476 477 478 479 480 481 482 483 484 485 486 487 488 489 490 491 492 493 494 495 496 497 498 499 500 501 502 503 504 505 506 507 508 509 510 511 512 513 514 515 516 517 518 519 520 521 522 523 524 525 526 527 528 529 530 531 532 533 534 535 536 537 538 539 540 541 542 543 544 545 546 547 548 549 550 551 552 553 554 555 556 557 558 559 560 561 562 563 564 565 566 567 568 569 570 571 572 573 574 |
# File 'lib/intersight_client/models/compute_physical_summary.rb', line 341 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `IntersightClient::ComputePhysicalSummary` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `#{self.class.name}`. Please check the name to make sure it's valid. List of attributes: " + self.class.acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } # call parent's initialize super(attributes) if attributes.key?(:'class_id') self.class_id = attributes[:'class_id'] else self.class_id = 'compute.PhysicalSummary' end if attributes.key?(:'object_type') self.object_type = attributes[:'object_type'] else self.object_type = 'compute.PhysicalSummary' end if attributes.key?(:'admin_power_state') self.admin_power_state = attributes[:'admin_power_state'] end if attributes.key?(:'alarm_summary') self.alarm_summary = attributes[:'alarm_summary'] end if attributes.key?(:'asset_tag') self.asset_tag = attributes[:'asset_tag'] end if attributes.key?(:'available_memory') self.available_memory = attributes[:'available_memory'] end if attributes.key?(:'bios_post_complete') self.bios_post_complete = attributes[:'bios_post_complete'] end if attributes.key?(:'chassis_id') self.chassis_id = attributes[:'chassis_id'] end if attributes.key?(:'connection_status') self.connection_status = attributes[:'connection_status'] end if attributes.key?(:'cpu_capacity') self.cpu_capacity = attributes[:'cpu_capacity'] end if attributes.key?(:'device_mo_id') self.device_mo_id = attributes[:'device_mo_id'] end if attributes.key?(:'dn') self.dn = attributes[:'dn'] end if attributes.key?(:'fault_summary') self.fault_summary = attributes[:'fault_summary'] end if attributes.key?(:'firmware') self.firmware = attributes[:'firmware'] end if attributes.key?(:'hardware_uuid') self.hardware_uuid = attributes[:'hardware_uuid'] end if attributes.key?(:'ipv4_address') self.ipv4_address = attributes[:'ipv4_address'] end if attributes.key?(:'kvm_ip_addresses') if (value = attributes[:'kvm_ip_addresses']).is_a?(Array) self.kvm_ip_addresses = value end end if attributes.key?(:'management_mode') self.management_mode = attributes[:'management_mode'] else self.management_mode = 'IntersightStandalone' end if attributes.key?(:'memory_speed') self.memory_speed = attributes[:'memory_speed'] end if attributes.key?(:'mgmt_ip_address') self.mgmt_ip_address = attributes[:'mgmt_ip_address'] end if attributes.key?(:'model') self.model = attributes[:'model'] end if attributes.key?(:'name') self.name = attributes[:'name'] end if attributes.key?(:'num_adaptors') self.num_adaptors = attributes[:'num_adaptors'] end if attributes.key?(:'num_cpu_cores') self.num_cpu_cores = attributes[:'num_cpu_cores'] end if attributes.key?(:'num_cpu_cores_enabled') self.num_cpu_cores_enabled = attributes[:'num_cpu_cores_enabled'] end if attributes.key?(:'num_cpus') self.num_cpus = attributes[:'num_cpus'] end if attributes.key?(:'num_eth_host_interfaces') self.num_eth_host_interfaces = attributes[:'num_eth_host_interfaces'] end if attributes.key?(:'num_fc_host_interfaces') self.num_fc_host_interfaces = attributes[:'num_fc_host_interfaces'] end if attributes.key?(:'num_threads') self.num_threads = attributes[:'num_threads'] end if attributes.key?(:'oper_power_state') self.oper_power_state = attributes[:'oper_power_state'] end if attributes.key?(:'oper_reason') if (value = attributes[:'oper_reason']).is_a?(Array) self.oper_reason = value end end if attributes.key?(:'oper_state') self.oper_state = attributes[:'oper_state'] end if attributes.key?(:'operability') self.operability = attributes[:'operability'] end if attributes.key?(:'personality') self.personality = attributes[:'personality'] end if attributes.key?(:'platform_type') self.platform_type = attributes[:'platform_type'] end if attributes.key?(:'presence') self.presence = attributes[:'presence'] end if attributes.key?(:'revision') self.revision = attributes[:'revision'] end if attributes.key?(:'rn') self.rn = attributes[:'rn'] end if attributes.key?(:'scaled_mode') self.scaled_mode = attributes[:'scaled_mode'] end if attributes.key?(:'serial') self.serial = attributes[:'serial'] end if attributes.key?(:'server_id') self.server_id = attributes[:'server_id'] end if attributes.key?(:'service_profile') self.service_profile = attributes[:'service_profile'] end if attributes.key?(:'slot_id') self.slot_id = attributes[:'slot_id'] end if attributes.key?(:'source_object_type') self.source_object_type = attributes[:'source_object_type'] end if attributes.key?(:'topology_scan_status') self.topology_scan_status = attributes[:'topology_scan_status'] end if attributes.key?(:'total_memory') self.total_memory = attributes[:'total_memory'] end if attributes.key?(:'user_label') self.user_label = attributes[:'user_label'] end if attributes.key?(:'uuid') self.uuid = attributes[:'uuid'] end if attributes.key?(:'vendor') self.vendor = attributes[:'vendor'] end if attributes.key?(:'equipment_chassis') self.equipment_chassis = attributes[:'equipment_chassis'] end if attributes.key?(:'inventory_device_info') self.inventory_device_info = attributes[:'inventory_device_info'] end if attributes.key?(:'registered_device') self.registered_device = attributes[:'registered_device'] end end |
Instance Attribute Details
#admin_power_state ⇒ Object
The desired power state of the server.
26 27 28 |
# File 'lib/intersight_client/models/compute_physical_summary.rb', line 26 def admin_power_state @admin_power_state end |
#alarm_summary ⇒ Object
Returns the value of attribute alarm_summary.
28 29 30 |
# File 'lib/intersight_client/models/compute_physical_summary.rb', line 28 def alarm_summary @alarm_summary end |
#asset_tag ⇒ Object
The user defined asset tag assigned to the server.
31 32 33 |
# File 'lib/intersight_client/models/compute_physical_summary.rb', line 31 def asset_tag @asset_tag end |
#available_memory ⇒ Object
The amount of memory available on the server.
34 35 36 |
# File 'lib/intersight_client/models/compute_physical_summary.rb', line 34 def available_memory @available_memory end |
#bios_post_complete ⇒ Object
The BIOS POST completion status of the server.
37 38 39 |
# File 'lib/intersight_client/models/compute_physical_summary.rb', line 37 def bios_post_complete @bios_post_complete end |
#chassis_id ⇒ Object
The id of the chassis that the blade is discovered in.
40 41 42 |
# File 'lib/intersight_client/models/compute_physical_summary.rb', line 40 def chassis_id @chassis_id end |
#class_id ⇒ Object
The fully-qualified name of the instantiated, concrete type. This property is used as a discriminator to identify the type of the payload when marshaling and unmarshaling data.
20 21 22 |
# File 'lib/intersight_client/models/compute_physical_summary.rb', line 20 def class_id @class_id end |
#connection_status ⇒ Object
Connectivity Status of RackUnit to Switch - A or B or AB.
43 44 45 |
# File 'lib/intersight_client/models/compute_physical_summary.rb', line 43 def connection_status @connection_status end |
#cpu_capacity ⇒ Object
CPU Capacity = Number of CPU Sockets x Enabled Cores x Speed (GHz).
46 47 48 |
# File 'lib/intersight_client/models/compute_physical_summary.rb', line 46 def cpu_capacity @cpu_capacity end |
#device_mo_id ⇒ Object
The database identifier of the registered device of an object.
49 50 51 |
# File 'lib/intersight_client/models/compute_physical_summary.rb', line 49 def device_mo_id @device_mo_id end |
#dn ⇒ Object
The Distinguished Name unambiguously identifies an object in the system.
52 53 54 |
# File 'lib/intersight_client/models/compute_physical_summary.rb', line 52 def dn @dn end |
#equipment_chassis ⇒ Object
Returns the value of attribute equipment_chassis.
163 164 165 |
# File 'lib/intersight_client/models/compute_physical_summary.rb', line 163 def equipment_chassis @equipment_chassis end |
#fault_summary ⇒ Object
The fault summary for the server.
55 56 57 |
# File 'lib/intersight_client/models/compute_physical_summary.rb', line 55 def fault_summary @fault_summary end |
#firmware ⇒ Object
The firmware version of the Cisco Integrated Management Controller (CIMC) for this server.
58 59 60 |
# File 'lib/intersight_client/models/compute_physical_summary.rb', line 58 def firmware @firmware end |
#hardware_uuid ⇒ Object
The universally unique hardware identity of the server provided by the manufacturer.
61 62 63 |
# File 'lib/intersight_client/models/compute_physical_summary.rb', line 61 def hardware_uuid @hardware_uuid end |
#inventory_device_info ⇒ Object
Returns the value of attribute inventory_device_info.
165 166 167 |
# File 'lib/intersight_client/models/compute_physical_summary.rb', line 165 def inventory_device_info @inventory_device_info end |
#ipv4_address ⇒ Object
The IPv4 address configured on the management interface of the Integrated Management Controller.
64 65 66 |
# File 'lib/intersight_client/models/compute_physical_summary.rb', line 64 def ipv4_address @ipv4_address end |
#kvm_ip_addresses ⇒ Object
Returns the value of attribute kvm_ip_addresses.
66 67 68 |
# File 'lib/intersight_client/models/compute_physical_summary.rb', line 66 def kvm_ip_addresses @kvm_ip_addresses end |
#management_mode ⇒ Object
The management mode of the server. * IntersightStandalone - Intersight Standalone mode of operation. * UCSM - Unified Computing System Manager mode of operation. * Intersight - Intersight managed mode of operation.
69 70 71 |
# File 'lib/intersight_client/models/compute_physical_summary.rb', line 69 def management_mode @management_mode end |
#memory_speed ⇒ Object
The maximum memory speed in MHz available on the server.
72 73 74 |
# File 'lib/intersight_client/models/compute_physical_summary.rb', line 72 def memory_speed @memory_speed end |
#mgmt_ip_address ⇒ Object
Management address of the server.
75 76 77 |
# File 'lib/intersight_client/models/compute_physical_summary.rb', line 75 def mgmt_ip_address @mgmt_ip_address end |
#model ⇒ Object
This field identifies the model of the given component.
78 79 80 |
# File 'lib/intersight_client/models/compute_physical_summary.rb', line 78 def model @model end |
#name ⇒ Object
The name of the UCS Fabric Interconnect cluster or Cisco Integrated Management Controller (CIMC). When this server is attached to a UCS Fabric Interconnect, the value of this property is the name of the UCS Fabric Interconnect. When this server configured in standalone mode, the value of this property is the name of the Cisco Integrated Management Controller.
81 82 83 |
# File 'lib/intersight_client/models/compute_physical_summary.rb', line 81 def name @name end |
#num_adaptors ⇒ Object
The total number of network adapters present on the server.
84 85 86 |
# File 'lib/intersight_client/models/compute_physical_summary.rb', line 84 def num_adaptors @num_adaptors end |
#num_cpu_cores ⇒ Object
The total number of CPU cores present on the server.
87 88 89 |
# File 'lib/intersight_client/models/compute_physical_summary.rb', line 87 def num_cpu_cores @num_cpu_cores end |
#num_cpu_cores_enabled ⇒ Object
The total number of CPU cores enabled on the server.
90 91 92 |
# File 'lib/intersight_client/models/compute_physical_summary.rb', line 90 def num_cpu_cores_enabled @num_cpu_cores_enabled end |
#num_cpus ⇒ Object
The total number of CPUs present on the server.
93 94 95 |
# File 'lib/intersight_client/models/compute_physical_summary.rb', line 93 def num_cpus @num_cpus end |
#num_eth_host_interfaces ⇒ Object
The total number of vNICs which are visible to a host on the server.
96 97 98 |
# File 'lib/intersight_client/models/compute_physical_summary.rb', line 96 def num_eth_host_interfaces @num_eth_host_interfaces end |
#num_fc_host_interfaces ⇒ Object
The total number of vHBAs which are visible to a host on the server.
99 100 101 |
# File 'lib/intersight_client/models/compute_physical_summary.rb', line 99 def num_fc_host_interfaces @num_fc_host_interfaces end |
#num_threads ⇒ Object
The total number of threads the server is capable of handling.
102 103 104 |
# File 'lib/intersight_client/models/compute_physical_summary.rb', line 102 def num_threads @num_threads end |
#object_type ⇒ Object
The fully-qualified name of the instantiated, concrete type. The value should be the same as the ‘ClassId’ property.
23 24 25 |
# File 'lib/intersight_client/models/compute_physical_summary.rb', line 23 def object_type @object_type end |
#oper_power_state ⇒ Object
The actual power state of the server.
105 106 107 |
# File 'lib/intersight_client/models/compute_physical_summary.rb', line 105 def oper_power_state @oper_power_state end |
#oper_reason ⇒ Object
Returns the value of attribute oper_reason.
107 108 109 |
# File 'lib/intersight_client/models/compute_physical_summary.rb', line 107 def oper_reason @oper_reason end |
#oper_state ⇒ Object
The operational state of the server.
110 111 112 |
# File 'lib/intersight_client/models/compute_physical_summary.rb', line 110 def oper_state @oper_state end |
#operability ⇒ Object
The operability of the server.
113 114 115 |
# File 'lib/intersight_client/models/compute_physical_summary.rb', line 113 def operability @operability end |
#personality ⇒ Object
The Rack unit software Personality.
116 117 118 |
# File 'lib/intersight_client/models/compute_physical_summary.rb', line 116 def personality @personality end |
#platform_type ⇒ Object
The platform type of the registered device - whether managed by UCSM or operating in standalone mode.
119 120 121 |
# File 'lib/intersight_client/models/compute_physical_summary.rb', line 119 def platform_type @platform_type end |
#presence ⇒ Object
This field identifies the presence (equipped) or absence of the given component.
122 123 124 |
# File 'lib/intersight_client/models/compute_physical_summary.rb', line 122 def presence @presence end |
#registered_device ⇒ Object
Returns the value of attribute registered_device.
167 168 169 |
# File 'lib/intersight_client/models/compute_physical_summary.rb', line 167 def registered_device @registered_device end |
#revision ⇒ Object
This field identifies the revision of the given component.
125 126 127 |
# File 'lib/intersight_client/models/compute_physical_summary.rb', line 125 def revision @revision end |
#rn ⇒ Object
The Relative Name uniquely identifies an object within a given context.
128 129 130 |
# File 'lib/intersight_client/models/compute_physical_summary.rb', line 128 def rn @rn end |
#scaled_mode ⇒ Object
The mode of the server that determines it is scaled.
131 132 133 |
# File 'lib/intersight_client/models/compute_physical_summary.rb', line 131 def scaled_mode @scaled_mode end |
#serial ⇒ Object
This field identifies the serial of the given component.
134 135 136 |
# File 'lib/intersight_client/models/compute_physical_summary.rb', line 134 def serial @serial end |
#server_id ⇒ Object
RackUnit ID that uniquely identifies the server.
137 138 139 |
# File 'lib/intersight_client/models/compute_physical_summary.rb', line 137 def server_id @server_id end |
#service_profile ⇒ Object
The distinguished name of the service profile to which the server is associated to. It is applicable only for servers which are managed via UCSM.
140 141 142 |
# File 'lib/intersight_client/models/compute_physical_summary.rb', line 140 def service_profile @service_profile end |
#slot_id ⇒ Object
The slot number in the chassis that the blade is discovered in.
143 144 145 |
# File 'lib/intersight_client/models/compute_physical_summary.rb', line 143 def slot_id @slot_id end |
#source_object_type ⇒ Object
The source object type of this view MO.
146 147 148 |
# File 'lib/intersight_client/models/compute_physical_summary.rb', line 146 def source_object_type @source_object_type end |
#topology_scan_status ⇒ Object
To maintain the Topology workflow run status.
149 150 151 |
# File 'lib/intersight_client/models/compute_physical_summary.rb', line 149 def topology_scan_status @topology_scan_status end |
#total_memory ⇒ Object
The total memory available on the server.
152 153 154 |
# File 'lib/intersight_client/models/compute_physical_summary.rb', line 152 def total_memory @total_memory end |
#user_label ⇒ Object
The user defined label assigned to the server.
155 156 157 |
# File 'lib/intersight_client/models/compute_physical_summary.rb', line 155 def user_label @user_label end |
#uuid ⇒ Object
The universally unique identity of the server.
158 159 160 |
# File 'lib/intersight_client/models/compute_physical_summary.rb', line 158 def uuid @uuid end |
#vendor ⇒ Object
This field identifies the vendor of the given component.
161 162 163 |
# File 'lib/intersight_client/models/compute_physical_summary.rb', line 161 def vendor @vendor end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns the key-value map of all the JSON attributes this model knows about, including the ones defined in its parent(s)
255 256 257 |
# File 'lib/intersight_client/models/compute_physical_summary.rb', line 255 def self.acceptable_attribute_map attribute_map.merge(superclass.acceptable_attribute_map) end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about, including the ones defined in its parent(s)
250 251 252 |
# File 'lib/intersight_client/models/compute_physical_summary.rb', line 250 def self.acceptable_attributes attribute_map.values.concat(superclass.acceptable_attributes) end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 |
# File 'lib/intersight_client/models/compute_physical_summary.rb', line 192 def self.attribute_map { :'class_id' => :'ClassId', :'object_type' => :'ObjectType', :'admin_power_state' => :'AdminPowerState', :'alarm_summary' => :'AlarmSummary', :'asset_tag' => :'AssetTag', :'available_memory' => :'AvailableMemory', :'bios_post_complete' => :'BiosPostComplete', :'chassis_id' => :'ChassisId', :'connection_status' => :'ConnectionStatus', :'cpu_capacity' => :'CpuCapacity', :'device_mo_id' => :'DeviceMoId', :'dn' => :'Dn', :'fault_summary' => :'FaultSummary', :'firmware' => :'Firmware', :'hardware_uuid' => :'HardwareUuid', :'ipv4_address' => :'Ipv4Address', :'kvm_ip_addresses' => :'KvmIpAddresses', :'management_mode' => :'ManagementMode', :'memory_speed' => :'MemorySpeed', :'mgmt_ip_address' => :'MgmtIpAddress', :'model' => :'Model', :'name' => :'Name', :'num_adaptors' => :'NumAdaptors', :'num_cpu_cores' => :'NumCpuCores', :'num_cpu_cores_enabled' => :'NumCpuCoresEnabled', :'num_cpus' => :'NumCpus', :'num_eth_host_interfaces' => :'NumEthHostInterfaces', :'num_fc_host_interfaces' => :'NumFcHostInterfaces', :'num_threads' => :'NumThreads', :'oper_power_state' => :'OperPowerState', :'oper_reason' => :'OperReason', :'oper_state' => :'OperState', :'operability' => :'Operability', :'personality' => :'Personality', :'platform_type' => :'PlatformType', :'presence' => :'Presence', :'revision' => :'Revision', :'rn' => :'Rn', :'scaled_mode' => :'ScaledMode', :'serial' => :'Serial', :'server_id' => :'ServerId', :'service_profile' => :'ServiceProfile', :'slot_id' => :'SlotId', :'source_object_type' => :'SourceObjectType', :'topology_scan_status' => :'TopologyScanStatus', :'total_memory' => :'TotalMemory', :'user_label' => :'UserLabel', :'uuid' => :'Uuid', :'vendor' => :'Vendor', :'equipment_chassis' => :'EquipmentChassis', :'inventory_device_info' => :'InventoryDeviceInfo', :'registered_device' => :'RegisteredDevice' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
709 710 711 |
# File 'lib/intersight_client/models/compute_physical_summary.rb', line 709 def self.build_from_hash(attributes) new.build_from_hash(attributes) end |
.openapi_all_of ⇒ Object
List of class defined in allOf (OpenAPI v3)
327 328 329 330 331 332 |
# File 'lib/intersight_client/models/compute_physical_summary.rb', line 327 def self.openapi_all_of [ :'ComputePhysicalSummaryAllOf', :'ViewsView' ] end |
.openapi_discriminator_name ⇒ Object
discriminator’s property name in OpenAPI v3
335 336 337 |
# File 'lib/intersight_client/models/compute_physical_summary.rb', line 335 def self.openapi_discriminator_name :'ClassId' end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
318 319 320 321 322 323 324 |
# File 'lib/intersight_client/models/compute_physical_summary.rb', line 318 def self.openapi_nullable Set.new([ :'alarm_summary', :'kvm_ip_addresses', :'oper_reason', ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 |
# File 'lib/intersight_client/models/compute_physical_summary.rb', line 260 def self.openapi_types { :'class_id' => :'String', :'object_type' => :'String', :'admin_power_state' => :'String', :'alarm_summary' => :'ComputeAlarmSummary', :'asset_tag' => :'String', :'available_memory' => :'Integer', :'bios_post_complete' => :'Boolean', :'chassis_id' => :'String', :'connection_status' => :'String', :'cpu_capacity' => :'Float', :'device_mo_id' => :'String', :'dn' => :'String', :'fault_summary' => :'Integer', :'firmware' => :'String', :'hardware_uuid' => :'String', :'ipv4_address' => :'String', :'kvm_ip_addresses' => :'Array<ComputeIpAddress>', :'management_mode' => :'String', :'memory_speed' => :'String', :'mgmt_ip_address' => :'String', :'model' => :'String', :'name' => :'String', :'num_adaptors' => :'Integer', :'num_cpu_cores' => :'Integer', :'num_cpu_cores_enabled' => :'Integer', :'num_cpus' => :'Integer', :'num_eth_host_interfaces' => :'Integer', :'num_fc_host_interfaces' => :'Integer', :'num_threads' => :'Integer', :'oper_power_state' => :'String', :'oper_reason' => :'Array<String>', :'oper_state' => :'String', :'operability' => :'String', :'personality' => :'String', :'platform_type' => :'String', :'presence' => :'String', :'revision' => :'String', :'rn' => :'String', :'scaled_mode' => :'String', :'serial' => :'String', :'server_id' => :'Integer', :'service_profile' => :'String', :'slot_id' => :'Integer', :'source_object_type' => :'String', :'topology_scan_status' => :'String', :'total_memory' => :'Integer', :'user_label' => :'String', :'uuid' => :'String', :'vendor' => :'String', :'equipment_chassis' => :'EquipmentChassisRelationship', :'inventory_device_info' => :'InventoryDeviceInfoRelationship', :'registered_device' => :'AssetDeviceRegistrationRelationship' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
637 638 639 640 641 642 643 644 645 646 647 648 649 650 651 652 653 654 655 656 657 658 659 660 661 662 663 664 665 666 667 668 669 670 671 672 673 674 675 676 677 678 679 680 681 682 683 684 685 686 687 688 689 690 691 692 |
# File 'lib/intersight_client/models/compute_physical_summary.rb', line 637 def ==(o) return true if self.equal?(o) self.class == o.class && class_id == o.class_id && object_type == o.object_type && admin_power_state == o.admin_power_state && alarm_summary == o.alarm_summary && asset_tag == o.asset_tag && available_memory == o.available_memory && bios_post_complete == o.bios_post_complete && chassis_id == o.chassis_id && connection_status == o.connection_status && cpu_capacity == o.cpu_capacity && device_mo_id == o.device_mo_id && dn == o.dn && fault_summary == o.fault_summary && firmware == o.firmware && hardware_uuid == o.hardware_uuid && ipv4_address == o.ipv4_address && kvm_ip_addresses == o.kvm_ip_addresses && management_mode == o.management_mode && memory_speed == o.memory_speed && mgmt_ip_address == o.mgmt_ip_address && model == o.model && name == o.name && num_adaptors == o.num_adaptors && num_cpu_cores == o.num_cpu_cores && num_cpu_cores_enabled == o.num_cpu_cores_enabled && num_cpus == o.num_cpus && num_eth_host_interfaces == o.num_eth_host_interfaces && num_fc_host_interfaces == o.num_fc_host_interfaces && num_threads == o.num_threads && oper_power_state == o.oper_power_state && oper_reason == o.oper_reason && oper_state == o.oper_state && operability == o.operability && personality == o.personality && platform_type == o.platform_type && presence == o.presence && revision == o.revision && rn == o.rn && scaled_mode == o.scaled_mode && serial == o.serial && server_id == o.server_id && service_profile == o.service_profile && slot_id == o.slot_id && source_object_type == o.source_object_type && topology_scan_status == o.topology_scan_status && total_memory == o.total_memory && user_label == o.user_label && uuid == o.uuid && vendor == o.vendor && equipment_chassis == o.equipment_chassis && inventory_device_info == o.inventory_device_info && registered_device == o.registered_device && super(o) end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
740 741 742 743 744 745 746 747 748 749 750 751 752 753 754 755 756 757 758 759 760 761 762 763 764 765 766 767 768 769 770 771 772 773 774 775 776 777 |
# File 'lib/intersight_client/models/compute_physical_summary.rb', line 740 def _deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = IntersightClient.const_get(type) klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
811 812 813 814 815 816 817 818 819 820 821 822 823 |
# File 'lib/intersight_client/models/compute_physical_summary.rb', line 811 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
716 717 718 719 720 721 722 723 724 725 726 727 728 729 730 731 732 733 734 |
# File 'lib/intersight_client/models/compute_physical_summary.rb', line 716 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) super(attributes) ComputePhysicalSummary.openapi_types.each_pair do |key, type| if attributes[ComputePhysicalSummary.attribute_map[key]].nil? && ComputePhysicalSummary.openapi_nullable.include?(key) self.send("#{key}=", nil) elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[ComputePhysicalSummary.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[ComputePhysicalSummary.attribute_map[key]].map { |v| _deserialize($1, v) }) end elsif !attributes[ComputePhysicalSummary.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[ComputePhysicalSummary.attribute_map[key]])) end end self end |
#eql?(o) ⇒ Boolean
696 697 698 |
# File 'lib/intersight_client/models/compute_physical_summary.rb', line 696 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
702 703 704 |
# File 'lib/intersight_client/models/compute_physical_summary.rb', line 702 def hash [class_id, object_type, admin_power_state, alarm_summary, asset_tag, available_memory, bios_post_complete, chassis_id, connection_status, cpu_capacity, device_mo_id, dn, fault_summary, firmware, hardware_uuid, ipv4_address, kvm_ip_addresses, management_mode, memory_speed, mgmt_ip_address, model, name, num_adaptors, num_cpu_cores, num_cpu_cores_enabled, num_cpus, num_eth_host_interfaces, num_fc_host_interfaces, num_threads, oper_power_state, oper_reason, oper_state, operability, personality, platform_type, presence, revision, rn, scaled_mode, serial, server_id, service_profile, slot_id, source_object_type, topology_scan_status, total_memory, user_label, uuid, vendor, equipment_chassis, inventory_device_info, registered_device].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
578 579 580 581 582 583 584 585 586 587 588 589 |
# File 'lib/intersight_client/models/compute_physical_summary.rb', line 578 def list_invalid_properties invalid_properties = super if @class_id.nil? invalid_properties.push('invalid value for "class_id", class_id cannot be nil.') end if @object_type.nil? invalid_properties.push('invalid value for "object_type", object_type cannot be nil.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
787 788 789 |
# File 'lib/intersight_client/models/compute_physical_summary.rb', line 787 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
793 794 795 796 797 798 799 800 801 802 803 804 805 |
# File 'lib/intersight_client/models/compute_physical_summary.rb', line 793 def to_hash hash = super ComputePhysicalSummary.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = ComputePhysicalSummary.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
781 782 783 |
# File 'lib/intersight_client/models/compute_physical_summary.rb', line 781 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
593 594 595 596 597 598 599 600 601 602 603 |
# File 'lib/intersight_client/models/compute_physical_summary.rb', line 593 def valid? return false if @class_id.nil? class_id_validator = EnumAttributeValidator.new('String', ["compute.PhysicalSummary"]) return false unless class_id_validator.valid?(@class_id) return false if @object_type.nil? object_type_validator = EnumAttributeValidator.new('String', ["compute.PhysicalSummary"]) return false unless object_type_validator.valid?(@object_type) management_mode_validator = EnumAttributeValidator.new('String', ["IntersightStandalone", "UCSM", "Intersight"]) return false unless management_mode_validator.valid?(@management_mode) true && super end |