Class: IntersightClient::ConnectorBaseMessage
- Inherits:
-
MoBaseComplexType
- Object
- MoBaseComplexType
- IntersightClient::ConnectorBaseMessage
- Defined in:
- lib/intersight_client/models/connector_base_message.rb
Overview
A base abstract message that handles the common request properties applicable for all the message types.
Direct Known Subclasses
ConnectorAuthMessage, ConnectorCommandTerminalStream, ConnectorFileMessage, ConnectorHttpRequest, ConnectorSshConfig, ConnectorSshMessage, ConnectorStreamMessage, ConnectorTargetChangeMessage, WorkflowFileTransfer, WorkflowSshCmd, WorkflowSshConfig
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#class_id ⇒ Object
The fully-qualified name of the instantiated, concrete type.
-
#encrypted_aes_key ⇒ Object
The secure properties that have large text content as value can be encrypted using AES key.
-
#encryption_key ⇒ Object
The public key that was used to encrypt the values present in SecureProperties dictionary.
-
#object_type ⇒ Object
The fully-qualified name of the instantiated, concrete type.
-
#secure_properties ⇒ Object
A dictionary of encrypted secure values mapped against the secure property name.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns the key-value map of all the JSON attributes this model knows about, including the ones defined in its parent(s).
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about, including the ones defined in its parent(s).
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_all_of ⇒ Object
List of class defined in allOf (OpenAPI v3).
-
.openapi_discriminator_name ⇒ Object
discriminator’s property name in OpenAPI v3.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ConnectorBaseMessage
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ ConnectorBaseMessage
Initializes the object
110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 |
# File 'lib/intersight_client/models/connector_base_message.rb', line 110 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `IntersightClient::ConnectorBaseMessage` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `#{self.class.name}`. Please check the name to make sure it's valid. List of attributes: " + self.class.acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } # call parent's initialize super(attributes) if attributes.key?(:'class_id') self.class_id = attributes[:'class_id'] end if attributes.key?(:'object_type') self.object_type = attributes[:'object_type'] end if attributes.key?(:'encrypted_aes_key') self.encrypted_aes_key = attributes[:'encrypted_aes_key'] end if attributes.key?(:'encryption_key') self.encryption_key = attributes[:'encryption_key'] end if attributes.key?(:'secure_properties') self.secure_properties = attributes[:'secure_properties'] end end |
Instance Attribute Details
#class_id ⇒ Object
The fully-qualified name of the instantiated, concrete type. This property is used as a discriminator to identify the type of the payload when marshaling and unmarshaling data. The enum values provides the list of concrete types that can be instantiated from this abstract type.
20 21 22 |
# File 'lib/intersight_client/models/connector_base_message.rb', line 20 def class_id @class_id end |
#encrypted_aes_key ⇒ Object
The secure properties that have large text content as value can be encrypted using AES key. In these cases, the AES key needs to be encrypted using the device connector public key and passed as the value for this property. The secure properties that are encrypted using the AES key are mapped against the property name with prefix ‘AES’ in SecureProperties dictionary.
26 27 28 |
# File 'lib/intersight_client/models/connector_base_message.rb', line 26 def encrypted_aes_key @encrypted_aes_key end |
#encryption_key ⇒ Object
The public key that was used to encrypt the values present in SecureProperties dictionary. If the given public key is not same as device connector’s public key, an error reponse with appropriate error message is thrown back.
29 30 31 |
# File 'lib/intersight_client/models/connector_base_message.rb', line 29 def encryption_key @encryption_key end |
#object_type ⇒ Object
The fully-qualified name of the instantiated, concrete type. The value should be the same as the ‘ClassId’ property. The enum values provides the list of concrete types that can be instantiated from this abstract type.
23 24 25 |
# File 'lib/intersight_client/models/connector_base_message.rb', line 23 def object_type @object_type end |
#secure_properties ⇒ Object
A dictionary of encrypted secure values mapped against the secure property name. The values that are encrypted using AES key must be mapped against the secure property name with a ‘AES’ prefix Device connector expects the message body to be a golang template and the template can use the secure property names as placeholders.
32 33 34 |
# File 'lib/intersight_client/models/connector_base_message.rb', line 32 def secure_properties @secure_properties end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns the key-value map of all the JSON attributes this model knows about, including the ones defined in its parent(s)
73 74 75 |
# File 'lib/intersight_client/models/connector_base_message.rb', line 73 def self.acceptable_attribute_map attribute_map.merge(superclass.acceptable_attribute_map) end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about, including the ones defined in its parent(s)
68 69 70 |
# File 'lib/intersight_client/models/connector_base_message.rb', line 68 def self.acceptable_attributes attribute_map.values.concat(superclass.acceptable_attributes) end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
57 58 59 60 61 62 63 64 65 |
# File 'lib/intersight_client/models/connector_base_message.rb', line 57 def self.attribute_map { :'class_id' => :'ClassId', :'object_type' => :'ObjectType', :'encrypted_aes_key' => :'EncryptedAesKey', :'encryption_key' => :'EncryptionKey', :'secure_properties' => :'SecureProperties' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
221 222 223 |
# File 'lib/intersight_client/models/connector_base_message.rb', line 221 def self.build_from_hash(attributes) new.build_from_hash(attributes) end |
.openapi_all_of ⇒ Object
List of class defined in allOf (OpenAPI v3)
96 97 98 99 100 101 |
# File 'lib/intersight_client/models/connector_base_message.rb', line 96 def self.openapi_all_of [ :'ConnectorBaseMessageAllOf', :'MoBaseComplexType' ] end |
.openapi_discriminator_name ⇒ Object
discriminator’s property name in OpenAPI v3
104 105 106 |
# File 'lib/intersight_client/models/connector_base_message.rb', line 104 def self.openapi_discriminator_name :'ClassId' end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
89 90 91 92 93 |
# File 'lib/intersight_client/models/connector_base_message.rb', line 89 def self.openapi_nullable Set.new([ :'secure_properties' ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
78 79 80 81 82 83 84 85 86 |
# File 'lib/intersight_client/models/connector_base_message.rb', line 78 def self.openapi_types { :'class_id' => :'String', :'object_type' => :'String', :'encrypted_aes_key' => :'String', :'encryption_key' => :'String', :'secure_properties' => :'Object' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
196 197 198 199 200 201 202 203 204 |
# File 'lib/intersight_client/models/connector_base_message.rb', line 196 def ==(o) return true if self.equal?(o) self.class == o.class && class_id == o.class_id && object_type == o.object_type && encrypted_aes_key == o.encrypted_aes_key && encryption_key == o.encryption_key && secure_properties == o.secure_properties && super(o) end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 |
# File 'lib/intersight_client/models/connector_base_message.rb', line 252 def _deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = IntersightClient.const_get(type) klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
323 324 325 326 327 328 329 330 331 332 333 334 335 |
# File 'lib/intersight_client/models/connector_base_message.rb', line 323 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 |
# File 'lib/intersight_client/models/connector_base_message.rb', line 228 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) super(attributes) ConnectorBaseMessage.openapi_types.each_pair do |key, type| if attributes[ConnectorBaseMessage.attribute_map[key]].nil? && ConnectorBaseMessage.openapi_nullable.include?(key) self.send("#{key}=", nil) elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[ConnectorBaseMessage.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[ConnectorBaseMessage.attribute_map[key]].map { |v| _deserialize($1, v) }) end elsif !attributes[ConnectorBaseMessage.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[ConnectorBaseMessage.attribute_map[key]])) end end self end |
#eql?(o) ⇒ Boolean
208 209 210 |
# File 'lib/intersight_client/models/connector_base_message.rb', line 208 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
214 215 216 |
# File 'lib/intersight_client/models/connector_base_message.rb', line 214 def hash [class_id, object_type, encrypted_aes_key, encryption_key, secure_properties].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
149 150 151 152 153 154 155 156 157 158 159 160 |
# File 'lib/intersight_client/models/connector_base_message.rb', line 149 def list_invalid_properties invalid_properties = super if @class_id.nil? invalid_properties.push('invalid value for "class_id", class_id cannot be nil.') end if @object_type.nil? invalid_properties.push('invalid value for "object_type", object_type cannot be nil.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
299 300 301 |
# File 'lib/intersight_client/models/connector_base_message.rb', line 299 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
305 306 307 308 309 310 311 312 313 314 315 316 317 |
# File 'lib/intersight_client/models/connector_base_message.rb', line 305 def to_hash hash = super ConnectorBaseMessage.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = ConnectorBaseMessage.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
293 294 295 |
# File 'lib/intersight_client/models/connector_base_message.rb', line 293 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
164 165 166 167 168 169 170 171 172 |
# File 'lib/intersight_client/models/connector_base_message.rb', line 164 def valid? return false if @class_id.nil? class_id_validator = EnumAttributeValidator.new('String', ["connector.CloseStreamMessage", "connector.CommandControlMessage", "connector.CommandTerminalStream", "connector.FetchStreamMessage", "connector.FileMessage", "connector.HttpRequest", "connector.SshConfig", "connector.SshMessage", "connector.StartStream", "connector.StartStreamFromDevice", "connector.StreamAcknowledge", "connector.StreamInput", "connector.StreamKeepalive", "connector.TargetChangeMessage", "connector.XmlApiMessage", "imcconnector.WebUiMessage", "ucsdconnector.RestClientMessage", "workflow.FileTransfer", "workflow.SshCmd", "workflow.SshConfig"]) return false unless class_id_validator.valid?(@class_id) return false if @object_type.nil? object_type_validator = EnumAttributeValidator.new('String', ["connector.CloseStreamMessage", "connector.CommandControlMessage", "connector.CommandTerminalStream", "connector.FetchStreamMessage", "connector.FileMessage", "connector.HttpRequest", "connector.SshConfig", "connector.SshMessage", "connector.StartStream", "connector.StartStreamFromDevice", "connector.StreamAcknowledge", "connector.StreamInput", "connector.StreamKeepalive", "connector.TargetChangeMessage", "connector.XmlApiMessage", "imcconnector.WebUiMessage", "ucsdconnector.RestClientMessage", "workflow.FileTransfer", "workflow.SshCmd", "workflow.SshConfig"]) return false unless object_type_validator.valid?(@object_type) true && super end |