Class: IntersightClient::ConnectorStartStreamAllOf

Inherits:
Object
  • Object
show all
Defined in:
lib/intersight_client/models/connector_start_stream_all_of.rb

Overview

Definition of the list of properties defined in ‘connector.StartStream’, excluding properties defined in parent classes.

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ ConnectorStartStreamAllOf

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
# File 'lib/intersight_client/models/connector_start_stream_all_of.rb', line 126

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `IntersightClient::ConnectorStartStreamAllOf` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `#{self.class.name}`. Please check the name to make sure it's valid. List of attributes: " + self.class.acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'class_id')
    self.class_id = attributes[:'class_id']
  else
    self.class_id = 'connector.StartStream'
  end

  if attributes.key?(:'object_type')
    self.object_type = attributes[:'object_type']
  else
    self.object_type = 'connector.StartStream'
  end

  if attributes.key?(:'batch_size')
    self.batch_size = attributes[:'batch_size']
  end

  if attributes.key?(:'force_rebuild')
    self.force_rebuild = attributes[:'force_rebuild']
  end

  if attributes.key?(:'input')
    self.input = attributes[:'input']
  end

  if attributes.key?(:'keep_alive_interval')
    self.keep_alive_interval = attributes[:'keep_alive_interval']
  end

  if attributes.key?(:'plugin_name')
    self.plugin_name = attributes[:'plugin_name']
  end

  if attributes.key?(:'poll_interval')
    self.poll_interval = attributes[:'poll_interval']
  end

  if attributes.key?(:'priority')
    self.priority = attributes[:'priority']
  end

  if attributes.key?(:'protocol_version')
    self.protocol_version = attributes[:'protocol_version']
  end

  if attributes.key?(:'response_topic')
    self.response_topic = attributes[:'response_topic']
  end
end

Instance Attribute Details

#batch_sizeObject

The number of outputs from a plugin to collect into a single message. Applicable only to streams that involve polling plugins and plugins which support emitting batchable data. Default value of zero indicates no batching.



26
27
28
# File 'lib/intersight_client/models/connector_start_stream_all_of.rb', line 26

def batch_size
  @batch_size
end

#class_idObject

The fully-qualified name of the instantiated, concrete type. This property is used as a discriminator to identify the type of the payload when marshaling and unmarshaling data.



20
21
22
# File 'lib/intersight_client/models/connector_start_stream_all_of.rb', line 20

def class_id
  @class_id
end

#force_rebuildObject

Flag to force a rebuild of an existing stream. To be used if a stream is unable to recover itself in response to dropped messages.



29
30
31
# File 'lib/intersight_client/models/connector_start_stream_all_of.rb', line 29

def force_rebuild
  @force_rebuild
end

#inputObject

Input to the plugin to start the start the stream or collect stream messages.



32
33
34
# File 'lib/intersight_client/models/connector_start_stream_all_of.rb', line 32

def input
  @input
end

#keep_alive_intervalObject

Interval at which device should emit a keepalive message for this stream. Device will also expect a keepalive response from the cloud within the interval. If zero, no keepalive is required and stream should not timeout.



35
36
37
# File 'lib/intersight_client/models/connector_start_stream_all_of.rb', line 35

def keep_alive_interval
  @keep_alive_interval
end

#object_typeObject

The fully-qualified name of the instantiated, concrete type. The value should be the same as the ‘ClassId’ property.



23
24
25
# File 'lib/intersight_client/models/connector_start_stream_all_of.rb', line 23

def object_type
  @object_type
end

#plugin_nameObject

The plugin to run the stream on.



38
39
40
# File 'lib/intersight_client/models/connector_start_stream_all_of.rb', line 38

def plugin_name
  @plugin_name
end

#poll_intervalObject

The desired interval to emit messages from this stream. The stream plugin will poll plugins at this interval to create a stream event.



41
42
43
# File 'lib/intersight_client/models/connector_start_stream_all_of.rb', line 41

def poll_interval
  @poll_interval
end

#priorityObject

The priority level to apply to messages emitted by this stream.



44
45
46
# File 'lib/intersight_client/models/connector_start_stream_all_of.rb', line 44

def priority
  @priority
end

#protocol_versionObject

The version of the device connector stream protocol. Used to change behavior of the device connector stream plugin based on the version of the Intersight service. Allows for multiple versions of Intersight services to interact with the stream plugin of devices.



47
48
49
# File 'lib/intersight_client/models/connector_start_stream_all_of.rb', line 47

def protocol_version
  @protocol_version
end

#response_topicObject

The topic for the device connector to publish messages to.



50
51
52
# File 'lib/intersight_client/models/connector_start_stream_all_of.rb', line 50

def response_topic
  @response_topic
end

Class Method Details

.acceptable_attribute_mapObject

Returns the key-value map of all the JSON attributes this model knows about



97
98
99
# File 'lib/intersight_client/models/connector_start_stream_all_of.rb', line 97

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



92
93
94
# File 'lib/intersight_client/models/connector_start_stream_all_of.rb', line 92

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
# File 'lib/intersight_client/models/connector_start_stream_all_of.rb', line 75

def self.attribute_map
  {
    :'class_id' => :'ClassId',
    :'object_type' => :'ObjectType',
    :'batch_size' => :'BatchSize',
    :'force_rebuild' => :'ForceRebuild',
    :'input' => :'Input',
    :'keep_alive_interval' => :'KeepAliveInterval',
    :'plugin_name' => :'PluginName',
    :'poll_interval' => :'PollInterval',
    :'priority' => :'Priority',
    :'protocol_version' => :'ProtocolVersion',
    :'response_topic' => :'ResponseTopic'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



268
269
270
# File 'lib/intersight_client/models/connector_start_stream_all_of.rb', line 268

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_nullableObject

List of attributes with nullable: true



119
120
121
122
# File 'lib/intersight_client/models/connector_start_stream_all_of.rb', line 119

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
# File 'lib/intersight_client/models/connector_start_stream_all_of.rb', line 102

def self.openapi_types
  {
    :'class_id' => :'String',
    :'object_type' => :'String',
    :'batch_size' => :'Integer',
    :'force_rebuild' => :'Boolean',
    :'input' => :'String',
    :'keep_alive_interval' => :'Integer',
    :'plugin_name' => :'String',
    :'poll_interval' => :'Integer',
    :'priority' => :'Integer',
    :'protocol_version' => :'Integer',
    :'response_topic' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
# File 'lib/intersight_client/models/connector_start_stream_all_of.rb', line 237

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      class_id == o.class_id &&
      object_type == o.object_type &&
      batch_size == o.batch_size &&
      force_rebuild == o.force_rebuild &&
      input == o.input &&
      keep_alive_interval == o.keep_alive_interval &&
      plugin_name == o.plugin_name &&
      poll_interval == o.poll_interval &&
      priority == o.priority &&
      protocol_version == o.protocol_version &&
      response_topic == o.response_topic
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
# File 'lib/intersight_client/models/connector_start_stream_all_of.rb', line 298

def _deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = IntersightClient.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



369
370
371
372
373
374
375
376
377
378
379
380
381
# File 'lib/intersight_client/models/connector_start_stream_all_of.rb', line 369

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
# File 'lib/intersight_client/models/connector_start_stream_all_of.rb', line 275

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  ConnectorStartStreamAllOf.openapi_types.each_pair do |key, type|
    if attributes[ConnectorStartStreamAllOf.attribute_map[key]].nil? && ConnectorStartStreamAllOf.openapi_nullable.include?(key)
      self.send("#{key}=", nil)
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[ConnectorStartStreamAllOf.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[ConnectorStartStreamAllOf.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[ConnectorStartStreamAllOf.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[ConnectorStartStreamAllOf.attribute_map[key]]))
    end
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


255
256
257
# File 'lib/intersight_client/models/connector_start_stream_all_of.rb', line 255

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



261
262
263
# File 'lib/intersight_client/models/connector_start_stream_all_of.rb', line 261

def hash
  [class_id, object_type, batch_size, force_rebuild, input, keep_alive_interval, plugin_name, poll_interval, priority, protocol_version, response_topic].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



190
191
192
193
194
195
196
197
198
199
200
201
# File 'lib/intersight_client/models/connector_start_stream_all_of.rb', line 190

def list_invalid_properties
  invalid_properties = Array.new
  if @class_id.nil?
    invalid_properties.push('invalid value for "class_id", class_id cannot be nil.')
  end

  if @object_type.nil?
    invalid_properties.push('invalid value for "object_type", object_type cannot be nil.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



345
346
347
# File 'lib/intersight_client/models/connector_start_stream_all_of.rb', line 345

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



351
352
353
354
355
356
357
358
359
360
361
362
363
# File 'lib/intersight_client/models/connector_start_stream_all_of.rb', line 351

def to_hash
  hash = {}
  ConnectorStartStreamAllOf.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = ConnectorStartStreamAllOf.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



339
340
341
# File 'lib/intersight_client/models/connector_start_stream_all_of.rb', line 339

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



205
206
207
208
209
210
211
212
213
# File 'lib/intersight_client/models/connector_start_stream_all_of.rb', line 205

def valid?
  return false if @class_id.nil?
  class_id_validator = EnumAttributeValidator.new('String', ["connector.StartStream"])
  return false unless class_id_validator.valid?(@class_id)
  return false if @object_type.nil?
  object_type_validator = EnumAttributeValidator.new('String', ["connector.StartStream"])
  return false unless object_type_validator.valid?(@object_type)
  true
end