Class: IntersightClient::ConnectorUrl
- Inherits:
-
MoBaseComplexType
- Object
- MoBaseComplexType
- IntersightClient::ConnectorUrl
- Defined in:
- lib/intersight_client/models/connector_url.rb
Overview
The URL to proxy the request to.
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#class_id ⇒ Object
The fully-qualified name of the instantiated, concrete type.
-
#force_query ⇒ Object
Flag to append a query to the url even if rawQuery is empty.
-
#fragment ⇒ Object
The fragment identifier component of a URI allows indirect identification of a secondary resource by reference to a primary resource and additional identifying information.
-
#host ⇒ Object
The host name identifies the host that holds the resource.
-
#object_type ⇒ Object
The fully-qualified name of the instantiated, concrete type.
-
#opaque ⇒ Object
A URI is opaque if, and only if, it is absolute and its scheme-specific part does not begin with a slash character (‘/’).
-
#path ⇒ Object
The path identifies the specific resource in the host that the web client wants to access.
-
#raw_path ⇒ Object
The URI encoded form of the path property.
-
#raw_query ⇒ Object
The query component, as defined in RFC 3986, contains non-hierarchical data that, along with data in the path component, serves to identify a resource within the scope of the URI’s scheme and naming authority (if any).
-
#scheme ⇒ Object
The scheme identifies the protocol to be used to access the resource on the Internet.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns the key-value map of all the JSON attributes this model knows about, including the ones defined in its parent(s).
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about, including the ones defined in its parent(s).
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_all_of ⇒ Object
List of class defined in allOf (OpenAPI v3).
-
.openapi_discriminator_name ⇒ Object
discriminator’s property name in OpenAPI v3.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ConnectorUrl
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ ConnectorUrl
Initializes the object
134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 |
# File 'lib/intersight_client/models/connector_url.rb', line 134 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `IntersightClient::ConnectorUrl` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `#{self.class.name}`. Please check the name to make sure it's valid. List of attributes: " + self.class.acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } # call parent's initialize super(attributes) if attributes.key?(:'class_id') self.class_id = attributes[:'class_id'] else self.class_id = 'connector.Url' end if attributes.key?(:'object_type') self.object_type = attributes[:'object_type'] else self.object_type = 'connector.Url' end if attributes.key?(:'force_query') self.force_query = attributes[:'force_query'] end if attributes.key?(:'fragment') self.fragment = attributes[:'fragment'] end if attributes.key?(:'host') self.host = attributes[:'host'] end if attributes.key?(:'opaque') self.opaque = attributes[:'opaque'] end if attributes.key?(:'path') self.path = attributes[:'path'] end if attributes.key?(:'raw_path') self.raw_path = attributes[:'raw_path'] end if attributes.key?(:'raw_query') self.raw_query = attributes[:'raw_query'] end if attributes.key?(:'scheme') self.scheme = attributes[:'scheme'] end end |
Instance Attribute Details
#class_id ⇒ Object
The fully-qualified name of the instantiated, concrete type. This property is used as a discriminator to identify the type of the payload when marshaling and unmarshaling data.
20 21 22 |
# File 'lib/intersight_client/models/connector_url.rb', line 20 def class_id @class_id end |
#force_query ⇒ Object
Flag to append a query to the url even if rawQuery is empty.
26 27 28 |
# File 'lib/intersight_client/models/connector_url.rb', line 26 def force_query @force_query end |
#fragment ⇒ Object
The fragment identifier component of a URI allows indirect identification of a secondary resource by reference to a primary resource and additional identifying information. The identified secondary resource may be some portion or subset of the primary resource, some view on representations of the primary resource, or some other resource defined or described by those representations. A fragment identifier component is indicated by the presence of a number sign ("#") character and terminated by the end of the URI.
29 30 31 |
# File 'lib/intersight_client/models/connector_url.rb', line 29 def fragment @fragment end |
#host ⇒ Object
The host name identifies the host that holds the resource. The host can be an IP or a hostname that is resolvable by the dns server configured on the platform.
32 33 34 |
# File 'lib/intersight_client/models/connector_url.rb', line 32 def host @host end |
#object_type ⇒ Object
The fully-qualified name of the instantiated, concrete type. The value should be the same as the ‘ClassId’ property.
23 24 25 |
# File 'lib/intersight_client/models/connector_url.rb', line 23 def object_type @object_type end |
#opaque ⇒ Object
A URI is opaque if, and only if, it is absolute and its scheme-specific part does not begin with a slash character (‘/’). An opaque URI has a scheme, a scheme-specific part, and possibly a fragment; all other components are undefined.
35 36 37 |
# File 'lib/intersight_client/models/connector_url.rb', line 35 def opaque @opaque end |
#path ⇒ Object
The path identifies the specific resource in the host that the web client wants to access. Value is the decoded form of the path. e.g. ‘/foo/bar’.
38 39 40 |
# File 'lib/intersight_client/models/connector_url.rb', line 38 def path @path end |
#raw_path ⇒ Object
The URI encoded form of the path property. e.g. ‘%2Fapi%2Fv1%2F’.
41 42 43 |
# File 'lib/intersight_client/models/connector_url.rb', line 41 def raw_path @raw_path end |
#raw_query ⇒ Object
The query component, as defined in RFC 3986, contains non-hierarchical data that, along with data in the path component, serves to identify a resource within the scope of the URI’s scheme and naming authority (if any). The query component is indicated by the first question mark character and terminated by a number sign character or by the end of the URI. The rawQuery contains the URIs encoded query component, excluding the ? character.
44 45 46 |
# File 'lib/intersight_client/models/connector_url.rb', line 44 def raw_query @raw_query end |
#scheme ⇒ Object
The scheme identifies the protocol to be used to access the resource on the Internet. It can be HTTP (without SSL) or HTTPS (with SSL).
47 48 49 |
# File 'lib/intersight_client/models/connector_url.rb', line 47 def scheme @scheme end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns the key-value map of all the JSON attributes this model knows about, including the ones defined in its parent(s)
93 94 95 |
# File 'lib/intersight_client/models/connector_url.rb', line 93 def self.acceptable_attribute_map attribute_map.merge(superclass.acceptable_attribute_map) end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about, including the ones defined in its parent(s)
88 89 90 |
# File 'lib/intersight_client/models/connector_url.rb', line 88 def self.acceptable_attributes attribute_map.values.concat(superclass.acceptable_attributes) end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
72 73 74 75 76 77 78 79 80 81 82 83 84 85 |
# File 'lib/intersight_client/models/connector_url.rb', line 72 def self.attribute_map { :'class_id' => :'ClassId', :'object_type' => :'ObjectType', :'force_query' => :'ForceQuery', :'fragment' => :'Fragment', :'host' => :'Host', :'opaque' => :'Opaque', :'path' => :'Path', :'raw_path' => :'RawPath', :'raw_query' => :'RawQuery', :'scheme' => :'Scheme' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
274 275 276 |
# File 'lib/intersight_client/models/connector_url.rb', line 274 def self.build_from_hash(attributes) new.build_from_hash(attributes) end |
.openapi_all_of ⇒ Object
List of class defined in allOf (OpenAPI v3)
120 121 122 123 124 125 |
# File 'lib/intersight_client/models/connector_url.rb', line 120 def self.openapi_all_of [ :'ConnectorUrlAllOf', :'MoBaseComplexType' ] end |
.openapi_discriminator_name ⇒ Object
discriminator’s property name in OpenAPI v3
128 129 130 |
# File 'lib/intersight_client/models/connector_url.rb', line 128 def self.openapi_discriminator_name :'ClassId' end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
114 115 116 117 |
# File 'lib/intersight_client/models/connector_url.rb', line 114 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
98 99 100 101 102 103 104 105 106 107 108 109 110 111 |
# File 'lib/intersight_client/models/connector_url.rb', line 98 def self.openapi_types { :'class_id' => :'String', :'object_type' => :'String', :'force_query' => :'Boolean', :'fragment' => :'String', :'host' => :'String', :'opaque' => :'String', :'path' => :'String', :'raw_path' => :'String', :'raw_query' => :'String', :'scheme' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
244 245 246 247 248 249 250 251 252 253 254 255 256 257 |
# File 'lib/intersight_client/models/connector_url.rb', line 244 def ==(o) return true if self.equal?(o) self.class == o.class && class_id == o.class_id && object_type == o.object_type && force_query == o.force_query && fragment == o.fragment && host == o.host && opaque == o.opaque && path == o.path && raw_path == o.raw_path && raw_query == o.raw_query && scheme == o.scheme && super(o) end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 |
# File 'lib/intersight_client/models/connector_url.rb', line 305 def _deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = IntersightClient.const_get(type) klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
376 377 378 379 380 381 382 383 384 385 386 387 388 |
# File 'lib/intersight_client/models/connector_url.rb', line 376 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 |
# File 'lib/intersight_client/models/connector_url.rb', line 281 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) super(attributes) ConnectorUrl.openapi_types.each_pair do |key, type| if attributes[ConnectorUrl.attribute_map[key]].nil? && ConnectorUrl.openapi_nullable.include?(key) self.send("#{key}=", nil) elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[ConnectorUrl.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[ConnectorUrl.attribute_map[key]].map { |v| _deserialize($1, v) }) end elsif !attributes[ConnectorUrl.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[ConnectorUrl.attribute_map[key]])) end end self end |
#eql?(o) ⇒ Boolean
261 262 263 |
# File 'lib/intersight_client/models/connector_url.rb', line 261 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
267 268 269 |
# File 'lib/intersight_client/models/connector_url.rb', line 267 def hash [class_id, object_type, force_query, fragment, host, opaque, path, raw_path, raw_query, scheme].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
197 198 199 200 201 202 203 204 205 206 207 208 |
# File 'lib/intersight_client/models/connector_url.rb', line 197 def list_invalid_properties invalid_properties = super if @class_id.nil? invalid_properties.push('invalid value for "class_id", class_id cannot be nil.') end if @object_type.nil? invalid_properties.push('invalid value for "object_type", object_type cannot be nil.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
352 353 354 |
# File 'lib/intersight_client/models/connector_url.rb', line 352 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
358 359 360 361 362 363 364 365 366 367 368 369 370 |
# File 'lib/intersight_client/models/connector_url.rb', line 358 def to_hash hash = super ConnectorUrl.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = ConnectorUrl.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
346 347 348 |
# File 'lib/intersight_client/models/connector_url.rb', line 346 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
212 213 214 215 216 217 218 219 220 |
# File 'lib/intersight_client/models/connector_url.rb', line 212 def valid? return false if @class_id.nil? class_id_validator = EnumAttributeValidator.new('String', ["connector.Url"]) return false unless class_id_validator.valid?(@class_id) return false if @object_type.nil? object_type_validator = EnumAttributeValidator.new('String', ["connector.Url"]) return false unless object_type_validator.valid?(@object_type) true && super end |