Class: IntersightClient::ConvergedinfraBasePodAllOf

Inherits:
Object
  • Object
show all
Defined in:
lib/intersight_client/models/convergedinfra_base_pod_all_of.rb

Overview

Definition of the list of properties defined in 'convergedinfra.BasePod', excluding properties defined in parent classes.

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ ConvergedinfraBasePodAllOf

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
# File 'lib/intersight_client/models/convergedinfra_base_pod_all_of.rb', line 96

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `IntersightClient::ConvergedinfraBasePodAllOf` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `#{self.class.name}`. Please check the name to make sure it's valid. List of attributes: " + self.class.acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'class_id')
    self.class_id = attributes[:'class_id']
  else
    self.class_id = 'convergedinfra.Pod'
  end

  if attributes.key?(:'object_type')
    self.object_type = attributes[:'object_type']
  else
    self.object_type = 'convergedinfra.Pod'
  end

  if attributes.key?(:'description')
    self.description = attributes[:'description']
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  end

  if attributes.key?(:'type')
    self.type = attributes[:'type']
  else
    self.type = 'FlexPod'
  end
end

Instance Attribute Details

#class_idObject

The fully-qualified name of the instantiated, concrete type. This property is used as a discriminator to identify the type of the payload when marshaling and unmarshaling data. The enum values provides the list of concrete types that can be instantiated from this abstract type.



20
21
22
# File 'lib/intersight_client/models/convergedinfra_base_pod_all_of.rb', line 20

def class_id
  @class_id
end

#descriptionObject

Description of the pod. A short note about the nature or purpose of the pod.



26
27
28
# File 'lib/intersight_client/models/convergedinfra_base_pod_all_of.rb', line 26

def description
  @description
end

#nameObject

Name of the pod. Concrete pod will be created with this name.



29
30
31
# File 'lib/intersight_client/models/convergedinfra_base_pod_all_of.rb', line 29

def name
  @name
end

#object_typeObject

The fully-qualified name of the instantiated, concrete type. The value should be the same as the 'ClassId' property. The enum values provides the list of concrete types that can be instantiated from this abstract type.



23
24
25
# File 'lib/intersight_client/models/convergedinfra_base_pod_all_of.rb', line 23

def object_type
  @object_type
end

#typeObject

Defines the type of the pod. * FlexPod - Pod type is FlexPod, an integrated infrastructure solution developed by Cisco and NetApp. * FlashStack - Pod type is FlashStack, an integrated infrastructure solution developed by Cisco and Pure Storage.



32
33
34
# File 'lib/intersight_client/models/convergedinfra_base_pod_all_of.rb', line 32

def type
  @type
end

Class Method Details

.acceptable_attribute_mapObject

Returns the key-value map of all the JSON attributes this model knows about



73
74
75
# File 'lib/intersight_client/models/convergedinfra_base_pod_all_of.rb', line 73

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



68
69
70
# File 'lib/intersight_client/models/convergedinfra_base_pod_all_of.rb', line 68

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



57
58
59
60
61
62
63
64
65
# File 'lib/intersight_client/models/convergedinfra_base_pod_all_of.rb', line 57

def self.attribute_map
  {
    :'class_id' => :'ClassId',
    :'object_type' => :'ObjectType',
    :'description' => :'Description',
    :'name' => :'Name',
    :'type' => :'Type'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



265
266
267
# File 'lib/intersight_client/models/convergedinfra_base_pod_all_of.rb', line 265

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_nullableObject

List of attributes with nullable: true



89
90
91
92
# File 'lib/intersight_client/models/convergedinfra_base_pod_all_of.rb', line 89

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



78
79
80
81
82
83
84
85
86
# File 'lib/intersight_client/models/convergedinfra_base_pod_all_of.rb', line 78

def self.openapi_types
  {
    :'class_id' => :'String',
    :'object_type' => :'String',
    :'description' => :'String',
    :'name' => :'String',
    :'type' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



240
241
242
243
244
245
246
247
248
# File 'lib/intersight_client/models/convergedinfra_base_pod_all_of.rb', line 240

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      class_id == o.class_id &&
      object_type == o.object_type &&
      description == o.description &&
      name == o.name &&
      type == o.type
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
# File 'lib/intersight_client/models/convergedinfra_base_pod_all_of.rb', line 295

def _deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = IntersightClient.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



366
367
368
369
370
371
372
373
374
375
376
377
378
# File 'lib/intersight_client/models/convergedinfra_base_pod_all_of.rb', line 366

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
# File 'lib/intersight_client/models/convergedinfra_base_pod_all_of.rb', line 272

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  ConvergedinfraBasePodAllOf.openapi_types.each_pair do |key, type|
    if attributes[ConvergedinfraBasePodAllOf.attribute_map[key]].nil? && ConvergedinfraBasePodAllOf.openapi_nullable.include?(key)
      self.send("#{key}=", nil)
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[ConvergedinfraBasePodAllOf.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[ConvergedinfraBasePodAllOf.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[ConvergedinfraBasePodAllOf.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[ConvergedinfraBasePodAllOf.attribute_map[key]]))
    end
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


252
253
254
# File 'lib/intersight_client/models/convergedinfra_base_pod_all_of.rb', line 252

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



258
259
260
# File 'lib/intersight_client/models/convergedinfra_base_pod_all_of.rb', line 258

def hash
  [class_id, object_type, description, name, type].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
# File 'lib/intersight_client/models/convergedinfra_base_pod_all_of.rb', line 138

def list_invalid_properties
  invalid_properties = Array.new
  if @class_id.nil?
    invalid_properties.push('invalid value for "class_id", class_id cannot be nil.')
  end

  if @object_type.nil?
    invalid_properties.push('invalid value for "object_type", object_type cannot be nil.')
  end

  if !@description.nil? && @description.to_s.length > 1024
    invalid_properties.push('invalid value for "description", the character length must be smaller than or equal to 1024.')
  end

  pattern = Regexp.new(/^$|^[a-zA-Z0-9]+[\x00-\u00FF]*$/)
  if !@description.nil? && @description !~ pattern
    invalid_properties.push("invalid value for \"description\", must conform to the pattern #{pattern}.")
  end

  pattern = Regexp.new(/^[a-zA-Z0-9_.-]{1,64}$/)
  if !@name.nil? && @name !~ pattern
    invalid_properties.push("invalid value for \"name\", must conform to the pattern #{pattern}.")
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



342
343
344
# File 'lib/intersight_client/models/convergedinfra_base_pod_all_of.rb', line 342

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



348
349
350
351
352
353
354
355
356
357
358
359
360
# File 'lib/intersight_client/models/convergedinfra_base_pod_all_of.rb', line 348

def to_hash
  hash = {}
  ConvergedinfraBasePodAllOf.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = ConvergedinfraBasePodAllOf.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



336
337
338
# File 'lib/intersight_client/models/convergedinfra_base_pod_all_of.rb', line 336

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



167
168
169
170
171
172
173
174
175
176
177
178
179
180
# File 'lib/intersight_client/models/convergedinfra_base_pod_all_of.rb', line 167

def valid?
  return false if @class_id.nil?
  class_id_validator = EnumAttributeValidator.new('String', ["convergedinfra.Pod"])
  return false unless class_id_validator.valid?(@class_id)
  return false if @object_type.nil?
  object_type_validator = EnumAttributeValidator.new('String', ["convergedinfra.Pod"])
  return false unless object_type_validator.valid?(@object_type)
  return false if !@description.nil? && @description.to_s.length > 1024
  return false if !@description.nil? && @description !~ Regexp.new(/^$|^[a-zA-Z0-9]+[\x00-\u00FF]*$/)
  return false if !@name.nil? && @name !~ Regexp.new(/^[a-zA-Z0-9_.-]{1,64}$/)
  type_validator = EnumAttributeValidator.new('String', ["FlexPod", "FlashStack"])
  return false unless type_validator.valid?(@type)
  true
end