Class: IntersightClient::ConvergedinfraBasePodSummaryAllOf

Inherits:
Object
  • Object
show all
Defined in:
lib/intersight_client/models/convergedinfra_base_pod_summary_all_of.rb

Overview

Definition of the list of properties defined in 'convergedinfra.BasePodSummary', excluding properties defined in parent classes.

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ ConvergedinfraBasePodSummaryAllOf

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
# File 'lib/intersight_client/models/convergedinfra_base_pod_summary_all_of.rb', line 111

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `IntersightClient::ConvergedinfraBasePodSummaryAllOf` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `#{self.class.name}`. Please check the name to make sure it's valid. List of attributes: " + self.class.acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'class_id')
    self.class_id = attributes[:'class_id']
  else
    self.class_id = 'convergedinfra.PodSummary'
  end

  if attributes.key?(:'object_type')
    self.object_type = attributes[:'object_type']
  else
    self.object_type = 'convergedinfra.PodSummary'
  end

  if attributes.key?(:'alarm_summary')
    self.alarm_summary = attributes[:'alarm_summary']
  end

  if attributes.key?(:'compliance_summary')
    self.compliance_summary = attributes[:'compliance_summary']
  end

  if attributes.key?(:'node_count')
    self.node_count = attributes[:'node_count']
  end

  if attributes.key?(:'storage_available')
    self.storage_available = attributes[:'storage_available']
  end

  if attributes.key?(:'storage_capacity')
    self.storage_capacity = attributes[:'storage_capacity']
  end

  if attributes.key?(:'storage_utilization')
    self.storage_utilization = attributes[:'storage_utilization']
  end
end

Instance Attribute Details

#alarm_summaryObject

Returns the value of attribute alarm_summary.



25
26
27
# File 'lib/intersight_client/models/convergedinfra_base_pod_summary_all_of.rb', line 25

def alarm_summary
  @alarm_summary
end

#class_idObject

The fully-qualified name of the instantiated, concrete type. This property is used as a discriminator to identify the type of the payload when marshaling and unmarshaling data. The enum values provides the list of concrete types that can be instantiated from this abstract type.



20
21
22
# File 'lib/intersight_client/models/convergedinfra_base_pod_summary_all_of.rb', line 20

def class_id
  @class_id
end

#compliance_summaryObject

Returns the value of attribute compliance_summary.



27
28
29
# File 'lib/intersight_client/models/convergedinfra_base_pod_summary_all_of.rb', line 27

def compliance_summary
  @compliance_summary
end

#node_countObject

Number of nodes associated with the pod.



30
31
32
# File 'lib/intersight_client/models/convergedinfra_base_pod_summary_all_of.rb', line 30

def node_count
  @node_count
end

#object_typeObject

The fully-qualified name of the instantiated, concrete type. The value should be the same as the 'ClassId' property. The enum values provides the list of concrete types that can be instantiated from this abstract type.



23
24
25
# File 'lib/intersight_client/models/convergedinfra_base_pod_summary_all_of.rb', line 23

def object_type
  @object_type
end

#storage_availableObject

The available storage capacity for this pod.



33
34
35
# File 'lib/intersight_client/models/convergedinfra_base_pod_summary_all_of.rb', line 33

def storage_available
  @storage_available
end

#storage_capacityObject

The total storage capacity for this pod.



36
37
38
# File 'lib/intersight_client/models/convergedinfra_base_pod_summary_all_of.rb', line 36

def storage_capacity
  @storage_capacity
end

#storage_utilizationObject

The percentage storage utilization for this pod.



39
40
41
# File 'lib/intersight_client/models/convergedinfra_base_pod_summary_all_of.rb', line 39

def storage_utilization
  @storage_utilization
end

Class Method Details

.acceptable_attribute_mapObject

Returns the key-value map of all the JSON attributes this model knows about



83
84
85
# File 'lib/intersight_client/models/convergedinfra_base_pod_summary_all_of.rb', line 83

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



78
79
80
# File 'lib/intersight_client/models/convergedinfra_base_pod_summary_all_of.rb', line 78

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



64
65
66
67
68
69
70
71
72
73
74
75
# File 'lib/intersight_client/models/convergedinfra_base_pod_summary_all_of.rb', line 64

def self.attribute_map
  {
    :'class_id' => :'ClassId',
    :'object_type' => :'ObjectType',
    :'alarm_summary' => :'AlarmSummary',
    :'compliance_summary' => :'ComplianceSummary',
    :'node_count' => :'NodeCount',
    :'storage_available' => :'StorageAvailable',
    :'storage_capacity' => :'StorageCapacity',
    :'storage_utilization' => :'StorageUtilization'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



238
239
240
# File 'lib/intersight_client/models/convergedinfra_base_pod_summary_all_of.rb', line 238

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_nullableObject

List of attributes with nullable: true



102
103
104
105
106
107
# File 'lib/intersight_client/models/convergedinfra_base_pod_summary_all_of.rb', line 102

def self.openapi_nullable
  Set.new([
    :'alarm_summary',
    :'compliance_summary',
  ])
end

.openapi_typesObject

Attribute type mapping.



88
89
90
91
92
93
94
95
96
97
98
99
# File 'lib/intersight_client/models/convergedinfra_base_pod_summary_all_of.rb', line 88

def self.openapi_types
  {
    :'class_id' => :'String',
    :'object_type' => :'String',
    :'alarm_summary' => :'ConvergedinfraAlarmSummary',
    :'compliance_summary' => :'ConvergedinfraComplianceSummary',
    :'node_count' => :'Integer',
    :'storage_available' => :'Integer',
    :'storage_capacity' => :'Integer',
    :'storage_utilization' => :'Float'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



210
211
212
213
214
215
216
217
218
219
220
221
# File 'lib/intersight_client/models/convergedinfra_base_pod_summary_all_of.rb', line 210

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      class_id == o.class_id &&
      object_type == o.object_type &&
      alarm_summary == o.alarm_summary &&
      compliance_summary == o.compliance_summary &&
      node_count == o.node_count &&
      storage_available == o.storage_available &&
      storage_capacity == o.storage_capacity &&
      storage_utilization == o.storage_utilization
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
# File 'lib/intersight_client/models/convergedinfra_base_pod_summary_all_of.rb', line 268

def _deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = IntersightClient.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



339
340
341
342
343
344
345
346
347
348
349
350
351
# File 'lib/intersight_client/models/convergedinfra_base_pod_summary_all_of.rb', line 339

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
# File 'lib/intersight_client/models/convergedinfra_base_pod_summary_all_of.rb', line 245

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  ConvergedinfraBasePodSummaryAllOf.openapi_types.each_pair do |key, type|
    if attributes[ConvergedinfraBasePodSummaryAllOf.attribute_map[key]].nil? && ConvergedinfraBasePodSummaryAllOf.openapi_nullable.include?(key)
      self.send("#{key}=", nil)
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[ConvergedinfraBasePodSummaryAllOf.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[ConvergedinfraBasePodSummaryAllOf.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[ConvergedinfraBasePodSummaryAllOf.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[ConvergedinfraBasePodSummaryAllOf.attribute_map[key]]))
    end
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


225
226
227
# File 'lib/intersight_client/models/convergedinfra_base_pod_summary_all_of.rb', line 225

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



231
232
233
# File 'lib/intersight_client/models/convergedinfra_base_pod_summary_all_of.rb', line 231

def hash
  [class_id, object_type, alarm_summary, compliance_summary, node_count, storage_available, storage_capacity, storage_utilization].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



163
164
165
166
167
168
169
170
171
172
173
174
# File 'lib/intersight_client/models/convergedinfra_base_pod_summary_all_of.rb', line 163

def list_invalid_properties
  invalid_properties = Array.new
  if @class_id.nil?
    invalid_properties.push('invalid value for "class_id", class_id cannot be nil.')
  end

  if @object_type.nil?
    invalid_properties.push('invalid value for "object_type", object_type cannot be nil.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



315
316
317
# File 'lib/intersight_client/models/convergedinfra_base_pod_summary_all_of.rb', line 315

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



321
322
323
324
325
326
327
328
329
330
331
332
333
# File 'lib/intersight_client/models/convergedinfra_base_pod_summary_all_of.rb', line 321

def to_hash
  hash = {}
  ConvergedinfraBasePodSummaryAllOf.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = ConvergedinfraBasePodSummaryAllOf.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



309
310
311
# File 'lib/intersight_client/models/convergedinfra_base_pod_summary_all_of.rb', line 309

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



178
179
180
181
182
183
184
185
186
# File 'lib/intersight_client/models/convergedinfra_base_pod_summary_all_of.rb', line 178

def valid?
  return false if @class_id.nil?
  class_id_validator = EnumAttributeValidator.new('String', ["convergedinfra.PodSummary"])
  return false unless class_id_validator.valid?(@class_id)
  return false if @object_type.nil?
  object_type_validator = EnumAttributeValidator.new('String', ["convergedinfra.PodSummary"])
  return false unless object_type_validator.valid?(@object_type)
  true
end