Class: IntersightClient::EquipmentIoCardAllOf

Inherits:
Object
  • Object
show all
Defined in:
lib/intersight_client/models/equipment_io_card_all_of.rb

Overview

Definition of the list of properties defined in 'equipment.IoCard', excluding properties defined in parent classes.

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ EquipmentIoCardAllOf

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
# File 'lib/intersight_client/models/equipment_io_card_all_of.rb', line 127

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `IntersightClient::EquipmentIoCardAllOf` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `#{self.class.name}`. Please check the name to make sure it's valid. List of attributes: " + self.class.acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'class_id')
    self.class_id = attributes[:'class_id']
  else
    self.class_id = 'equipment.IoCard'
  end

  if attributes.key?(:'object_type')
    self.object_type = attributes[:'object_type']
  else
    self.object_type = 'equipment.IoCard'
  end

  if attributes.key?(:'connection_path')
    self.connection_path = attributes[:'connection_path']
  end

  if attributes.key?(:'dc_supported')
    self.dc_supported = attributes[:'dc_supported']
  end

  if attributes.key?(:'inband_ip_addresses')
    if (value = attributes[:'inband_ip_addresses']).is_a?(Array)
      self.inband_ip_addresses = value
    end
  end

  if attributes.key?(:'side')
    self.side = attributes[:'side']
  end

  if attributes.key?(:'equipment_chassis')
    self.equipment_chassis = attributes[:'equipment_chassis']
  end

  if attributes.key?(:'equipment_fex')
    self.equipment_fex = attributes[:'equipment_fex']
  end

  if attributes.key?(:'fan_modules')
    if (value = attributes[:'fan_modules']).is_a?(Array)
      self.fan_modules = value
    end
  end

  if attributes.key?(:'inventory_device_info')
    self.inventory_device_info = attributes[:'inventory_device_info']
  end

  if attributes.key?(:'physical_device_registration')
    self.physical_device_registration = attributes[:'physical_device_registration']
  end

  if attributes.key?(:'registered_device')
    self.registered_device = attributes[:'registered_device']
  end
end

Instance Attribute Details

#class_idObject

The fully-qualified name of the instantiated, concrete type. This property is used as a discriminator to identify the type of the payload when marshaling and unmarshaling data.



20
21
22
# File 'lib/intersight_client/models/equipment_io_card_all_of.rb', line 20

def class_id
  @class_id
end

#connection_pathObject

Switch Id to which the IOM is connected to. The value can be A or B.



26
27
28
# File 'lib/intersight_client/models/equipment_io_card_all_of.rb', line 26

def connection_path
  @connection_path
end

#dc_supportedObject

IOM device connector support.



29
30
31
# File 'lib/intersight_client/models/equipment_io_card_all_of.rb', line 29

def dc_supported
  @dc_supported
end

#equipment_chassisObject

Returns the value of attribute equipment_chassis.



36
37
38
# File 'lib/intersight_client/models/equipment_io_card_all_of.rb', line 36

def equipment_chassis
  @equipment_chassis
end

#equipment_fexObject

Returns the value of attribute equipment_fex.



38
39
40
# File 'lib/intersight_client/models/equipment_io_card_all_of.rb', line 38

def equipment_fex
  @equipment_fex
end

#fan_modulesObject

An array of relationships to equipmentFanModule resources.



41
42
43
# File 'lib/intersight_client/models/equipment_io_card_all_of.rb', line 41

def fan_modules
  @fan_modules
end

#inband_ip_addressesObject

Returns the value of attribute inband_ip_addresses.



31
32
33
# File 'lib/intersight_client/models/equipment_io_card_all_of.rb', line 31

def inband_ip_addresses
  @inband_ip_addresses
end

#inventory_device_infoObject

Returns the value of attribute inventory_device_info.



43
44
45
# File 'lib/intersight_client/models/equipment_io_card_all_of.rb', line 43

def inventory_device_info
  @inventory_device_info
end

#object_typeObject

The fully-qualified name of the instantiated, concrete type. The value should be the same as the 'ClassId' property.



23
24
25
# File 'lib/intersight_client/models/equipment_io_card_all_of.rb', line 23

def object_type
  @object_type
end

#physical_device_registrationObject

Returns the value of attribute physical_device_registration.



45
46
47
# File 'lib/intersight_client/models/equipment_io_card_all_of.rb', line 45

def physical_device_registration
  @physical_device_registration
end

#registered_deviceObject

Returns the value of attribute registered_device.



47
48
49
# File 'lib/intersight_client/models/equipment_io_card_all_of.rb', line 47

def registered_device
  @registered_device
end

#sideObject

Location of IOM within a chassis. The value can be left or right.



34
35
36
# File 'lib/intersight_client/models/equipment_io_card_all_of.rb', line 34

def side
  @side
end

Class Method Details

.acceptable_attribute_mapObject

Returns the key-value map of all the JSON attributes this model knows about



95
96
97
# File 'lib/intersight_client/models/equipment_io_card_all_of.rb', line 95

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



90
91
92
# File 'lib/intersight_client/models/equipment_io_card_all_of.rb', line 90

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
# File 'lib/intersight_client/models/equipment_io_card_all_of.rb', line 72

def self.attribute_map
  {
    :'class_id' => :'ClassId',
    :'object_type' => :'ObjectType',
    :'connection_path' => :'ConnectionPath',
    :'dc_supported' => :'DcSupported',
    :'inband_ip_addresses' => :'InbandIpAddresses',
    :'side' => :'Side',
    :'equipment_chassis' => :'EquipmentChassis',
    :'equipment_fex' => :'EquipmentFex',
    :'fan_modules' => :'FanModules',
    :'inventory_device_info' => :'InventoryDeviceInfo',
    :'physical_device_registration' => :'PhysicalDeviceRegistration',
    :'registered_device' => :'RegisteredDevice'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



278
279
280
# File 'lib/intersight_client/models/equipment_io_card_all_of.rb', line 278

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_nullableObject

List of attributes with nullable: true



118
119
120
121
122
123
# File 'lib/intersight_client/models/equipment_io_card_all_of.rb', line 118

def self.openapi_nullable
  Set.new([
    :'inband_ip_addresses',
    :'fan_modules',
  ])
end

.openapi_typesObject

Attribute type mapping.



100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
# File 'lib/intersight_client/models/equipment_io_card_all_of.rb', line 100

def self.openapi_types
  {
    :'class_id' => :'String',
    :'object_type' => :'String',
    :'connection_path' => :'String',
    :'dc_supported' => :'Boolean',
    :'inband_ip_addresses' => :'Array<ComputeIpAddress>',
    :'side' => :'String',
    :'equipment_chassis' => :'EquipmentChassisRelationship',
    :'equipment_fex' => :'EquipmentFexRelationship',
    :'fan_modules' => :'Array<EquipmentFanModuleRelationship>',
    :'inventory_device_info' => :'InventoryDeviceInfoRelationship',
    :'physical_device_registration' => :'AssetDeviceRegistrationRelationship',
    :'registered_device' => :'AssetDeviceRegistrationRelationship'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
# File 'lib/intersight_client/models/equipment_io_card_all_of.rb', line 246

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      class_id == o.class_id &&
      object_type == o.object_type &&
      connection_path == o.connection_path &&
      dc_supported == o.dc_supported &&
      inband_ip_addresses == o.inband_ip_addresses &&
      side == o.side &&
      equipment_chassis == o.equipment_chassis &&
      equipment_fex == o.equipment_fex &&
      fan_modules == o.fan_modules &&
      inventory_device_info == o.inventory_device_info &&
      physical_device_registration == o.physical_device_registration &&
      registered_device == o.registered_device
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
# File 'lib/intersight_client/models/equipment_io_card_all_of.rb', line 308

def _deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = IntersightClient.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



379
380
381
382
383
384
385
386
387
388
389
390
391
# File 'lib/intersight_client/models/equipment_io_card_all_of.rb', line 379

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
# File 'lib/intersight_client/models/equipment_io_card_all_of.rb', line 285

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  EquipmentIoCardAllOf.openapi_types.each_pair do |key, type|
    if attributes[EquipmentIoCardAllOf.attribute_map[key]].nil? && EquipmentIoCardAllOf.openapi_nullable.include?(key)
      self.send("#{key}=", nil)
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[EquipmentIoCardAllOf.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[EquipmentIoCardAllOf.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[EquipmentIoCardAllOf.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[EquipmentIoCardAllOf.attribute_map[key]]))
    end
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


265
266
267
# File 'lib/intersight_client/models/equipment_io_card_all_of.rb', line 265

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



271
272
273
# File 'lib/intersight_client/models/equipment_io_card_all_of.rb', line 271

def hash
  [class_id, object_type, connection_path, dc_supported, inband_ip_addresses, side, equipment_chassis, equipment_fex, fan_modules, inventory_device_info, physical_device_registration, registered_device].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



199
200
201
202
203
204
205
206
207
208
209
210
# File 'lib/intersight_client/models/equipment_io_card_all_of.rb', line 199

def list_invalid_properties
  invalid_properties = Array.new
  if @class_id.nil?
    invalid_properties.push('invalid value for "class_id", class_id cannot be nil.')
  end

  if @object_type.nil?
    invalid_properties.push('invalid value for "object_type", object_type cannot be nil.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



355
356
357
# File 'lib/intersight_client/models/equipment_io_card_all_of.rb', line 355

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



361
362
363
364
365
366
367
368
369
370
371
372
373
# File 'lib/intersight_client/models/equipment_io_card_all_of.rb', line 361

def to_hash
  hash = {}
  EquipmentIoCardAllOf.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = EquipmentIoCardAllOf.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



349
350
351
# File 'lib/intersight_client/models/equipment_io_card_all_of.rb', line 349

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



214
215
216
217
218
219
220
221
222
# File 'lib/intersight_client/models/equipment_io_card_all_of.rb', line 214

def valid?
  return false if @class_id.nil?
  class_id_validator = EnumAttributeValidator.new('String', ["equipment.IoCard"])
  return false unless class_id_validator.valid?(@class_id)
  return false if @object_type.nil?
  object_type_validator = EnumAttributeValidator.new('String', ["equipment.IoCard"])
  return false unless object_type_validator.valid?(@object_type)
  true
end