Class: IntersightClient::EquipmentIoCardBaseAllOf
- Inherits:
-
Object
- Object
- IntersightClient::EquipmentIoCardBaseAllOf
- Defined in:
- lib/intersight_client/models/equipment_io_card_base_all_of.rb
Overview
Definition of the list of properties defined in 'equipment.IoCardBase', excluding properties defined in parent classes.
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#class_id ⇒ Object
The fully-qualified name of the instantiated, concrete type.
-
#connection_status ⇒ Object
Connectivity Status of FEX/IOM to Switch - A or B or AB.
-
#description ⇒ Object
This field is to provide description for the iocard module model.
-
#host_ports ⇒ Object
An array of relationships to etherHostPort resources.
-
#mgmt_controller ⇒ Object
Returns the value of attribute mgmt_controller.
-
#module_id ⇒ Object
Module Identifier for the IO module.
-
#network_ports ⇒ Object
An array of relationships to etherNetworkPort resources.
-
#object_type ⇒ Object
The fully-qualified name of the instantiated, concrete type.
-
#oper_reason ⇒ Object
Returns the value of attribute oper_reason.
-
#oper_state ⇒ Object
Operational state of IO card or fabric extender.
-
#part_number ⇒ Object
Part Number identifier for the IO module.
-
#pid ⇒ Object
This field identifies the Product ID for the IO module.
-
#product_name ⇒ Object
This field identifies the Product Name for the iocard module model.
-
#sku ⇒ Object
This field identifies the Stock Keeping Unit for the IO card module.
-
#version ⇒ Object
This field identifies the version of the IO card module.
-
#vid ⇒ Object
This field identifies the Vendor ID for the IO card module.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns the key-value map of all the JSON attributes this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ EquipmentIoCardBaseAllOf
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ EquipmentIoCardBaseAllOf
Initializes the object
152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 |
# File 'lib/intersight_client/models/equipment_io_card_base_all_of.rb', line 152 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `IntersightClient::EquipmentIoCardBaseAllOf` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `#{self.class.name}`. Please check the name to make sure it's valid. List of attributes: " + self.class.acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'class_id') self.class_id = attributes[:'class_id'] end if attributes.key?(:'object_type') self.object_type = attributes[:'object_type'] end if attributes.key?(:'connection_status') self.connection_status = attributes[:'connection_status'] end if attributes.key?(:'description') self.description = attributes[:'description'] end if attributes.key?(:'module_id') self.module_id = attributes[:'module_id'] end if attributes.key?(:'oper_reason') if (value = attributes[:'oper_reason']).is_a?(Array) self.oper_reason = value end end if attributes.key?(:'oper_state') self.oper_state = attributes[:'oper_state'] end if attributes.key?(:'part_number') self.part_number = attributes[:'part_number'] end if attributes.key?(:'pid') self.pid = attributes[:'pid'] end if attributes.key?(:'product_name') self.product_name = attributes[:'product_name'] end if attributes.key?(:'sku') self.sku = attributes[:'sku'] end if attributes.key?(:'version') self.version = attributes[:'version'] end if attributes.key?(:'vid') self.vid = attributes[:'vid'] end if attributes.key?(:'host_ports') if (value = attributes[:'host_ports']).is_a?(Array) self.host_ports = value end end if attributes.key?(:'mgmt_controller') self.mgmt_controller = attributes[:'mgmt_controller'] end if attributes.key?(:'network_ports') if (value = attributes[:'network_ports']).is_a?(Array) self.network_ports = value end end end |
Instance Attribute Details
#class_id ⇒ Object
The fully-qualified name of the instantiated, concrete type. This property is used as a discriminator to identify the type of the payload when marshaling and unmarshaling data. The enum values provides the list of concrete types that can be instantiated from this abstract type.
20 21 22 |
# File 'lib/intersight_client/models/equipment_io_card_base_all_of.rb', line 20 def class_id @class_id end |
#connection_status ⇒ Object
Connectivity Status of FEX/IOM to Switch - A or B or AB.
26 27 28 |
# File 'lib/intersight_client/models/equipment_io_card_base_all_of.rb', line 26 def connection_status @connection_status end |
#description ⇒ Object
This field is to provide description for the iocard module model.
29 30 31 |
# File 'lib/intersight_client/models/equipment_io_card_base_all_of.rb', line 29 def description @description end |
#host_ports ⇒ Object
An array of relationships to etherHostPort resources.
58 59 60 |
# File 'lib/intersight_client/models/equipment_io_card_base_all_of.rb', line 58 def host_ports @host_ports end |
#mgmt_controller ⇒ Object
Returns the value of attribute mgmt_controller.
60 61 62 |
# File 'lib/intersight_client/models/equipment_io_card_base_all_of.rb', line 60 def mgmt_controller @mgmt_controller end |
#module_id ⇒ Object
Module Identifier for the IO module.
32 33 34 |
# File 'lib/intersight_client/models/equipment_io_card_base_all_of.rb', line 32 def module_id @module_id end |
#network_ports ⇒ Object
An array of relationships to etherNetworkPort resources.
63 64 65 |
# File 'lib/intersight_client/models/equipment_io_card_base_all_of.rb', line 63 def network_ports @network_ports end |
#object_type ⇒ Object
The fully-qualified name of the instantiated, concrete type. The value should be the same as the 'ClassId' property. The enum values provides the list of concrete types that can be instantiated from this abstract type.
23 24 25 |
# File 'lib/intersight_client/models/equipment_io_card_base_all_of.rb', line 23 def object_type @object_type end |
#oper_reason ⇒ Object
Returns the value of attribute oper_reason.
34 35 36 |
# File 'lib/intersight_client/models/equipment_io_card_base_all_of.rb', line 34 def oper_reason @oper_reason end |
#oper_state ⇒ Object
Operational state of IO card or fabric extender.
37 38 39 |
# File 'lib/intersight_client/models/equipment_io_card_base_all_of.rb', line 37 def oper_state @oper_state end |
#part_number ⇒ Object
Part Number identifier for the IO module.
40 41 42 |
# File 'lib/intersight_client/models/equipment_io_card_base_all_of.rb', line 40 def part_number @part_number end |
#pid ⇒ Object
This field identifies the Product ID for the IO module.
43 44 45 |
# File 'lib/intersight_client/models/equipment_io_card_base_all_of.rb', line 43 def pid @pid end |
#product_name ⇒ Object
This field identifies the Product Name for the iocard module model.
46 47 48 |
# File 'lib/intersight_client/models/equipment_io_card_base_all_of.rb', line 46 def product_name @product_name end |
#sku ⇒ Object
This field identifies the Stock Keeping Unit for the IO card module.
49 50 51 |
# File 'lib/intersight_client/models/equipment_io_card_base_all_of.rb', line 49 def sku @sku end |
#version ⇒ Object
This field identifies the version of the IO card module.
52 53 54 |
# File 'lib/intersight_client/models/equipment_io_card_base_all_of.rb', line 52 def version @version end |
#vid ⇒ Object
This field identifies the Vendor ID for the IO card module.
55 56 57 |
# File 'lib/intersight_client/models/equipment_io_card_base_all_of.rb', line 55 def vid @vid end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns the key-value map of all the JSON attributes this model knows about
115 116 117 |
# File 'lib/intersight_client/models/equipment_io_card_base_all_of.rb', line 115 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
110 111 112 |
# File 'lib/intersight_client/models/equipment_io_card_base_all_of.rb', line 110 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 |
# File 'lib/intersight_client/models/equipment_io_card_base_all_of.rb', line 88 def self.attribute_map { :'class_id' => :'ClassId', :'object_type' => :'ObjectType', :'connection_status' => :'ConnectionStatus', :'description' => :'Description', :'module_id' => :'ModuleId', :'oper_reason' => :'OperReason', :'oper_state' => :'OperState', :'part_number' => :'PartNumber', :'pid' => :'Pid', :'product_name' => :'ProductName', :'sku' => :'Sku', :'version' => :'Version', :'vid' => :'Vid', :'host_ports' => :'HostPorts', :'mgmt_controller' => :'MgmtController', :'network_ports' => :'NetworkPorts' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
321 322 323 |
# File 'lib/intersight_client/models/equipment_io_card_base_all_of.rb', line 321 def self.build_from_hash(attributes) new.build_from_hash(attributes) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
142 143 144 145 146 147 148 |
# File 'lib/intersight_client/models/equipment_io_card_base_all_of.rb', line 142 def self.openapi_nullable Set.new([ :'oper_reason', :'host_ports', :'network_ports' ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 |
# File 'lib/intersight_client/models/equipment_io_card_base_all_of.rb', line 120 def self.openapi_types { :'class_id' => :'String', :'object_type' => :'String', :'connection_status' => :'String', :'description' => :'String', :'module_id' => :'Integer', :'oper_reason' => :'Array<String>', :'oper_state' => :'String', :'part_number' => :'String', :'pid' => :'String', :'product_name' => :'String', :'sku' => :'String', :'version' => :'String', :'vid' => :'String', :'host_ports' => :'Array<EtherHostPortRelationship>', :'mgmt_controller' => :'ManagementControllerRelationship', :'network_ports' => :'Array<EtherNetworkPortRelationship>' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 |
# File 'lib/intersight_client/models/equipment_io_card_base_all_of.rb', line 285 def ==(o) return true if self.equal?(o) self.class == o.class && class_id == o.class_id && object_type == o.object_type && connection_status == o.connection_status && description == o.description && module_id == o.module_id && oper_reason == o.oper_reason && oper_state == o.oper_state && part_number == o.part_number && pid == o.pid && product_name == o.product_name && sku == o.sku && version == o.version && vid == o.vid && host_ports == o.host_ports && mgmt_controller == o.mgmt_controller && network_ports == o.network_ports end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 |
# File 'lib/intersight_client/models/equipment_io_card_base_all_of.rb', line 351 def _deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = IntersightClient.const_get(type) klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
422 423 424 425 426 427 428 429 430 431 432 433 434 |
# File 'lib/intersight_client/models/equipment_io_card_base_all_of.rb', line 422 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 |
# File 'lib/intersight_client/models/equipment_io_card_base_all_of.rb', line 328 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) EquipmentIoCardBaseAllOf.openapi_types.each_pair do |key, type| if attributes[EquipmentIoCardBaseAllOf.attribute_map[key]].nil? && EquipmentIoCardBaseAllOf.openapi_nullable.include?(key) self.send("#{key}=", nil) elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[EquipmentIoCardBaseAllOf.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[EquipmentIoCardBaseAllOf.attribute_map[key]].map { |v| _deserialize($1, v) }) end elsif !attributes[EquipmentIoCardBaseAllOf.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[EquipmentIoCardBaseAllOf.attribute_map[key]])) end end self end |
#eql?(o) ⇒ Boolean
308 309 310 |
# File 'lib/intersight_client/models/equipment_io_card_base_all_of.rb', line 308 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
314 315 316 |
# File 'lib/intersight_client/models/equipment_io_card_base_all_of.rb', line 314 def hash [class_id, object_type, connection_status, description, module_id, oper_reason, oper_state, part_number, pid, product_name, sku, version, vid, host_ports, mgmt_controller, network_ports].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
238 239 240 241 242 243 244 245 246 247 248 249 |
# File 'lib/intersight_client/models/equipment_io_card_base_all_of.rb', line 238 def list_invalid_properties invalid_properties = Array.new if @class_id.nil? invalid_properties.push('invalid value for "class_id", class_id cannot be nil.') end if @object_type.nil? invalid_properties.push('invalid value for "object_type", object_type cannot be nil.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
398 399 400 |
# File 'lib/intersight_client/models/equipment_io_card_base_all_of.rb', line 398 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
404 405 406 407 408 409 410 411 412 413 414 415 416 |
# File 'lib/intersight_client/models/equipment_io_card_base_all_of.rb', line 404 def to_hash hash = {} EquipmentIoCardBaseAllOf.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = EquipmentIoCardBaseAllOf.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
392 393 394 |
# File 'lib/intersight_client/models/equipment_io_card_base_all_of.rb', line 392 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
253 254 255 256 257 258 259 260 261 |
# File 'lib/intersight_client/models/equipment_io_card_base_all_of.rb', line 253 def valid? return false if @class_id.nil? class_id_validator = EnumAttributeValidator.new('String', ["equipment.Fex", "equipment.IoCard"]) return false unless class_id_validator.valid?(@class_id) return false if @object_type.nil? object_type_validator = EnumAttributeValidator.new('String', ["equipment.Fex", "equipment.IoCard"]) return false unless object_type_validator.valid?(@object_type) true end |