Class: IntersightClient::EquipmentSwitchCard
- Inherits:
-
EquipmentBase
- Object
- MoBaseMo
- InventoryBase
- EquipmentBase
- IntersightClient::EquipmentSwitchCard
- Defined in:
- lib/intersight_client/models/equipment_switch_card.rb
Overview
Fixed / Removable module on a Fabric Interconnect / Switch.
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#class_id ⇒ Object
The fully-qualified name of the instantiated, concrete type.
-
#description ⇒ Object
Detailed description of this switch hardware.
-
#ethernet_switching_mode ⇒ Object
The user configured Ethernet switching mode for this switch (End-Host or Switch).
-
#fc_port_channels ⇒ Object
An array of relationships to fcPortChannel resources.
-
#fc_switching_mode ⇒ Object
The user configured FC switching mode for this switch (End-Host or Switch).
-
#inventory_device_info ⇒ Object
Returns the value of attribute inventory_device_info.
-
#network_element ⇒ Object
Returns the value of attribute network_element.
-
#num_ports ⇒ Object
Number of ports present in this switch hardware.
-
#object_type ⇒ Object
The fully-qualified name of the instantiated, concrete type.
-
#out_of_band_ip_address ⇒ Object
Field specifies this Switch’s Out-of-band IP address.
-
#out_of_band_ip_gateway ⇒ Object
Field specifies this Switch’s default gateway for the out-of-band management interface.
-
#out_of_band_ip_mask ⇒ Object
Field specifies the Netmask for this Switch’s Out-of-band IP address.
-
#port_channels ⇒ Object
An array of relationships to etherPortChannel resources.
-
#port_groups ⇒ Object
An array of relationships to portGroup resources.
-
#registered_device ⇒ Object
Returns the value of attribute registered_device.
-
#slot_id ⇒ Object
Slot identifier of the local Switch slot Interface.
-
#state ⇒ Object
Operational state of the switch hardware.
-
#switch_id ⇒ Object
Switch Identifier that is local to a cluster.
-
#thermal ⇒ Object
The Thermal status of the fabric interconnect.
Attributes inherited from EquipmentBase
#model, #presence, #previous_fru, #revision, #serial, #vendor
Attributes inherited from InventoryBase
Attributes inherited from MoBaseMo
#account_moid, #ancestors, #create_time, #display_names, #domain_group_moid, #mod_time, #moid, #owners, #parent, #permission_resources, #shared_scope, #tags, #version_context
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns the key-value map of all the JSON attributes this model knows about, including the ones defined in its parent(s).
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about, including the ones defined in its parent(s).
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_all_of ⇒ Object
List of class defined in allOf (OpenAPI v3).
-
.openapi_discriminator_name ⇒ Object
discriminator’s property name in OpenAPI v3.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ EquipmentSwitchCard
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ EquipmentSwitchCard
Initializes the object
179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 |
# File 'lib/intersight_client/models/equipment_switch_card.rb', line 179 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `IntersightClient::EquipmentSwitchCard` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `#{self.class.name}`. Please check the name to make sure it's valid. List of attributes: " + self.class.acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } # call parent's initialize super(attributes) if attributes.key?(:'class_id') self.class_id = attributes[:'class_id'] else self.class_id = 'equipment.SwitchCard' end if attributes.key?(:'object_type') self.object_type = attributes[:'object_type'] else self.object_type = 'equipment.SwitchCard' end if attributes.key?(:'description') self.description = attributes[:'description'] end if attributes.key?(:'ethernet_switching_mode') self.ethernet_switching_mode = attributes[:'ethernet_switching_mode'] else self.ethernet_switching_mode = 'end-host' end if attributes.key?(:'fc_switching_mode') self.fc_switching_mode = attributes[:'fc_switching_mode'] else self.fc_switching_mode = 'end-host' end if attributes.key?(:'num_ports') self.num_ports = attributes[:'num_ports'] end if attributes.key?(:'out_of_band_ip_address') self.out_of_band_ip_address = attributes[:'out_of_band_ip_address'] end if attributes.key?(:'out_of_band_ip_gateway') self.out_of_band_ip_gateway = attributes[:'out_of_band_ip_gateway'] end if attributes.key?(:'out_of_band_ip_mask') self.out_of_band_ip_mask = attributes[:'out_of_band_ip_mask'] end if attributes.key?(:'slot_id') self.slot_id = attributes[:'slot_id'] end if attributes.key?(:'state') self.state = attributes[:'state'] end if attributes.key?(:'switch_id') self.switch_id = attributes[:'switch_id'] end if attributes.key?(:'thermal') self.thermal = attributes[:'thermal'] else self.thermal = 'unknown' end if attributes.key?(:'fc_port_channels') if (value = attributes[:'fc_port_channels']).is_a?(Array) self.fc_port_channels = value end end if attributes.key?(:'inventory_device_info') self.inventory_device_info = attributes[:'inventory_device_info'] end if attributes.key?(:'network_element') self.network_element = attributes[:'network_element'] end if attributes.key?(:'port_channels') if (value = attributes[:'port_channels']).is_a?(Array) self.port_channels = value end end if attributes.key?(:'port_groups') if (value = attributes[:'port_groups']).is_a?(Array) self.port_groups = value end end if attributes.key?(:'registered_device') self.registered_device = attributes[:'registered_device'] end end |
Instance Attribute Details
#class_id ⇒ Object
The fully-qualified name of the instantiated, concrete type. This property is used as a discriminator to identify the type of the payload when marshaling and unmarshaling data.
20 21 22 |
# File 'lib/intersight_client/models/equipment_switch_card.rb', line 20 def class_id @class_id end |
#description ⇒ Object
Detailed description of this switch hardware.
26 27 28 |
# File 'lib/intersight_client/models/equipment_switch_card.rb', line 26 def description @description end |
#ethernet_switching_mode ⇒ Object
The user configured Ethernet switching mode for this switch (End-Host or Switch). * end-host - In end-host mode, the fabric interconnects appear to the upstream devices as end hosts with multiple links.In this mode, the switch does not run Spanning Tree Protocol and avoids loops by following a set of rules for traffic forwarding.In case of ethernet switching mode - Ethernet end-host mode is also known as Ethernet host virtualizer. * switch - In switch mode, the switch runs Spanning Tree Protocol to avoid loops, and broadcast and multicast packets are handled in the traditional way.This is the traditional switch mode.
29 30 31 |
# File 'lib/intersight_client/models/equipment_switch_card.rb', line 29 def ethernet_switching_mode @ethernet_switching_mode end |
#fc_port_channels ⇒ Object
An array of relationships to fcPortChannel resources.
59 60 61 |
# File 'lib/intersight_client/models/equipment_switch_card.rb', line 59 def fc_port_channels @fc_port_channels end |
#fc_switching_mode ⇒ Object
The user configured FC switching mode for this switch (End-Host or Switch). * end-host - In end-host mode, the fabric interconnects appear to the upstream devices as end hosts with multiple links.In this mode, the switch does not run Spanning Tree Protocol and avoids loops by following a set of rules for traffic forwarding.In case of ethernet switching mode - Ethernet end-host mode is also known as Ethernet host virtualizer. * switch - In switch mode, the switch runs Spanning Tree Protocol to avoid loops, and broadcast and multicast packets are handled in the traditional way.This is the traditional switch mode.
32 33 34 |
# File 'lib/intersight_client/models/equipment_switch_card.rb', line 32 def fc_switching_mode @fc_switching_mode end |
#inventory_device_info ⇒ Object
Returns the value of attribute inventory_device_info.
61 62 63 |
# File 'lib/intersight_client/models/equipment_switch_card.rb', line 61 def inventory_device_info @inventory_device_info end |
#network_element ⇒ Object
Returns the value of attribute network_element.
63 64 65 |
# File 'lib/intersight_client/models/equipment_switch_card.rb', line 63 def network_element @network_element end |
#num_ports ⇒ Object
Number of ports present in this switch hardware.
35 36 37 |
# File 'lib/intersight_client/models/equipment_switch_card.rb', line 35 def num_ports @num_ports end |
#object_type ⇒ Object
The fully-qualified name of the instantiated, concrete type. The value should be the same as the ‘ClassId’ property.
23 24 25 |
# File 'lib/intersight_client/models/equipment_switch_card.rb', line 23 def object_type @object_type end |
#out_of_band_ip_address ⇒ Object
Field specifies this Switch’s Out-of-band IP address.
38 39 40 |
# File 'lib/intersight_client/models/equipment_switch_card.rb', line 38 def out_of_band_ip_address @out_of_band_ip_address end |
#out_of_band_ip_gateway ⇒ Object
Field specifies this Switch’s default gateway for the out-of-band management interface.
41 42 43 |
# File 'lib/intersight_client/models/equipment_switch_card.rb', line 41 def out_of_band_ip_gateway @out_of_band_ip_gateway end |
#out_of_band_ip_mask ⇒ Object
Field specifies the Netmask for this Switch’s Out-of-band IP address.
44 45 46 |
# File 'lib/intersight_client/models/equipment_switch_card.rb', line 44 def out_of_band_ip_mask @out_of_band_ip_mask end |
#port_channels ⇒ Object
An array of relationships to etherPortChannel resources.
66 67 68 |
# File 'lib/intersight_client/models/equipment_switch_card.rb', line 66 def port_channels @port_channels end |
#port_groups ⇒ Object
An array of relationships to portGroup resources.
69 70 71 |
# File 'lib/intersight_client/models/equipment_switch_card.rb', line 69 def port_groups @port_groups end |
#registered_device ⇒ Object
Returns the value of attribute registered_device.
71 72 73 |
# File 'lib/intersight_client/models/equipment_switch_card.rb', line 71 def registered_device @registered_device end |
#slot_id ⇒ Object
Slot identifier of the local Switch slot Interface.
47 48 49 |
# File 'lib/intersight_client/models/equipment_switch_card.rb', line 47 def slot_id @slot_id end |
#state ⇒ Object
Operational state of the switch hardware.
50 51 52 |
# File 'lib/intersight_client/models/equipment_switch_card.rb', line 50 def state @state end |
#switch_id ⇒ Object
Switch Identifier that is local to a cluster.
53 54 55 |
# File 'lib/intersight_client/models/equipment_switch_card.rb', line 53 def switch_id @switch_id end |
#thermal ⇒ Object
The Thermal status of the fabric interconnect. * unknown - The default state of the sensor (in case no data is received). * ok - State of the sensor indicating the sensor’s temperature range is okay. * upper-non-recoverable - State of the sensor indicating that the temperature is extremely high above normal range. * upper-critical - State of the sensor indicating that the temperature is above normal range. * upper-non-critical - State of the sensor indicating that the temperature is a little above the normal range. * lower-non-critical - State of the sensor indicating that the temperature is a little below the normal range. * lower-critical - State of the sensor indicating that the temperature is below normal range. * lower-non-recoverable - State of the sensor indicating that the temperature is extremely below normal range.
56 57 58 |
# File 'lib/intersight_client/models/equipment_switch_card.rb', line 56 def thermal @thermal end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns the key-value map of all the JSON attributes this model knows about, including the ones defined in its parent(s)
126 127 128 |
# File 'lib/intersight_client/models/equipment_switch_card.rb', line 126 def self.acceptable_attribute_map attribute_map.merge(superclass.acceptable_attribute_map) end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about, including the ones defined in its parent(s)
121 122 123 |
# File 'lib/intersight_client/models/equipment_switch_card.rb', line 121 def self.acceptable_attributes attribute_map.values.concat(superclass.acceptable_attributes) end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 |
# File 'lib/intersight_client/models/equipment_switch_card.rb', line 96 def self.attribute_map { :'class_id' => :'ClassId', :'object_type' => :'ObjectType', :'description' => :'Description', :'ethernet_switching_mode' => :'EthernetSwitchingMode', :'fc_switching_mode' => :'FcSwitchingMode', :'num_ports' => :'NumPorts', :'out_of_band_ip_address' => :'OutOfBandIpAddress', :'out_of_band_ip_gateway' => :'OutOfBandIpGateway', :'out_of_band_ip_mask' => :'OutOfBandIpMask', :'slot_id' => :'SlotId', :'state' => :'State', :'switch_id' => :'SwitchId', :'thermal' => :'Thermal', :'fc_port_channels' => :'FcPortChannels', :'inventory_device_info' => :'InventoryDeviceInfo', :'network_element' => :'NetworkElement', :'port_channels' => :'PortChannels', :'port_groups' => :'PortGroups', :'registered_device' => :'RegisteredDevice' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
412 413 414 |
# File 'lib/intersight_client/models/equipment_switch_card.rb', line 412 def self.build_from_hash(attributes) new.build_from_hash(attributes) end |
.openapi_all_of ⇒ Object
List of class defined in allOf (OpenAPI v3)
165 166 167 168 169 170 |
# File 'lib/intersight_client/models/equipment_switch_card.rb', line 165 def self.openapi_all_of [ :'EquipmentBase', :'EquipmentSwitchCardAllOf' ] end |
.openapi_discriminator_name ⇒ Object
discriminator’s property name in OpenAPI v3
173 174 175 |
# File 'lib/intersight_client/models/equipment_switch_card.rb', line 173 def self.openapi_discriminator_name :'ClassId' end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
156 157 158 159 160 161 162 |
# File 'lib/intersight_client/models/equipment_switch_card.rb', line 156 def self.openapi_nullable Set.new([ :'fc_port_channels', :'port_channels', :'port_groups', ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 |
# File 'lib/intersight_client/models/equipment_switch_card.rb', line 131 def self.openapi_types { :'class_id' => :'String', :'object_type' => :'String', :'description' => :'String', :'ethernet_switching_mode' => :'String', :'fc_switching_mode' => :'String', :'num_ports' => :'Integer', :'out_of_band_ip_address' => :'String', :'out_of_band_ip_gateway' => :'String', :'out_of_band_ip_mask' => :'String', :'slot_id' => :'Integer', :'state' => :'String', :'switch_id' => :'String', :'thermal' => :'String', :'fc_port_channels' => :'Array<FcPortChannelRelationship>', :'inventory_device_info' => :'InventoryDeviceInfoRelationship', :'network_element' => :'NetworkElementRelationship', :'port_channels' => :'Array<EtherPortChannelRelationship>', :'port_groups' => :'Array<PortGroupRelationship>', :'registered_device' => :'AssetDeviceRegistrationRelationship' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 |
# File 'lib/intersight_client/models/equipment_switch_card.rb', line 373 def ==(o) return true if self.equal?(o) self.class == o.class && class_id == o.class_id && object_type == o.object_type && description == o.description && ethernet_switching_mode == o.ethernet_switching_mode && fc_switching_mode == o.fc_switching_mode && num_ports == o.num_ports && out_of_band_ip_address == o.out_of_band_ip_address && out_of_band_ip_gateway == o.out_of_band_ip_gateway && out_of_band_ip_mask == o.out_of_band_ip_mask && slot_id == o.slot_id && state == o.state && switch_id == o.switch_id && thermal == o.thermal && fc_port_channels == o.fc_port_channels && inventory_device_info == o.inventory_device_info && network_element == o.network_element && port_channels == o.port_channels && port_groups == o.port_groups && registered_device == o.registered_device && super(o) end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
443 444 445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 463 464 465 466 467 468 469 470 471 472 473 474 475 476 477 478 479 480 |
# File 'lib/intersight_client/models/equipment_switch_card.rb', line 443 def _deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = IntersightClient.const_get(type) klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
514 515 516 517 518 519 520 521 522 523 524 525 526 |
# File 'lib/intersight_client/models/equipment_switch_card.rb', line 514 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 434 435 436 437 |
# File 'lib/intersight_client/models/equipment_switch_card.rb', line 419 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) super(attributes) EquipmentSwitchCard.openapi_types.each_pair do |key, type| if attributes[EquipmentSwitchCard.attribute_map[key]].nil? && EquipmentSwitchCard.openapi_nullable.include?(key) self.send("#{key}=", nil) elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[EquipmentSwitchCard.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[EquipmentSwitchCard.attribute_map[key]].map { |v| _deserialize($1, v) }) end elsif !attributes[EquipmentSwitchCard.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[EquipmentSwitchCard.attribute_map[key]])) end end self end |
#eql?(o) ⇒ Boolean
399 400 401 |
# File 'lib/intersight_client/models/equipment_switch_card.rb', line 399 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
405 406 407 |
# File 'lib/intersight_client/models/equipment_switch_card.rb', line 405 def hash [class_id, object_type, description, ethernet_switching_mode, fc_switching_mode, num_ports, out_of_band_ip_address, out_of_band_ip_gateway, out_of_band_ip_mask, slot_id, state, switch_id, thermal, fc_port_channels, inventory_device_info, network_element, port_channels, port_groups, registered_device].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
290 291 292 293 294 295 296 297 298 299 300 301 |
# File 'lib/intersight_client/models/equipment_switch_card.rb', line 290 def list_invalid_properties invalid_properties = super if @class_id.nil? invalid_properties.push('invalid value for "class_id", class_id cannot be nil.') end if @object_type.nil? invalid_properties.push('invalid value for "object_type", object_type cannot be nil.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
490 491 492 |
# File 'lib/intersight_client/models/equipment_switch_card.rb', line 490 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
496 497 498 499 500 501 502 503 504 505 506 507 508 |
# File 'lib/intersight_client/models/equipment_switch_card.rb', line 496 def to_hash hash = super EquipmentSwitchCard.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = EquipmentSwitchCard.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
484 485 486 |
# File 'lib/intersight_client/models/equipment_switch_card.rb', line 484 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 |
# File 'lib/intersight_client/models/equipment_switch_card.rb', line 305 def valid? return false if @class_id.nil? class_id_validator = EnumAttributeValidator.new('String', ["equipment.SwitchCard"]) return false unless class_id_validator.valid?(@class_id) return false if @object_type.nil? object_type_validator = EnumAttributeValidator.new('String', ["equipment.SwitchCard"]) return false unless object_type_validator.valid?(@object_type) ethernet_switching_mode_validator = EnumAttributeValidator.new('String', ["end-host", "switch"]) return false unless ethernet_switching_mode_validator.valid?(@ethernet_switching_mode) fc_switching_mode_validator = EnumAttributeValidator.new('String', ["end-host", "switch"]) return false unless fc_switching_mode_validator.valid?(@fc_switching_mode) thermal_validator = EnumAttributeValidator.new('String', ["unknown", "ok", "upper-non-recoverable", "upper-critical", "upper-non-critical", "lower-non-critical", "lower-critical", "lower-non-recoverable"]) return false unless thermal_validator.valid?(@thermal) true && super end |