Class: IntersightClient::FabricAppliancePcRoleAllOf
- Inherits:
-
Object
- Object
- IntersightClient::FabricAppliancePcRoleAllOf
- Defined in:
- lib/intersight_client/models/fabric_appliance_pc_role_all_of.rb
Overview
Definition of the list of properties defined in 'fabric.AppliancePcRole', excluding properties defined in parent classes.
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#admin_speed ⇒ Object
Admin configured speed for the port channel.
-
#class_id ⇒ Object
The fully-qualified name of the instantiated, concrete type.
-
#eth_network_control_policy ⇒ Object
Returns the value of attribute eth_network_control_policy.
-
#eth_network_group_policy ⇒ Object
Returns the value of attribute eth_network_group_policy.
-
#mode ⇒ Object
Port mode to be set on the appliance port-channel.
-
#object_type ⇒ Object
The fully-qualified name of the instantiated, concrete type.
-
#priority ⇒ Object
The 'name' of the System QoS Class.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns the key-value map of all the JSON attributes this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ FabricAppliancePcRoleAllOf
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ FabricAppliancePcRoleAllOf
Initializes the object
104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 |
# File 'lib/intersight_client/models/fabric_appliance_pc_role_all_of.rb', line 104 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `IntersightClient::FabricAppliancePcRoleAllOf` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `#{self.class.name}`. Please check the name to make sure it's valid. List of attributes: " + self.class.acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'class_id') self.class_id = attributes[:'class_id'] else self.class_id = 'fabric.AppliancePcRole' end if attributes.key?(:'object_type') self.object_type = attributes[:'object_type'] else self.object_type = 'fabric.AppliancePcRole' end if attributes.key?(:'admin_speed') self.admin_speed = attributes[:'admin_speed'] else self.admin_speed = 'Auto' end if attributes.key?(:'mode') self.mode = attributes[:'mode'] else self.mode = 'trunk' end if attributes.key?(:'priority') self.priority = attributes[:'priority'] else self.priority = 'Best Effort' end if attributes.key?(:'eth_network_control_policy') self.eth_network_control_policy = attributes[:'eth_network_control_policy'] end if attributes.key?(:'eth_network_group_policy') self.eth_network_group_policy = attributes[:'eth_network_group_policy'] end end |
Instance Attribute Details
#admin_speed ⇒ Object
Admin configured speed for the port channel. * Auto - Admin configurable speed AUTO ( default ). * 1Gbps - Admin configurable speed 1Gbps. * 10Gbps - Admin configurable speed 10Gbps. * 25Gbps - Admin configurable speed 25Gbps. * 40Gbps - Admin configurable speed 40Gbps. * 100Gbps - Admin configurable speed 100Gbps.
26 27 28 |
# File 'lib/intersight_client/models/fabric_appliance_pc_role_all_of.rb', line 26 def admin_speed @admin_speed end |
#class_id ⇒ Object
The fully-qualified name of the instantiated, concrete type. This property is used as a discriminator to identify the type of the payload when marshaling and unmarshaling data.
20 21 22 |
# File 'lib/intersight_client/models/fabric_appliance_pc_role_all_of.rb', line 20 def class_id @class_id end |
#eth_network_control_policy ⇒ Object
Returns the value of attribute eth_network_control_policy.
34 35 36 |
# File 'lib/intersight_client/models/fabric_appliance_pc_role_all_of.rb', line 34 def eth_network_control_policy @eth_network_control_policy end |
#eth_network_group_policy ⇒ Object
Returns the value of attribute eth_network_group_policy.
36 37 38 |
# File 'lib/intersight_client/models/fabric_appliance_pc_role_all_of.rb', line 36 def eth_network_group_policy @eth_network_group_policy end |
#mode ⇒ Object
Port mode to be set on the appliance port-channel. * trunk - Trunk Mode Switch Port Type. * access - Access Mode Switch Port Type.
29 30 31 |
# File 'lib/intersight_client/models/fabric_appliance_pc_role_all_of.rb', line 29 def mode @mode end |
#object_type ⇒ Object
The fully-qualified name of the instantiated, concrete type. The value should be the same as the 'ClassId' property.
23 24 25 |
# File 'lib/intersight_client/models/fabric_appliance_pc_role_all_of.rb', line 23 def object_type @object_type end |
#priority ⇒ Object
The 'name' of the System QoS Class. * Best Effort - QoS Priority for Best-effort traffic. * FC - QoS Priority for FC traffic. * Platinum - QoS Priority for Platinum traffic. * Gold - QoS Priority for Gold traffic. * Silver - QoS Priority for Silver traffic. * Bronze - QoS Priority for Bronze traffic.
32 33 34 |
# File 'lib/intersight_client/models/fabric_appliance_pc_role_all_of.rb', line 32 def priority @priority end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns the key-value map of all the JSON attributes this model knows about
79 80 81 |
# File 'lib/intersight_client/models/fabric_appliance_pc_role_all_of.rb', line 79 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
74 75 76 |
# File 'lib/intersight_client/models/fabric_appliance_pc_role_all_of.rb', line 74 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
61 62 63 64 65 66 67 68 69 70 71 |
# File 'lib/intersight_client/models/fabric_appliance_pc_role_all_of.rb', line 61 def self.attribute_map { :'class_id' => :'ClassId', :'object_type' => :'ObjectType', :'admin_speed' => :'AdminSpeed', :'mode' => :'Mode', :'priority' => :'Priority', :'eth_network_control_policy' => :'EthNetworkControlPolicy', :'eth_network_group_policy' => :'EthNetworkGroupPolicy' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
268 269 270 |
# File 'lib/intersight_client/models/fabric_appliance_pc_role_all_of.rb', line 268 def self.build_from_hash(attributes) new.build_from_hash(attributes) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
97 98 99 100 |
# File 'lib/intersight_client/models/fabric_appliance_pc_role_all_of.rb', line 97 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
84 85 86 87 88 89 90 91 92 93 94 |
# File 'lib/intersight_client/models/fabric_appliance_pc_role_all_of.rb', line 84 def self.openapi_types { :'class_id' => :'String', :'object_type' => :'String', :'admin_speed' => :'String', :'mode' => :'String', :'priority' => :'String', :'eth_network_control_policy' => :'FabricEthNetworkControlPolicyRelationship', :'eth_network_group_policy' => :'FabricEthNetworkGroupPolicyRelationship' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
241 242 243 244 245 246 247 248 249 250 251 |
# File 'lib/intersight_client/models/fabric_appliance_pc_role_all_of.rb', line 241 def ==(o) return true if self.equal?(o) self.class == o.class && class_id == o.class_id && object_type == o.object_type && admin_speed == o.admin_speed && mode == o.mode && priority == o.priority && eth_network_control_policy == o.eth_network_control_policy && eth_network_group_policy == o.eth_network_group_policy end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 |
# File 'lib/intersight_client/models/fabric_appliance_pc_role_all_of.rb', line 298 def _deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = IntersightClient.const_get(type) klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
369 370 371 372 373 374 375 376 377 378 379 380 381 |
# File 'lib/intersight_client/models/fabric_appliance_pc_role_all_of.rb', line 369 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 |
# File 'lib/intersight_client/models/fabric_appliance_pc_role_all_of.rb', line 275 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) FabricAppliancePcRoleAllOf.openapi_types.each_pair do |key, type| if attributes[FabricAppliancePcRoleAllOf.attribute_map[key]].nil? && FabricAppliancePcRoleAllOf.openapi_nullable.include?(key) self.send("#{key}=", nil) elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[FabricAppliancePcRoleAllOf.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[FabricAppliancePcRoleAllOf.attribute_map[key]].map { |v| _deserialize($1, v) }) end elsif !attributes[FabricAppliancePcRoleAllOf.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[FabricAppliancePcRoleAllOf.attribute_map[key]])) end end self end |
#eql?(o) ⇒ Boolean
255 256 257 |
# File 'lib/intersight_client/models/fabric_appliance_pc_role_all_of.rb', line 255 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
261 262 263 |
# File 'lib/intersight_client/models/fabric_appliance_pc_role_all_of.rb', line 261 def hash [class_id, object_type, admin_speed, mode, priority, eth_network_control_policy, eth_network_group_policy].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
158 159 160 161 162 163 164 165 166 167 168 169 |
# File 'lib/intersight_client/models/fabric_appliance_pc_role_all_of.rb', line 158 def list_invalid_properties invalid_properties = Array.new if @class_id.nil? invalid_properties.push('invalid value for "class_id", class_id cannot be nil.') end if @object_type.nil? invalid_properties.push('invalid value for "object_type", object_type cannot be nil.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
345 346 347 |
# File 'lib/intersight_client/models/fabric_appliance_pc_role_all_of.rb', line 345 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
351 352 353 354 355 356 357 358 359 360 361 362 363 |
# File 'lib/intersight_client/models/fabric_appliance_pc_role_all_of.rb', line 351 def to_hash hash = {} FabricAppliancePcRoleAllOf.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = FabricAppliancePcRoleAllOf.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
339 340 341 |
# File 'lib/intersight_client/models/fabric_appliance_pc_role_all_of.rb', line 339 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 |
# File 'lib/intersight_client/models/fabric_appliance_pc_role_all_of.rb', line 173 def valid? return false if @class_id.nil? class_id_validator = EnumAttributeValidator.new('String', ["fabric.AppliancePcRole"]) return false unless class_id_validator.valid?(@class_id) return false if @object_type.nil? object_type_validator = EnumAttributeValidator.new('String', ["fabric.AppliancePcRole"]) return false unless object_type_validator.valid?(@object_type) admin_speed_validator = EnumAttributeValidator.new('String', ["Auto", "1Gbps", "10Gbps", "25Gbps", "40Gbps", "100Gbps"]) return false unless admin_speed_validator.valid?(@admin_speed) mode_validator = EnumAttributeValidator.new('String', ["trunk", "access"]) return false unless mode_validator.valid?(@mode) priority_validator = EnumAttributeValidator.new('String', ["Best Effort", "FC", "Platinum", "Gold", "Silver", "Bronze"]) return false unless priority_validator.valid?(@priority) true end |