Class: IntersightClient::FabricFcUplinkPcRoleAllOf

Inherits:
Object
  • Object
show all
Defined in:
lib/intersight_client/models/fabric_fc_uplink_pc_role_all_of.rb

Overview

Definition of the list of properties defined in 'fabric.FcUplinkPcRole', excluding properties defined in parent classes.

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ FabricFcUplinkPcRoleAllOf

Initializes the object



96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
# File 'lib/intersight_client/models/fabric_fc_uplink_pc_role_all_of.rb', line 96

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `IntersightClient::FabricFcUplinkPcRoleAllOf` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `#{self.class.name}`. Please check the name to make sure it's valid. List of attributes: " + self.class.acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'class_id')
    self.class_id = attributes[:'class_id']
  else
    self.class_id = 'fabric.FcUplinkPcRole'
  end

  if attributes.key?(:'object_type')
    self.object_type = attributes[:'object_type']
  else
    self.object_type = 'fabric.FcUplinkPcRole'
  end

  if attributes.key?(:'admin_speed')
    self.admin_speed = attributes[:'admin_speed']
  else
    self.admin_speed = 'Auto'
  end

  if attributes.key?(:'fill_pattern')
    self.fill_pattern = attributes[:'fill_pattern']
  else
    self.fill_pattern = 'Idle'
  end

  if attributes.key?(:'vsan_id')
    self.vsan_id = attributes[:'vsan_id']
  end
end

Instance Attribute Details

#admin_speed ⇒ Object

Admin configured speed for the port. * Auto - Admin configurable speed AUTO ( default ). * 8Gbps - Admin configurable speed 8Gbps. * 16Gbps - Admin configurable speed 16Gbps. * 32Gbps - Admin configurable speed 32Gbps.



26
27
28
# File 'lib/intersight_client/models/fabric_fc_uplink_pc_role_all_of.rb', line 26

def admin_speed
  @admin_speed
end

#class_id ⇒ Object

The fully-qualified name of the instantiated, concrete type. This property is used as a discriminator to identify the type of the payload when marshaling and unmarshaling data.



20
21
22
# File 'lib/intersight_client/models/fabric_fc_uplink_pc_role_all_of.rb', line 20

def class_id
  @class_id
end

#fill_pattern ⇒ Object

Fill pattern to differentiate the configs in NPIV. * Idle - Fc Fill Pattern type Idle. * Arbff - Fc Fill Pattern type Arbff.



29
30
31
# File 'lib/intersight_client/models/fabric_fc_uplink_pc_role_all_of.rb', line 29

def fill_pattern
  @fill_pattern
end

#object_type ⇒ Object

The fully-qualified name of the instantiated, concrete type. The value should be the same as the 'ClassId' property.



23
24
25
# File 'lib/intersight_client/models/fabric_fc_uplink_pc_role_all_of.rb', line 23

def object_type
  @object_type
end

#vsan_id ⇒ Object

Virtual San Identifier associated to the FC port.



32
33
34
# File 'lib/intersight_client/models/fabric_fc_uplink_pc_role_all_of.rb', line 32

def vsan_id
  @vsan_id
end

Class Method Details

.acceptable_attribute_map ⇒ Object

Returns the key-value map of all the JSON attributes this model knows about



73
74
75
# File 'lib/intersight_client/models/fabric_fc_uplink_pc_role_all_of.rb', line 73

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributes ⇒ Object

Returns all the JSON keys this model knows about



68
69
70
# File 'lib/intersight_client/models/fabric_fc_uplink_pc_role_all_of.rb', line 68

def self.acceptable_attributes
  attribute_map.values
end

.attribute_map ⇒ Object

Attribute mapping from ruby-style variable name to JSON key.



57
58
59
60
61
62
63
64
65
# File 'lib/intersight_client/models/fabric_fc_uplink_pc_role_all_of.rb', line 57

def self.attribute_map
  {
    :'class_id' => :'ClassId',
    :'object_type' => :'ObjectType',
    :'admin_speed' => :'AdminSpeed',
    :'fill_pattern' => :'FillPattern',
    :'vsan_id' => :'VsanId'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash



260
261
262
# File 'lib/intersight_client/models/fabric_fc_uplink_pc_role_all_of.rb', line 260

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_nullable ⇒ Object

List of attributes with nullable: true



89
90
91
92
# File 'lib/intersight_client/models/fabric_fc_uplink_pc_role_all_of.rb', line 89

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_types ⇒ Object

Attribute type mapping.



78
79
80
81
82
83
84
85
86
# File 'lib/intersight_client/models/fabric_fc_uplink_pc_role_all_of.rb', line 78

def self.openapi_types
  {
    :'class_id' => :'String',
    :'object_type' => :'String',
    :'admin_speed' => :'String',
    :'fill_pattern' => :'String',
    :'vsan_id' => :'Integer'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.



235
236
237
238
239
240
241
242
243
# File 'lib/intersight_client/models/fabric_fc_uplink_pc_role_all_of.rb', line 235

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      class_id == o.class_id &&
      object_type == o.object_type &&
      admin_speed == o.admin_speed &&
      fill_pattern == o.fill_pattern &&
      vsan_id == o.vsan_id
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type



290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
# File 'lib/intersight_client/models/fabric_fc_uplink_pc_role_all_of.rb', line 290

def _deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = IntersightClient.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value



361
362
363
364
365
366
367
368
369
370
371
372
373
# File 'lib/intersight_client/models/fabric_fc_uplink_pc_role_all_of.rb', line 361

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash



267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
# File 'lib/intersight_client/models/fabric_fc_uplink_pc_role_all_of.rb', line 267

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  FabricFcUplinkPcRoleAllOf.openapi_types.each_pair do |key, type|
    if attributes[FabricFcUplinkPcRoleAllOf.attribute_map[key]].nil? && FabricFcUplinkPcRoleAllOf.openapi_nullable.include?(key)
      self.send("#{key}=", nil)
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[FabricFcUplinkPcRoleAllOf.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[FabricFcUplinkPcRoleAllOf.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[FabricFcUplinkPcRoleAllOf.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[FabricFcUplinkPcRoleAllOf.attribute_map[key]]))
    end
  end

  self
end

#eql?(o) ⇒ Boolean

See Also:

  • `==` method


247
248
249
# File 'lib/intersight_client/models/fabric_fc_uplink_pc_role_all_of.rb', line 247

def eql?(o)
  self == o
end

#hash ⇒ Integer

Calculates hash code according to all attributes.



253
254
255
# File 'lib/intersight_client/models/fabric_fc_uplink_pc_role_all_of.rb', line 253

def hash
  [class_id, object_type, admin_speed, fill_pattern, vsan_id].hash
end

#list_invalid_properties ⇒ Object

Show invalid properties with the reasons. Usually used together with valid?



140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
# File 'lib/intersight_client/models/fabric_fc_uplink_pc_role_all_of.rb', line 140

def list_invalid_properties
  invalid_properties = Array.new
  if @class_id.nil?
    invalid_properties.push('invalid value for "class_id", class_id cannot be nil.')
  end

  if @object_type.nil?
    invalid_properties.push('invalid value for "object_type", object_type cannot be nil.')
  end

  if !@vsan_id.nil? && @vsan_id > 4093
    invalid_properties.push('invalid value for "vsan_id", must be smaller than or equal to 4093.')
  end

  if !@vsan_id.nil? && @vsan_id < 1
    invalid_properties.push('invalid value for "vsan_id", must be greater than or equal to 1.')
  end

  invalid_properties
end

#to_body ⇒ Hash

to_body is an alias to to_hash (backward compatibility)



337
338
339
# File 'lib/intersight_client/models/fabric_fc_uplink_pc_role_all_of.rb', line 337

def to_body
  to_hash
end

#to_hash ⇒ Hash

Returns the object in the form of hash



343
344
345
346
347
348
349
350
351
352
353
354
355
# File 'lib/intersight_client/models/fabric_fc_uplink_pc_role_all_of.rb', line 343

def to_hash
  hash = {}
  FabricFcUplinkPcRoleAllOf.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = FabricFcUplinkPcRoleAllOf.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_s ⇒ String

Returns the string representation of the object



331
332
333
# File 'lib/intersight_client/models/fabric_fc_uplink_pc_role_all_of.rb', line 331

def to_s
  to_hash.to_s
end

#valid? ⇒ Boolean

Check to see if the all the properties in the model are valid



163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
# File 'lib/intersight_client/models/fabric_fc_uplink_pc_role_all_of.rb', line 163

def valid?
  return false if @class_id.nil?
  class_id_validator = EnumAttributeValidator.new('String', ["fabric.FcUplinkPcRole"])
  return false unless class_id_validator.valid?(@class_id)
  return false if @object_type.nil?
  object_type_validator = EnumAttributeValidator.new('String', ["fabric.FcUplinkPcRole"])
  return false unless object_type_validator.valid?(@object_type)
  admin_speed_validator = EnumAttributeValidator.new('String', ["Auto", "8Gbps", "16Gbps", "32Gbps"])
  return false unless admin_speed_validator.valid?(@admin_speed)
  fill_pattern_validator = EnumAttributeValidator.new('String', ["Idle", "Arbff"])
  return false unless fill_pattern_validator.valid?(@fill_pattern)
  return false if !@vsan_id.nil? && @vsan_id > 4093
  return false if !@vsan_id.nil? && @vsan_id < 1
  true
end