Class: IntersightClient::FabricQosClass
- Inherits:
-
MoBaseComplexType
- Object
- MoBaseComplexType
- IntersightClient::FabricQosClass
- Defined in:
- lib/intersight_client/models/fabric_qos_class.rb
Overview
Type to represent the Best Effort QoS class.
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#admin_state ⇒ Object
Administrative state for this QoS class.
-
#bandwidth_percent ⇒ Object
Percentage of bandwidth received by the traffic tagged with this QoS.
-
#class_id ⇒ Object
The fully-qualified name of the instantiated, concrete type.
-
#cos ⇒ Object
Class of service received by the traffic tagged with this QoS.
-
#mtu ⇒ Object
Maximum transmission unit (MTU) is the largest size packet or frame, that can be sent in a packet- or frame-based network such as the Internet.
-
#multicast_optimize ⇒ Object
If enabled, this QoS class will be optimized to send multiple packets.
-
#name ⇒ Object
The ‘name’ of this QoS Class.
-
#object_type ⇒ Object
The fully-qualified name of the instantiated, concrete type.
-
#packet_drop ⇒ Object
If enabled, this QoS class will allow packet drops within an acceptable limit.
-
#weight ⇒ Object
The weight of the QoS Class controls the distribution of bandwidth between QoS Classes, with the same priority after the Guarantees for the QoS Classes are reached.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns the key-value map of all the JSON attributes this model knows about, including the ones defined in its parent(s).
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about, including the ones defined in its parent(s).
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_all_of ⇒ Object
List of class defined in allOf (OpenAPI v3).
-
.openapi_discriminator_name ⇒ Object
discriminator’s property name in OpenAPI v3.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ FabricQosClass
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ FabricQosClass
Initializes the object
134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 |
# File 'lib/intersight_client/models/fabric_qos_class.rb', line 134 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `IntersightClient::FabricQosClass` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `#{self.class.name}`. Please check the name to make sure it's valid. List of attributes: " + self.class.acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } # call parent's initialize super(attributes) if attributes.key?(:'class_id') self.class_id = attributes[:'class_id'] else self.class_id = 'fabric.QosClass' end if attributes.key?(:'object_type') self.object_type = attributes[:'object_type'] else self.object_type = 'fabric.QosClass' end if attributes.key?(:'admin_state') self.admin_state = attributes[:'admin_state'] else self.admin_state = 'Disabled' end if attributes.key?(:'bandwidth_percent') self.bandwidth_percent = attributes[:'bandwidth_percent'] end if attributes.key?(:'cos') self.cos = attributes[:'cos'] end if attributes.key?(:'mtu') self.mtu = attributes[:'mtu'] else self.mtu = 1500 end if attributes.key?(:'multicast_optimize') self.multicast_optimize = attributes[:'multicast_optimize'] else self.multicast_optimize = false end if attributes.key?(:'name') self.name = attributes[:'name'] else self.name = 'Best Effort' end if attributes.key?(:'packet_drop') self.packet_drop = attributes[:'packet_drop'] else self.packet_drop = true end if attributes.key?(:'weight') self.weight = attributes[:'weight'] end end |
Instance Attribute Details
#admin_state ⇒ Object
Administrative state for this QoS class. * Disabled - Admin configured Disabled State. * Enabled - Admin configured Enabled State.
26 27 28 |
# File 'lib/intersight_client/models/fabric_qos_class.rb', line 26 def admin_state @admin_state end |
#bandwidth_percent ⇒ Object
Percentage of bandwidth received by the traffic tagged with this QoS.
29 30 31 |
# File 'lib/intersight_client/models/fabric_qos_class.rb', line 29 def bandwidth_percent @bandwidth_percent end |
#class_id ⇒ Object
The fully-qualified name of the instantiated, concrete type. This property is used as a discriminator to identify the type of the payload when marshaling and unmarshaling data.
20 21 22 |
# File 'lib/intersight_client/models/fabric_qos_class.rb', line 20 def class_id @class_id end |
#cos ⇒ Object
Class of service received by the traffic tagged with this QoS.
32 33 34 |
# File 'lib/intersight_client/models/fabric_qos_class.rb', line 32 def cos @cos end |
#mtu ⇒ Object
Maximum transmission unit (MTU) is the largest size packet or frame, that can be sent in a packet- or frame-based network such as the Internet. User can select from the following: 1. Any value between 1500 and 9216 2. ‘Normal’ (default) mapping to a value of 1500. 3. ‘FC’ mapping to a value of 2240.
35 36 37 |
# File 'lib/intersight_client/models/fabric_qos_class.rb', line 35 def mtu @mtu end |
#multicast_optimize ⇒ Object
If enabled, this QoS class will be optimized to send multiple packets.
38 39 40 |
# File 'lib/intersight_client/models/fabric_qos_class.rb', line 38 def multicast_optimize @multicast_optimize end |
#name ⇒ Object
The ‘name’ of this QoS Class. * ‘Best Effort` - QoS Priority for Best-effort traffic. * FC - QoS Priority for FC traffic. * Platinum - QoS Priority for Platinum traffic. * Gold - QoS Priority for Gold traffic. * Silver - QoS Priority for Silver traffic. * Bronze - QoS Priority for Bronze traffic.
41 42 43 |
# File 'lib/intersight_client/models/fabric_qos_class.rb', line 41 def name @name end |
#object_type ⇒ Object
The fully-qualified name of the instantiated, concrete type. The value should be the same as the ‘ClassId’ property.
23 24 25 |
# File 'lib/intersight_client/models/fabric_qos_class.rb', line 23 def object_type @object_type end |
#packet_drop ⇒ Object
If enabled, this QoS class will allow packet drops within an acceptable limit.
44 45 46 |
# File 'lib/intersight_client/models/fabric_qos_class.rb', line 44 def packet_drop @packet_drop end |
#weight ⇒ Object
The weight of the QoS Class controls the distribution of bandwidth between QoS Classes, with the same priority after the Guarantees for the QoS Classes are reached.
47 48 49 |
# File 'lib/intersight_client/models/fabric_qos_class.rb', line 47 def weight @weight end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns the key-value map of all the JSON attributes this model knows about, including the ones defined in its parent(s)
93 94 95 |
# File 'lib/intersight_client/models/fabric_qos_class.rb', line 93 def self.acceptable_attribute_map attribute_map.merge(superclass.acceptable_attribute_map) end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about, including the ones defined in its parent(s)
88 89 90 |
# File 'lib/intersight_client/models/fabric_qos_class.rb', line 88 def self.acceptable_attributes attribute_map.values.concat(superclass.acceptable_attributes) end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
72 73 74 75 76 77 78 79 80 81 82 83 84 85 |
# File 'lib/intersight_client/models/fabric_qos_class.rb', line 72 def self.attribute_map { :'class_id' => :'ClassId', :'object_type' => :'ObjectType', :'admin_state' => :'AdminState', :'bandwidth_percent' => :'BandwidthPercent', :'cos' => :'Cos', :'mtu' => :'Mtu', :'multicast_optimize' => :'MulticastOptimize', :'name' => :'Name', :'packet_drop' => :'PacketDrop', :'weight' => :'Weight' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
404 405 406 |
# File 'lib/intersight_client/models/fabric_qos_class.rb', line 404 def self.build_from_hash(attributes) new.build_from_hash(attributes) end |
.openapi_all_of ⇒ Object
List of class defined in allOf (OpenAPI v3)
120 121 122 123 124 125 |
# File 'lib/intersight_client/models/fabric_qos_class.rb', line 120 def self.openapi_all_of [ :'FabricQosClassAllOf', :'MoBaseComplexType' ] end |
.openapi_discriminator_name ⇒ Object
discriminator’s property name in OpenAPI v3
128 129 130 |
# File 'lib/intersight_client/models/fabric_qos_class.rb', line 128 def self.openapi_discriminator_name :'ClassId' end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
114 115 116 117 |
# File 'lib/intersight_client/models/fabric_qos_class.rb', line 114 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
98 99 100 101 102 103 104 105 106 107 108 109 110 111 |
# File 'lib/intersight_client/models/fabric_qos_class.rb', line 98 def self.openapi_types { :'class_id' => :'String', :'object_type' => :'String', :'admin_state' => :'String', :'bandwidth_percent' => :'Integer', :'cos' => :'Integer', :'mtu' => :'Integer', :'multicast_optimize' => :'Boolean', :'name' => :'String', :'packet_drop' => :'Boolean', :'weight' => :'Integer' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
374 375 376 377 378 379 380 381 382 383 384 385 386 387 |
# File 'lib/intersight_client/models/fabric_qos_class.rb', line 374 def ==(o) return true if self.equal?(o) self.class == o.class && class_id == o.class_id && object_type == o.object_type && admin_state == o.admin_state && bandwidth_percent == o.bandwidth_percent && cos == o.cos && mtu == o.mtu && multicast_optimize == o.multicast_optimize && name == o.name && packet_drop == o.packet_drop && weight == o.weight && super(o) end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 463 464 465 466 467 468 469 470 471 472 |
# File 'lib/intersight_client/models/fabric_qos_class.rb', line 435 def _deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = IntersightClient.const_get(type) klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
506 507 508 509 510 511 512 513 514 515 516 517 518 |
# File 'lib/intersight_client/models/fabric_qos_class.rb', line 506 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 |
# File 'lib/intersight_client/models/fabric_qos_class.rb', line 411 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) super(attributes) FabricQosClass.openapi_types.each_pair do |key, type| if attributes[FabricQosClass.attribute_map[key]].nil? && FabricQosClass.openapi_nullable.include?(key) self.send("#{key}=", nil) elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[FabricQosClass.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[FabricQosClass.attribute_map[key]].map { |v| _deserialize($1, v) }) end elsif !attributes[FabricQosClass.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[FabricQosClass.attribute_map[key]])) end end self end |
#eql?(o) ⇒ Boolean
391 392 393 |
# File 'lib/intersight_client/models/fabric_qos_class.rb', line 391 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
397 398 399 |
# File 'lib/intersight_client/models/fabric_qos_class.rb', line 397 def hash [class_id, object_type, admin_state, bandwidth_percent, cos, mtu, multicast_optimize, name, packet_drop, weight].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 |
# File 'lib/intersight_client/models/fabric_qos_class.rb', line 207 def list_invalid_properties invalid_properties = super if @class_id.nil? invalid_properties.push('invalid value for "class_id", class_id cannot be nil.') end if @object_type.nil? invalid_properties.push('invalid value for "object_type", object_type cannot be nil.') end if !@bandwidth_percent.nil? && @bandwidth_percent > 100 invalid_properties.push('invalid value for "bandwidth_percent", must be smaller than or equal to 100.') end if !@bandwidth_percent.nil? && @bandwidth_percent < 0 invalid_properties.push('invalid value for "bandwidth_percent", must be greater than or equal to 0.') end if !@cos.nil? && @cos > 255 invalid_properties.push('invalid value for "cos", must be smaller than or equal to 255.') end if !@cos.nil? && @cos < 0 invalid_properties.push('invalid value for "cos", must be greater than or equal to 0.') end if !@mtu.nil? && @mtu > 9216 invalid_properties.push('invalid value for "mtu", must be smaller than or equal to 9216.') end if !@mtu.nil? && @mtu < 1500 invalid_properties.push('invalid value for "mtu", must be greater than or equal to 1500.') end if !@weight.nil? && @weight > 10 invalid_properties.push('invalid value for "weight", must be smaller than or equal to 10.') end if !@weight.nil? && @weight < 0 invalid_properties.push('invalid value for "weight", must be greater than or equal to 0.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
482 483 484 |
# File 'lib/intersight_client/models/fabric_qos_class.rb', line 482 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
488 489 490 491 492 493 494 495 496 497 498 499 500 |
# File 'lib/intersight_client/models/fabric_qos_class.rb', line 488 def to_hash hash = super FabricQosClass.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = FabricQosClass.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
476 477 478 |
# File 'lib/intersight_client/models/fabric_qos_class.rb', line 476 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 |
# File 'lib/intersight_client/models/fabric_qos_class.rb', line 254 def valid? return false if @class_id.nil? class_id_validator = EnumAttributeValidator.new('String', ["fabric.QosClass"]) return false unless class_id_validator.valid?(@class_id) return false if @object_type.nil? object_type_validator = EnumAttributeValidator.new('String', ["fabric.QosClass"]) return false unless object_type_validator.valid?(@object_type) admin_state_validator = EnumAttributeValidator.new('String', ["Disabled", "Enabled"]) return false unless admin_state_validator.valid?(@admin_state) return false if !@bandwidth_percent.nil? && @bandwidth_percent > 100 return false if !@bandwidth_percent.nil? && @bandwidth_percent < 0 return false if !@cos.nil? && @cos > 255 return false if !@cos.nil? && @cos < 0 return false if !@mtu.nil? && @mtu > 9216 return false if !@mtu.nil? && @mtu < 1500 name_validator = EnumAttributeValidator.new('String', ["Best Effort", "FC", "Platinum", "Gold", "Silver", "Bronze"]) return false unless name_validator.valid?(@name) return false if !@weight.nil? && @weight > 10 return false if !@weight.nil? && @weight < 0 true && super end |