Class: IntersightClient::FirmwareComponentMeta

Inherits:
MoBaseComplexType show all
Defined in:
lib/intersight_client/models/firmware_component_meta.rb

Overview

Contains the details for each component in the HSU bundle catalog.

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ FirmwareComponentMeta

Initializes the object



149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
# File 'lib/intersight_client/models/firmware_component_meta.rb', line 149

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `IntersightClient::FirmwareComponentMeta` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `#{self.class.name}`. Please check the name to make sure it's valid. List of attributes: " + self.class.acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  # call parent's initialize
  super(attributes)

  if attributes.key?(:'class_id')
    self.class_id = attributes[:'class_id']
  else
    self.class_id = 'firmware.ComponentMeta'
  end

  if attributes.key?(:'object_type')
    self.object_type = attributes[:'object_type']
  else
    self.object_type = 'firmware.ComponentMeta'
  end

  if attributes.key?(:'component_label')
    self.component_label = attributes[:'component_label']
  end

  if attributes.key?(:'component_type')
    self.component_type = attributes[:'component_type']
  else
    self.component_type = 'ALL'
  end

  if attributes.key?(:'description')
    self.description = attributes[:'description']
  end

  if attributes.key?(:'disruption')
    self.disruption = attributes[:'disruption']
  else
    self.disruption = 'None'
  end

  if attributes.key?(:'image_path')
    self.image_path = attributes[:'image_path']
  end

  if attributes.key?(:'is_oob_supported')
    self.is_oob_supported = attributes[:'is_oob_supported']
  end

  if attributes.key?(:'model')
    self.model = attributes[:'model']
  end

  if attributes.key?(:'oob_manageability')
    if (value = attributes[:'oob_manageability']).is_a?(Array)
      self.oob_manageability = value
    end
  end

  if attributes.key?(:'packed_version')
    self.packed_version = attributes[:'packed_version']
  end

  if attributes.key?(:'redfish_url')
    self.redfish_url = attributes[:'redfish_url']
  end

  if attributes.key?(:'vendor')
    self.vendor = attributes[:'vendor']
  end
end

Instance Attribute Details

#class_id ⇒ Object

The fully-qualified name of the instantiated, concrete type. This property is used as a discriminator to identify the type of the payload when marshaling and unmarshaling data.



20
21
22
# File 'lib/intersight_client/models/firmware_component_meta.rb', line 20

def class_id
  @class_id
end

#component_label ⇒ Object

The name of the component in the compressed HSU bundle.



26
27
28
# File 'lib/intersight_client/models/firmware_component_meta.rb', line 26

def component_label
  @component_label
end

#component_type ⇒ Object

The type of component image within the distributable. * ALL - This represents all the components. * ALL,HDD - This represents all the components plus the HDDs. * Drive-U.2 - This represents the U.2 drives that are SFF/LFF drives (mostly all the drives will fall under this category). * Storage - This represents the storage controller components. * None - This represents none of the components. * NXOS - This represents NXOS components. * IOM - This represents IOM components. * PSU - This represents PSU components. * CIMC - This represents CIMC components. * BIOS - This represents BIOS components. * PCIE - This represents PCIE components. * Drive - This represents Drive components. * DIMM - This represents DIMM components. * BoardController - This represents Board Controller components. * StorageController - This represents Storage Controller components. * HBA - This represents HBA components. * GPU - This represents GPU components. * SasExpander - This represents SasExpander components. * MSwitch - This represents mSwitch components. * CMC - This represents CMC components.



29
30
31
# File 'lib/intersight_client/models/firmware_component_meta.rb', line 29

def component_type
  @component_type
end

#description ⇒ Object

This shows the description of component image within the distributable.



32
33
34
# File 'lib/intersight_client/models/firmware_component_meta.rb', line 32

def description
  @description
end

#disruption ⇒ Object

The type of disruption on each component. For example, host reboot, automatic power cycle, and manual power cycle. * None - Indicates that the component did not receive a disruption request. * HostReboot - Indicates that the component received a host reboot request. * EndpointReboot - Indicates that the component received an end point reboot request. * ManualPowerCycle - Indicates that the component received a manual power cycle request. * AutomaticPowerCycle - Indicates that the component received an automatic power cycle request.



35
36
37
# File 'lib/intersight_client/models/firmware_component_meta.rb', line 35

def disruption
  @disruption
end

#image_path ⇒ Object

This shows the path of component image within the distributable.



38
39
40
# File 'lib/intersight_client/models/firmware_component_meta.rb', line 38

def image_path
  @image_path
end

#is_oob_supported ⇒ Object

If set, the component can be updated through out-of-band management, else, is updated through host service utility boot.



41
42
43
# File 'lib/intersight_client/models/firmware_component_meta.rb', line 41

def is_oob_supported
  @is_oob_supported
end

#model ⇒ Object

The model of the component image in the distributable.



44
45
46
# File 'lib/intersight_client/models/firmware_component_meta.rb', line 44

def model
  @model
end

#object_type ⇒ Object

The fully-qualified name of the instantiated, concrete type. The value should be the same as the 'ClassId' property.



23
24
25
# File 'lib/intersight_client/models/firmware_component_meta.rb', line 23

def object_type
  @object_type
end

#oob_manageability ⇒ Object

Returns the value of attribute oob_manageability.



46
47
48
# File 'lib/intersight_client/models/firmware_component_meta.rb', line 46

def oob_manageability
  @oob_manageability
end

#packed_version ⇒ Object

The image version of components packaged in the distributable.



49
50
51
# File 'lib/intersight_client/models/firmware_component_meta.rb', line 49

def packed_version
  @packed_version
end

#redfish_url ⇒ Object

The redfish target for each component.



52
53
54
# File 'lib/intersight_client/models/firmware_component_meta.rb', line 52

def redfish_url
  @redfish_url
end

#vendor ⇒ Object

The version of component image in the distributable.



55
56
57
# File 'lib/intersight_client/models/firmware_component_meta.rb', line 55

def vendor
  @vendor
end

Class Method Details

.acceptable_attribute_map ⇒ Object

Returns the key-value map of all the JSON attributes this model knows about, including the ones defined in its parent(s)



104
105
106
# File 'lib/intersight_client/models/firmware_component_meta.rb', line 104

def self.acceptable_attribute_map
  attribute_map.merge(superclass.acceptable_attribute_map)
end

.acceptable_attributes ⇒ Object

Returns all the JSON keys this model knows about, including the ones defined in its parent(s)



99
100
101
# File 'lib/intersight_client/models/firmware_component_meta.rb', line 99

def self.acceptable_attributes
  attribute_map.values.concat(superclass.acceptable_attributes)
end

.attribute_map ⇒ Object

Attribute mapping from ruby-style variable name to JSON key.



80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
# File 'lib/intersight_client/models/firmware_component_meta.rb', line 80

def self.attribute_map
  {
    :'class_id' => :'ClassId',
    :'object_type' => :'ObjectType',
    :'component_label' => :'ComponentLabel',
    :'component_type' => :'ComponentType',
    :'description' => :'Description',
    :'disruption' => :'Disruption',
    :'image_path' => :'ImagePath',
    :'is_oob_supported' => :'IsOobSupported',
    :'model' => :'Model',
    :'oob_manageability' => :'OobManageability',
    :'packed_version' => :'PackedVersion',
    :'redfish_url' => :'RedfishUrl',
    :'vendor' => :'Vendor'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash



334
335
336
# File 'lib/intersight_client/models/firmware_component_meta.rb', line 334

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_all_of ⇒ Object

List of class defined in allOf (OpenAPI v3)



135
136
137
138
139
140
# File 'lib/intersight_client/models/firmware_component_meta.rb', line 135

def self.openapi_all_of
  [
  :'FirmwareComponentMetaAllOf',
  :'MoBaseComplexType'
  ]
end

.openapi_discriminator_name ⇒ Object

discriminator's property name in OpenAPI v3



143
144
145
# File 'lib/intersight_client/models/firmware_component_meta.rb', line 143

def self.openapi_discriminator_name
  :'ClassId'
end

.openapi_nullable ⇒ Object

List of attributes with nullable: true



128
129
130
131
132
# File 'lib/intersight_client/models/firmware_component_meta.rb', line 128

def self.openapi_nullable
  Set.new([
    :'oob_manageability',
  ])
end

.openapi_types ⇒ Object

Attribute type mapping.



109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
# File 'lib/intersight_client/models/firmware_component_meta.rb', line 109

def self.openapi_types
  {
    :'class_id' => :'String',
    :'object_type' => :'String',
    :'component_label' => :'String',
    :'component_type' => :'String',
    :'description' => :'String',
    :'disruption' => :'String',
    :'image_path' => :'String',
    :'is_oob_supported' => :'Boolean',
    :'model' => :'String',
    :'oob_manageability' => :'Array<String>',
    :'packed_version' => :'String',
    :'redfish_url' => :'String',
    :'vendor' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.



301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
# File 'lib/intersight_client/models/firmware_component_meta.rb', line 301

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      class_id == o.class_id &&
      object_type == o.object_type &&
      component_label == o.component_label &&
      component_type == o.component_type &&
      description == o.description &&
      disruption == o.disruption &&
      image_path == o.image_path &&
      is_oob_supported == o.is_oob_supported &&
      model == o.model &&
      oob_manageability == o.oob_manageability &&
      packed_version == o.packed_version &&
      redfish_url == o.redfish_url &&
      vendor == o.vendor && super(o)
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type



365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
# File 'lib/intersight_client/models/firmware_component_meta.rb', line 365

def _deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = IntersightClient.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value



436
437
438
439
440
441
442
443
444
445
446
447
448
# File 'lib/intersight_client/models/firmware_component_meta.rb', line 436

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash



341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
# File 'lib/intersight_client/models/firmware_component_meta.rb', line 341

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  super(attributes)
  FirmwareComponentMeta.openapi_types.each_pair do |key, type|
    if attributes[FirmwareComponentMeta.attribute_map[key]].nil? && FirmwareComponentMeta.openapi_nullable.include?(key)
      self.send("#{key}=", nil)
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[FirmwareComponentMeta.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[FirmwareComponentMeta.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[FirmwareComponentMeta.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[FirmwareComponentMeta.attribute_map[key]]))
    end
  end

  self
end

#eql?(o) ⇒ Boolean

See Also:

  • `==` method


321
322
323
# File 'lib/intersight_client/models/firmware_component_meta.rb', line 321

def eql?(o)
  self == o
end

#hash ⇒ Integer

Calculates hash code according to all attributes.



327
328
329
# File 'lib/intersight_client/models/firmware_component_meta.rb', line 327

def hash
  [class_id, object_type, component_label, component_type, description, disruption, image_path, is_oob_supported, model, oob_manageability, packed_version, redfish_url, vendor].hash
end

#list_invalid_properties ⇒ Object

Show invalid properties with the reasons. Usually used together with valid?



230
231
232
233
234
235
236
237
238
239
240
241
# File 'lib/intersight_client/models/firmware_component_meta.rb', line 230

def list_invalid_properties
  invalid_properties = super
  if @class_id.nil?
    invalid_properties.push('invalid value for "class_id", class_id cannot be nil.')
  end

  if @object_type.nil?
    invalid_properties.push('invalid value for "object_type", object_type cannot be nil.')
  end

  invalid_properties
end

#to_body ⇒ Hash

to_body is an alias to to_hash (backward compatibility)



412
413
414
# File 'lib/intersight_client/models/firmware_component_meta.rb', line 412

def to_body
  to_hash
end

#to_hash ⇒ Hash

Returns the object in the form of hash



418
419
420
421
422
423
424
425
426
427
428
429
430
# File 'lib/intersight_client/models/firmware_component_meta.rb', line 418

def to_hash
  hash = super
  FirmwareComponentMeta.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = FirmwareComponentMeta.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_s ⇒ String

Returns the string representation of the object



406
407
408
# File 'lib/intersight_client/models/firmware_component_meta.rb', line 406

def to_s
  to_hash.to_s
end

#valid? ⇒ Boolean

Check to see if the all the properties in the model are valid



245
246
247
248
249
250
251
252
253
254
255
256
257
# File 'lib/intersight_client/models/firmware_component_meta.rb', line 245

def valid?
  return false if @class_id.nil?
  class_id_validator = EnumAttributeValidator.new('String', ["firmware.ComponentMeta"])
  return false unless class_id_validator.valid?(@class_id)
  return false if @object_type.nil?
  object_type_validator = EnumAttributeValidator.new('String', ["firmware.ComponentMeta"])
  return false unless object_type_validator.valid?(@object_type)
  component_type_validator = EnumAttributeValidator.new('String', ["ALL", "ALL,HDD", "Drive-U.2", "Storage", "None", "NXOS", "IOM", "PSU", "CIMC", "BIOS", "PCIE", "Drive", "DIMM", "BoardController", "StorageController", "HBA", "GPU", "SasExpander", "MSwitch", "CMC"])
  return false unless component_type_validator.valid?(@component_type)
  disruption_validator = EnumAttributeValidator.new('String', ["None", "HostReboot", "EndpointReboot", "ManualPowerCycle", "AutomaticPowerCycle"])
  return false unless disruption_validator.valid?(@disruption)
  true && super
end