Class: IntersightClient::FirmwareRunningFirmware
- Inherits:
-
InventoryBase
- Object
- MoBaseMo
- InventoryBase
- IntersightClient::FirmwareRunningFirmware
- Defined in:
- lib/intersight_client/models/firmware_running_firmware.rb
Overview
Running Firmware on an endpoint.
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#bios_unit ⇒ Object
Returns the value of attribute bios_unit.
-
#class_id ⇒ Object
The fully-qualified name of the instantiated, concrete type.
-
#component ⇒ Object
Kind of the firmware - boot-booloader/system/kernel.
-
#graphics_card ⇒ Object
Returns the value of attribute graphics_card.
-
#inventory_device_info ⇒ Object
Returns the value of attribute inventory_device_info.
-
#management_controller ⇒ Object
Returns the value of attribute management_controller.
-
#network_elements ⇒ Object
An array of relationships to networkElement resources.
-
#object_type ⇒ Object
The fully-qualified name of the instantiated, concrete type.
-
#package_version ⇒ Object
Package version which the firmware belongs to.
-
#pci_switch ⇒ Object
Returns the value of attribute pci_switch.
-
#registered_device ⇒ Object
Returns the value of attribute registered_device.
-
#storage_controller ⇒ Object
Returns the value of attribute storage_controller.
-
#storage_flex_flash_controller ⇒ Object
Returns the value of attribute storage_flex_flash_controller.
-
#storage_physical_disk ⇒ Object
Returns the value of attribute storage_physical_disk.
-
#type ⇒ Object
The type of the firmware.
-
#version ⇒ Object
The version of the firmware.
Attributes inherited from InventoryBase
Attributes inherited from MoBaseMo
#account_moid, #ancestors, #create_time, #display_names, #domain_group_moid, #mod_time, #moid, #owners, #parent, #permission_resources, #shared_scope, #tags, #version_context
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns the key-value map of all the JSON attributes this model knows about, including the ones defined in its parent(s).
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about, including the ones defined in its parent(s).
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_all_of ⇒ Object
List of class defined in allOf (OpenAPI v3).
-
.openapi_discriminator_name ⇒ Object
discriminator’s property name in OpenAPI v3.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ FirmwareRunningFirmware
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ FirmwareRunningFirmware
Initializes the object
156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 |
# File 'lib/intersight_client/models/firmware_running_firmware.rb', line 156 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `IntersightClient::FirmwareRunningFirmware` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `#{self.class.name}`. Please check the name to make sure it's valid. List of attributes: " + self.class.acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } # call parent's initialize super(attributes) if attributes.key?(:'class_id') self.class_id = attributes[:'class_id'] else self.class_id = 'firmware.RunningFirmware' end if attributes.key?(:'object_type') self.object_type = attributes[:'object_type'] else self.object_type = 'firmware.RunningFirmware' end if attributes.key?(:'component') self.component = attributes[:'component'] end if attributes.key?(:'package_version') self.package_version = attributes[:'package_version'] end if attributes.key?(:'type') self.type = attributes[:'type'] end if attributes.key?(:'version') self.version = attributes[:'version'] end if attributes.key?(:'bios_unit') self.bios_unit = attributes[:'bios_unit'] end if attributes.key?(:'graphics_card') self.graphics_card = attributes[:'graphics_card'] end if attributes.key?(:'inventory_device_info') self.inventory_device_info = attributes[:'inventory_device_info'] end if attributes.key?(:'management_controller') self.management_controller = attributes[:'management_controller'] end if attributes.key?(:'network_elements') if (value = attributes[:'network_elements']).is_a?(Array) self.network_elements = value end end if attributes.key?(:'pci_switch') self.pci_switch = attributes[:'pci_switch'] end if attributes.key?(:'registered_device') self.registered_device = attributes[:'registered_device'] end if attributes.key?(:'storage_controller') self.storage_controller = attributes[:'storage_controller'] end if attributes.key?(:'storage_flex_flash_controller') self.storage_flex_flash_controller = attributes[:'storage_flex_flash_controller'] end if attributes.key?(:'storage_physical_disk') self.storage_physical_disk = attributes[:'storage_physical_disk'] end end |
Instance Attribute Details
#bios_unit ⇒ Object
Returns the value of attribute bios_unit.
37 38 39 |
# File 'lib/intersight_client/models/firmware_running_firmware.rb', line 37 def bios_unit @bios_unit end |
#class_id ⇒ Object
The fully-qualified name of the instantiated, concrete type. This property is used as a discriminator to identify the type of the payload when marshaling and unmarshaling data.
20 21 22 |
# File 'lib/intersight_client/models/firmware_running_firmware.rb', line 20 def class_id @class_id end |
#component ⇒ Object
Kind of the firmware - boot-booloader/system/kernel.
26 27 28 |
# File 'lib/intersight_client/models/firmware_running_firmware.rb', line 26 def component @component end |
#graphics_card ⇒ Object
Returns the value of attribute graphics_card.
39 40 41 |
# File 'lib/intersight_client/models/firmware_running_firmware.rb', line 39 def graphics_card @graphics_card end |
#inventory_device_info ⇒ Object
Returns the value of attribute inventory_device_info.
41 42 43 |
# File 'lib/intersight_client/models/firmware_running_firmware.rb', line 41 def inventory_device_info @inventory_device_info end |
#management_controller ⇒ Object
Returns the value of attribute management_controller.
43 44 45 |
# File 'lib/intersight_client/models/firmware_running_firmware.rb', line 43 def management_controller @management_controller end |
#network_elements ⇒ Object
An array of relationships to networkElement resources.
46 47 48 |
# File 'lib/intersight_client/models/firmware_running_firmware.rb', line 46 def network_elements @network_elements end |
#object_type ⇒ Object
The fully-qualified name of the instantiated, concrete type. The value should be the same as the ‘ClassId’ property.
23 24 25 |
# File 'lib/intersight_client/models/firmware_running_firmware.rb', line 23 def object_type @object_type end |
#package_version ⇒ Object
Package version which the firmware belongs to.
29 30 31 |
# File 'lib/intersight_client/models/firmware_running_firmware.rb', line 29 def package_version @package_version end |
#pci_switch ⇒ Object
Returns the value of attribute pci_switch.
48 49 50 |
# File 'lib/intersight_client/models/firmware_running_firmware.rb', line 48 def pci_switch @pci_switch end |
#registered_device ⇒ Object
Returns the value of attribute registered_device.
50 51 52 |
# File 'lib/intersight_client/models/firmware_running_firmware.rb', line 50 def registered_device @registered_device end |
#storage_controller ⇒ Object
Returns the value of attribute storage_controller.
52 53 54 |
# File 'lib/intersight_client/models/firmware_running_firmware.rb', line 52 def storage_controller @storage_controller end |
#storage_flex_flash_controller ⇒ Object
Returns the value of attribute storage_flex_flash_controller.
54 55 56 |
# File 'lib/intersight_client/models/firmware_running_firmware.rb', line 54 def storage_flex_flash_controller @storage_flex_flash_controller end |
#storage_physical_disk ⇒ Object
Returns the value of attribute storage_physical_disk.
56 57 58 |
# File 'lib/intersight_client/models/firmware_running_firmware.rb', line 56 def storage_physical_disk @storage_physical_disk end |
#type ⇒ Object
The type of the firmware.
32 33 34 |
# File 'lib/intersight_client/models/firmware_running_firmware.rb', line 32 def type @type end |
#version ⇒ Object
The version of the firmware.
35 36 37 |
# File 'lib/intersight_client/models/firmware_running_firmware.rb', line 35 def version @version end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns the key-value map of all the JSON attributes this model knows about, including the ones defined in its parent(s)
108 109 110 |
# File 'lib/intersight_client/models/firmware_running_firmware.rb', line 108 def self.acceptable_attribute_map attribute_map.merge(superclass.acceptable_attribute_map) end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about, including the ones defined in its parent(s)
103 104 105 |
# File 'lib/intersight_client/models/firmware_running_firmware.rb', line 103 def self.acceptable_attributes attribute_map.values.concat(superclass.acceptable_attributes) end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 |
# File 'lib/intersight_client/models/firmware_running_firmware.rb', line 81 def self.attribute_map { :'class_id' => :'ClassId', :'object_type' => :'ObjectType', :'component' => :'Component', :'package_version' => :'PackageVersion', :'type' => :'Type', :'version' => :'Version', :'bios_unit' => :'BiosUnit', :'graphics_card' => :'GraphicsCard', :'inventory_device_info' => :'InventoryDeviceInfo', :'management_controller' => :'ManagementController', :'network_elements' => :'NetworkElements', :'pci_switch' => :'PciSwitch', :'registered_device' => :'RegisteredDevice', :'storage_controller' => :'StorageController', :'storage_flex_flash_controller' => :'StorageFlexFlashController', :'storage_physical_disk' => :'StoragePhysicalDisk' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
328 329 330 |
# File 'lib/intersight_client/models/firmware_running_firmware.rb', line 328 def self.build_from_hash(attributes) new.build_from_hash(attributes) end |
.openapi_all_of ⇒ Object
List of class defined in allOf (OpenAPI v3)
142 143 144 145 146 147 |
# File 'lib/intersight_client/models/firmware_running_firmware.rb', line 142 def self.openapi_all_of [ :'FirmwareRunningFirmwareAllOf', :'InventoryBase' ] end |
.openapi_discriminator_name ⇒ Object
discriminator’s property name in OpenAPI v3
150 151 152 |
# File 'lib/intersight_client/models/firmware_running_firmware.rb', line 150 def self.openapi_discriminator_name :'ClassId' end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
135 136 137 138 139 |
# File 'lib/intersight_client/models/firmware_running_firmware.rb', line 135 def self.openapi_nullable Set.new([ :'network_elements', ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 |
# File 'lib/intersight_client/models/firmware_running_firmware.rb', line 113 def self.openapi_types { :'class_id' => :'String', :'object_type' => :'String', :'component' => :'String', :'package_version' => :'String', :'type' => :'String', :'version' => :'String', :'bios_unit' => :'BiosUnitRelationship', :'graphics_card' => :'GraphicsCardRelationship', :'inventory_device_info' => :'InventoryDeviceInfoRelationship', :'management_controller' => :'ManagementControllerRelationship', :'network_elements' => :'Array<NetworkElementRelationship>', :'pci_switch' => :'PciSwitchRelationship', :'registered_device' => :'AssetDeviceRegistrationRelationship', :'storage_controller' => :'StorageControllerRelationship', :'storage_flex_flash_controller' => :'StorageFlexFlashControllerRelationship', :'storage_physical_disk' => :'StoragePhysicalDiskRelationship' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 |
# File 'lib/intersight_client/models/firmware_running_firmware.rb', line 292 def ==(o) return true if self.equal?(o) self.class == o.class && class_id == o.class_id && object_type == o.object_type && component == o.component && package_version == o.package_version && type == o.type && version == o.version && bios_unit == o.bios_unit && graphics_card == o.graphics_card && inventory_device_info == o.inventory_device_info && management_controller == o.management_controller && network_elements == o.network_elements && pci_switch == o.pci_switch && registered_device == o.registered_device && storage_controller == o.storage_controller && storage_flex_flash_controller == o.storage_flex_flash_controller && storage_physical_disk == o.storage_physical_disk && super(o) end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 |
# File 'lib/intersight_client/models/firmware_running_firmware.rb', line 359 def _deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = IntersightClient.const_get(type) klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
430 431 432 433 434 435 436 437 438 439 440 441 442 |
# File 'lib/intersight_client/models/firmware_running_firmware.rb', line 430 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 |
# File 'lib/intersight_client/models/firmware_running_firmware.rb', line 335 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) super(attributes) FirmwareRunningFirmware.openapi_types.each_pair do |key, type| if attributes[FirmwareRunningFirmware.attribute_map[key]].nil? && FirmwareRunningFirmware.openapi_nullable.include?(key) self.send("#{key}=", nil) elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[FirmwareRunningFirmware.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[FirmwareRunningFirmware.attribute_map[key]].map { |v| _deserialize($1, v) }) end elsif !attributes[FirmwareRunningFirmware.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[FirmwareRunningFirmware.attribute_map[key]])) end end self end |
#eql?(o) ⇒ Boolean
315 316 317 |
# File 'lib/intersight_client/models/firmware_running_firmware.rb', line 315 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
321 322 323 |
# File 'lib/intersight_client/models/firmware_running_firmware.rb', line 321 def hash [class_id, object_type, component, package_version, type, version, bios_unit, graphics_card, inventory_device_info, management_controller, network_elements, pci_switch, registered_device, storage_controller, storage_flex_flash_controller, storage_physical_disk].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
245 246 247 248 249 250 251 252 253 254 255 256 |
# File 'lib/intersight_client/models/firmware_running_firmware.rb', line 245 def list_invalid_properties invalid_properties = super if @class_id.nil? invalid_properties.push('invalid value for "class_id", class_id cannot be nil.') end if @object_type.nil? invalid_properties.push('invalid value for "object_type", object_type cannot be nil.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
406 407 408 |
# File 'lib/intersight_client/models/firmware_running_firmware.rb', line 406 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
412 413 414 415 416 417 418 419 420 421 422 423 424 |
# File 'lib/intersight_client/models/firmware_running_firmware.rb', line 412 def to_hash hash = super FirmwareRunningFirmware.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = FirmwareRunningFirmware.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
400 401 402 |
# File 'lib/intersight_client/models/firmware_running_firmware.rb', line 400 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
260 261 262 263 264 265 266 267 268 |
# File 'lib/intersight_client/models/firmware_running_firmware.rb', line 260 def valid? return false if @class_id.nil? class_id_validator = EnumAttributeValidator.new('String', ["firmware.RunningFirmware"]) return false unless class_id_validator.valid?(@class_id) return false if @object_type.nil? object_type_validator = EnumAttributeValidator.new('String', ["firmware.RunningFirmware"]) return false unless object_type_validator.valid?(@object_type) true && super end |