Class: IntersightClient::ForecastInstanceAllOf

Inherits:
Object
  • Object
show all
Defined in:
lib/intersight_client/models/forecast_instance_all_of.rb

Overview

Definition of the list of properties defined in ‘forecast.Instance’, excluding properties defined in parent classes.

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ ForecastInstanceAllOf

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
# File 'lib/intersight_client/models/forecast_instance_all_of.rb', line 144

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `IntersightClient::ForecastInstanceAllOf` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `#{self.class.name}`. Please check the name to make sure it's valid. List of attributes: " + self.class.acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'class_id')
    self.class_id = attributes[:'class_id']
  else
    self.class_id = 'forecast.Instance'
  end

  if attributes.key?(:'object_type')
    self.object_type = attributes[:'object_type']
  else
    self.object_type = 'forecast.Instance'
  end

  if attributes.key?(:'action')
    self.action = attributes[:'action']
  else
    self.action = 'None'
  end

  if attributes.key?(:'alt_model')
    if (value = attributes[:'alt_model']).is_a?(Array)
      self.alt_model = value
    end
  end

  if attributes.key?(:'data_interval')
    self.data_interval = attributes[:'data_interval']
  else
    self.data_interval = 180
  end

  if attributes.key?(:'data_start_date')
    self.data_start_date = attributes[:'data_start_date']
  end

  if attributes.key?(:'device_id')
    self.device_id = attributes[:'device_id']
  end

  if attributes.key?(:'full_cap_days')
    self.full_cap_days = attributes[:'full_cap_days']
  end

  if attributes.key?(:'last_model_update_time')
    self.last_model_update_time = attributes[:'last_model_update_time']
  end

  if attributes.key?(:'metric_name')
    self.metric_name = attributes[:'metric_name']
  end

  if attributes.key?(:'min_days_for_forecast')
    self.min_days_for_forecast = attributes[:'min_days_for_forecast']
  end

  if attributes.key?(:'model')
    self.model = attributes[:'model']
  end

  if attributes.key?(:'threshold_days')
    self.threshold_days = attributes[:'threshold_days']
  else
    self.threshold_days = 2147483647
  end

  if attributes.key?(:'forecast_def')
    self.forecast_def = attributes[:'forecast_def']
  end

  if attributes.key?(:'registered_device')
    self.registered_device = attributes[:'registered_device']
  end
end

Instance Attribute Details

#actionObject

Action to be triggered on forecast instance. Default value is None. * None - The Enum value None represents that no action is triggered on the forecast Instance managed object. * Evaluate - The Enum value Evaluate represents that a re-evaluation of the forecast needs to be triggered.



26
27
28
# File 'lib/intersight_client/models/forecast_instance_all_of.rb', line 26

def action
  @action
end

#alt_modelObject

Returns the value of attribute alt_model.



28
29
30
# File 'lib/intersight_client/models/forecast_instance_all_of.rb', line 28

def alt_model
  @alt_model
end

#class_idObject

The fully-qualified name of the instantiated, concrete type. This property is used as a discriminator to identify the type of the payload when marshaling and unmarshaling data.



20
21
22
# File 'lib/intersight_client/models/forecast_instance_all_of.rb', line 20

def class_id
  @class_id
end

#data_intervalObject

The time interval (in days) for the data to be used for computing forecast model.



31
32
33
# File 'lib/intersight_client/models/forecast_instance_all_of.rb', line 31

def data_interval
  @data_interval
end

#data_start_dateObject

The start date from when the data should be used for computing forecast model.



34
35
36
# File 'lib/intersight_client/models/forecast_instance_all_of.rb', line 34

def data_start_date
  @data_start_date
end

#device_idObject

The Moid of the Intersight managed device instance for which regression model is derived.



37
38
39
# File 'lib/intersight_client/models/forecast_instance_all_of.rb', line 37

def device_id
  @device_id
end

#forecast_defObject

Returns the value of attribute forecast_def.



56
57
58
# File 'lib/intersight_client/models/forecast_instance_all_of.rb', line 56

def forecast_def
  @forecast_def
end

#full_cap_daysObject

The number of days remaining before the device reaches its full functional capacity.



40
41
42
# File 'lib/intersight_client/models/forecast_instance_all_of.rb', line 40

def full_cap_days
  @full_cap_days
end

#last_model_update_timeObject

The time when the forecast model was last updated.



43
44
45
# File 'lib/intersight_client/models/forecast_instance_all_of.rb', line 43

def last_model_update_time
  @last_model_update_time
end

#metric_nameObject

The name of the metric for which regression model is generated.



46
47
48
# File 'lib/intersight_client/models/forecast_instance_all_of.rb', line 46

def metric_name
  @metric_name
end

#min_days_for_forecastObject

The minimum number of days the HyperFlex cluster should be up for computing forecast.



49
50
51
# File 'lib/intersight_client/models/forecast_instance_all_of.rb', line 49

def min_days_for_forecast
  @min_days_for_forecast
end

#modelObject

Returns the value of attribute model.



51
52
53
# File 'lib/intersight_client/models/forecast_instance_all_of.rb', line 51

def model
  @model
end

#object_typeObject

The fully-qualified name of the instantiated, concrete type. The value should be the same as the ‘ClassId’ property.



23
24
25
# File 'lib/intersight_client/models/forecast_instance_all_of.rb', line 23

def object_type
  @object_type
end

#registered_deviceObject

Returns the value of attribute registered_device.



58
59
60
# File 'lib/intersight_client/models/forecast_instance_all_of.rb', line 58

def registered_device
  @registered_device
end

#threshold_daysObject

The number of days remaining before the device reaches the specified threshold for the metric as defined in definition.



54
55
56
# File 'lib/intersight_client/models/forecast_instance_all_of.rb', line 54

def threshold_days
  @threshold_days
end

Class Method Details

.acceptable_attribute_mapObject

Returns the key-value map of all the JSON attributes this model knows about



109
110
111
# File 'lib/intersight_client/models/forecast_instance_all_of.rb', line 109

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



104
105
106
# File 'lib/intersight_client/models/forecast_instance_all_of.rb', line 104

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
# File 'lib/intersight_client/models/forecast_instance_all_of.rb', line 83

def self.attribute_map
  {
    :'class_id' => :'ClassId',
    :'object_type' => :'ObjectType',
    :'action' => :'Action',
    :'alt_model' => :'AltModel',
    :'data_interval' => :'DataInterval',
    :'data_start_date' => :'DataStartDate',
    :'device_id' => :'DeviceId',
    :'full_cap_days' => :'FullCapDays',
    :'last_model_update_time' => :'LastModelUpdateTime',
    :'metric_name' => :'MetricName',
    :'min_days_for_forecast' => :'MinDaysForForecast',
    :'model' => :'Model',
    :'threshold_days' => :'ThresholdDays',
    :'forecast_def' => :'ForecastDef',
    :'registered_device' => :'RegisteredDevice'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



350
351
352
# File 'lib/intersight_client/models/forecast_instance_all_of.rb', line 350

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_nullableObject

List of attributes with nullable: true



135
136
137
138
139
140
# File 'lib/intersight_client/models/forecast_instance_all_of.rb', line 135

def self.openapi_nullable
  Set.new([
    :'alt_model',
    :'model',
  ])
end

.openapi_typesObject

Attribute type mapping.



114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
# File 'lib/intersight_client/models/forecast_instance_all_of.rb', line 114

def self.openapi_types
  {
    :'class_id' => :'String',
    :'object_type' => :'String',
    :'action' => :'String',
    :'alt_model' => :'Array<Float>',
    :'data_interval' => :'Integer',
    :'data_start_date' => :'Time',
    :'device_id' => :'String',
    :'full_cap_days' => :'Integer',
    :'last_model_update_time' => :'Time',
    :'metric_name' => :'String',
    :'min_days_for_forecast' => :'Integer',
    :'model' => :'ForecastModel',
    :'threshold_days' => :'Integer',
    :'forecast_def' => :'ForecastDefinitionRelationship',
    :'registered_device' => :'AssetDeviceRegistrationRelationship'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
# File 'lib/intersight_client/models/forecast_instance_all_of.rb', line 315

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      class_id == o.class_id &&
      object_type == o.object_type &&
      action == o.action &&
      alt_model == o.alt_model &&
      data_interval == o.data_interval &&
      data_start_date == o.data_start_date &&
      device_id == o.device_id &&
      full_cap_days == o.full_cap_days &&
      last_model_update_time == o.last_model_update_time &&
      metric_name == o.metric_name &&
      min_days_for_forecast == o.min_days_for_forecast &&
      model == o.model &&
      threshold_days == o.threshold_days &&
      forecast_def == o.forecast_def &&
      registered_device == o.registered_device
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
410
411
412
413
414
415
416
417
# File 'lib/intersight_client/models/forecast_instance_all_of.rb', line 380

def _deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = IntersightClient.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



451
452
453
454
455
456
457
458
459
460
461
462
463
# File 'lib/intersight_client/models/forecast_instance_all_of.rb', line 451

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
# File 'lib/intersight_client/models/forecast_instance_all_of.rb', line 357

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  ForecastInstanceAllOf.openapi_types.each_pair do |key, type|
    if attributes[ForecastInstanceAllOf.attribute_map[key]].nil? && ForecastInstanceAllOf.openapi_nullable.include?(key)
      self.send("#{key}=", nil)
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[ForecastInstanceAllOf.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[ForecastInstanceAllOf.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[ForecastInstanceAllOf.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[ForecastInstanceAllOf.attribute_map[key]]))
    end
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


337
338
339
# File 'lib/intersight_client/models/forecast_instance_all_of.rb', line 337

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



343
344
345
# File 'lib/intersight_client/models/forecast_instance_all_of.rb', line 343

def hash
  [class_id, object_type, action, alt_model, data_interval, data_start_date, device_id, full_cap_days, last_model_update_time, metric_name, min_days_for_forecast, model, threshold_days, forecast_def, registered_device].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
# File 'lib/intersight_client/models/forecast_instance_all_of.rb', line 232

def list_invalid_properties
  invalid_properties = Array.new
  if @class_id.nil?
    invalid_properties.push('invalid value for "class_id", class_id cannot be nil.')
  end

  if @object_type.nil?
    invalid_properties.push('invalid value for "object_type", object_type cannot be nil.')
  end

  if !@data_interval.nil? && @data_interval > 365
    invalid_properties.push('invalid value for "data_interval", must be smaller than or equal to 365.')
  end

  if !@data_interval.nil? && @data_interval < 60
    invalid_properties.push('invalid value for "data_interval", must be greater than or equal to 60.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



427
428
429
# File 'lib/intersight_client/models/forecast_instance_all_of.rb', line 427

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



433
434
435
436
437
438
439
440
441
442
443
444
445
# File 'lib/intersight_client/models/forecast_instance_all_of.rb', line 433

def to_hash
  hash = {}
  ForecastInstanceAllOf.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = ForecastInstanceAllOf.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



421
422
423
# File 'lib/intersight_client/models/forecast_instance_all_of.rb', line 421

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



255
256
257
258
259
260
261
262
263
264
265
266
267
# File 'lib/intersight_client/models/forecast_instance_all_of.rb', line 255

def valid?
  return false if @class_id.nil?
  class_id_validator = EnumAttributeValidator.new('String', ["forecast.Instance"])
  return false unless class_id_validator.valid?(@class_id)
  return false if @object_type.nil?
  object_type_validator = EnumAttributeValidator.new('String', ["forecast.Instance"])
  return false unless object_type_validator.valid?(@object_type)
  action_validator = EnumAttributeValidator.new('String', ["None", "Evaluate"])
  return false unless action_validator.valid?(@action)
  return false if !@data_interval.nil? && @data_interval > 365
  return false if !@data_interval.nil? && @data_interval < 60
  true
end