Class: IntersightClient::HyperflexClusterReplicationNetworkPolicy
- Inherits:
-
PolicyAbstractPolicy
- Object
- MoBaseMo
- PolicyAbstractPolicy
- IntersightClient::HyperflexClusterReplicationNetworkPolicy
- Defined in:
- lib/intersight_client/models/hyperflex_cluster_replication_network_policy.rb
Overview
Specifies all replication network parameters for the cluster.
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#class_id ⇒ Object
The fully-qualified name of the instantiated, concrete type.
-
#cluster_profiles ⇒ Object
An array of relationships to hyperflexClusterProfile resources.
-
#object_type ⇒ Object
The fully-qualified name of the instantiated, concrete type.
-
#organization ⇒ Object
Returns the value of attribute organization.
-
#replication_bandwidth_mbps ⇒ Object
Bandwidth for the Replication network in Mbps.
-
#replication_ipranges ⇒ Object
Returns the value of attribute replication_ipranges.
-
#replication_mtu ⇒ Object
MTU for the Replication network.
-
#replication_vlan ⇒ Object
Returns the value of attribute replication_vlan.
Attributes inherited from PolicyAbstractPolicy
Attributes inherited from MoBaseMo
#account_moid, #ancestors, #create_time, #display_names, #domain_group_moid, #mod_time, #moid, #owners, #parent, #permission_resources, #shared_scope, #tags, #version_context
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns the key-value map of all the JSON attributes this model knows about, including the ones defined in its parent(s).
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about, including the ones defined in its parent(s).
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_all_of ⇒ Object
List of class defined in allOf (OpenAPI v3).
-
.openapi_discriminator_name ⇒ Object
discriminator’s property name in OpenAPI v3.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ HyperflexClusterReplicationNetworkPolicy
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ HyperflexClusterReplicationNetworkPolicy
Initializes the object
124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 |
# File 'lib/intersight_client/models/hyperflex_cluster_replication_network_policy.rb', line 124 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `IntersightClient::HyperflexClusterReplicationNetworkPolicy` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `#{self.class.name}`. Please check the name to make sure it's valid. List of attributes: " + self.class.acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } # call parent's initialize super(attributes) if attributes.key?(:'class_id') self.class_id = attributes[:'class_id'] else self.class_id = 'hyperflex.ClusterReplicationNetworkPolicy' end if attributes.key?(:'object_type') self.object_type = attributes[:'object_type'] else self.object_type = 'hyperflex.ClusterReplicationNetworkPolicy' end if attributes.key?(:'replication_bandwidth_mbps') self.replication_bandwidth_mbps = attributes[:'replication_bandwidth_mbps'] else self.replication_bandwidth_mbps = 0 end if attributes.key?(:'replication_ipranges') if (value = attributes[:'replication_ipranges']).is_a?(Array) self.replication_ipranges = value end end if attributes.key?(:'replication_mtu') self.replication_mtu = attributes[:'replication_mtu'] else self.replication_mtu = 1500 end if attributes.key?(:'replication_vlan') self.replication_vlan = attributes[:'replication_vlan'] end if attributes.key?(:'cluster_profiles') if (value = attributes[:'cluster_profiles']).is_a?(Array) self.cluster_profiles = value end end if attributes.key?(:'organization') self.organization = attributes[:'organization'] end end |
Instance Attribute Details
#class_id ⇒ Object
The fully-qualified name of the instantiated, concrete type. This property is used as a discriminator to identify the type of the payload when marshaling and unmarshaling data.
20 21 22 |
# File 'lib/intersight_client/models/hyperflex_cluster_replication_network_policy.rb', line 20 def class_id @class_id end |
#cluster_profiles ⇒ Object
An array of relationships to hyperflexClusterProfile resources.
36 37 38 |
# File 'lib/intersight_client/models/hyperflex_cluster_replication_network_policy.rb', line 36 def cluster_profiles @cluster_profiles end |
#object_type ⇒ Object
The fully-qualified name of the instantiated, concrete type. The value should be the same as the ‘ClassId’ property.
23 24 25 |
# File 'lib/intersight_client/models/hyperflex_cluster_replication_network_policy.rb', line 23 def object_type @object_type end |
#organization ⇒ Object
Returns the value of attribute organization.
38 39 40 |
# File 'lib/intersight_client/models/hyperflex_cluster_replication_network_policy.rb', line 38 def organization @organization end |
#replication_bandwidth_mbps ⇒ Object
Bandwidth for the Replication network in Mbps.
26 27 28 |
# File 'lib/intersight_client/models/hyperflex_cluster_replication_network_policy.rb', line 26 def replication_bandwidth_mbps @replication_bandwidth_mbps end |
#replication_ipranges ⇒ Object
Returns the value of attribute replication_ipranges.
28 29 30 |
# File 'lib/intersight_client/models/hyperflex_cluster_replication_network_policy.rb', line 28 def replication_ipranges @replication_ipranges end |
#replication_mtu ⇒ Object
MTU for the Replication network.
31 32 33 |
# File 'lib/intersight_client/models/hyperflex_cluster_replication_network_policy.rb', line 31 def replication_mtu @replication_mtu end |
#replication_vlan ⇒ Object
Returns the value of attribute replication_vlan.
33 34 35 |
# File 'lib/intersight_client/models/hyperflex_cluster_replication_network_policy.rb', line 33 def replication_vlan @replication_vlan end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns the key-value map of all the JSON attributes this model knows about, including the ones defined in its parent(s)
82 83 84 |
# File 'lib/intersight_client/models/hyperflex_cluster_replication_network_policy.rb', line 82 def self.acceptable_attribute_map attribute_map.merge(superclass.acceptable_attribute_map) end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about, including the ones defined in its parent(s)
77 78 79 |
# File 'lib/intersight_client/models/hyperflex_cluster_replication_network_policy.rb', line 77 def self.acceptable_attributes attribute_map.values.concat(superclass.acceptable_attributes) end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
63 64 65 66 67 68 69 70 71 72 73 74 |
# File 'lib/intersight_client/models/hyperflex_cluster_replication_network_policy.rb', line 63 def self.attribute_map { :'class_id' => :'ClassId', :'object_type' => :'ObjectType', :'replication_bandwidth_mbps' => :'ReplicationBandwidthMbps', :'replication_ipranges' => :'ReplicationIpranges', :'replication_mtu' => :'ReplicationMtu', :'replication_vlan' => :'ReplicationVlan', :'cluster_profiles' => :'ClusterProfiles', :'organization' => :'Organization' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
325 326 327 |
# File 'lib/intersight_client/models/hyperflex_cluster_replication_network_policy.rb', line 325 def self.build_from_hash(attributes) new.build_from_hash(attributes) end |
.openapi_all_of ⇒ Object
List of class defined in allOf (OpenAPI v3)
110 111 112 113 114 115 |
# File 'lib/intersight_client/models/hyperflex_cluster_replication_network_policy.rb', line 110 def self.openapi_all_of [ :'HyperflexClusterReplicationNetworkPolicyAllOf', :'PolicyAbstractPolicy' ] end |
.openapi_discriminator_name ⇒ Object
discriminator’s property name in OpenAPI v3
118 119 120 |
# File 'lib/intersight_client/models/hyperflex_cluster_replication_network_policy.rb', line 118 def self.openapi_discriminator_name :'ClassId' end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
101 102 103 104 105 106 107 |
# File 'lib/intersight_client/models/hyperflex_cluster_replication_network_policy.rb', line 101 def self.openapi_nullable Set.new([ :'replication_ipranges', :'replication_vlan', :'cluster_profiles', ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
87 88 89 90 91 92 93 94 95 96 97 98 |
# File 'lib/intersight_client/models/hyperflex_cluster_replication_network_policy.rb', line 87 def self.openapi_types { :'class_id' => :'String', :'object_type' => :'String', :'replication_bandwidth_mbps' => :'Integer', :'replication_ipranges' => :'Array<HyperflexIpAddrRange>', :'replication_mtu' => :'Integer', :'replication_vlan' => :'HyperflexNamedVlan', :'cluster_profiles' => :'Array<HyperflexClusterProfileRelationship>', :'organization' => :'OrganizationOrganizationRelationship' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
297 298 299 300 301 302 303 304 305 306 307 308 |
# File 'lib/intersight_client/models/hyperflex_cluster_replication_network_policy.rb', line 297 def ==(o) return true if self.equal?(o) self.class == o.class && class_id == o.class_id && object_type == o.object_type && replication_bandwidth_mbps == o.replication_bandwidth_mbps && replication_ipranges == o.replication_ipranges && replication_mtu == o.replication_mtu && replication_vlan == o.replication_vlan && cluster_profiles == o.cluster_profiles && organization == o.organization && super(o) end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 |
# File 'lib/intersight_client/models/hyperflex_cluster_replication_network_policy.rb', line 356 def _deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = IntersightClient.const_get(type) klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
427 428 429 430 431 432 433 434 435 436 437 438 439 |
# File 'lib/intersight_client/models/hyperflex_cluster_replication_network_policy.rb', line 427 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 |
# File 'lib/intersight_client/models/hyperflex_cluster_replication_network_policy.rb', line 332 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) super(attributes) HyperflexClusterReplicationNetworkPolicy.openapi_types.each_pair do |key, type| if attributes[HyperflexClusterReplicationNetworkPolicy.attribute_map[key]].nil? && HyperflexClusterReplicationNetworkPolicy.openapi_nullable.include?(key) self.send("#{key}=", nil) elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[HyperflexClusterReplicationNetworkPolicy.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[HyperflexClusterReplicationNetworkPolicy.attribute_map[key]].map { |v| _deserialize($1, v) }) end elsif !attributes[HyperflexClusterReplicationNetworkPolicy.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[HyperflexClusterReplicationNetworkPolicy.attribute_map[key]])) end end self end |
#eql?(o) ⇒ Boolean
312 313 314 |
# File 'lib/intersight_client/models/hyperflex_cluster_replication_network_policy.rb', line 312 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
318 319 320 |
# File 'lib/intersight_client/models/hyperflex_cluster_replication_network_policy.rb', line 318 def hash [class_id, object_type, replication_bandwidth_mbps, replication_ipranges, replication_mtu, replication_vlan, cluster_profiles, organization].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 |
# File 'lib/intersight_client/models/hyperflex_cluster_replication_network_policy.rb', line 187 def list_invalid_properties invalid_properties = super if @class_id.nil? invalid_properties.push('invalid value for "class_id", class_id cannot be nil.') end if @object_type.nil? invalid_properties.push('invalid value for "object_type", object_type cannot be nil.') end if !@replication_bandwidth_mbps.nil? && @replication_bandwidth_mbps > 100000 invalid_properties.push('invalid value for "replication_bandwidth_mbps", must be smaller than or equal to 100000.') end if !@replication_bandwidth_mbps.nil? && @replication_bandwidth_mbps < 0 invalid_properties.push('invalid value for "replication_bandwidth_mbps", must be greater than or equal to 0.') end if !@replication_ipranges.nil? && @replication_ipranges.length < 1 invalid_properties.push('invalid value for "replication_ipranges", number of items must be greater than or equal to 1.') end if !@replication_mtu.nil? && @replication_mtu > 1500 invalid_properties.push('invalid value for "replication_mtu", must be smaller than or equal to 1500.') end if !@replication_mtu.nil? && @replication_mtu < 1024 invalid_properties.push('invalid value for "replication_mtu", must be greater than or equal to 1024.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
403 404 405 |
# File 'lib/intersight_client/models/hyperflex_cluster_replication_network_policy.rb', line 403 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
409 410 411 412 413 414 415 416 417 418 419 420 421 |
# File 'lib/intersight_client/models/hyperflex_cluster_replication_network_policy.rb', line 409 def to_hash hash = super HyperflexClusterReplicationNetworkPolicy.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = HyperflexClusterReplicationNetworkPolicy.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
397 398 399 |
# File 'lib/intersight_client/models/hyperflex_cluster_replication_network_policy.rb', line 397 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
222 223 224 225 226 227 228 229 230 231 232 233 234 235 |
# File 'lib/intersight_client/models/hyperflex_cluster_replication_network_policy.rb', line 222 def valid? return false if @class_id.nil? class_id_validator = EnumAttributeValidator.new('String', ["hyperflex.ClusterReplicationNetworkPolicy"]) return false unless class_id_validator.valid?(@class_id) return false if @object_type.nil? object_type_validator = EnumAttributeValidator.new('String', ["hyperflex.ClusterReplicationNetworkPolicy"]) return false unless object_type_validator.valid?(@object_type) return false if !@replication_bandwidth_mbps.nil? && @replication_bandwidth_mbps > 100000 return false if !@replication_bandwidth_mbps.nil? && @replication_bandwidth_mbps < 0 return false if !@replication_ipranges.nil? && @replication_ipranges.length < 1 return false if !@replication_mtu.nil? && @replication_mtu > 1500 return false if !@replication_mtu.nil? && @replication_mtu < 1024 true && super end |