Class: IntersightClient::HyperflexHealth

Inherits:
MoBaseMo
  • Object
show all
Defined in:
lib/intersight_client/models/hyperflex_health.rb

Overview

The data health status and ability of the HyperFlex storage cluster to tolerate failures.

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Attributes inherited from MoBaseMo

#account_moid, #ancestors, #create_time, #display_names, #domain_group_moid, #mod_time, #moid, #owners, #parent, #permission_resources, #shared_scope, #tags, #version_context

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ HyperflexHealth

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
# File 'lib/intersight_client/models/hyperflex_health.rb', line 133

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `IntersightClient::HyperflexHealth` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `#{self.class.name}`. Please check the name to make sure it's valid. List of attributes: " + self.class.acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  # call parent's initialize
  super(attributes)

  if attributes.key?(:'class_id')
    self.class_id = attributes[:'class_id']
  else
    self.class_id = 'hyperflex.Health'
  end

  if attributes.key?(:'object_type')
    self.object_type = attributes[:'object_type']
  else
    self.object_type = 'hyperflex.Health'
  end

  if attributes.key?(:'arbitration_service_state')
    self.arbitration_service_state = attributes[:'arbitration_service_state']
  else
    self.arbitration_service_state = 'NOT_AVAILABLE'
  end

  if attributes.key?(:'data_replication_compliance')
    self.data_replication_compliance = attributes[:'data_replication_compliance']
  else
    self.data_replication_compliance = 'UNKNOWN'
  end

  if attributes.key?(:'resiliency_details')
    self.resiliency_details = attributes[:'resiliency_details']
  end

  if attributes.key?(:'state')
    self.state = attributes[:'state']
  else
    self.state = 'UNKNOWN'
  end

  if attributes.key?(:'uuid')
    self.uuid = attributes[:'uuid']
  end

  if attributes.key?(:'zk_health')
    self.zk_health = attributes[:'zk_health']
  else
    self.zk_health = 'NOT_AVAILABLE'
  end

  if attributes.key?(:'zone_resiliency_list')
    if (value = attributes[:'zone_resiliency_list']).is_a?(Array)
      self.zone_resiliency_list = value
    end
  end

  if attributes.key?(:'cluster')
    self.cluster = attributes[:'cluster']
  end
end

Instance Attribute Details

#arbitration_service_stateObject

The status of the HyperFlex cluster’s connection to the Intersight arbitration service. The arbitration service state is only applicable to 2-node edge clusters. * NOT_AVAILABLE - The cluster does not require a connection to the arbitration service. * UNKNOWN - The cluster’s connection state to the arbitration service cannot be determined. * ONLINE - The cluster is connected to the arbitration service. * OFFLINE - The cluster is disconnected from the arbitration service.



26
27
28
# File 'lib/intersight_client/models/hyperflex_health.rb', line 26

def arbitration_service_state
  @arbitration_service_state
end

#class_idObject

The fully-qualified name of the instantiated, concrete type. This property is used as a discriminator to identify the type of the payload when marshaling and unmarshaling data.



20
21
22
# File 'lib/intersight_client/models/hyperflex_health.rb', line 20

def class_id
  @class_id
end

#clusterObject

Returns the value of attribute cluster.



44
45
46
# File 'lib/intersight_client/models/hyperflex_health.rb', line 44

def cluster
  @cluster
end

#data_replication_complianceObject

The HyperFlex cluster’s compliance to the configured replication factor. It indicates that the compliance has degraded if the number of copies of data is reduced. * UNKNOWN - The replication compliance of the HyperFlex cluster is not known. * COMPLIANT - The HyperFlex cluster is compliant with the replication policy. All data on the cluster is replicated according to the configured replication factor. * NON_COMPLIANT - The HyperFlex cluster is not compliant with the replication policy. Some data on the cluster is not replicated in accordance with the configured replication factor.



29
30
31
# File 'lib/intersight_client/models/hyperflex_health.rb', line 29

def data_replication_compliance
  @data_replication_compliance
end

#object_typeObject

The fully-qualified name of the instantiated, concrete type. The value should be the same as the ‘ClassId’ property.



23
24
25
# File 'lib/intersight_client/models/hyperflex_health.rb', line 23

def object_type
  @object_type
end

#resiliency_detailsObject

Returns the value of attribute resiliency_details.



31
32
33
# File 'lib/intersight_client/models/hyperflex_health.rb', line 31

def resiliency_details
  @resiliency_details
end

#stateObject

The operational status of the HyperFlex cluster. * UNKNOWN - The operational status of the cluster cannot be determined. * ONLINE - The HyperFlex cluster is online and is performing IO operations. * OFFLINE - The HyperFlex cluster is offline and is not ready to perform IO operations. * ENOSPACE - The HyperFlex cluster is out of available storage capacity and cannot perform write transactions. * READONLY - The HyperFlex cluster is not accepting write transactions, but can still display static cluster information.



34
35
36
# File 'lib/intersight_client/models/hyperflex_health.rb', line 34

def state
  @state
end

#uuidObject

The unique identifier for the cluster.



37
38
39
# File 'lib/intersight_client/models/hyperflex_health.rb', line 37

def uuid
  @uuid
end

#zk_healthObject

The health status of the HyperFlex cluster’s zookeeper ensemble. * NOT_AVAILABLE - The operational status of the ZK ensemble is not provided by the HyperFlex cluster. * UNKNOWN - The operational status of the ZK ensemble cannot be determined. * ONLINE - The ZK ensemble is online and operational. * OFFLINE - The ZK ensemble is offline and not operational.



40
41
42
# File 'lib/intersight_client/models/hyperflex_health.rb', line 40

def zk_health
  @zk_health
end

#zone_resiliency_listObject

Returns the value of attribute zone_resiliency_list.



42
43
44
# File 'lib/intersight_client/models/hyperflex_health.rb', line 42

def zone_resiliency_list
  @zone_resiliency_list
end

Class Method Details

.acceptable_attribute_mapObject

Returns the key-value map of all the JSON attributes this model knows about, including the ones defined in its parent(s)



90
91
92
# File 'lib/intersight_client/models/hyperflex_health.rb', line 90

def self.acceptable_attribute_map
  attribute_map.merge(superclass.acceptable_attribute_map)
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about, including the ones defined in its parent(s)



85
86
87
# File 'lib/intersight_client/models/hyperflex_health.rb', line 85

def self.acceptable_attributes
  attribute_map.values.concat(superclass.acceptable_attributes)
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



69
70
71
72
73
74
75
76
77
78
79
80
81
82
# File 'lib/intersight_client/models/hyperflex_health.rb', line 69

def self.attribute_map
  {
    :'class_id' => :'ClassId',
    :'object_type' => :'ObjectType',
    :'arbitration_service_state' => :'ArbitrationServiceState',
    :'data_replication_compliance' => :'DataReplicationCompliance',
    :'resiliency_details' => :'ResiliencyDetails',
    :'state' => :'State',
    :'uuid' => :'Uuid',
    :'zk_health' => :'ZkHealth',
    :'zone_resiliency_list' => :'ZoneResiliencyList',
    :'cluster' => :'Cluster'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



331
332
333
# File 'lib/intersight_client/models/hyperflex_health.rb', line 331

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_all_ofObject

List of class defined in allOf (OpenAPI v3)



119
120
121
122
123
124
# File 'lib/intersight_client/models/hyperflex_health.rb', line 119

def self.openapi_all_of
  [
  :'HyperflexHealthAllOf',
  :'MoBaseMo'
  ]
end

.openapi_discriminator_nameObject

discriminator’s property name in OpenAPI v3



127
128
129
# File 'lib/intersight_client/models/hyperflex_health.rb', line 127

def self.openapi_discriminator_name
  :'ClassId'
end

.openapi_nullableObject

List of attributes with nullable: true



111
112
113
114
115
116
# File 'lib/intersight_client/models/hyperflex_health.rb', line 111

def self.openapi_nullable
  Set.new([
    :'resiliency_details',
    :'zone_resiliency_list',
  ])
end

.openapi_typesObject

Attribute type mapping.



95
96
97
98
99
100
101
102
103
104
105
106
107
108
# File 'lib/intersight_client/models/hyperflex_health.rb', line 95

def self.openapi_types
  {
    :'class_id' => :'String',
    :'object_type' => :'String',
    :'arbitration_service_state' => :'String',
    :'data_replication_compliance' => :'String',
    :'resiliency_details' => :'HyperflexHxResiliencyInfoDt',
    :'state' => :'String',
    :'uuid' => :'String',
    :'zk_health' => :'String',
    :'zone_resiliency_list' => :'Array<HyperflexHxZoneResiliencyInfoDt>',
    :'cluster' => :'HyperflexClusterRelationship'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



301
302
303
304
305
306
307
308
309
310
311
312
313
314
# File 'lib/intersight_client/models/hyperflex_health.rb', line 301

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      class_id == o.class_id &&
      object_type == o.object_type &&
      arbitration_service_state == o.arbitration_service_state &&
      data_replication_compliance == o.data_replication_compliance &&
      resiliency_details == o.resiliency_details &&
      state == o.state &&
      uuid == o.uuid &&
      zk_health == o.zk_health &&
      zone_resiliency_list == o.zone_resiliency_list &&
      cluster == o.cluster && super(o)
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
# File 'lib/intersight_client/models/hyperflex_health.rb', line 362

def _deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = IntersightClient.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



433
434
435
436
437
438
439
440
441
442
443
444
445
# File 'lib/intersight_client/models/hyperflex_health.rb', line 433

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
# File 'lib/intersight_client/models/hyperflex_health.rb', line 338

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  super(attributes)
  HyperflexHealth.openapi_types.each_pair do |key, type|
    if attributes[HyperflexHealth.attribute_map[key]].nil? && HyperflexHealth.openapi_nullable.include?(key)
      self.send("#{key}=", nil)
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[HyperflexHealth.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[HyperflexHealth.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[HyperflexHealth.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[HyperflexHealth.attribute_map[key]]))
    end
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


318
319
320
# File 'lib/intersight_client/models/hyperflex_health.rb', line 318

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



324
325
326
# File 'lib/intersight_client/models/hyperflex_health.rb', line 324

def hash
  [class_id, object_type, arbitration_service_state, data_replication_compliance, resiliency_details, state, uuid, zk_health, zone_resiliency_list, cluster].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



206
207
208
209
210
211
212
213
214
215
216
217
# File 'lib/intersight_client/models/hyperflex_health.rb', line 206

def list_invalid_properties
  invalid_properties = super
  if @class_id.nil?
    invalid_properties.push('invalid value for "class_id", class_id cannot be nil.')
  end

  if @object_type.nil?
    invalid_properties.push('invalid value for "object_type", object_type cannot be nil.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



409
410
411
# File 'lib/intersight_client/models/hyperflex_health.rb', line 409

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



415
416
417
418
419
420
421
422
423
424
425
426
427
# File 'lib/intersight_client/models/hyperflex_health.rb', line 415

def to_hash
  hash = super
  HyperflexHealth.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = HyperflexHealth.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



403
404
405
# File 'lib/intersight_client/models/hyperflex_health.rb', line 403

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
# File 'lib/intersight_client/models/hyperflex_health.rb', line 221

def valid?
  return false if @class_id.nil?
  class_id_validator = EnumAttributeValidator.new('String', ["hyperflex.Health"])
  return false unless class_id_validator.valid?(@class_id)
  return false if @object_type.nil?
  object_type_validator = EnumAttributeValidator.new('String', ["hyperflex.Health"])
  return false unless object_type_validator.valid?(@object_type)
  arbitration_service_state_validator = EnumAttributeValidator.new('String', ["NOT_AVAILABLE", "UNKNOWN", "ONLINE", "OFFLINE"])
  return false unless arbitration_service_state_validator.valid?(@arbitration_service_state)
  data_replication_compliance_validator = EnumAttributeValidator.new('String', ["UNKNOWN", "COMPLIANT", "NON_COMPLIANT"])
  return false unless data_replication_compliance_validator.valid?(@data_replication_compliance)
  state_validator = EnumAttributeValidator.new('String', ["UNKNOWN", "ONLINE", "OFFLINE", "ENOSPACE", "READONLY"])
  return false unless state_validator.valid?(@state)
  zk_health_validator = EnumAttributeValidator.new('String', ["NOT_AVAILABLE", "UNKNOWN", "ONLINE", "OFFLINE"])
  return false unless zk_health_validator.valid?(@zk_health)
  true && super
end