Class: IntersightClient::HyperflexHxResiliencyInfoDt

Inherits:
MoBaseComplexType show all
Defined in:
lib/intersight_client/models/hyperflex_hx_resiliency_info_dt.rb

Overview

A representation of the data health status and ability of the cluster to tolerate failures.

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ HyperflexHxResiliencyInfoDt

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
# File 'lib/intersight_client/models/hyperflex_hx_resiliency_info_dt.rb', line 129

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `IntersightClient::HyperflexHxResiliencyInfoDt` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `#{self.class.name}`. Please check the name to make sure it's valid. List of attributes: " + self.class.acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  # call parent's initialize
  super(attributes)

  if attributes.key?(:'class_id')
    self.class_id = attributes[:'class_id']
  else
    self.class_id = 'hyperflex.HxResiliencyInfoDt'
  end

  if attributes.key?(:'object_type')
    self.object_type = attributes[:'object_type']
  else
    self.object_type = 'hyperflex.HxResiliencyInfoDt'
  end

  if attributes.key?(:'data_replication_factor')
    self.data_replication_factor = attributes[:'data_replication_factor']
  else
    self.data_replication_factor = 'ONE_COPY'
  end

  if attributes.key?(:'hdd_failures_tolerable')
    self.hdd_failures_tolerable = attributes[:'hdd_failures_tolerable']
  end

  if attributes.key?(:'messages')
    if (value = attributes[:'messages']).is_a?(Array)
      self.messages = value
    end
  end

  if attributes.key?(:'node_failures_tolerable')
    self.node_failures_tolerable = attributes[:'node_failures_tolerable']
  end

  if attributes.key?(:'policy_compliance')
    self.policy_compliance = attributes[:'policy_compliance']
  else
    self.policy_compliance = 'UNKNOWN'
  end

  if attributes.key?(:'resiliency_state')
    self.resiliency_state = attributes[:'resiliency_state']
  else
    self.resiliency_state = 'UNKNOWN'
  end

  if attributes.key?(:'ssd_failures_tolerable')
    self.ssd_failures_tolerable = attributes[:'ssd_failures_tolerable']
  end
end

Instance Attribute Details

#class_idObject

The fully-qualified name of the instantiated, concrete type. This property is used as a discriminator to identify the type of the payload when marshaling and unmarshaling data.



20
21
22
# File 'lib/intersight_client/models/hyperflex_hx_resiliency_info_dt.rb', line 20

def class_id
  @class_id
end

#data_replication_factorObject

The number of copies of data replicated by the cluster. * ONE_COPY - The HyperFlex cluster does not replicate data. * TWO_COPIES - The HyperFlex cluster keeps 2 copies of data. * THREE_COPIES - The HyperFlex cluster keeps 3 copies of data. * FOUR_COPIES - The HyperFlex cluster keeps 4 copies of data. * SIX_COPIES - The HyperFlex cluster keeps 6 copies of data.



26
27
28
# File 'lib/intersight_client/models/hyperflex_hx_resiliency_info_dt.rb', line 26

def data_replication_factor
  @data_replication_factor
end

#hdd_failures_tolerableObject

The number of persistent device disruptions the HyperFlex storage cluster can handle at this point in time.



29
30
31
# File 'lib/intersight_client/models/hyperflex_hx_resiliency_info_dt.rb', line 29

def hdd_failures_tolerable
  @hdd_failures_tolerable
end

#messagesObject

Returns the value of attribute messages.



31
32
33
# File 'lib/intersight_client/models/hyperflex_hx_resiliency_info_dt.rb', line 31

def messages
  @messages
end

#node_failures_tolerableObject

The number of node disruptions the HyperFlex storage cluster can handle at this point in time.



34
35
36
# File 'lib/intersight_client/models/hyperflex_hx_resiliency_info_dt.rb', line 34

def node_failures_tolerable
  @node_failures_tolerable
end

#object_typeObject

The fully-qualified name of the instantiated, concrete type. The value should be the same as the ‘ClassId’ property.



23
24
25
# File 'lib/intersight_client/models/hyperflex_hx_resiliency_info_dt.rb', line 23

def object_type
  @object_type
end

#policy_complianceObject

The state of the storage cluster’s compliance with the cluster access policy. * UNKNOWN - The HyperFlex cluster’s compliance with the data replication policy could not be determined. * COMPLIANT - The HyperFlex cluster is compliant with the data replication policy and data is replicated to the configured replication factor. * NON_COMPLIANT - The HyperFlex cluster is not compliant with the data replication policy because some data is not replicated.



37
38
39
# File 'lib/intersight_client/models/hyperflex_hx_resiliency_info_dt.rb', line 37

def policy_compliance
  @policy_compliance
end

#resiliency_stateObject

The resiliency state of the storage platform. The resiliency state is the storage cluster’s current ability to maintain data. * UNKNOWN - The resiliency status of the HyperFlex cluster cannot be determined, or the cluster is transitioning into ONLINE state. * HEALTHY - The HyperFlex cluster is healthy. The cluster is able to perform IO operations and data is available. * WARNING - The HyperFlex cluster or data availability is adversely affected. This can happen if there are node or storage device failures beyond the tolerable failure threshold. * OFFLINE - The HyperFlex cluster is offline and not performing IO operations. * CRITICAL - The HyperFlex cluster has severe faults that affect cluster and data availability.



40
41
42
# File 'lib/intersight_client/models/hyperflex_hx_resiliency_info_dt.rb', line 40

def resiliency_state
  @resiliency_state
end

#ssd_failures_tolerableObject

The number of cache device disruptions the HyperFlex storage cluster can handle at this point in time.



43
44
45
# File 'lib/intersight_client/models/hyperflex_hx_resiliency_info_dt.rb', line 43

def ssd_failures_tolerable
  @ssd_failures_tolerable
end

Class Method Details

.acceptable_attribute_mapObject

Returns the key-value map of all the JSON attributes this model knows about, including the ones defined in its parent(s)



88
89
90
# File 'lib/intersight_client/models/hyperflex_hx_resiliency_info_dt.rb', line 88

def self.acceptable_attribute_map
  attribute_map.merge(superclass.acceptable_attribute_map)
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about, including the ones defined in its parent(s)



83
84
85
# File 'lib/intersight_client/models/hyperflex_hx_resiliency_info_dt.rb', line 83

def self.acceptable_attributes
  attribute_map.values.concat(superclass.acceptable_attributes)
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



68
69
70
71
72
73
74
75
76
77
78
79
80
# File 'lib/intersight_client/models/hyperflex_hx_resiliency_info_dt.rb', line 68

def self.attribute_map
  {
    :'class_id' => :'ClassId',
    :'object_type' => :'ObjectType',
    :'data_replication_factor' => :'DataReplicationFactor',
    :'hdd_failures_tolerable' => :'HddFailuresTolerable',
    :'messages' => :'Messages',
    :'node_failures_tolerable' => :'NodeFailuresTolerable',
    :'policy_compliance' => :'PolicyCompliance',
    :'resiliency_state' => :'ResiliencyState',
    :'ssd_failures_tolerable' => :'SsdFailuresTolerable'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



308
309
310
# File 'lib/intersight_client/models/hyperflex_hx_resiliency_info_dt.rb', line 308

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_all_ofObject

List of class defined in allOf (OpenAPI v3)



115
116
117
118
119
120
# File 'lib/intersight_client/models/hyperflex_hx_resiliency_info_dt.rb', line 115

def self.openapi_all_of
  [
  :'HyperflexHxResiliencyInfoDtAllOf',
  :'MoBaseComplexType'
  ]
end

.openapi_discriminator_nameObject

discriminator’s property name in OpenAPI v3



123
124
125
# File 'lib/intersight_client/models/hyperflex_hx_resiliency_info_dt.rb', line 123

def self.openapi_discriminator_name
  :'ClassId'
end

.openapi_nullableObject

List of attributes with nullable: true



108
109
110
111
112
# File 'lib/intersight_client/models/hyperflex_hx_resiliency_info_dt.rb', line 108

def self.openapi_nullable
  Set.new([
    :'messages',
  ])
end

.openapi_typesObject

Attribute type mapping.



93
94
95
96
97
98
99
100
101
102
103
104
105
# File 'lib/intersight_client/models/hyperflex_hx_resiliency_info_dt.rb', line 93

def self.openapi_types
  {
    :'class_id' => :'String',
    :'object_type' => :'String',
    :'data_replication_factor' => :'String',
    :'hdd_failures_tolerable' => :'Integer',
    :'messages' => :'Array<String>',
    :'node_failures_tolerable' => :'Integer',
    :'policy_compliance' => :'String',
    :'resiliency_state' => :'String',
    :'ssd_failures_tolerable' => :'Integer'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



279
280
281
282
283
284
285
286
287
288
289
290
291
# File 'lib/intersight_client/models/hyperflex_hx_resiliency_info_dt.rb', line 279

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      class_id == o.class_id &&
      object_type == o.object_type &&
      data_replication_factor == o.data_replication_factor &&
      hdd_failures_tolerable == o.hdd_failures_tolerable &&
      messages == o.messages &&
      node_failures_tolerable == o.node_failures_tolerable &&
      policy_compliance == o.policy_compliance &&
      resiliency_state == o.resiliency_state &&
      ssd_failures_tolerable == o.ssd_failures_tolerable && super(o)
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
# File 'lib/intersight_client/models/hyperflex_hx_resiliency_info_dt.rb', line 339

def _deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = IntersightClient.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



410
411
412
413
414
415
416
417
418
419
420
421
422
# File 'lib/intersight_client/models/hyperflex_hx_resiliency_info_dt.rb', line 410

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
# File 'lib/intersight_client/models/hyperflex_hx_resiliency_info_dt.rb', line 315

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  super(attributes)
  HyperflexHxResiliencyInfoDt.openapi_types.each_pair do |key, type|
    if attributes[HyperflexHxResiliencyInfoDt.attribute_map[key]].nil? && HyperflexHxResiliencyInfoDt.openapi_nullable.include?(key)
      self.send("#{key}=", nil)
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[HyperflexHxResiliencyInfoDt.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[HyperflexHxResiliencyInfoDt.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[HyperflexHxResiliencyInfoDt.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[HyperflexHxResiliencyInfoDt.attribute_map[key]]))
    end
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


295
296
297
# File 'lib/intersight_client/models/hyperflex_hx_resiliency_info_dt.rb', line 295

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



301
302
303
# File 'lib/intersight_client/models/hyperflex_hx_resiliency_info_dt.rb', line 301

def hash
  [class_id, object_type, data_replication_factor, hdd_failures_tolerable, messages, node_failures_tolerable, policy_compliance, resiliency_state, ssd_failures_tolerable].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



196
197
198
199
200
201
202
203
204
205
206
207
# File 'lib/intersight_client/models/hyperflex_hx_resiliency_info_dt.rb', line 196

def list_invalid_properties
  invalid_properties = super
  if @class_id.nil?
    invalid_properties.push('invalid value for "class_id", class_id cannot be nil.')
  end

  if @object_type.nil?
    invalid_properties.push('invalid value for "object_type", object_type cannot be nil.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



386
387
388
# File 'lib/intersight_client/models/hyperflex_hx_resiliency_info_dt.rb', line 386

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



392
393
394
395
396
397
398
399
400
401
402
403
404
# File 'lib/intersight_client/models/hyperflex_hx_resiliency_info_dt.rb', line 392

def to_hash
  hash = super
  HyperflexHxResiliencyInfoDt.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = HyperflexHxResiliencyInfoDt.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



380
381
382
# File 'lib/intersight_client/models/hyperflex_hx_resiliency_info_dt.rb', line 380

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
# File 'lib/intersight_client/models/hyperflex_hx_resiliency_info_dt.rb', line 211

def valid?
  return false if @class_id.nil?
  class_id_validator = EnumAttributeValidator.new('String', ["hyperflex.HxResiliencyInfoDt"])
  return false unless class_id_validator.valid?(@class_id)
  return false if @object_type.nil?
  object_type_validator = EnumAttributeValidator.new('String', ["hyperflex.HxResiliencyInfoDt"])
  return false unless object_type_validator.valid?(@object_type)
  data_replication_factor_validator = EnumAttributeValidator.new('String', ["ONE_COPY", "TWO_COPIES", "THREE_COPIES", "FOUR_COPIES", "SIX_COPIES"])
  return false unless data_replication_factor_validator.valid?(@data_replication_factor)
  policy_compliance_validator = EnumAttributeValidator.new('String', ["UNKNOWN", "COMPLIANT", "NON_COMPLIANT"])
  return false unless policy_compliance_validator.valid?(@policy_compliance)
  resiliency_state_validator = EnumAttributeValidator.new('String', ["UNKNOWN", "HEALTHY", "WARNING", "OFFLINE", "CRITICAL"])
  return false unless resiliency_state_validator.valid?(@resiliency_state)
  true && super
end