Class: IntersightClient::HyperflexHxapVirtualDisk

Inherits:
VirtualizationBaseVirtualDisk show all
Defined in:
lib/intersight_client/models/hyperflex_hxap_virtual_disk.rb

Overview

The Virtual disk created on HyperFlex Application Platform compute cluster.

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Attributes inherited from VirtualizationBaseVirtualDisk

#name, #size

Attributes inherited from VirtualizationBaseSourceDevice

#registered_device

Attributes inherited from MoBaseMo

#account_moid, #ancestors, #create_time, #display_names, #domain_group_moid, #mod_time, #moid, #owners, #parent, #permission_resources, #shared_scope, #tags, #version_context

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ HyperflexHxapVirtualDisk

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
# File 'lib/intersight_client/models/hyperflex_hxap_virtual_disk.rb', line 132

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `IntersightClient::HyperflexHxapVirtualDisk` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `#{self.class.name}`. Please check the name to make sure it's valid. List of attributes: " + self.class.acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  # call parent's initialize
  super(attributes)

  if attributes.key?(:'class_id')
    self.class_id = attributes[:'class_id']
  else
    self.class_id = 'hyperflex.HxapVirtualDisk'
  end

  if attributes.key?(:'object_type')
    self.object_type = attributes[:'object_type']
  else
    self.object_type = 'hyperflex.HxapVirtualDisk'
  end

  if attributes.key?(:'access_mode')
    self.access_mode = attributes[:'access_mode']
  else
    self.access_mode = 'ReadWriteOnce'
  end

  if attributes.key?(:'mode')
    self.mode = attributes[:'mode']
  else
    self.mode = 'Block'
  end

  if attributes.key?(:'source_file_path')
    self.source_file_path = attributes[:'source_file_path']
  end

  if attributes.key?(:'source_virtual_disk')
    self.source_virtual_disk = attributes[:'source_virtual_disk']
  end

  if attributes.key?(:'status')
    self.status = attributes[:'status']
  end

  if attributes.key?(:'uuid')
    self.uuid = attributes[:'uuid']
  end

  if attributes.key?(:'cluster')
    self.cluster = attributes[:'cluster']
  end

  if attributes.key?(:'virtual_machine')
    self.virtual_machine = attributes[:'virtual_machine']
  end
end

Instance Attribute Details

#access_modeObject

Access mode of the virtual disk. * ReadWriteOnce - Read write permisisons to a Virtual disk by a single virtual machine. * ReadWriteMany - Read write permisisons to a Virtual disk by multiple virtual machines. * ReadOnlyMany - Read only permisisons to a Virtual disk by multiple virtual machines. * “ - Unknown disk access mode.



26
27
28
# File 'lib/intersight_client/models/hyperflex_hxap_virtual_disk.rb', line 26

def access_mode
  @access_mode
end

#class_idObject

The fully-qualified name of the instantiated, concrete type. This property is used as a discriminator to identify the type of the payload when marshaling and unmarshaling data.



20
21
22
# File 'lib/intersight_client/models/hyperflex_hxap_virtual_disk.rb', line 20

def class_id
  @class_id
end

#clusterObject

Returns the value of attribute cluster.



42
43
44
# File 'lib/intersight_client/models/hyperflex_hxap_virtual_disk.rb', line 42

def cluster
  @cluster
end

#modeObject

File mode of the disk example - Filesystem, Block. * Block - It is a Block virtual disk. * Filesystem - It is a File system virtual disk. * “ - Disk mode is either unknown or not supported.



29
30
31
# File 'lib/intersight_client/models/hyperflex_hxap_virtual_disk.rb', line 29

def mode
  @mode
end

#object_typeObject

The fully-qualified name of the instantiated, concrete type. The value should be the same as the ‘ClassId’ property.



23
24
25
# File 'lib/intersight_client/models/hyperflex_hxap_virtual_disk.rb', line 23

def object_type
  @object_type
end

#source_file_pathObject

Source file path associated with virtual machine disk.



32
33
34
# File 'lib/intersight_client/models/hyperflex_hxap_virtual_disk.rb', line 32

def source_file_path
  @source_file_path
end

#source_virtual_diskObject

Virtual disk used for cloning new disk.



35
36
37
# File 'lib/intersight_client/models/hyperflex_hxap_virtual_disk.rb', line 35

def source_virtual_disk
  @source_virtual_disk
end

#statusObject

Returns the value of attribute status.



37
38
39
# File 'lib/intersight_client/models/hyperflex_hxap_virtual_disk.rb', line 37

def status
  @status
end

#uuidObject

UUID of the virtual disk.



40
41
42
# File 'lib/intersight_client/models/hyperflex_hxap_virtual_disk.rb', line 40

def uuid
  @uuid
end

#virtual_machineObject

Returns the value of attribute virtual_machine.



44
45
46
# File 'lib/intersight_client/models/hyperflex_hxap_virtual_disk.rb', line 44

def virtual_machine
  @virtual_machine
end

Class Method Details

.acceptable_attribute_mapObject

Returns the key-value map of all the JSON attributes this model knows about, including the ones defined in its parent(s)



90
91
92
# File 'lib/intersight_client/models/hyperflex_hxap_virtual_disk.rb', line 90

def self.acceptable_attribute_map
  attribute_map.merge(superclass.acceptable_attribute_map)
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about, including the ones defined in its parent(s)



85
86
87
# File 'lib/intersight_client/models/hyperflex_hxap_virtual_disk.rb', line 85

def self.acceptable_attributes
  attribute_map.values.concat(superclass.acceptable_attributes)
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



69
70
71
72
73
74
75
76
77
78
79
80
81
82
# File 'lib/intersight_client/models/hyperflex_hxap_virtual_disk.rb', line 69

def self.attribute_map
  {
    :'class_id' => :'ClassId',
    :'object_type' => :'ObjectType',
    :'access_mode' => :'AccessMode',
    :'mode' => :'Mode',
    :'source_file_path' => :'SourceFilePath',
    :'source_virtual_disk' => :'SourceVirtualDisk',
    :'status' => :'Status',
    :'uuid' => :'Uuid',
    :'cluster' => :'Cluster',
    :'virtual_machine' => :'VirtualMachine'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



300
301
302
# File 'lib/intersight_client/models/hyperflex_hxap_virtual_disk.rb', line 300

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_all_ofObject

List of class defined in allOf (OpenAPI v3)



118
119
120
121
122
123
# File 'lib/intersight_client/models/hyperflex_hxap_virtual_disk.rb', line 118

def self.openapi_all_of
  [
  :'HyperflexHxapVirtualDiskAllOf',
  :'VirtualizationBaseVirtualDisk'
  ]
end

.openapi_discriminator_nameObject

discriminator’s property name in OpenAPI v3



126
127
128
# File 'lib/intersight_client/models/hyperflex_hxap_virtual_disk.rb', line 126

def self.openapi_discriminator_name
  :'ClassId'
end

.openapi_nullableObject

List of attributes with nullable: true



111
112
113
114
115
# File 'lib/intersight_client/models/hyperflex_hxap_virtual_disk.rb', line 111

def self.openapi_nullable
  Set.new([
    :'status',
  ])
end

.openapi_typesObject

Attribute type mapping.



95
96
97
98
99
100
101
102
103
104
105
106
107
108
# File 'lib/intersight_client/models/hyperflex_hxap_virtual_disk.rb', line 95

def self.openapi_types
  {
    :'class_id' => :'String',
    :'object_type' => :'String',
    :'access_mode' => :'String',
    :'mode' => :'String',
    :'source_file_path' => :'String',
    :'source_virtual_disk' => :'String',
    :'status' => :'HyperflexDiskStatus',
    :'uuid' => :'String',
    :'cluster' => :'HyperflexHxapClusterRelationship',
    :'virtual_machine' => :'HyperflexHxapVirtualMachineRelationship'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



270
271
272
273
274
275
276
277
278
279
280
281
282
283
# File 'lib/intersight_client/models/hyperflex_hxap_virtual_disk.rb', line 270

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      class_id == o.class_id &&
      object_type == o.object_type &&
      access_mode == o.access_mode &&
      mode == o.mode &&
      source_file_path == o.source_file_path &&
      source_virtual_disk == o.source_virtual_disk &&
      status == o.status &&
      uuid == o.uuid &&
      cluster == o.cluster &&
      virtual_machine == o.virtual_machine && super(o)
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
# File 'lib/intersight_client/models/hyperflex_hxap_virtual_disk.rb', line 331

def _deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = IntersightClient.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



402
403
404
405
406
407
408
409
410
411
412
413
414
# File 'lib/intersight_client/models/hyperflex_hxap_virtual_disk.rb', line 402

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
# File 'lib/intersight_client/models/hyperflex_hxap_virtual_disk.rb', line 307

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  super(attributes)
  HyperflexHxapVirtualDisk.openapi_types.each_pair do |key, type|
    if attributes[HyperflexHxapVirtualDisk.attribute_map[key]].nil? && HyperflexHxapVirtualDisk.openapi_nullable.include?(key)
      self.send("#{key}=", nil)
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[HyperflexHxapVirtualDisk.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[HyperflexHxapVirtualDisk.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[HyperflexHxapVirtualDisk.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[HyperflexHxapVirtualDisk.attribute_map[key]]))
    end
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


287
288
289
# File 'lib/intersight_client/models/hyperflex_hxap_virtual_disk.rb', line 287

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



293
294
295
# File 'lib/intersight_client/models/hyperflex_hxap_virtual_disk.rb', line 293

def hash
  [class_id, object_type, access_mode, mode, source_file_path, source_virtual_disk, status, uuid, cluster, virtual_machine].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



199
200
201
202
203
204
205
206
207
208
209
210
# File 'lib/intersight_client/models/hyperflex_hxap_virtual_disk.rb', line 199

def list_invalid_properties
  invalid_properties = super
  if @class_id.nil?
    invalid_properties.push('invalid value for "class_id", class_id cannot be nil.')
  end

  if @object_type.nil?
    invalid_properties.push('invalid value for "object_type", object_type cannot be nil.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



378
379
380
# File 'lib/intersight_client/models/hyperflex_hxap_virtual_disk.rb', line 378

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



384
385
386
387
388
389
390
391
392
393
394
395
396
# File 'lib/intersight_client/models/hyperflex_hxap_virtual_disk.rb', line 384

def to_hash
  hash = super
  HyperflexHxapVirtualDisk.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = HyperflexHxapVirtualDisk.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



372
373
374
# File 'lib/intersight_client/models/hyperflex_hxap_virtual_disk.rb', line 372

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



214
215
216
217
218
219
220
221
222
223
224
225
226
# File 'lib/intersight_client/models/hyperflex_hxap_virtual_disk.rb', line 214

def valid?
  return false if @class_id.nil?
  class_id_validator = EnumAttributeValidator.new('String', ["hyperflex.HxapVirtualDisk"])
  return false unless class_id_validator.valid?(@class_id)
  return false if @object_type.nil?
  object_type_validator = EnumAttributeValidator.new('String', ["hyperflex.HxapVirtualDisk"])
  return false unless object_type_validator.valid?(@object_type)
  access_mode_validator = EnumAttributeValidator.new('String', ["ReadWriteOnce", "ReadWriteMany", "ReadOnlyMany", ""])
  return false unless access_mode_validator.valid?(@access_mode)
  mode_validator = EnumAttributeValidator.new('String', ["Block", "Filesystem", ""])
  return false unless mode_validator.valid?(@mode)
  true && super
end