Class: IntersightClient::HyperflexSummaryAllOf
- Inherits:
-
Object
- Object
- IntersightClient::HyperflexSummaryAllOf
- Defined in:
- lib/intersight_client/models/hyperflex_summary_all_of.rb
Overview
Definition of the list of properties defined in ‘hyperflex.Summary’, excluding properties defined in parent classes.
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#active_nodes ⇒ Object
The number of nodes currently participating in the storage cluster.
-
#address ⇒ Object
The data IP address of the HyperFlex cluster.
-
#boottime ⇒ Object
The time taken during last cluster startup in seconds.
-
#class_id ⇒ Object
The fully-qualified name of the instantiated, concrete type.
-
#cluster_access_policy ⇒ Object
The cluster access policy for the HyperFlex cluster.
-
#compression_savings ⇒ Object
The percentage of storage space saved using data compression.
-
#data_replication_compliance ⇒ Object
The compliance with the data replication factor set for the HyperFlex cluster.
-
#data_replication_factor ⇒ Object
The number of data copies retained by the HyperFlex cluster.
-
#deduplication_savings ⇒ Object
The percentage of storage space saved using data deduplication.
-
#downtime ⇒ Object
The amount of time the HyperFlex cluster has been offline.
-
#free_capacity ⇒ Object
The amount of storage capacity currently not in use, represented in bytes.
-
#healing_info ⇒ Object
Returns the value of attribute healing_info.
-
#name ⇒ Object
The name of the HyperFlex cluster.
-
#object_type ⇒ Object
The fully-qualified name of the instantiated, concrete type.
-
#resiliency_details ⇒ Object
The details about the resiliency health of the cluster.
-
#resiliency_details_size ⇒ Object
The number of elements in the resiliency details property.
-
#resiliency_info ⇒ Object
Returns the value of attribute resiliency_info.
-
#space_status ⇒ Object
The space utilization status of the HyperFlex cluster.
-
#state ⇒ Object
The operational state of the HyperFlex cluster.
-
#total_capacity ⇒ Object
The total amount of storage capacity available for the HyperFlex cluster, represented in bytes.
-
#total_savings ⇒ Object
The percentage of storage space saved in total.
-
#uptime ⇒ Object
The amount of time the HyperFlex cluster has been running since last startup.
-
#used_capacity ⇒ Object
The amount of storage capacity in use, represented in bytes.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns the key-value map of all the JSON attributes this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ HyperflexSummaryAllOf
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ HyperflexSummaryAllOf
Initializes the object
187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 |
# File 'lib/intersight_client/models/hyperflex_summary_all_of.rb', line 187 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `IntersightClient::HyperflexSummaryAllOf` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `#{self.class.name}`. Please check the name to make sure it's valid. List of attributes: " + self.class.acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'class_id') self.class_id = attributes[:'class_id'] else self.class_id = 'hyperflex.Summary' end if attributes.key?(:'object_type') self.object_type = attributes[:'object_type'] else self.object_type = 'hyperflex.Summary' end if attributes.key?(:'active_nodes') self.active_nodes = attributes[:'active_nodes'] end if attributes.key?(:'address') self.address = attributes[:'address'] end if attributes.key?(:'boottime') self.boottime = attributes[:'boottime'] end if attributes.key?(:'cluster_access_policy') self.cluster_access_policy = attributes[:'cluster_access_policy'] end if attributes.key?(:'compression_savings') self.compression_savings = attributes[:'compression_savings'] end if attributes.key?(:'data_replication_compliance') self.data_replication_compliance = attributes[:'data_replication_compliance'] end if attributes.key?(:'data_replication_factor') self.data_replication_factor = attributes[:'data_replication_factor'] end if attributes.key?(:'deduplication_savings') self.deduplication_savings = attributes[:'deduplication_savings'] end if attributes.key?(:'downtime') self.downtime = attributes[:'downtime'] end if attributes.key?(:'free_capacity') self.free_capacity = attributes[:'free_capacity'] end if attributes.key?(:'healing_info') self.healing_info = attributes[:'healing_info'] end if attributes.key?(:'name') self.name = attributes[:'name'] end if attributes.key?(:'resiliency_details') self.resiliency_details = attributes[:'resiliency_details'] end if attributes.key?(:'resiliency_details_size') self.resiliency_details_size = attributes[:'resiliency_details_size'] end if attributes.key?(:'resiliency_info') self.resiliency_info = attributes[:'resiliency_info'] end if attributes.key?(:'space_status') self.space_status = attributes[:'space_status'] end if attributes.key?(:'state') self.state = attributes[:'state'] end if attributes.key?(:'total_capacity') self.total_capacity = attributes[:'total_capacity'] end if attributes.key?(:'total_savings') self.total_savings = attributes[:'total_savings'] end if attributes.key?(:'uptime') self.uptime = attributes[:'uptime'] end if attributes.key?(:'used_capacity') self.used_capacity = attributes[:'used_capacity'] end end |
Instance Attribute Details
#active_nodes ⇒ Object
The number of nodes currently participating in the storage cluster.
26 27 28 |
# File 'lib/intersight_client/models/hyperflex_summary_all_of.rb', line 26 def active_nodes @active_nodes end |
#address ⇒ Object
The data IP address of the HyperFlex cluster.
29 30 31 |
# File 'lib/intersight_client/models/hyperflex_summary_all_of.rb', line 29 def address @address end |
#boottime ⇒ Object
The time taken during last cluster startup in seconds.
32 33 34 |
# File 'lib/intersight_client/models/hyperflex_summary_all_of.rb', line 32 def boottime @boottime end |
#class_id ⇒ Object
The fully-qualified name of the instantiated, concrete type. This property is used as a discriminator to identify the type of the payload when marshaling and unmarshaling data.
20 21 22 |
# File 'lib/intersight_client/models/hyperflex_summary_all_of.rb', line 20 def class_id @class_id end |
#cluster_access_policy ⇒ Object
The cluster access policy for the HyperFlex cluster. An access policy of ‘STRICT’ means that the cluster becomes readonly once any fragment of data is reduced to one copy. ‘LENIENT’ means that the cluster stays in read-write mode even if any fragment of data is reduced to one copy.
35 36 37 |
# File 'lib/intersight_client/models/hyperflex_summary_all_of.rb', line 35 def cluster_access_policy @cluster_access_policy end |
#compression_savings ⇒ Object
The percentage of storage space saved using data compression.
38 39 40 |
# File 'lib/intersight_client/models/hyperflex_summary_all_of.rb', line 38 def compression_savings @compression_savings end |
#data_replication_compliance ⇒ Object
The compliance with the data replication factor set for the HyperFlex cluster.
41 42 43 |
# File 'lib/intersight_client/models/hyperflex_summary_all_of.rb', line 41 def data_replication_compliance @data_replication_compliance end |
#data_replication_factor ⇒ Object
The number of data copies retained by the HyperFlex cluster.
44 45 46 |
# File 'lib/intersight_client/models/hyperflex_summary_all_of.rb', line 44 def data_replication_factor @data_replication_factor end |
#deduplication_savings ⇒ Object
The percentage of storage space saved using data deduplication.
47 48 49 |
# File 'lib/intersight_client/models/hyperflex_summary_all_of.rb', line 47 def deduplication_savings @deduplication_savings end |
#downtime ⇒ Object
The amount of time the HyperFlex cluster has been offline.
50 51 52 |
# File 'lib/intersight_client/models/hyperflex_summary_all_of.rb', line 50 def downtime @downtime end |
#free_capacity ⇒ Object
The amount of storage capacity currently not in use, represented in bytes.
53 54 55 |
# File 'lib/intersight_client/models/hyperflex_summary_all_of.rb', line 53 def free_capacity @free_capacity end |
#healing_info ⇒ Object
Returns the value of attribute healing_info.
55 56 57 |
# File 'lib/intersight_client/models/hyperflex_summary_all_of.rb', line 55 def healing_info @healing_info end |
#name ⇒ Object
The name of the HyperFlex cluster.
58 59 60 |
# File 'lib/intersight_client/models/hyperflex_summary_all_of.rb', line 58 def name @name end |
#object_type ⇒ Object
The fully-qualified name of the instantiated, concrete type. The value should be the same as the ‘ClassId’ property.
23 24 25 |
# File 'lib/intersight_client/models/hyperflex_summary_all_of.rb', line 23 def object_type @object_type end |
#resiliency_details ⇒ Object
The details about the resiliency health of the cluster. Includes information about the cluster healing status and the storage cluster health.
61 62 63 |
# File 'lib/intersight_client/models/hyperflex_summary_all_of.rb', line 61 def resiliency_details @resiliency_details end |
#resiliency_details_size ⇒ Object
The number of elements in the resiliency details property.
64 65 66 |
# File 'lib/intersight_client/models/hyperflex_summary_all_of.rb', line 64 def resiliency_details_size @resiliency_details_size end |
#resiliency_info ⇒ Object
Returns the value of attribute resiliency_info.
66 67 68 |
# File 'lib/intersight_client/models/hyperflex_summary_all_of.rb', line 66 def resiliency_info @resiliency_info end |
#space_status ⇒ Object
The space utilization status of the HyperFlex cluster.
69 70 71 |
# File 'lib/intersight_client/models/hyperflex_summary_all_of.rb', line 69 def space_status @space_status end |
#state ⇒ Object
The operational state of the HyperFlex cluster.
72 73 74 |
# File 'lib/intersight_client/models/hyperflex_summary_all_of.rb', line 72 def state @state end |
#total_capacity ⇒ Object
The total amount of storage capacity available for the HyperFlex cluster, represented in bytes.
75 76 77 |
# File 'lib/intersight_client/models/hyperflex_summary_all_of.rb', line 75 def total_capacity @total_capacity end |
#total_savings ⇒ Object
The percentage of storage space saved in total.
78 79 80 |
# File 'lib/intersight_client/models/hyperflex_summary_all_of.rb', line 78 def total_savings @total_savings end |
#uptime ⇒ Object
The amount of time the HyperFlex cluster has been running since last startup.
81 82 83 |
# File 'lib/intersight_client/models/hyperflex_summary_all_of.rb', line 81 def uptime @uptime end |
#used_capacity ⇒ Object
The amount of storage capacity in use, represented in bytes.
84 85 86 |
# File 'lib/intersight_client/models/hyperflex_summary_all_of.rb', line 84 def used_capacity @used_capacity end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns the key-value map of all the JSON attributes this model knows about
143 144 145 |
# File 'lib/intersight_client/models/hyperflex_summary_all_of.rb', line 143 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
138 139 140 |
# File 'lib/intersight_client/models/hyperflex_summary_all_of.rb', line 138 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 |
# File 'lib/intersight_client/models/hyperflex_summary_all_of.rb', line 109 def self.attribute_map { :'class_id' => :'ClassId', :'object_type' => :'ObjectType', :'active_nodes' => :'ActiveNodes', :'address' => :'Address', :'boottime' => :'Boottime', :'cluster_access_policy' => :'ClusterAccessPolicy', :'compression_savings' => :'CompressionSavings', :'data_replication_compliance' => :'DataReplicationCompliance', :'data_replication_factor' => :'DataReplicationFactor', :'deduplication_savings' => :'DeduplicationSavings', :'downtime' => :'Downtime', :'free_capacity' => :'FreeCapacity', :'healing_info' => :'HealingInfo', :'name' => :'Name', :'resiliency_details' => :'ResiliencyDetails', :'resiliency_details_size' => :'ResiliencyDetailsSize', :'resiliency_info' => :'ResiliencyInfo', :'space_status' => :'SpaceStatus', :'state' => :'State', :'total_capacity' => :'TotalCapacity', :'total_savings' => :'TotalSavings', :'uptime' => :'Uptime', :'used_capacity' => :'UsedCapacity' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
389 390 391 |
# File 'lib/intersight_client/models/hyperflex_summary_all_of.rb', line 389 def self.build_from_hash(attributes) new.build_from_hash(attributes) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
177 178 179 180 181 182 183 |
# File 'lib/intersight_client/models/hyperflex_summary_all_of.rb', line 177 def self.openapi_nullable Set.new([ :'healing_info', :'resiliency_details', :'resiliency_info', ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 |
# File 'lib/intersight_client/models/hyperflex_summary_all_of.rb', line 148 def self.openapi_types { :'class_id' => :'String', :'object_type' => :'String', :'active_nodes' => :'String', :'address' => :'String', :'boottime' => :'Integer', :'cluster_access_policy' => :'String', :'compression_savings' => :'Float', :'data_replication_compliance' => :'String', :'data_replication_factor' => :'String', :'deduplication_savings' => :'Float', :'downtime' => :'String', :'free_capacity' => :'Integer', :'healing_info' => :'HyperflexStPlatformClusterHealingInfo', :'name' => :'String', :'resiliency_details' => :'Object', :'resiliency_details_size' => :'Integer', :'resiliency_info' => :'HyperflexStPlatformClusterResiliencyInfo', :'space_status' => :'String', :'state' => :'String', :'total_capacity' => :'Integer', :'total_savings' => :'Float', :'uptime' => :'String', :'used_capacity' => :'Integer' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 |
# File 'lib/intersight_client/models/hyperflex_summary_all_of.rb', line 346 def ==(o) return true if self.equal?(o) self.class == o.class && class_id == o.class_id && object_type == o.object_type && active_nodes == o.active_nodes && address == o.address && boottime == o.boottime && cluster_access_policy == o.cluster_access_policy && compression_savings == o.compression_savings && data_replication_compliance == o.data_replication_compliance && data_replication_factor == o.data_replication_factor && deduplication_savings == o.deduplication_savings && downtime == o.downtime && free_capacity == o.free_capacity && healing_info == o.healing_info && name == o.name && resiliency_details == o.resiliency_details && resiliency_details_size == o.resiliency_details_size && resiliency_info == o.resiliency_info && space_status == o.space_status && state == o.state && total_capacity == o.total_capacity && total_savings == o.total_savings && uptime == o.uptime && used_capacity == o.used_capacity end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 450 451 452 453 454 455 456 |
# File 'lib/intersight_client/models/hyperflex_summary_all_of.rb', line 419 def _deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = IntersightClient.const_get(type) klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
490 491 492 493 494 495 496 497 498 499 500 501 502 |
# File 'lib/intersight_client/models/hyperflex_summary_all_of.rb', line 490 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 |
# File 'lib/intersight_client/models/hyperflex_summary_all_of.rb', line 396 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) HyperflexSummaryAllOf.openapi_types.each_pair do |key, type| if attributes[HyperflexSummaryAllOf.attribute_map[key]].nil? && HyperflexSummaryAllOf.openapi_nullable.include?(key) self.send("#{key}=", nil) elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[HyperflexSummaryAllOf.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[HyperflexSummaryAllOf.attribute_map[key]].map { |v| _deserialize($1, v) }) end elsif !attributes[HyperflexSummaryAllOf.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[HyperflexSummaryAllOf.attribute_map[key]])) end end self end |
#eql?(o) ⇒ Boolean
376 377 378 |
# File 'lib/intersight_client/models/hyperflex_summary_all_of.rb', line 376 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
382 383 384 |
# File 'lib/intersight_client/models/hyperflex_summary_all_of.rb', line 382 def hash [class_id, object_type, active_nodes, address, boottime, cluster_access_policy, compression_savings, data_replication_compliance, data_replication_factor, deduplication_savings, downtime, free_capacity, healing_info, name, resiliency_details, resiliency_details_size, resiliency_info, space_status, state, total_capacity, total_savings, uptime, used_capacity].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
299 300 301 302 303 304 305 306 307 308 309 310 |
# File 'lib/intersight_client/models/hyperflex_summary_all_of.rb', line 299 def list_invalid_properties invalid_properties = Array.new if @class_id.nil? invalid_properties.push('invalid value for "class_id", class_id cannot be nil.') end if @object_type.nil? invalid_properties.push('invalid value for "object_type", object_type cannot be nil.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
466 467 468 |
# File 'lib/intersight_client/models/hyperflex_summary_all_of.rb', line 466 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
472 473 474 475 476 477 478 479 480 481 482 483 484 |
# File 'lib/intersight_client/models/hyperflex_summary_all_of.rb', line 472 def to_hash hash = {} HyperflexSummaryAllOf.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = HyperflexSummaryAllOf.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
460 461 462 |
# File 'lib/intersight_client/models/hyperflex_summary_all_of.rb', line 460 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
314 315 316 317 318 319 320 321 322 |
# File 'lib/intersight_client/models/hyperflex_summary_all_of.rb', line 314 def valid? return false if @class_id.nil? class_id_validator = EnumAttributeValidator.new('String', ["hyperflex.Summary"]) return false unless class_id_validator.valid?(@class_id) return false if @object_type.nil? object_type_validator = EnumAttributeValidator.new('String', ["hyperflex.Summary"]) return false unless object_type_validator.valid?(@object_type) true end |