Class: IntersightClient::IaasUcsdInfo

Inherits:
MoBaseMo
  • Object
show all
Defined in:
lib/intersight_client/models/iaas_ucsd_info.rb

Overview

UCS Director accounts managed by Intersight.

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Attributes inherited from MoBaseMo

#account_moid, #ancestors, #create_time, #display_names, #domain_group_moid, #mod_time, #moid, #owners, #parent, #permission_resources, #shared_scope, #tags, #version_context

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ IaasUcsdInfo

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
# File 'lib/intersight_client/models/iaas_ucsd_info.rb', line 174

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `IntersightClient::IaasUcsdInfo` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `#{self.class.name}`. Please check the name to make sure it's valid. List of attributes: " + self.class.acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  # call parent's initialize
  super(attributes)

  if attributes.key?(:'class_id')
    self.class_id = attributes[:'class_id']
  else
    self.class_id = 'iaas.UcsdInfo'
  end

  if attributes.key?(:'object_type')
    self.object_type = attributes[:'object_type']
  else
    self.object_type = 'iaas.UcsdInfo'
  end

  if attributes.key?(:'device_id')
    self.device_id = attributes[:'device_id']
  end

  if attributes.key?(:'guid')
    self.guid = attributes[:'guid']
  end

  if attributes.key?(:'host_name')
    self.host_name = attributes[:'host_name']
  end

  if attributes.key?(:'ip')
    self.ip = attributes[:'ip']
  end

  if attributes.key?(:'last_backup')
    self.last_backup = attributes[:'last_backup']
  end

  if attributes.key?(:'node_type')
    self.node_type = attributes[:'node_type']
  end

  if attributes.key?(:'product_name')
    self.product_name = attributes[:'product_name']
  end

  if attributes.key?(:'product_vendor')
    self.product_vendor = attributes[:'product_vendor']
  end

  if attributes.key?(:'product_version')
    self.product_version = attributes[:'product_version']
  end

  if attributes.key?(:'status')
    self.status = attributes[:'status']
  end

  if attributes.key?(:'connector_pack')
    if (value = attributes[:'connector_pack']).is_a?(Array)
      self.connector_pack = value
    end
  end

  if attributes.key?(:'device_status')
    if (value = attributes[:'device_status']).is_a?(Array)
      self.device_status = value
    end
  end

  if attributes.key?(:'license_info')
    self.license_info = attributes[:'license_info']
  end

  if attributes.key?(:'most_run_tasks')
    if (value = attributes[:'most_run_tasks']).is_a?(Array)
      self.most_run_tasks = value
    end
  end

  if attributes.key?(:'registered_device')
    self.registered_device = attributes[:'registered_device']
  end

  if attributes.key?(:'ucsd_managed_infra')
    self.ucsd_managed_infra = attributes[:'ucsd_managed_infra']
  end
end

Instance Attribute Details

#class_idObject

The fully-qualified name of the instantiated, concrete type. This property is used as a discriminator to identify the type of the payload when marshaling and unmarshaling data.



20
21
22
# File 'lib/intersight_client/models/iaas_ucsd_info.rb', line 20

def class_id
  @class_id
end

#connector_packObject

An array of relationships to iaasConnectorPack resources.



56
57
58
# File 'lib/intersight_client/models/iaas_ucsd_info.rb', line 56

def connector_pack
  @connector_pack
end

#device_idObject

Moid of the UCS Director device connector’s asset.DeviceRegistration.



26
27
28
# File 'lib/intersight_client/models/iaas_ucsd_info.rb', line 26

def device_id
  @device_id
end

#device_statusObject

An array of relationships to iaasDeviceStatus resources.



59
60
61
# File 'lib/intersight_client/models/iaas_ucsd_info.rb', line 59

def device_status
  @device_status
end

#guidObject

Unique ID of UCS Director getting registerd with Intersight.



29
30
31
# File 'lib/intersight_client/models/iaas_ucsd_info.rb', line 29

def guid
  @guid
end

#host_nameObject

The UCS Director hostname for management.



32
33
34
# File 'lib/intersight_client/models/iaas_ucsd_info.rb', line 32

def host_name
  @host_name
end

#ipObject

The UCS Director IP address for management.



35
36
37
# File 'lib/intersight_client/models/iaas_ucsd_info.rb', line 35

def ip
  @ip
end

#last_backupObject

Last successful backup created for this UCS Director appliance if backup is configured.



38
39
40
# File 'lib/intersight_client/models/iaas_ucsd_info.rb', line 38

def last_backup
  @last_backup
end

#license_infoObject

Returns the value of attribute license_info.



61
62
63
# File 'lib/intersight_client/models/iaas_ucsd_info.rb', line 61

def license_info
  @license_info
end

#most_run_tasksObject

An array of relationships to iaasMostRunTasks resources.



64
65
66
# File 'lib/intersight_client/models/iaas_ucsd_info.rb', line 64

def most_run_tasks
  @most_run_tasks
end

#node_typeObject

NodeType specifies if UCS Director is deployed in Stand-alone or Multi Node.



41
42
43
# File 'lib/intersight_client/models/iaas_ucsd_info.rb', line 41

def node_type
  @node_type
end

#object_typeObject

The fully-qualified name of the instantiated, concrete type. The value should be the same as the ‘ClassId’ property.



23
24
25
# File 'lib/intersight_client/models/iaas_ucsd_info.rb', line 23

def object_type
  @object_type
end

#product_nameObject

The UCS Director product name.



44
45
46
# File 'lib/intersight_client/models/iaas_ucsd_info.rb', line 44

def product_name
  @product_name
end

#product_vendorObject

The UCS Director product vendor.



47
48
49
# File 'lib/intersight_client/models/iaas_ucsd_info.rb', line 47

def product_vendor
  @product_vendor
end

#product_versionObject

The UCS Director product/platform version.



50
51
52
# File 'lib/intersight_client/models/iaas_ucsd_info.rb', line 50

def product_version
  @product_version
end

#registered_deviceObject

Returns the value of attribute registered_device.



66
67
68
# File 'lib/intersight_client/models/iaas_ucsd_info.rb', line 66

def registered_device
  @registered_device
end

#statusObject

The UCS Director status. Possible values are Active, Inactive, Unknown.



53
54
55
# File 'lib/intersight_client/models/iaas_ucsd_info.rb', line 53

def status
  @status
end

#ucsd_managed_infraObject

Returns the value of attribute ucsd_managed_infra.



68
69
70
# File 'lib/intersight_client/models/iaas_ucsd_info.rb', line 68

def ucsd_managed_infra
  @ucsd_managed_infra
end

Class Method Details

.acceptable_attribute_mapObject

Returns the key-value map of all the JSON attributes this model knows about, including the ones defined in its parent(s)



122
123
124
# File 'lib/intersight_client/models/iaas_ucsd_info.rb', line 122

def self.acceptable_attribute_map
  attribute_map.merge(superclass.acceptable_attribute_map)
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about, including the ones defined in its parent(s)



117
118
119
# File 'lib/intersight_client/models/iaas_ucsd_info.rb', line 117

def self.acceptable_attributes
  attribute_map.values.concat(superclass.acceptable_attributes)
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
# File 'lib/intersight_client/models/iaas_ucsd_info.rb', line 93

def self.attribute_map
  {
    :'class_id' => :'ClassId',
    :'object_type' => :'ObjectType',
    :'device_id' => :'DeviceId',
    :'guid' => :'Guid',
    :'host_name' => :'HostName',
    :'ip' => :'Ip',
    :'last_backup' => :'LastBackup',
    :'node_type' => :'NodeType',
    :'product_name' => :'ProductName',
    :'product_vendor' => :'ProductVendor',
    :'product_version' => :'ProductVersion',
    :'status' => :'Status',
    :'connector_pack' => :'ConnectorPack',
    :'device_status' => :'DeviceStatus',
    :'license_info' => :'LicenseInfo',
    :'most_run_tasks' => :'MostRunTasks',
    :'registered_device' => :'RegisteredDevice',
    :'ucsd_managed_infra' => :'UcsdManagedInfra'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



360
361
362
# File 'lib/intersight_client/models/iaas_ucsd_info.rb', line 360

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_all_ofObject

List of class defined in allOf (OpenAPI v3)



160
161
162
163
164
165
# File 'lib/intersight_client/models/iaas_ucsd_info.rb', line 160

def self.openapi_all_of
  [
  :'IaasUcsdInfoAllOf',
  :'MoBaseMo'
  ]
end

.openapi_discriminator_nameObject

discriminator’s property name in OpenAPI v3



168
169
170
# File 'lib/intersight_client/models/iaas_ucsd_info.rb', line 168

def self.openapi_discriminator_name
  :'ClassId'
end

.openapi_nullableObject

List of attributes with nullable: true



151
152
153
154
155
156
157
# File 'lib/intersight_client/models/iaas_ucsd_info.rb', line 151

def self.openapi_nullable
  Set.new([
    :'connector_pack',
    :'device_status',
    :'most_run_tasks',
  ])
end

.openapi_typesObject

Attribute type mapping.



127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
# File 'lib/intersight_client/models/iaas_ucsd_info.rb', line 127

def self.openapi_types
  {
    :'class_id' => :'String',
    :'object_type' => :'String',
    :'device_id' => :'String',
    :'guid' => :'String',
    :'host_name' => :'String',
    :'ip' => :'String',
    :'last_backup' => :'Time',
    :'node_type' => :'String',
    :'product_name' => :'String',
    :'product_vendor' => :'String',
    :'product_version' => :'String',
    :'status' => :'String',
    :'connector_pack' => :'Array<IaasConnectorPackRelationship>',
    :'device_status' => :'Array<IaasDeviceStatusRelationship>',
    :'license_info' => :'IaasLicenseInfoRelationship',
    :'most_run_tasks' => :'Array<IaasMostRunTasksRelationship>',
    :'registered_device' => :'AssetDeviceRegistrationRelationship',
    :'ucsd_managed_infra' => :'IaasUcsdManagedInfraRelationship'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
# File 'lib/intersight_client/models/iaas_ucsd_info.rb', line 322

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      class_id == o.class_id &&
      object_type == o.object_type &&
      device_id == o.device_id &&
      guid == o.guid &&
      host_name == o.host_name &&
      ip == o.ip &&
      last_backup == o.last_backup &&
      node_type == o.node_type &&
      product_name == o.product_name &&
      product_vendor == o.product_vendor &&
      product_version == o.product_version &&
      status == o.status &&
      connector_pack == o.connector_pack &&
      device_status == o.device_status &&
      license_info == o.license_info &&
      most_run_tasks == o.most_run_tasks &&
      registered_device == o.registered_device &&
      ucsd_managed_infra == o.ucsd_managed_infra && super(o)
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
410
411
412
413
414
415
416
417
418
419
420
421
422
423
424
425
426
427
428
# File 'lib/intersight_client/models/iaas_ucsd_info.rb', line 391

def _deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = IntersightClient.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



462
463
464
465
466
467
468
469
470
471
472
473
474
# File 'lib/intersight_client/models/iaas_ucsd_info.rb', line 462

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
# File 'lib/intersight_client/models/iaas_ucsd_info.rb', line 367

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  super(attributes)
  IaasUcsdInfo.openapi_types.each_pair do |key, type|
    if attributes[IaasUcsdInfo.attribute_map[key]].nil? && IaasUcsdInfo.openapi_nullable.include?(key)
      self.send("#{key}=", nil)
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[IaasUcsdInfo.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[IaasUcsdInfo.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[IaasUcsdInfo.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[IaasUcsdInfo.attribute_map[key]]))
    end
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


347
348
349
# File 'lib/intersight_client/models/iaas_ucsd_info.rb', line 347

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



353
354
355
# File 'lib/intersight_client/models/iaas_ucsd_info.rb', line 353

def hash
  [class_id, object_type, device_id, guid, host_name, ip, last_backup, node_type, product_name, product_vendor, product_version, status, connector_pack, device_status, license_info, most_run_tasks, registered_device, ucsd_managed_infra].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



275
276
277
278
279
280
281
282
283
284
285
286
# File 'lib/intersight_client/models/iaas_ucsd_info.rb', line 275

def list_invalid_properties
  invalid_properties = super
  if @class_id.nil?
    invalid_properties.push('invalid value for "class_id", class_id cannot be nil.')
  end

  if @object_type.nil?
    invalid_properties.push('invalid value for "object_type", object_type cannot be nil.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



438
439
440
# File 'lib/intersight_client/models/iaas_ucsd_info.rb', line 438

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



444
445
446
447
448
449
450
451
452
453
454
455
456
# File 'lib/intersight_client/models/iaas_ucsd_info.rb', line 444

def to_hash
  hash = super
  IaasUcsdInfo.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = IaasUcsdInfo.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



432
433
434
# File 'lib/intersight_client/models/iaas_ucsd_info.rb', line 432

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



290
291
292
293
294
295
296
297
298
# File 'lib/intersight_client/models/iaas_ucsd_info.rb', line 290

def valid?
  return false if @class_id.nil?
  class_id_validator = EnumAttributeValidator.new('String', ["iaas.UcsdInfo"])
  return false unless class_id_validator.valid?(@class_id)
  return false if @object_type.nil?
  object_type_validator = EnumAttributeValidator.new('String', ["iaas.UcsdInfo"])
  return false unless object_type_validator.valid?(@object_type)
  true && super
end