Class: IntersightClient::IamApiKeyAllOf

Inherits:
Object
  • Object
show all
Defined in:
lib/intersight_client/models/iam_api_key_all_of.rb

Overview

Definition of the list of properties defined in ‘iam.ApiKey’, excluding properties defined in parent classes.

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ IamApiKeyAllOf

Initializes the object



114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
# File 'lib/intersight_client/models/iam_api_key_all_of.rb', line 114

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `IntersightClient::IamApiKeyAllOf` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `#{self.class.name}`. Please check the name to make sure it's valid. List of attributes: " + self.class.acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'class_id')
    self.class_id = attributes[:'class_id']
  else
    self.class_id = 'iam.ApiKey'
  end

  if attributes.key?(:'object_type')
    self.object_type = attributes[:'object_type']
  else
    self.object_type = 'iam.ApiKey'
  end

  if attributes.key?(:'hash_algorithm')
    self.hash_algorithm = attributes[:'hash_algorithm']
  else
    self.hash_algorithm = 'SHA256'
  end

  if attributes.key?(:'key_spec')
    self.key_spec = attributes[:'key_spec']
  end

  if attributes.key?(:'private_key')
    self.private_key = attributes[:'private_key']
  end

  if attributes.key?(:'purpose')
    self.purpose = attributes[:'purpose']
  end

  if attributes.key?(:'signing_algorithm')
    self.signing_algorithm = attributes[:'signing_algorithm']
  else
    self.signing_algorithm = 'RSASSA-PKCS1-v1_5'
  end

  if attributes.key?(:'permission')
    self.permission = attributes[:'permission']
  end

  if attributes.key?(:'user')
    self.user = attributes[:'user']
  end
end

Instance Attribute Details

#class_idObject

The fully-qualified name of the instantiated, concrete type. This property is used as a discriminator to identify the type of the payload when marshaling and unmarshaling data.



20
21
22
# File 'lib/intersight_client/models/iam_api_key_all_of.rb', line 20

def class_id
  @class_id
end

#hash_algorithmObject

The cryptographic hash algorithm to calculate the message digest. * SHA256 - The SHA-256 cryptographic hash, as defined by NIST in FIPS 180-4. * SHA384 - The SHA-384 cryptographic hash, as defined by NIST in FIPS 180-4. * SHA512 - The SHA-512 cryptographic hash, as defined by NIST in FIPS 180-4. * SHA512_224 - The SHA-512/224 cryptographic hash, as defined by NIST in FIPS 180-4. * SHA512_256 - The SHA-512/256 cryptographic hash, as defined by NIST in FIPS 180-4.



26
27
28
# File 'lib/intersight_client/models/iam_api_key_all_of.rb', line 26

def hash_algorithm
  @hash_algorithm
end

#key_specObject

Returns the value of attribute key_spec.



28
29
30
# File 'lib/intersight_client/models/iam_api_key_all_of.rb', line 28

def key_spec
  @key_spec
end

#object_typeObject

The fully-qualified name of the instantiated, concrete type. The value should be the same as the ‘ClassId’ property.



23
24
25
# File 'lib/intersight_client/models/iam_api_key_all_of.rb', line 23

def object_type
  @object_type
end

#permissionObject

Returns the value of attribute permission.



39
40
41
# File 'lib/intersight_client/models/iam_api_key_all_of.rb', line 39

def permission
  @permission
end

#private_keyObject

Holds the private key for the API key.



31
32
33
# File 'lib/intersight_client/models/iam_api_key_all_of.rb', line 31

def private_key
  @private_key
end

#purposeObject

The purpose of the API Key.



34
35
36
# File 'lib/intersight_client/models/iam_api_key_all_of.rb', line 34

def purpose
  @purpose
end

#signing_algorithmObject

The signing algorithm used by the client to authenticate API requests to Intersight. The signing algorithm must be compatible with the key generation specification. * RSASSA-PKCS1-v1_5 - RSASSA-PKCS1-v1_5 is a RSA signature scheme specified in [RFC 8017](tools.ietf.org/html/rfc8017).RSASSA-PKCS1-v1_5 is included only for compatibility with existing applications. * RSASSA-PSS - RSASSA-PSS is a RSA signature scheme specified in [RFC 8017](tools.ietf.org/html/rfc8017).It combines the RSASP1 and RSAVP1 primitives with the EMSA-PSS encoding method.In the interest of increased robustness, RSASSA-PSS is required in new applications. * Ed25519 - The Ed25519 signature algorithm, as specified in [RFC 8032](tools.ietf.org/html/rfc8032).Ed25519 is a public-key signature system with several attractive features, includingfast single-signature verification, very fast signing, fast key generation and high security level. * Ecdsa - The Elliptic Curve Digital Signature Standard (ECDSA), as defined by NIST in FIPS 186-4 and ANSI X9.62.The signature is encoded as a ASN.1 DER SEQUENCE with two INTEGERs (r and s), as defined in RFC3279.When using ECDSA signatures, configure the client to use the same signature encoding as specified on the server side. * EcdsaP1363Format - The Elliptic Curve Digital Signature Standard (ECDSA), as defined by NIST in FIPS 186-4 and ANSI X9.62.The signature is the raw concatenation of r and s, as defined in the ISO/IEC 7816-8 IEEE P.1363 standard.In that format, r and s are represented as unsigned, big endian numbers.Extra padding bytes (of value 0x00) is applied so that both r and s encodings have the same size.When using ECDSA signatures, configure the client to use the same signature encoding as specified on the server side.



37
38
39
# File 'lib/intersight_client/models/iam_api_key_all_of.rb', line 37

def signing_algorithm
  @signing_algorithm
end

#userObject

Returns the value of attribute user.



41
42
43
# File 'lib/intersight_client/models/iam_api_key_all_of.rb', line 41

def user
  @user
end

Class Method Details

.acceptable_attribute_mapObject

Returns the key-value map of all the JSON attributes this model knows about



86
87
88
# File 'lib/intersight_client/models/iam_api_key_all_of.rb', line 86

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



81
82
83
# File 'lib/intersight_client/models/iam_api_key_all_of.rb', line 81

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



66
67
68
69
70
71
72
73
74
75
76
77
78
# File 'lib/intersight_client/models/iam_api_key_all_of.rb', line 66

def self.attribute_map
  {
    :'class_id' => :'ClassId',
    :'object_type' => :'ObjectType',
    :'hash_algorithm' => :'HashAlgorithm',
    :'key_spec' => :'KeySpec',
    :'private_key' => :'PrivateKey',
    :'purpose' => :'Purpose',
    :'signing_algorithm' => :'SigningAlgorithm',
    :'permission' => :'Permission',
    :'user' => :'User'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash



274
275
276
# File 'lib/intersight_client/models/iam_api_key_all_of.rb', line 274

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_nullableObject

List of attributes with nullable: true



106
107
108
109
110
# File 'lib/intersight_client/models/iam_api_key_all_of.rb', line 106

def self.openapi_nullable
  Set.new([
    :'key_spec',
  ])
end

.openapi_typesObject

Attribute type mapping.



91
92
93
94
95
96
97
98
99
100
101
102
103
# File 'lib/intersight_client/models/iam_api_key_all_of.rb', line 91

def self.openapi_types
  {
    :'class_id' => :'String',
    :'object_type' => :'String',
    :'hash_algorithm' => :'String',
    :'key_spec' => :'PkixKeyGenerationSpec',
    :'private_key' => :'String',
    :'purpose' => :'String',
    :'signing_algorithm' => :'String',
    :'permission' => :'IamPermissionRelationship',
    :'user' => :'IamUserRelationship'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.



245
246
247
248
249
250
251
252
253
254
255
256
257
# File 'lib/intersight_client/models/iam_api_key_all_of.rb', line 245

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      class_id == o.class_id &&
      object_type == o.object_type &&
      hash_algorithm == o.hash_algorithm &&
      key_spec == o.key_spec &&
      private_key == o.private_key &&
      purpose == o.purpose &&
      signing_algorithm == o.signing_algorithm &&
      permission == o.permission &&
      user == o.user
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type



304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
# File 'lib/intersight_client/models/iam_api_key_all_of.rb', line 304

def _deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = IntersightClient.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value



375
376
377
378
379
380
381
382
383
384
385
386
387
# File 'lib/intersight_client/models/iam_api_key_all_of.rb', line 375

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash



281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
# File 'lib/intersight_client/models/iam_api_key_all_of.rb', line 281

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  IamApiKeyAllOf.openapi_types.each_pair do |key, type|
    if attributes[IamApiKeyAllOf.attribute_map[key]].nil? && IamApiKeyAllOf.openapi_nullable.include?(key)
      self.send("#{key}=", nil)
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[IamApiKeyAllOf.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[IamApiKeyAllOf.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[IamApiKeyAllOf.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[IamApiKeyAllOf.attribute_map[key]]))
    end
  end

  self
end

#eql?(o) ⇒ Boolean

See Also:

  • `==` method


261
262
263
# File 'lib/intersight_client/models/iam_api_key_all_of.rb', line 261

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.



267
268
269
# File 'lib/intersight_client/models/iam_api_key_all_of.rb', line 267

def hash
  [class_id, object_type, hash_algorithm, key_spec, private_key, purpose, signing_algorithm, permission, user].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?



174
175
176
177
178
179
180
181
182
183
184
185
# File 'lib/intersight_client/models/iam_api_key_all_of.rb', line 174

def list_invalid_properties
  invalid_properties = Array.new
  if @class_id.nil?
    invalid_properties.push('invalid value for "class_id", class_id cannot be nil.')
  end

  if @object_type.nil?
    invalid_properties.push('invalid value for "object_type", object_type cannot be nil.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)



351
352
353
# File 'lib/intersight_client/models/iam_api_key_all_of.rb', line 351

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash



357
358
359
360
361
362
363
364
365
366
367
368
369
# File 'lib/intersight_client/models/iam_api_key_all_of.rb', line 357

def to_hash
  hash = {}
  IamApiKeyAllOf.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = IamApiKeyAllOf.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object



345
346
347
# File 'lib/intersight_client/models/iam_api_key_all_of.rb', line 345

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid



189
190
191
192
193
194
195
196
197
198
199
200
201
# File 'lib/intersight_client/models/iam_api_key_all_of.rb', line 189

def valid?
  return false if @class_id.nil?
  class_id_validator = EnumAttributeValidator.new('String', ["iam.ApiKey"])
  return false unless class_id_validator.valid?(@class_id)
  return false if @object_type.nil?
  object_type_validator = EnumAttributeValidator.new('String', ["iam.ApiKey"])
  return false unless object_type_validator.valid?(@object_type)
  hash_algorithm_validator = EnumAttributeValidator.new('String', ["SHA256", "SHA384", "SHA512", "SHA512_224", "SHA512_256"])
  return false unless hash_algorithm_validator.valid?(@hash_algorithm)
  signing_algorithm_validator = EnumAttributeValidator.new('String', ["RSASSA-PKCS1-v1_5", "RSASSA-PSS", "Ed25519", "Ecdsa", "EcdsaP1363Format"])
  return false unless signing_algorithm_validator.valid?(@signing_algorithm)
  true
end