Class: IntersightClient::IamLdapDnsParametersAllOf
- Inherits:
-
Object
- Object
- IntersightClient::IamLdapDnsParametersAllOf
- Defined in:
- lib/intersight_client/models/iam_ldap_dns_parameters_all_of.rb
Overview
Definition of the list of properties defined in 'iam.LdapDnsParameters', excluding properties defined in parent classes.
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#class_id ⇒ Object
The fully-qualified name of the instantiated, concrete type.
-
#object_type ⇒ Object
The fully-qualified name of the instantiated, concrete type.
-
#search_domain ⇒ Object
Domain name that acts as a source for a DNS query.
-
#search_forest ⇒ Object
Forest name that acts as a source for a DNS query.
-
#source ⇒ Object
Source of the domain name used for the DNS SRV request.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns the key-value map of all the JSON attributes this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ IamLdapDnsParametersAllOf
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ IamLdapDnsParametersAllOf
Initializes the object
96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 |
# File 'lib/intersight_client/models/iam_ldap_dns_parameters_all_of.rb', line 96 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `IntersightClient::IamLdapDnsParametersAllOf` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `#{self.class.name}`. Please check the name to make sure it's valid. List of attributes: " + self.class.acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'class_id') self.class_id = attributes[:'class_id'] else self.class_id = 'iam.LdapDnsParameters' end if attributes.key?(:'object_type') self.object_type = attributes[:'object_type'] else self.object_type = 'iam.LdapDnsParameters' end if attributes.key?(:'search_domain') self.search_domain = attributes[:'search_domain'] end if attributes.key?(:'search_forest') self.search_forest = attributes[:'search_forest'] end if attributes.key?(:'source') self.source = attributes[:'source'] else self.source = 'Extracted' end end |
Instance Attribute Details
#class_id ⇒ Object
The fully-qualified name of the instantiated, concrete type. This property is used as a discriminator to identify the type of the payload when marshaling and unmarshaling data.
20 21 22 |
# File 'lib/intersight_client/models/iam_ldap_dns_parameters_all_of.rb', line 20 def class_id @class_id end |
#object_type ⇒ Object
The fully-qualified name of the instantiated, concrete type. The value should be the same as the 'ClassId' property.
23 24 25 |
# File 'lib/intersight_client/models/iam_ldap_dns_parameters_all_of.rb', line 23 def object_type @object_type end |
#search_domain ⇒ Object
Domain name that acts as a source for a DNS query.
26 27 28 |
# File 'lib/intersight_client/models/iam_ldap_dns_parameters_all_of.rb', line 26 def search_domain @search_domain end |
#search_forest ⇒ Object
Forest name that acts as a source for a DNS query.
29 30 31 |
# File 'lib/intersight_client/models/iam_ldap_dns_parameters_all_of.rb', line 29 def search_forest @search_forest end |
#source ⇒ Object
Source of the domain name used for the DNS SRV request. * Extracted - The domain name extracted-domain from the login ID. * Configured - The configured-search domain. * ConfiguredExtracted - The domain name extracted from the login ID than the configured-search domain.
32 33 34 |
# File 'lib/intersight_client/models/iam_ldap_dns_parameters_all_of.rb', line 32 def source @source end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns the key-value map of all the JSON attributes this model knows about
73 74 75 |
# File 'lib/intersight_client/models/iam_ldap_dns_parameters_all_of.rb', line 73 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
68 69 70 |
# File 'lib/intersight_client/models/iam_ldap_dns_parameters_all_of.rb', line 68 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
57 58 59 60 61 62 63 64 65 |
# File 'lib/intersight_client/models/iam_ldap_dns_parameters_all_of.rb', line 57 def self.attribute_map { :'class_id' => :'ClassId', :'object_type' => :'ObjectType', :'search_domain' => :'SearchDomain', :'search_forest' => :'SearchForest', :'source' => :'Source' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
274 275 276 |
# File 'lib/intersight_client/models/iam_ldap_dns_parameters_all_of.rb', line 274 def self.build_from_hash(attributes) new.build_from_hash(attributes) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
89 90 91 92 |
# File 'lib/intersight_client/models/iam_ldap_dns_parameters_all_of.rb', line 89 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
78 79 80 81 82 83 84 85 86 |
# File 'lib/intersight_client/models/iam_ldap_dns_parameters_all_of.rb', line 78 def self.openapi_types { :'class_id' => :'String', :'object_type' => :'String', :'search_domain' => :'String', :'search_forest' => :'String', :'source' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
249 250 251 252 253 254 255 256 257 |
# File 'lib/intersight_client/models/iam_ldap_dns_parameters_all_of.rb', line 249 def ==(o) return true if self.equal?(o) self.class == o.class && class_id == o.class_id && object_type == o.object_type && search_domain == o.search_domain && search_forest == o.search_forest && source == o.source end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 |
# File 'lib/intersight_client/models/iam_ldap_dns_parameters_all_of.rb', line 304 def _deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = IntersightClient.const_get(type) klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
375 376 377 378 379 380 381 382 383 384 385 386 387 |
# File 'lib/intersight_client/models/iam_ldap_dns_parameters_all_of.rb', line 375 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 |
# File 'lib/intersight_client/models/iam_ldap_dns_parameters_all_of.rb', line 281 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) IamLdapDnsParametersAllOf.openapi_types.each_pair do |key, type| if attributes[IamLdapDnsParametersAllOf.attribute_map[key]].nil? && IamLdapDnsParametersAllOf.openapi_nullable.include?(key) self.send("#{key}=", nil) elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[IamLdapDnsParametersAllOf.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[IamLdapDnsParametersAllOf.attribute_map[key]].map { |v| _deserialize($1, v) }) end elsif !attributes[IamLdapDnsParametersAllOf.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[IamLdapDnsParametersAllOf.attribute_map[key]])) end end self end |
#eql?(o) ⇒ Boolean
261 262 263 |
# File 'lib/intersight_client/models/iam_ldap_dns_parameters_all_of.rb', line 261 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
267 268 269 |
# File 'lib/intersight_client/models/iam_ldap_dns_parameters_all_of.rb', line 267 def hash [class_id, object_type, search_domain, search_forest, source].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 |
# File 'lib/intersight_client/models/iam_ldap_dns_parameters_all_of.rb', line 138 def list_invalid_properties invalid_properties = Array.new if @class_id.nil? invalid_properties.push('invalid value for "class_id", class_id cannot be nil.') end if @object_type.nil? invalid_properties.push('invalid value for "object_type", object_type cannot be nil.') end if !@search_domain.nil? && @search_domain.to_s.length > 64 invalid_properties.push('invalid value for "search_domain", the character length must be smaller than or equal to 64.') end pattern = Regexp.new(/^$|^(([a-zA-Z0-9])|([a-zA-Z0-9][a-zA-Z0-9\.\-]*[a-zA-Z0-9]))$/) if !@search_domain.nil? && @search_domain !~ pattern invalid_properties.push("invalid value for \"search_domain\", must conform to the pattern #{pattern}.") end if !@search_forest.nil? && @search_forest.to_s.length > 64 invalid_properties.push('invalid value for "search_forest", the character length must be smaller than or equal to 64.') end pattern = Regexp.new(/^$|^(([a-zA-Z0-9])|([a-zA-Z0-9][a-zA-Z0-9\.\-]*[a-zA-Z0-9]))$/) if !@search_forest.nil? && @search_forest !~ pattern invalid_properties.push("invalid value for \"search_forest\", must conform to the pattern #{pattern}.") end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
351 352 353 |
# File 'lib/intersight_client/models/iam_ldap_dns_parameters_all_of.rb', line 351 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
357 358 359 360 361 362 363 364 365 366 367 368 369 |
# File 'lib/intersight_client/models/iam_ldap_dns_parameters_all_of.rb', line 357 def to_hash hash = {} IamLdapDnsParametersAllOf.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = IamLdapDnsParametersAllOf.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
345 346 347 |
# File 'lib/intersight_client/models/iam_ldap_dns_parameters_all_of.rb', line 345 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 |
# File 'lib/intersight_client/models/iam_ldap_dns_parameters_all_of.rb', line 171 def valid? return false if @class_id.nil? class_id_validator = EnumAttributeValidator.new('String', ["iam.LdapDnsParameters"]) return false unless class_id_validator.valid?(@class_id) return false if @object_type.nil? object_type_validator = EnumAttributeValidator.new('String', ["iam.LdapDnsParameters"]) return false unless object_type_validator.valid?(@object_type) return false if !@search_domain.nil? && @search_domain.to_s.length > 64 return false if !@search_domain.nil? && @search_domain !~ Regexp.new(/^$|^(([a-zA-Z0-9])|([a-zA-Z0-9][a-zA-Z0-9\.\-]*[a-zA-Z0-9]))$/) return false if !@search_forest.nil? && @search_forest.to_s.length > 64 return false if !@search_forest.nil? && @search_forest !~ Regexp.new(/^$|^(([a-zA-Z0-9])|([a-zA-Z0-9][a-zA-Z0-9\.\-]*[a-zA-Z0-9]))$/) source_validator = EnumAttributeValidator.new('String', ["Extracted", "Configured", "ConfiguredExtracted"]) return false unless source_validator.valid?(@source) true end |