Class: IntersightClient::IamSessionLimitsAllOf

Inherits:
Object
  • Object
show all
Defined in:
lib/intersight_client/models/iam_session_limits_all_of.rb

Overview

Definition of the list of properties defined in ‘iam.SessionLimits’, excluding properties defined in parent classes.

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ IamSessionLimitsAllOf

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
# File 'lib/intersight_client/models/iam_session_limits_all_of.rb', line 109

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `IntersightClient::IamSessionLimitsAllOf` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `#{self.class.name}`. Please check the name to make sure it's valid. List of attributes: " + self.class.acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'class_id')
    self.class_id = attributes[:'class_id']
  else
    self.class_id = 'iam.SessionLimits'
  end

  if attributes.key?(:'object_type')
    self.object_type = attributes[:'object_type']
  else
    self.object_type = 'iam.SessionLimits'
  end

  if attributes.key?(:'idle_time_out')
    self.idle_time_out = attributes[:'idle_time_out']
  else
    self.idle_time_out = 1800
  end

  if attributes.key?(:'maximum_limit')
    self.maximum_limit = attributes[:'maximum_limit']
  else
    self.maximum_limit = 128
  end

  if attributes.key?(:'per_user_limit')
    self.per_user_limit = attributes[:'per_user_limit']
  else
    self.per_user_limit = 32
  end

  if attributes.key?(:'session_time_out')
    self.session_time_out = attributes[:'session_time_out']
  else
    self.session_time_out = 57600
  end

  if attributes.key?(:'account')
    self. = attributes[:'account']
  end

  if attributes.key?(:'permission')
    self.permission = attributes[:'permission']
  end
end

Instance Attribute Details

#accountObject

Returns the value of attribute account.



37
38
39
# File 'lib/intersight_client/models/iam_session_limits_all_of.rb', line 37

def 
  @account
end

#class_idObject

The fully-qualified name of the instantiated, concrete type. This property is used as a discriminator to identify the type of the payload when marshaling and unmarshaling data.



20
21
22
# File 'lib/intersight_client/models/iam_session_limits_all_of.rb', line 20

def class_id
  @class_id
end

#idle_time_outObject

The idle timeout interval for the web session in seconds. When a session is not refreshed for this duration, the session is marked as idle and removed. The minimum value is 300 seconds and the maximum value is 18000 seconds (5 hours). The system default value is 1800 seconds.



26
27
28
# File 'lib/intersight_client/models/iam_session_limits_all_of.rb', line 26

def idle_time_out
  @idle_time_out
end

#maximum_limitObject

The maximum number of sessions allowed in an account or permission. The default value is 128.



29
30
31
# File 'lib/intersight_client/models/iam_session_limits_all_of.rb', line 29

def maximum_limit
  @maximum_limit
end

#object_typeObject

The fully-qualified name of the instantiated, concrete type. The value should be the same as the ‘ClassId’ property.



23
24
25
# File 'lib/intersight_client/models/iam_session_limits_all_of.rb', line 23

def object_type
  @object_type
end

#per_user_limitObject

The maximum number of sessions allowed per user. Default value is 32.



32
33
34
# File 'lib/intersight_client/models/iam_session_limits_all_of.rb', line 32

def per_user_limit
  @per_user_limit
end

#permissionObject

Returns the value of attribute permission.



39
40
41
# File 'lib/intersight_client/models/iam_session_limits_all_of.rb', line 39

def permission
  @permission
end

#session_time_outObject

The session expiry duration in seconds. The minimum value is 350 seconds and the maximum value is 31536000 seconds (1 year). The system default value is 57600 seconds.



35
36
37
# File 'lib/intersight_client/models/iam_session_limits_all_of.rb', line 35

def session_time_out
  @session_time_out
end

Class Method Details

.acceptable_attribute_mapObject

Returns the key-value map of all the JSON attributes this model knows about



83
84
85
# File 'lib/intersight_client/models/iam_session_limits_all_of.rb', line 83

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



78
79
80
# File 'lib/intersight_client/models/iam_session_limits_all_of.rb', line 78

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



64
65
66
67
68
69
70
71
72
73
74
75
# File 'lib/intersight_client/models/iam_session_limits_all_of.rb', line 64

def self.attribute_map
  {
    :'class_id' => :'ClassId',
    :'object_type' => :'ObjectType',
    :'idle_time_out' => :'IdleTimeOut',
    :'maximum_limit' => :'MaximumLimit',
    :'per_user_limit' => :'PerUserLimit',
    :'session_time_out' => :'SessionTimeOut',
    :'account' => :'Account',
    :'permission' => :'Permission'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



340
341
342
# File 'lib/intersight_client/models/iam_session_limits_all_of.rb', line 340

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_nullableObject

List of attributes with nullable: true



102
103
104
105
# File 'lib/intersight_client/models/iam_session_limits_all_of.rb', line 102

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



88
89
90
91
92
93
94
95
96
97
98
99
# File 'lib/intersight_client/models/iam_session_limits_all_of.rb', line 88

def self.openapi_types
  {
    :'class_id' => :'String',
    :'object_type' => :'String',
    :'idle_time_out' => :'Integer',
    :'maximum_limit' => :'Integer',
    :'per_user_limit' => :'Integer',
    :'session_time_out' => :'Integer',
    :'account' => :'IamAccountRelationship',
    :'permission' => :'IamPermissionRelationship'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



312
313
314
315
316
317
318
319
320
321
322
323
# File 'lib/intersight_client/models/iam_session_limits_all_of.rb', line 312

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      class_id == o.class_id &&
      object_type == o.object_type &&
      idle_time_out == o.idle_time_out &&
      maximum_limit == o.maximum_limit &&
      per_user_limit == o.per_user_limit &&
      session_time_out == o.session_time_out &&
       == o. &&
      permission == o.permission
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
# File 'lib/intersight_client/models/iam_session_limits_all_of.rb', line 370

def _deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = IntersightClient.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



441
442
443
444
445
446
447
448
449
450
451
452
453
# File 'lib/intersight_client/models/iam_session_limits_all_of.rb', line 441

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
# File 'lib/intersight_client/models/iam_session_limits_all_of.rb', line 347

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  IamSessionLimitsAllOf.openapi_types.each_pair do |key, type|
    if attributes[IamSessionLimitsAllOf.attribute_map[key]].nil? && IamSessionLimitsAllOf.openapi_nullable.include?(key)
      self.send("#{key}=", nil)
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[IamSessionLimitsAllOf.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[IamSessionLimitsAllOf.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[IamSessionLimitsAllOf.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[IamSessionLimitsAllOf.attribute_map[key]]))
    end
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


327
328
329
# File 'lib/intersight_client/models/iam_session_limits_all_of.rb', line 327

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



333
334
335
# File 'lib/intersight_client/models/iam_session_limits_all_of.rb', line 333

def hash
  [class_id, object_type, idle_time_out, maximum_limit, per_user_limit, session_time_out, , permission].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
# File 'lib/intersight_client/models/iam_session_limits_all_of.rb', line 169

def list_invalid_properties
  invalid_properties = Array.new
  if @class_id.nil?
    invalid_properties.push('invalid value for "class_id", class_id cannot be nil.')
  end

  if @object_type.nil?
    invalid_properties.push('invalid value for "object_type", object_type cannot be nil.')
  end

  if !@idle_time_out.nil? && @idle_time_out > 18000
    invalid_properties.push('invalid value for "idle_time_out", must be smaller than or equal to 18000.')
  end

  if !@idle_time_out.nil? && @idle_time_out < 300
    invalid_properties.push('invalid value for "idle_time_out", must be greater than or equal to 300.')
  end

  if !@maximum_limit.nil? && @maximum_limit > 128
    invalid_properties.push('invalid value for "maximum_limit", must be smaller than or equal to 128.')
  end

  if !@maximum_limit.nil? && @maximum_limit < 1
    invalid_properties.push('invalid value for "maximum_limit", must be greater than or equal to 1.')
  end

  if !@per_user_limit.nil? && @per_user_limit > 32
    invalid_properties.push('invalid value for "per_user_limit", must be smaller than or equal to 32.')
  end

  if !@per_user_limit.nil? && @per_user_limit < 2
    invalid_properties.push('invalid value for "per_user_limit", must be greater than or equal to 2.')
  end

  if !@session_time_out.nil? && @session_time_out > 31536000
    invalid_properties.push('invalid value for "session_time_out", must be smaller than or equal to 31536000.')
  end

  if !@session_time_out.nil? && @session_time_out < 300
    invalid_properties.push('invalid value for "session_time_out", must be greater than or equal to 300.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



417
418
419
# File 'lib/intersight_client/models/iam_session_limits_all_of.rb', line 417

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



423
424
425
426
427
428
429
430
431
432
433
434
435
# File 'lib/intersight_client/models/iam_session_limits_all_of.rb', line 423

def to_hash
  hash = {}
  IamSessionLimitsAllOf.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = IamSessionLimitsAllOf.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



411
412
413
# File 'lib/intersight_client/models/iam_session_limits_all_of.rb', line 411

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
# File 'lib/intersight_client/models/iam_session_limits_all_of.rb', line 216

def valid?
  return false if @class_id.nil?
  class_id_validator = EnumAttributeValidator.new('String', ["iam.SessionLimits"])
  return false unless class_id_validator.valid?(@class_id)
  return false if @object_type.nil?
  object_type_validator = EnumAttributeValidator.new('String', ["iam.SessionLimits"])
  return false unless object_type_validator.valid?(@object_type)
  return false if !@idle_time_out.nil? && @idle_time_out > 18000
  return false if !@idle_time_out.nil? && @idle_time_out < 300
  return false if !@maximum_limit.nil? && @maximum_limit > 128
  return false if !@maximum_limit.nil? && @maximum_limit < 1
  return false if !@per_user_limit.nil? && @per_user_limit > 32
  return false if !@per_user_limit.nil? && @per_user_limit < 2
  return false if !@session_time_out.nil? && @session_time_out > 31536000
  return false if !@session_time_out.nil? && @session_time_out < 300
  true
end