Class: IntersightClient::IppoolIpLease

Inherits:
PoolAbstractLease show all
Defined in:
lib/intersight_client/models/ippool_ip_lease.rb

Overview

IpLease represents an IP address that is allocated from a pool to a specific entity like server profile.

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Attributes inherited from PoolAbstractLease

#allocation_type

Attributes inherited from MoBaseMo

#account_moid, #ancestors, #create_time, #display_names, #domain_group_moid, #mod_time, #moid, #owners, #parent, #permission_resources, #shared_scope, #tags, #version_context

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ IppoolIpLease

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
# File 'lib/intersight_client/models/ippool_ip_lease.rb', line 143

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `IntersightClient::IppoolIpLease` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `#{self.class.name}`. Please check the name to make sure it's valid. List of attributes: " + self.class.acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  # call parent's initialize
  super(attributes)

  if attributes.key?(:'class_id')
    self.class_id = attributes[:'class_id']
  else
    self.class_id = 'ippool.IpLease'
  end

  if attributes.key?(:'object_type')
    self.object_type = attributes[:'object_type']
  else
    self.object_type = 'ippool.IpLease'
  end

  if attributes.key?(:'ip_type')
    self.ip_type = attributes[:'ip_type']
  else
    self.ip_type = 'IPv4'
  end

  if attributes.key?(:'ip_v4_address')
    self.ip_v4_address = attributes[:'ip_v4_address']
  end

  if attributes.key?(:'ip_v4_config')
    self.ip_v4_config = attributes[:'ip_v4_config']
  end

  if attributes.key?(:'ip_v6_address')
    self.ip_v6_address = attributes[:'ip_v6_address']
  end

  if attributes.key?(:'ip_v6_config')
    self.ip_v6_config = attributes[:'ip_v6_config']
  end

  if attributes.key?(:'assigned_to_entity')
    self.assigned_to_entity = attributes[:'assigned_to_entity']
  end

  if attributes.key?(:'block_lease')
    self.block_lease = attributes[:'block_lease']
  end

  if attributes.key?(:'pool')
    self.pool = attributes[:'pool']
  end

  if attributes.key?(:'pool_member')
    self.pool_member = attributes[:'pool_member']
  end

  if attributes.key?(:'universe')
    self.universe = attributes[:'universe']
  end

  if attributes.key?(:'vrf')
    self.vrf = attributes[:'vrf']
  end
end

Instance Attribute Details

#assigned_to_entityObject

Returns the value of attribute assigned_to_entity.



38
39
40
# File 'lib/intersight_client/models/ippool_ip_lease.rb', line 38

def assigned_to_entity
  @assigned_to_entity
end

#block_leaseObject

Returns the value of attribute block_lease.



40
41
42
# File 'lib/intersight_client/models/ippool_ip_lease.rb', line 40

def block_lease
  @block_lease
end

#class_idObject

The fully-qualified name of the instantiated, concrete type. This property is used as a discriminator to identify the type of the payload when marshaling and unmarshaling data.



20
21
22
# File 'lib/intersight_client/models/ippool_ip_lease.rb', line 20

def class_id
  @class_id
end

#ip_typeObject

Type of the IP address requested. * IPv4 - IP V4 address type requested. * IPv6 - IP V6 address type requested.



26
27
28
# File 'lib/intersight_client/models/ippool_ip_lease.rb', line 26

def ip_type
  @ip_type
end

#ip_v4_addressObject

IPv4 Address given as a lease to an external entity like server profiles.



29
30
31
# File 'lib/intersight_client/models/ippool_ip_lease.rb', line 29

def ip_v4_address
  @ip_v4_address
end

#ip_v4_configObject

Returns the value of attribute ip_v4_config.



31
32
33
# File 'lib/intersight_client/models/ippool_ip_lease.rb', line 31

def ip_v4_config
  @ip_v4_config
end

#ip_v6_addressObject

IPv6 Address given as a lease to an external entity like server profiles.



34
35
36
# File 'lib/intersight_client/models/ippool_ip_lease.rb', line 34

def ip_v6_address
  @ip_v6_address
end

#ip_v6_configObject

Returns the value of attribute ip_v6_config.



36
37
38
# File 'lib/intersight_client/models/ippool_ip_lease.rb', line 36

def ip_v6_config
  @ip_v6_config
end

#object_typeObject

The fully-qualified name of the instantiated, concrete type. The value should be the same as the 'ClassId' property.



23
24
25
# File 'lib/intersight_client/models/ippool_ip_lease.rb', line 23

def object_type
  @object_type
end

#poolObject

Returns the value of attribute pool.



42
43
44
# File 'lib/intersight_client/models/ippool_ip_lease.rb', line 42

def pool
  @pool
end

#pool_memberObject

Returns the value of attribute pool_member.



44
45
46
# File 'lib/intersight_client/models/ippool_ip_lease.rb', line 44

def pool_member
  @pool_member
end

#universeObject

Returns the value of attribute universe.



46
47
48
# File 'lib/intersight_client/models/ippool_ip_lease.rb', line 46

def universe
  @universe
end

#vrfObject

Returns the value of attribute vrf.



48
49
50
# File 'lib/intersight_client/models/ippool_ip_lease.rb', line 48

def vrf
  @vrf
end

Class Method Details

.acceptable_attribute_mapObject

Returns the key-value map of all the JSON attributes this model knows about, including the ones defined in its parent(s)



97
98
99
# File 'lib/intersight_client/models/ippool_ip_lease.rb', line 97

def self.acceptable_attribute_map
  attribute_map.merge(superclass.acceptable_attribute_map)
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about, including the ones defined in its parent(s)



92
93
94
# File 'lib/intersight_client/models/ippool_ip_lease.rb', line 92

def self.acceptable_attributes
  attribute_map.values.concat(superclass.acceptable_attributes)
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
# File 'lib/intersight_client/models/ippool_ip_lease.rb', line 73

def self.attribute_map
  {
    :'class_id' => :'ClassId',
    :'object_type' => :'ObjectType',
    :'ip_type' => :'IpType',
    :'ip_v4_address' => :'IpV4Address',
    :'ip_v4_config' => :'IpV4Config',
    :'ip_v6_address' => :'IpV6Address',
    :'ip_v6_config' => :'IpV6Config',
    :'assigned_to_entity' => :'AssignedToEntity',
    :'block_lease' => :'BlockLease',
    :'pool' => :'Pool',
    :'pool_member' => :'PoolMember',
    :'universe' => :'Universe',
    :'vrf' => :'Vrf'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



346
347
348
# File 'lib/intersight_client/models/ippool_ip_lease.rb', line 346

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_all_ofObject

List of class defined in allOf (OpenAPI v3)



129
130
131
132
133
134
# File 'lib/intersight_client/models/ippool_ip_lease.rb', line 129

def self.openapi_all_of
  [
  :'IppoolIpLeaseAllOf',
  :'PoolAbstractLease'
  ]
end

.openapi_discriminator_nameObject

discriminator's property name in OpenAPI v3



137
138
139
# File 'lib/intersight_client/models/ippool_ip_lease.rb', line 137

def self.openapi_discriminator_name
  :'ClassId'
end

.openapi_nullableObject

List of attributes with nullable: true



121
122
123
124
125
126
# File 'lib/intersight_client/models/ippool_ip_lease.rb', line 121

def self.openapi_nullable
  Set.new([
    :'ip_v4_config',
    :'ip_v6_config',
  ])
end

.openapi_typesObject

Attribute type mapping.



102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
# File 'lib/intersight_client/models/ippool_ip_lease.rb', line 102

def self.openapi_types
  {
    :'class_id' => :'String',
    :'object_type' => :'String',
    :'ip_type' => :'String',
    :'ip_v4_address' => :'String',
    :'ip_v4_config' => :'IppoolIpV4Config',
    :'ip_v6_address' => :'String',
    :'ip_v6_config' => :'IppoolIpV6Config',
    :'assigned_to_entity' => :'MoBaseMoRelationship',
    :'block_lease' => :'IppoolBlockLeaseRelationship',
    :'pool' => :'IppoolPoolRelationship',
    :'pool_member' => :'IppoolPoolMemberRelationship',
    :'universe' => :'IppoolUniverseRelationship',
    :'vrf' => :'VrfVrfRelationship'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
# File 'lib/intersight_client/models/ippool_ip_lease.rb', line 313

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      class_id == o.class_id &&
      object_type == o.object_type &&
      ip_type == o.ip_type &&
      ip_v4_address == o.ip_v4_address &&
      ip_v4_config == o.ip_v4_config &&
      ip_v6_address == o.ip_v6_address &&
      ip_v6_config == o.ip_v6_config &&
      assigned_to_entity == o.assigned_to_entity &&
      block_lease == o.block_lease &&
      pool == o.pool &&
      pool_member == o.pool_member &&
      universe == o.universe &&
      vrf == o.vrf && super(o)
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
410
411
412
413
414
# File 'lib/intersight_client/models/ippool_ip_lease.rb', line 377

def _deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = IntersightClient.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



448
449
450
451
452
453
454
455
456
457
458
459
460
# File 'lib/intersight_client/models/ippool_ip_lease.rb', line 448

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
# File 'lib/intersight_client/models/ippool_ip_lease.rb', line 353

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  super(attributes)
  IppoolIpLease.openapi_types.each_pair do |key, type|
    if attributes[IppoolIpLease.attribute_map[key]].nil? && IppoolIpLease.openapi_nullable.include?(key)
      self.send("#{key}=", nil)
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[IppoolIpLease.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[IppoolIpLease.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[IppoolIpLease.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[IppoolIpLease.attribute_map[key]]))
    end
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


333
334
335
# File 'lib/intersight_client/models/ippool_ip_lease.rb', line 333

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



339
340
341
# File 'lib/intersight_client/models/ippool_ip_lease.rb', line 339

def hash
  [class_id, object_type, ip_type, ip_v4_address, ip_v4_config, ip_v6_address, ip_v6_config, assigned_to_entity, block_lease, pool, pool_member, universe, vrf].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
# File 'lib/intersight_client/models/ippool_ip_lease.rb', line 220

def list_invalid_properties
  invalid_properties = super
  if @class_id.nil?
    invalid_properties.push('invalid value for "class_id", class_id cannot be nil.')
  end

  if @object_type.nil?
    invalid_properties.push('invalid value for "object_type", object_type cannot be nil.')
  end

  pattern = Regexp.new(/^$|^([1-9]|[1-9][0-9]|1[0-9][0-9]|2[0-4][0-9]|25[0-5])\.([0-9]|[1-9][0-9]|1[0-9][0-9]|2[0-4][0-9]|25[0-5])\.([0-9]|[1-9][0-9]|1[0-9][0-9]|2[0-4][0-9]|25[0-5])\.([0-9]|[1-9][0-9]|1[0-9][0-9]|2[0-4][0-9]|25[0-5])$/)
  if !@ip_v4_address.nil? && @ip_v4_address !~ pattern
    invalid_properties.push("invalid value for \"ip_v4_address\", must conform to the pattern #{pattern}.")
  end

  pattern = Regexp.new(/^$|^(([0-9A-Fa-f]{1,4}:([0-9A-Fa-f]{1,4}:([0-9A-Fa-f]{1,4}:([0-9A-Fa-f]{1,4}:([0-9A-Fa-f]{1,4}:[0-9A-Fa-f]{0,4}|:[0-9A-Fa-f]{1,4})?|(:[0-9A-Fa-f]{1,4}){0,2})|(:[0-9A-Fa-f]{1,4}){0,3})|(:[0-9A-Fa-f]{1,4}){0,4})|:(:[0-9A-Fa-f]{1,4}){0,5})((:[0-9A-Fa-f]{1,4}){2}|:(25[0-5]|(2[0-4]|1[0-9]|[1-9])?[0-9])(\.(25[0-5]|(2[0-4]|1[0-9]|[1-9])?[0-9])){3})|(([0-9A-Fa-f]{1,4}:){1,6}|:):[0-9A-Fa-f]{0,4}|([0-9A-Fa-f]{1,4}:){7}:)$/)
  if !@ip_v6_address.nil? && @ip_v6_address !~ pattern
    invalid_properties.push("invalid value for \"ip_v6_address\", must conform to the pattern #{pattern}.")
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



424
425
426
# File 'lib/intersight_client/models/ippool_ip_lease.rb', line 424

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



430
431
432
433
434
435
436
437
438
439
440
441
442
# File 'lib/intersight_client/models/ippool_ip_lease.rb', line 430

def to_hash
  hash = super
  IppoolIpLease.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = IppoolIpLease.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



418
419
420
# File 'lib/intersight_client/models/ippool_ip_lease.rb', line 418

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



245
246
247
248
249
250
251
252
253
254
255
256
257
# File 'lib/intersight_client/models/ippool_ip_lease.rb', line 245

def valid?
  return false if @class_id.nil?
  class_id_validator = EnumAttributeValidator.new('String', ["ippool.IpLease"])
  return false unless class_id_validator.valid?(@class_id)
  return false if @object_type.nil?
  object_type_validator = EnumAttributeValidator.new('String', ["ippool.IpLease"])
  return false unless object_type_validator.valid?(@object_type)
  ip_type_validator = EnumAttributeValidator.new('String', ["IPv4", "IPv6"])
  return false unless ip_type_validator.valid?(@ip_type)
  return false if !@ip_v4_address.nil? && @ip_v4_address !~ Regexp.new(/^$|^([1-9]|[1-9][0-9]|1[0-9][0-9]|2[0-4][0-9]|25[0-5])\.([0-9]|[1-9][0-9]|1[0-9][0-9]|2[0-4][0-9]|25[0-5])\.([0-9]|[1-9][0-9]|1[0-9][0-9]|2[0-4][0-9]|25[0-5])\.([0-9]|[1-9][0-9]|1[0-9][0-9]|2[0-4][0-9]|25[0-5])$/)
  return false if !@ip_v6_address.nil? && @ip_v6_address !~ Regexp.new(/^$|^(([0-9A-Fa-f]{1,4}:([0-9A-Fa-f]{1,4}:([0-9A-Fa-f]{1,4}:([0-9A-Fa-f]{1,4}:([0-9A-Fa-f]{1,4}:[0-9A-Fa-f]{0,4}|:[0-9A-Fa-f]{1,4})?|(:[0-9A-Fa-f]{1,4}){0,2})|(:[0-9A-Fa-f]{1,4}){0,3})|(:[0-9A-Fa-f]{1,4}){0,4})|:(:[0-9A-Fa-f]{1,4}){0,5})((:[0-9A-Fa-f]{1,4}){2}|:(25[0-5]|(2[0-4]|1[0-9]|[1-9])?[0-9])(\.(25[0-5]|(2[0-4]|1[0-9]|[1-9])?[0-9])){3})|(([0-9A-Fa-f]{1,4}:){1,6}|:):[0-9A-Fa-f]{0,4}|([0-9A-Fa-f]{1,4}:){7}:)$/)
  true && super
end