Class: IntersightClient::LsServiceProfile

Inherits:
InventoryBase show all
Defined in:
lib/intersight_client/models/ls_service_profile.rb

Overview

Logical Profile that can be associated to a physical server.

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Attributes inherited from InventoryBase

#device_mo_id, #dn, #rn

Attributes inherited from MoBaseMo

#account_moid, #ancestors, #create_time, #display_names, #domain_group_moid, #mod_time, #moid, #owners, #parent, #permission_resources, #shared_scope, #tags, #version_context

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ LsServiceProfile

Initializes the object



132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
# File 'lib/intersight_client/models/ls_service_profile.rb', line 132

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `IntersightClient::LsServiceProfile` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `#{self.class.name}`. Please check the name to make sure it's valid. List of attributes: " + self.class.acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  # call parent's initialize
  super(attributes)

  if attributes.key?(:'class_id')
    self.class_id = attributes[:'class_id']
  else
    self.class_id = 'ls.ServiceProfile'
  end

  if attributes.key?(:'object_type')
    self.object_type = attributes[:'object_type']
  else
    self.object_type = 'ls.ServiceProfile'
  end

  if attributes.key?(:'assign_state')
    self.assign_state = attributes[:'assign_state']
  end

  if attributes.key?(:'assoc_state')
    self.assoc_state = attributes[:'assoc_state']
  end

  if attributes.key?(:'associated_server')
    self.associated_server = attributes[:'associated_server']
  end

  if attributes.key?(:'config_state')
    self.config_state = attributes[:'config_state']
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  end

  if attributes.key?(:'oper_state')
    self.oper_state = attributes[:'oper_state']
  end

  if attributes.key?(:'inventory_device_info')
    self.inventory_device_info = attributes[:'inventory_device_info']
  end

  if attributes.key?(:'registered_device')
    self.registered_device = attributes[:'registered_device']
  end
end

Instance Attribute Details

#assign_stateObject

Assignment state of the service profile.



26
27
28
# File 'lib/intersight_client/models/ls_service_profile.rb', line 26

def assign_state
  @assign_state
end

#assoc_stateObject

Association state of the service profile.



29
30
31
# File 'lib/intersight_client/models/ls_service_profile.rb', line 29

def assoc_state
  @assoc_state
end

#associated_serverObject

Server to which the UCS Manager service profile is associated to.



32
33
34
# File 'lib/intersight_client/models/ls_service_profile.rb', line 32

def associated_server
  @associated_server
end

#class_idObject

The fully-qualified name of the instantiated, concrete type. This property is used as a discriminator to identify the type of the payload when marshaling and unmarshaling data.



20
21
22
# File 'lib/intersight_client/models/ls_service_profile.rb', line 20

def class_id
  @class_id
end

#config_stateObject

Configuration state of the service profile.



35
36
37
# File 'lib/intersight_client/models/ls_service_profile.rb', line 35

def config_state
  @config_state
end

#inventory_device_infoObject

Returns the value of attribute inventory_device_info.



43
44
45
# File 'lib/intersight_client/models/ls_service_profile.rb', line 43

def inventory_device_info
  @inventory_device_info
end

#nameObject

Name of the UCS Manager service profile.



38
39
40
# File 'lib/intersight_client/models/ls_service_profile.rb', line 38

def name
  @name
end

#object_typeObject

The fully-qualified name of the instantiated, concrete type. The value should be the same as the ‘ClassId’ property.



23
24
25
# File 'lib/intersight_client/models/ls_service_profile.rb', line 23

def object_type
  @object_type
end

#oper_stateObject

Operational state of the service profile.



41
42
43
# File 'lib/intersight_client/models/ls_service_profile.rb', line 41

def oper_state
  @oper_state
end

#registered_deviceObject

Returns the value of attribute registered_device.



45
46
47
# File 'lib/intersight_client/models/ls_service_profile.rb', line 45

def registered_device
  @registered_device
end

Class Method Details

.acceptable_attribute_mapObject

Returns the key-value map of all the JSON attributes this model knows about, including the ones defined in its parent(s)



91
92
93
# File 'lib/intersight_client/models/ls_service_profile.rb', line 91

def self.acceptable_attribute_map
  attribute_map.merge(superclass.acceptable_attribute_map)
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about, including the ones defined in its parent(s)



86
87
88
# File 'lib/intersight_client/models/ls_service_profile.rb', line 86

def self.acceptable_attributes
  attribute_map.values.concat(superclass.acceptable_attributes)
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



70
71
72
73
74
75
76
77
78
79
80
81
82
83
# File 'lib/intersight_client/models/ls_service_profile.rb', line 70

def self.attribute_map
  {
    :'class_id' => :'ClassId',
    :'object_type' => :'ObjectType',
    :'assign_state' => :'AssignState',
    :'assoc_state' => :'AssocState',
    :'associated_server' => :'AssociatedServer',
    :'config_state' => :'ConfigState',
    :'name' => :'Name',
    :'oper_state' => :'OperState',
    :'inventory_device_info' => :'InventoryDeviceInfo',
    :'registered_device' => :'RegisteredDevice'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash



272
273
274
# File 'lib/intersight_client/models/ls_service_profile.rb', line 272

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_all_ofObject

List of class defined in allOf (OpenAPI v3)



118
119
120
121
122
123
# File 'lib/intersight_client/models/ls_service_profile.rb', line 118

def self.openapi_all_of
  [
  :'InventoryBase',
  :'LsServiceProfileAllOf'
  ]
end

.openapi_discriminator_nameObject

discriminator’s property name in OpenAPI v3



126
127
128
# File 'lib/intersight_client/models/ls_service_profile.rb', line 126

def self.openapi_discriminator_name
  :'ClassId'
end

.openapi_nullableObject

List of attributes with nullable: true



112
113
114
115
# File 'lib/intersight_client/models/ls_service_profile.rb', line 112

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



96
97
98
99
100
101
102
103
104
105
106
107
108
109
# File 'lib/intersight_client/models/ls_service_profile.rb', line 96

def self.openapi_types
  {
    :'class_id' => :'String',
    :'object_type' => :'String',
    :'assign_state' => :'String',
    :'assoc_state' => :'String',
    :'associated_server' => :'String',
    :'config_state' => :'String',
    :'name' => :'String',
    :'oper_state' => :'String',
    :'inventory_device_info' => :'InventoryDeviceInfoRelationship',
    :'registered_device' => :'AssetDeviceRegistrationRelationship'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.



242
243
244
245
246
247
248
249
250
251
252
253
254
255
# File 'lib/intersight_client/models/ls_service_profile.rb', line 242

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      class_id == o.class_id &&
      object_type == o.object_type &&
      assign_state == o.assign_state &&
      assoc_state == o.assoc_state &&
      associated_server == o.associated_server &&
      config_state == o.config_state &&
      name == o.name &&
      oper_state == o.oper_state &&
      inventory_device_info == o.inventory_device_info &&
      registered_device == o.registered_device && super(o)
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type



303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
# File 'lib/intersight_client/models/ls_service_profile.rb', line 303

def _deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = IntersightClient.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value



374
375
376
377
378
379
380
381
382
383
384
385
386
# File 'lib/intersight_client/models/ls_service_profile.rb', line 374

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash



279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
# File 'lib/intersight_client/models/ls_service_profile.rb', line 279

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  super(attributes)
  LsServiceProfile.openapi_types.each_pair do |key, type|
    if attributes[LsServiceProfile.attribute_map[key]].nil? && LsServiceProfile.openapi_nullable.include?(key)
      self.send("#{key}=", nil)
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[LsServiceProfile.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[LsServiceProfile.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[LsServiceProfile.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[LsServiceProfile.attribute_map[key]]))
    end
  end

  self
end

#eql?(o) ⇒ Boolean

See Also:

  • `==` method


259
260
261
# File 'lib/intersight_client/models/ls_service_profile.rb', line 259

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.



265
266
267
# File 'lib/intersight_client/models/ls_service_profile.rb', line 265

def hash
  [class_id, object_type, assign_state, assoc_state, associated_server, config_state, name, oper_state, inventory_device_info, registered_device].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?



195
196
197
198
199
200
201
202
203
204
205
206
# File 'lib/intersight_client/models/ls_service_profile.rb', line 195

def list_invalid_properties
  invalid_properties = super
  if @class_id.nil?
    invalid_properties.push('invalid value for "class_id", class_id cannot be nil.')
  end

  if @object_type.nil?
    invalid_properties.push('invalid value for "object_type", object_type cannot be nil.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)



350
351
352
# File 'lib/intersight_client/models/ls_service_profile.rb', line 350

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash



356
357
358
359
360
361
362
363
364
365
366
367
368
# File 'lib/intersight_client/models/ls_service_profile.rb', line 356

def to_hash
  hash = super
  LsServiceProfile.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = LsServiceProfile.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object



344
345
346
# File 'lib/intersight_client/models/ls_service_profile.rb', line 344

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid



210
211
212
213
214
215
216
217
218
# File 'lib/intersight_client/models/ls_service_profile.rb', line 210

def valid?
  return false if @class_id.nil?
  class_id_validator = EnumAttributeValidator.new('String', ["ls.ServiceProfile"])
  return false unless class_id_validator.valid?(@class_id)
  return false if @object_type.nil?
  object_type_validator = EnumAttributeValidator.new('String', ["ls.ServiceProfile"])
  return false unless object_type_validator.valid?(@object_type)
  true && super
end