Class: IntersightClient::ManagementControllerAllOf
- Inherits:
-
Object
- Object
- IntersightClient::ManagementControllerAllOf
- Defined in:
- lib/intersight_client/models/management_controller_all_of.rb
Overview
Definition of the list of properties defined in ‘management.Controller’, excluding properties defined in parent classes.
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#adapter_unit ⇒ Object
Returns the value of attribute adapter_unit.
-
#class_id ⇒ Object
The fully-qualified name of the instantiated, concrete type.
-
#compute_blade ⇒ Object
Returns the value of attribute compute_blade.
-
#compute_rack_unit ⇒ Object
Returns the value of attribute compute_rack_unit.
-
#equipment_io_card_base ⇒ Object
Returns the value of attribute equipment_io_card_base.
-
#equipment_shared_io_module ⇒ Object
Returns the value of attribute equipment_shared_io_module.
-
#equipment_system_io_controller ⇒ Object
Returns the value of attribute equipment_system_io_controller.
-
#inventory_device_info ⇒ Object
Returns the value of attribute inventory_device_info.
-
#management_interfaces ⇒ Object
An array of relationships to managementInterface resources.
-
#model ⇒ Object
Model of the endpoint that houses the management controller.
-
#network_element ⇒ Object
Returns the value of attribute network_element.
-
#object_type ⇒ Object
The fully-qualified name of the instantiated, concrete type.
-
#registered_device ⇒ Object
Returns the value of attribute registered_device.
-
#running_firmware ⇒ Object
An array of relationships to firmwareRunningFirmware resources.
-
#storage_sas_expander ⇒ Object
Returns the value of attribute storage_sas_expander.
-
#top_system ⇒ Object
Returns the value of attribute top_system.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns the key-value map of all the JSON attributes this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ManagementControllerAllOf
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ ManagementControllerAllOf
Initializes the object
142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 |
# File 'lib/intersight_client/models/management_controller_all_of.rb', line 142 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `IntersightClient::ManagementControllerAllOf` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `#{self.class.name}`. Please check the name to make sure it's valid. List of attributes: " + self.class.acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'class_id') self.class_id = attributes[:'class_id'] else self.class_id = 'management.Controller' end if attributes.key?(:'object_type') self.object_type = attributes[:'object_type'] else self.object_type = 'management.Controller' end if attributes.key?(:'model') self.model = attributes[:'model'] end if attributes.key?(:'adapter_unit') self.adapter_unit = attributes[:'adapter_unit'] end if attributes.key?(:'compute_blade') self.compute_blade = attributes[:'compute_blade'] end if attributes.key?(:'compute_rack_unit') self.compute_rack_unit = attributes[:'compute_rack_unit'] end if attributes.key?(:'equipment_io_card_base') self.equipment_io_card_base = attributes[:'equipment_io_card_base'] end if attributes.key?(:'equipment_shared_io_module') self.equipment_shared_io_module = attributes[:'equipment_shared_io_module'] end if attributes.key?(:'equipment_system_io_controller') self.equipment_system_io_controller = attributes[:'equipment_system_io_controller'] end if attributes.key?(:'inventory_device_info') self.inventory_device_info = attributes[:'inventory_device_info'] end if attributes.key?(:'management_interfaces') if (value = attributes[:'management_interfaces']).is_a?(Array) self.management_interfaces = value end end if attributes.key?(:'network_element') self.network_element = attributes[:'network_element'] end if attributes.key?(:'registered_device') self.registered_device = attributes[:'registered_device'] end if attributes.key?(:'running_firmware') if (value = attributes[:'running_firmware']).is_a?(Array) self.running_firmware = value end end if attributes.key?(:'storage_sas_expander') self. = attributes[:'storage_sas_expander'] end if attributes.key?(:'top_system') self.top_system = attributes[:'top_system'] end end |
Instance Attribute Details
#adapter_unit ⇒ Object
Returns the value of attribute adapter_unit.
28 29 30 |
# File 'lib/intersight_client/models/management_controller_all_of.rb', line 28 def adapter_unit @adapter_unit end |
#class_id ⇒ Object
The fully-qualified name of the instantiated, concrete type. This property is used as a discriminator to identify the type of the payload when marshaling and unmarshaling data.
20 21 22 |
# File 'lib/intersight_client/models/management_controller_all_of.rb', line 20 def class_id @class_id end |
#compute_blade ⇒ Object
Returns the value of attribute compute_blade.
30 31 32 |
# File 'lib/intersight_client/models/management_controller_all_of.rb', line 30 def compute_blade @compute_blade end |
#compute_rack_unit ⇒ Object
Returns the value of attribute compute_rack_unit.
32 33 34 |
# File 'lib/intersight_client/models/management_controller_all_of.rb', line 32 def compute_rack_unit @compute_rack_unit end |
#equipment_io_card_base ⇒ Object
Returns the value of attribute equipment_io_card_base.
34 35 36 |
# File 'lib/intersight_client/models/management_controller_all_of.rb', line 34 def equipment_io_card_base @equipment_io_card_base end |
#equipment_shared_io_module ⇒ Object
Returns the value of attribute equipment_shared_io_module.
36 37 38 |
# File 'lib/intersight_client/models/management_controller_all_of.rb', line 36 def equipment_shared_io_module @equipment_shared_io_module end |
#equipment_system_io_controller ⇒ Object
Returns the value of attribute equipment_system_io_controller.
38 39 40 |
# File 'lib/intersight_client/models/management_controller_all_of.rb', line 38 def equipment_system_io_controller @equipment_system_io_controller end |
#inventory_device_info ⇒ Object
Returns the value of attribute inventory_device_info.
40 41 42 |
# File 'lib/intersight_client/models/management_controller_all_of.rb', line 40 def inventory_device_info @inventory_device_info end |
#management_interfaces ⇒ Object
An array of relationships to managementInterface resources.
43 44 45 |
# File 'lib/intersight_client/models/management_controller_all_of.rb', line 43 def management_interfaces @management_interfaces end |
#model ⇒ Object
Model of the endpoint that houses the management controller.
26 27 28 |
# File 'lib/intersight_client/models/management_controller_all_of.rb', line 26 def model @model end |
#network_element ⇒ Object
Returns the value of attribute network_element.
45 46 47 |
# File 'lib/intersight_client/models/management_controller_all_of.rb', line 45 def network_element @network_element end |
#object_type ⇒ Object
The fully-qualified name of the instantiated, concrete type. The value should be the same as the ‘ClassId’ property.
23 24 25 |
# File 'lib/intersight_client/models/management_controller_all_of.rb', line 23 def object_type @object_type end |
#registered_device ⇒ Object
Returns the value of attribute registered_device.
47 48 49 |
# File 'lib/intersight_client/models/management_controller_all_of.rb', line 47 def registered_device @registered_device end |
#running_firmware ⇒ Object
An array of relationships to firmwareRunningFirmware resources.
50 51 52 |
# File 'lib/intersight_client/models/management_controller_all_of.rb', line 50 def running_firmware @running_firmware end |
#storage_sas_expander ⇒ Object
Returns the value of attribute storage_sas_expander.
52 53 54 |
# File 'lib/intersight_client/models/management_controller_all_of.rb', line 52 def end |
#top_system ⇒ Object
Returns the value of attribute top_system.
54 55 56 |
# File 'lib/intersight_client/models/management_controller_all_of.rb', line 54 def top_system @top_system end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns the key-value map of all the JSON attributes this model knows about
106 107 108 |
# File 'lib/intersight_client/models/management_controller_all_of.rb', line 106 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
101 102 103 |
# File 'lib/intersight_client/models/management_controller_all_of.rb', line 101 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 |
# File 'lib/intersight_client/models/management_controller_all_of.rb', line 79 def self.attribute_map { :'class_id' => :'ClassId', :'object_type' => :'ObjectType', :'model' => :'Model', :'adapter_unit' => :'AdapterUnit', :'compute_blade' => :'ComputeBlade', :'compute_rack_unit' => :'ComputeRackUnit', :'equipment_io_card_base' => :'EquipmentIoCardBase', :'equipment_shared_io_module' => :'EquipmentSharedIoModule', :'equipment_system_io_controller' => :'EquipmentSystemIoController', :'inventory_device_info' => :'InventoryDeviceInfo', :'management_interfaces' => :'ManagementInterfaces', :'network_element' => :'NetworkElement', :'registered_device' => :'RegisteredDevice', :'running_firmware' => :'RunningFirmware', :'storage_sas_expander' => :'StorageSasExpander', :'top_system' => :'TopSystem' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
313 314 315 |
# File 'lib/intersight_client/models/management_controller_all_of.rb', line 313 def self.build_from_hash(attributes) new.build_from_hash(attributes) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
133 134 135 136 137 138 |
# File 'lib/intersight_client/models/management_controller_all_of.rb', line 133 def self.openapi_nullable Set.new([ :'management_interfaces', :'running_firmware', ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 |
# File 'lib/intersight_client/models/management_controller_all_of.rb', line 111 def self.openapi_types { :'class_id' => :'String', :'object_type' => :'String', :'model' => :'String', :'adapter_unit' => :'AdapterUnitRelationship', :'compute_blade' => :'ComputeBladeRelationship', :'compute_rack_unit' => :'ComputeRackUnitRelationship', :'equipment_io_card_base' => :'EquipmentIoCardBaseRelationship', :'equipment_shared_io_module' => :'EquipmentSharedIoModuleRelationship', :'equipment_system_io_controller' => :'EquipmentSystemIoControllerRelationship', :'inventory_device_info' => :'InventoryDeviceInfoRelationship', :'management_interfaces' => :'Array<ManagementInterfaceRelationship>', :'network_element' => :'NetworkElementRelationship', :'registered_device' => :'AssetDeviceRegistrationRelationship', :'running_firmware' => :'Array<FirmwareRunningFirmwareRelationship>', :'storage_sas_expander' => :'StorageSasExpanderRelationship', :'top_system' => :'TopSystemRelationship' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 |
# File 'lib/intersight_client/models/management_controller_all_of.rb', line 277 def ==(o) return true if self.equal?(o) self.class == o.class && class_id == o.class_id && object_type == o.object_type && model == o.model && adapter_unit == o.adapter_unit && compute_blade == o.compute_blade && compute_rack_unit == o.compute_rack_unit && equipment_io_card_base == o.equipment_io_card_base && equipment_shared_io_module == o.equipment_shared_io_module && equipment_system_io_controller == o.equipment_system_io_controller && inventory_device_info == o.inventory_device_info && management_interfaces == o.management_interfaces && network_element == o.network_element && registered_device == o.registered_device && running_firmware == o.running_firmware && == o. && top_system == o.top_system end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 |
# File 'lib/intersight_client/models/management_controller_all_of.rb', line 343 def _deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = IntersightClient.const_get(type) klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
414 415 416 417 418 419 420 421 422 423 424 425 426 |
# File 'lib/intersight_client/models/management_controller_all_of.rb', line 414 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 |
# File 'lib/intersight_client/models/management_controller_all_of.rb', line 320 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) ManagementControllerAllOf.openapi_types.each_pair do |key, type| if attributes[ManagementControllerAllOf.attribute_map[key]].nil? && ManagementControllerAllOf.openapi_nullable.include?(key) self.send("#{key}=", nil) elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[ManagementControllerAllOf.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[ManagementControllerAllOf.attribute_map[key]].map { |v| _deserialize($1, v) }) end elsif !attributes[ManagementControllerAllOf.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[ManagementControllerAllOf.attribute_map[key]])) end end self end |
#eql?(o) ⇒ Boolean
300 301 302 |
# File 'lib/intersight_client/models/management_controller_all_of.rb', line 300 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
306 307 308 |
# File 'lib/intersight_client/models/management_controller_all_of.rb', line 306 def hash [class_id, object_type, model, adapter_unit, compute_blade, compute_rack_unit, equipment_io_card_base, equipment_shared_io_module, equipment_system_io_controller, inventory_device_info, management_interfaces, network_element, registered_device, running_firmware, , top_system].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
230 231 232 233 234 235 236 237 238 239 240 241 |
# File 'lib/intersight_client/models/management_controller_all_of.rb', line 230 def list_invalid_properties invalid_properties = Array.new if @class_id.nil? invalid_properties.push('invalid value for "class_id", class_id cannot be nil.') end if @object_type.nil? invalid_properties.push('invalid value for "object_type", object_type cannot be nil.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
390 391 392 |
# File 'lib/intersight_client/models/management_controller_all_of.rb', line 390 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
396 397 398 399 400 401 402 403 404 405 406 407 408 |
# File 'lib/intersight_client/models/management_controller_all_of.rb', line 396 def to_hash hash = {} ManagementControllerAllOf.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = ManagementControllerAllOf.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
384 385 386 |
# File 'lib/intersight_client/models/management_controller_all_of.rb', line 384 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
245 246 247 248 249 250 251 252 253 |
# File 'lib/intersight_client/models/management_controller_all_of.rb', line 245 def valid? return false if @class_id.nil? class_id_validator = EnumAttributeValidator.new('String', ["management.Controller"]) return false unless class_id_validator.valid?(@class_id) return false if @object_type.nil? object_type_validator = EnumAttributeValidator.new('String', ["management.Controller"]) return false unless object_type_validator.valid?(@object_type) true end |