Class: IntersightClient::ManagementInterfaceAllOf
- Inherits:
-
Object
- Object
- IntersightClient::ManagementInterfaceAllOf
- Defined in:
- lib/intersight_client/models/management_interface_all_of.rb
Overview
Definition of the list of properties defined in ‘management.Interface’, excluding properties defined in parent classes.
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#class_id ⇒ Object
The fully-qualified name of the instantiated, concrete type.
-
#gateway ⇒ Object
Default gateway for the interface.
-
#host_name ⇒ Object
Hostname configured for the interface.
-
#inventory_device_info ⇒ Object
Returns the value of attribute inventory_device_info.
-
#ip_address ⇒ Object
IP address of the interface.
-
#ipv4_address ⇒ Object
IPv4 address of the interface.
-
#ipv4_gateway ⇒ Object
IPv4 default gateway for the interface.
-
#ipv4_mask ⇒ Object
IPv4 Netmask for the interface.
-
#ipv6_address ⇒ Object
IPv6 address of the interface.
-
#ipv6_gateway ⇒ Object
IPv6 default gateway for the interface.
-
#ipv6_prefix ⇒ Object
IPv6 prefix for the interface.
-
#mac_address ⇒ Object
MAC address configured for the interface.
-
#management_controller ⇒ Object
Returns the value of attribute management_controller.
-
#mask ⇒ Object
Netmask for the interface.
-
#object_type ⇒ Object
The fully-qualified name of the instantiated, concrete type.
-
#registered_device ⇒ Object
Returns the value of attribute registered_device.
-
#switch_id ⇒ Object
Switch Id connected to the interface.
-
#uem_conn_status ⇒ Object
The event channel connection status for the interface.
-
#virtual_host_name ⇒ Object
Virtual hostname configured for the interface in case of clustered environment.
-
#vlan_id ⇒ Object
VlanId configured for the interface.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns the key-value map of all the JSON attributes this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ManagementInterfaceAllOf
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ ManagementInterfaceAllOf
Initializes the object
168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 |
# File 'lib/intersight_client/models/management_interface_all_of.rb', line 168 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `IntersightClient::ManagementInterfaceAllOf` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `#{self.class.name}`. Please check the name to make sure it's valid. List of attributes: " + self.class.acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'class_id') self.class_id = attributes[:'class_id'] else self.class_id = 'management.Interface' end if attributes.key?(:'object_type') self.object_type = attributes[:'object_type'] else self.object_type = 'management.Interface' end if attributes.key?(:'gateway') self.gateway = attributes[:'gateway'] end if attributes.key?(:'host_name') self.host_name = attributes[:'host_name'] end if attributes.key?(:'ip_address') self.ip_address = attributes[:'ip_address'] end if attributes.key?(:'ipv4_address') self.ipv4_address = attributes[:'ipv4_address'] end if attributes.key?(:'ipv4_gateway') self.ipv4_gateway = attributes[:'ipv4_gateway'] end if attributes.key?(:'ipv4_mask') self.ipv4_mask = attributes[:'ipv4_mask'] end if attributes.key?(:'ipv6_address') self.ipv6_address = attributes[:'ipv6_address'] end if attributes.key?(:'ipv6_gateway') self.ipv6_gateway = attributes[:'ipv6_gateway'] end if attributes.key?(:'ipv6_prefix') self.ipv6_prefix = attributes[:'ipv6_prefix'] end if attributes.key?(:'mac_address') self.mac_address = attributes[:'mac_address'] end if attributes.key?(:'mask') self.mask = attributes[:'mask'] end if attributes.key?(:'switch_id') self.switch_id = attributes[:'switch_id'] end if attributes.key?(:'uem_conn_status') self.uem_conn_status = attributes[:'uem_conn_status'] end if attributes.key?(:'virtual_host_name') self.virtual_host_name = attributes[:'virtual_host_name'] end if attributes.key?(:'vlan_id') self.vlan_id = attributes[:'vlan_id'] end if attributes.key?(:'inventory_device_info') self.inventory_device_info = attributes[:'inventory_device_info'] end if attributes.key?(:'management_controller') self.management_controller = attributes[:'management_controller'] end if attributes.key?(:'registered_device') self.registered_device = attributes[:'registered_device'] end end |
Instance Attribute Details
#class_id ⇒ Object
The fully-qualified name of the instantiated, concrete type. This property is used as a discriminator to identify the type of the payload when marshaling and unmarshaling data.
20 21 22 |
# File 'lib/intersight_client/models/management_interface_all_of.rb', line 20 def class_id @class_id end |
#gateway ⇒ Object
Default gateway for the interface.
26 27 28 |
# File 'lib/intersight_client/models/management_interface_all_of.rb', line 26 def gateway @gateway end |
#host_name ⇒ Object
Hostname configured for the interface.
29 30 31 |
# File 'lib/intersight_client/models/management_interface_all_of.rb', line 29 def host_name @host_name end |
#inventory_device_info ⇒ Object
Returns the value of attribute inventory_device_info.
70 71 72 |
# File 'lib/intersight_client/models/management_interface_all_of.rb', line 70 def inventory_device_info @inventory_device_info end |
#ip_address ⇒ Object
IP address of the interface.
32 33 34 |
# File 'lib/intersight_client/models/management_interface_all_of.rb', line 32 def ip_address @ip_address end |
#ipv4_address ⇒ Object
IPv4 address of the interface.
35 36 37 |
# File 'lib/intersight_client/models/management_interface_all_of.rb', line 35 def ipv4_address @ipv4_address end |
#ipv4_gateway ⇒ Object
IPv4 default gateway for the interface.
38 39 40 |
# File 'lib/intersight_client/models/management_interface_all_of.rb', line 38 def ipv4_gateway @ipv4_gateway end |
#ipv4_mask ⇒ Object
IPv4 Netmask for the interface.
41 42 43 |
# File 'lib/intersight_client/models/management_interface_all_of.rb', line 41 def ipv4_mask @ipv4_mask end |
#ipv6_address ⇒ Object
IPv6 address of the interface.
44 45 46 |
# File 'lib/intersight_client/models/management_interface_all_of.rb', line 44 def ipv6_address @ipv6_address end |
#ipv6_gateway ⇒ Object
IPv6 default gateway for the interface.
47 48 49 |
# File 'lib/intersight_client/models/management_interface_all_of.rb', line 47 def ipv6_gateway @ipv6_gateway end |
#ipv6_prefix ⇒ Object
IPv6 prefix for the interface.
50 51 52 |
# File 'lib/intersight_client/models/management_interface_all_of.rb', line 50 def ipv6_prefix @ipv6_prefix end |
#mac_address ⇒ Object
MAC address configured for the interface.
53 54 55 |
# File 'lib/intersight_client/models/management_interface_all_of.rb', line 53 def mac_address @mac_address end |
#management_controller ⇒ Object
Returns the value of attribute management_controller.
72 73 74 |
# File 'lib/intersight_client/models/management_interface_all_of.rb', line 72 def management_controller @management_controller end |
#mask ⇒ Object
Netmask for the interface.
56 57 58 |
# File 'lib/intersight_client/models/management_interface_all_of.rb', line 56 def mask @mask end |
#object_type ⇒ Object
The fully-qualified name of the instantiated, concrete type. The value should be the same as the ‘ClassId’ property.
23 24 25 |
# File 'lib/intersight_client/models/management_interface_all_of.rb', line 23 def object_type @object_type end |
#registered_device ⇒ Object
Returns the value of attribute registered_device.
74 75 76 |
# File 'lib/intersight_client/models/management_interface_all_of.rb', line 74 def registered_device @registered_device end |
#switch_id ⇒ Object
Switch Id connected to the interface.
59 60 61 |
# File 'lib/intersight_client/models/management_interface_all_of.rb', line 59 def switch_id @switch_id end |
#uem_conn_status ⇒ Object
The event channel connection status for the interface.
62 63 64 |
# File 'lib/intersight_client/models/management_interface_all_of.rb', line 62 def uem_conn_status @uem_conn_status end |
#virtual_host_name ⇒ Object
Virtual hostname configured for the interface in case of clustered environment.
65 66 67 |
# File 'lib/intersight_client/models/management_interface_all_of.rb', line 65 def virtual_host_name @virtual_host_name end |
#vlan_id ⇒ Object
VlanId configured for the interface.
68 69 70 |
# File 'lib/intersight_client/models/management_interface_all_of.rb', line 68 def vlan_id @vlan_id end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns the key-value map of all the JSON attributes this model knows about
130 131 132 |
# File 'lib/intersight_client/models/management_interface_all_of.rb', line 130 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
125 126 127 |
# File 'lib/intersight_client/models/management_interface_all_of.rb', line 125 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 |
# File 'lib/intersight_client/models/management_interface_all_of.rb', line 99 def self.attribute_map { :'class_id' => :'ClassId', :'object_type' => :'ObjectType', :'gateway' => :'Gateway', :'host_name' => :'HostName', :'ip_address' => :'IpAddress', :'ipv4_address' => :'Ipv4Address', :'ipv4_gateway' => :'Ipv4Gateway', :'ipv4_mask' => :'Ipv4Mask', :'ipv6_address' => :'Ipv6Address', :'ipv6_gateway' => :'Ipv6Gateway', :'ipv6_prefix' => :'Ipv6Prefix', :'mac_address' => :'MacAddress', :'mask' => :'Mask', :'switch_id' => :'SwitchId', :'uem_conn_status' => :'UemConnStatus', :'virtual_host_name' => :'VirtualHostName', :'vlan_id' => :'VlanId', :'inventory_device_info' => :'InventoryDeviceInfo', :'management_controller' => :'ManagementController', :'registered_device' => :'RegisteredDevice' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
355 356 357 |
# File 'lib/intersight_client/models/management_interface_all_of.rb', line 355 def self.build_from_hash(attributes) new.build_from_hash(attributes) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
161 162 163 164 |
# File 'lib/intersight_client/models/management_interface_all_of.rb', line 161 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 |
# File 'lib/intersight_client/models/management_interface_all_of.rb', line 135 def self.openapi_types { :'class_id' => :'String', :'object_type' => :'String', :'gateway' => :'String', :'host_name' => :'String', :'ip_address' => :'String', :'ipv4_address' => :'String', :'ipv4_gateway' => :'String', :'ipv4_mask' => :'String', :'ipv6_address' => :'String', :'ipv6_gateway' => :'String', :'ipv6_prefix' => :'Integer', :'mac_address' => :'String', :'mask' => :'String', :'switch_id' => :'String', :'uem_conn_status' => :'String', :'virtual_host_name' => :'String', :'vlan_id' => :'Integer', :'inventory_device_info' => :'InventoryDeviceInfoRelationship', :'management_controller' => :'ManagementControllerRelationship', :'registered_device' => :'AssetDeviceRegistrationRelationship' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 |
# File 'lib/intersight_client/models/management_interface_all_of.rb', line 315 def ==(o) return true if self.equal?(o) self.class == o.class && class_id == o.class_id && object_type == o.object_type && gateway == o.gateway && host_name == o.host_name && ip_address == o.ip_address && ipv4_address == o.ipv4_address && ipv4_gateway == o.ipv4_gateway && ipv4_mask == o.ipv4_mask && ipv6_address == o.ipv6_address && ipv6_gateway == o.ipv6_gateway && ipv6_prefix == o.ipv6_prefix && mac_address == o.mac_address && mask == o.mask && switch_id == o.switch_id && uem_conn_status == o.uem_conn_status && virtual_host_name == o.virtual_host_name && vlan_id == o.vlan_id && inventory_device_info == o.inventory_device_info && management_controller == o.management_controller && registered_device == o.registered_device end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 |
# File 'lib/intersight_client/models/management_interface_all_of.rb', line 385 def _deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = IntersightClient.const_get(type) klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
456 457 458 459 460 461 462 463 464 465 466 467 468 |
# File 'lib/intersight_client/models/management_interface_all_of.rb', line 456 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 |
# File 'lib/intersight_client/models/management_interface_all_of.rb', line 362 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) ManagementInterfaceAllOf.openapi_types.each_pair do |key, type| if attributes[ManagementInterfaceAllOf.attribute_map[key]].nil? && ManagementInterfaceAllOf.openapi_nullable.include?(key) self.send("#{key}=", nil) elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[ManagementInterfaceAllOf.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[ManagementInterfaceAllOf.attribute_map[key]].map { |v| _deserialize($1, v) }) end elsif !attributes[ManagementInterfaceAllOf.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[ManagementInterfaceAllOf.attribute_map[key]])) end end self end |
#eql?(o) ⇒ Boolean
342 343 344 |
# File 'lib/intersight_client/models/management_interface_all_of.rb', line 342 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
348 349 350 |
# File 'lib/intersight_client/models/management_interface_all_of.rb', line 348 def hash [class_id, object_type, gateway, host_name, ip_address, ipv4_address, ipv4_gateway, ipv4_mask, ipv6_address, ipv6_gateway, ipv6_prefix, mac_address, mask, switch_id, uem_conn_status, virtual_host_name, vlan_id, inventory_device_info, management_controller, registered_device].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
268 269 270 271 272 273 274 275 276 277 278 279 |
# File 'lib/intersight_client/models/management_interface_all_of.rb', line 268 def list_invalid_properties invalid_properties = Array.new if @class_id.nil? invalid_properties.push('invalid value for "class_id", class_id cannot be nil.') end if @object_type.nil? invalid_properties.push('invalid value for "object_type", object_type cannot be nil.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
432 433 434 |
# File 'lib/intersight_client/models/management_interface_all_of.rb', line 432 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
438 439 440 441 442 443 444 445 446 447 448 449 450 |
# File 'lib/intersight_client/models/management_interface_all_of.rb', line 438 def to_hash hash = {} ManagementInterfaceAllOf.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = ManagementInterfaceAllOf.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
426 427 428 |
# File 'lib/intersight_client/models/management_interface_all_of.rb', line 426 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
283 284 285 286 287 288 289 290 291 |
# File 'lib/intersight_client/models/management_interface_all_of.rb', line 283 def valid? return false if @class_id.nil? class_id_validator = EnumAttributeValidator.new('String', ["management.Interface"]) return false unless class_id_validator.valid?(@class_id) return false if @object_type.nil? object_type_validator = EnumAttributeValidator.new('String', ["management.Interface"]) return false unless object_type_validator.valid?(@object_type) true end |