Class: IntersightClient::MemoryAbstractUnit
- Inherits:
-
EquipmentBase
- Object
- MoBaseMo
- InventoryBase
- EquipmentBase
- IntersightClient::MemoryAbstractUnit
- Defined in:
- lib/intersight_client/models/memory_abstract_unit.rb
Overview
Abstract class for all memory units.
Direct Known Subclasses
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#admin_state ⇒ Object
This represents the administrative state of the memory unit on a server.
-
#array_id ⇒ Object
This represents the memory array to which the memory unit belongs to.
-
#bank ⇒ Object
This represents the memory bank of the memory unit on a server.
-
#capacity ⇒ Object
This represents the memory capacity in MiB of the memory unit on a server.
-
#class_id ⇒ Object
The fully-qualified name of the instantiated, concrete type.
-
#clock ⇒ Object
This represents the clock of the memory unit on a server.
-
#form_factor ⇒ Object
This represents the form factor of the memory unit on a server.
-
#latency ⇒ Object
This represents the latency of the memory unit on a server.
-
#location ⇒ Object
This represents the location of the memory unit on a server.
-
#object_type ⇒ Object
The fully-qualified name of the instantiated, concrete type.
-
#oper_power_state ⇒ Object
This represents the operational power state of the memory unit on a server.
-
#oper_reason ⇒ Object
Returns the value of attribute oper_reason.
-
#oper_state ⇒ Object
This represents the operational state of the memory unit on a server.
-
#operability ⇒ Object
This represents the operability of the memory unit on a server.
-
#set ⇒ Object
This represents the set of the memory unit on a server.
-
#speed ⇒ Object
This represents the speed of the memory unit on a server.
-
#thermal ⇒ Object
This represents the thremal state of the memory unit on a server.
-
#type ⇒ Object
This represents the memory type of the memory unit on a server.
-
#visibility ⇒ Object
This represents the visibility of the memory unit on a server.
-
#width ⇒ Object
This represents the width of the memory unit on a server.
Attributes inherited from EquipmentBase
#model, #presence, #previous_fru, #revision, #serial, #vendor
Attributes inherited from InventoryBase
Attributes inherited from MoBaseMo
#account_moid, #ancestors, #create_time, #display_names, #domain_group_moid, #mod_time, #moid, #owners, #parent, #permission_resources, #shared_scope, #tags, #version_context
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns the key-value map of all the JSON attributes this model knows about, including the ones defined in its parent(s).
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about, including the ones defined in its parent(s).
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_all_of ⇒ Object
List of class defined in allOf (OpenAPI v3).
-
.openapi_discriminator_name ⇒ Object
discriminator’s property name in OpenAPI v3.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ MemoryAbstractUnit
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ MemoryAbstractUnit
Initializes the object
184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 |
# File 'lib/intersight_client/models/memory_abstract_unit.rb', line 184 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `IntersightClient::MemoryAbstractUnit` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `#{self.class.name}`. Please check the name to make sure it's valid. List of attributes: " + self.class.acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } # call parent's initialize super(attributes) if attributes.key?(:'class_id') self.class_id = attributes[:'class_id'] end if attributes.key?(:'object_type') self.object_type = attributes[:'object_type'] end if attributes.key?(:'admin_state') self.admin_state = attributes[:'admin_state'] end if attributes.key?(:'array_id') self.array_id = attributes[:'array_id'] end if attributes.key?(:'bank') self.bank = attributes[:'bank'] end if attributes.key?(:'capacity') self.capacity = attributes[:'capacity'] end if attributes.key?(:'clock') self.clock = attributes[:'clock'] end if attributes.key?(:'form_factor') self.form_factor = attributes[:'form_factor'] end if attributes.key?(:'latency') self.latency = attributes[:'latency'] end if attributes.key?(:'location') self.location = attributes[:'location'] end if attributes.key?(:'oper_power_state') self.oper_power_state = attributes[:'oper_power_state'] end if attributes.key?(:'oper_reason') if (value = attributes[:'oper_reason']).is_a?(Array) self.oper_reason = value end end if attributes.key?(:'oper_state') self.oper_state = attributes[:'oper_state'] end if attributes.key?(:'operability') self.operability = attributes[:'operability'] end if attributes.key?(:'set') self.set = attributes[:'set'] end if attributes.key?(:'speed') self.speed = attributes[:'speed'] end if attributes.key?(:'thermal') self.thermal = attributes[:'thermal'] end if attributes.key?(:'type') self.type = attributes[:'type'] end if attributes.key?(:'visibility') self.visibility = attributes[:'visibility'] end if attributes.key?(:'width') self.width = attributes[:'width'] end end |
Instance Attribute Details
#admin_state ⇒ Object
This represents the administrative state of the memory unit on a server.
26 27 28 |
# File 'lib/intersight_client/models/memory_abstract_unit.rb', line 26 def admin_state @admin_state end |
#array_id ⇒ Object
This represents the memory array to which the memory unit belongs to.
29 30 31 |
# File 'lib/intersight_client/models/memory_abstract_unit.rb', line 29 def array_id @array_id end |
#bank ⇒ Object
This represents the memory bank of the memory unit on a server.
32 33 34 |
# File 'lib/intersight_client/models/memory_abstract_unit.rb', line 32 def bank @bank end |
#capacity ⇒ Object
This represents the memory capacity in MiB of the memory unit on a server.
35 36 37 |
# File 'lib/intersight_client/models/memory_abstract_unit.rb', line 35 def capacity @capacity end |
#class_id ⇒ Object
The fully-qualified name of the instantiated, concrete type. This property is used as a discriminator to identify the type of the payload when marshaling and unmarshaling data. The enum values provides the list of concrete types that can be instantiated from this abstract type.
20 21 22 |
# File 'lib/intersight_client/models/memory_abstract_unit.rb', line 20 def class_id @class_id end |
#clock ⇒ Object
This represents the clock of the memory unit on a server.
38 39 40 |
# File 'lib/intersight_client/models/memory_abstract_unit.rb', line 38 def clock @clock end |
#form_factor ⇒ Object
This represents the form factor of the memory unit on a server.
41 42 43 |
# File 'lib/intersight_client/models/memory_abstract_unit.rb', line 41 def form_factor @form_factor end |
#latency ⇒ Object
This represents the latency of the memory unit on a server.
44 45 46 |
# File 'lib/intersight_client/models/memory_abstract_unit.rb', line 44 def latency @latency end |
#location ⇒ Object
This represents the location of the memory unit on a server.
47 48 49 |
# File 'lib/intersight_client/models/memory_abstract_unit.rb', line 47 def location @location end |
#object_type ⇒ Object
The fully-qualified name of the instantiated, concrete type. The value should be the same as the ‘ClassId’ property. The enum values provides the list of concrete types that can be instantiated from this abstract type.
23 24 25 |
# File 'lib/intersight_client/models/memory_abstract_unit.rb', line 23 def object_type @object_type end |
#oper_power_state ⇒ Object
This represents the operational power state of the memory unit on a server.
50 51 52 |
# File 'lib/intersight_client/models/memory_abstract_unit.rb', line 50 def oper_power_state @oper_power_state end |
#oper_reason ⇒ Object
Returns the value of attribute oper_reason.
52 53 54 |
# File 'lib/intersight_client/models/memory_abstract_unit.rb', line 52 def oper_reason @oper_reason end |
#oper_state ⇒ Object
This represents the operational state of the memory unit on a server.
55 56 57 |
# File 'lib/intersight_client/models/memory_abstract_unit.rb', line 55 def oper_state @oper_state end |
#operability ⇒ Object
This represents the operability of the memory unit on a server.
58 59 60 |
# File 'lib/intersight_client/models/memory_abstract_unit.rb', line 58 def operability @operability end |
#set ⇒ Object
This represents the set of the memory unit on a server.
61 62 63 |
# File 'lib/intersight_client/models/memory_abstract_unit.rb', line 61 def set @set end |
#speed ⇒ Object
This represents the speed of the memory unit on a server.
64 65 66 |
# File 'lib/intersight_client/models/memory_abstract_unit.rb', line 64 def speed @speed end |
#thermal ⇒ Object
This represents the thremal state of the memory unit on a server.
67 68 69 |
# File 'lib/intersight_client/models/memory_abstract_unit.rb', line 67 def thermal @thermal end |
#type ⇒ Object
This represents the memory type of the memory unit on a server.
70 71 72 |
# File 'lib/intersight_client/models/memory_abstract_unit.rb', line 70 def type @type end |
#visibility ⇒ Object
This represents the visibility of the memory unit on a server.
73 74 75 |
# File 'lib/intersight_client/models/memory_abstract_unit.rb', line 73 def visibility @visibility end |
#width ⇒ Object
This represents the width of the memory unit on a server.
76 77 78 |
# File 'lib/intersight_client/models/memory_abstract_unit.rb', line 76 def width @width end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns the key-value map of all the JSON attributes this model knows about, including the ones defined in its parent(s)
132 133 134 |
# File 'lib/intersight_client/models/memory_abstract_unit.rb', line 132 def self.acceptable_attribute_map attribute_map.merge(superclass.acceptable_attribute_map) end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about, including the ones defined in its parent(s)
127 128 129 |
# File 'lib/intersight_client/models/memory_abstract_unit.rb', line 127 def self.acceptable_attributes attribute_map.values.concat(superclass.acceptable_attributes) end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 |
# File 'lib/intersight_client/models/memory_abstract_unit.rb', line 101 def self.attribute_map { :'class_id' => :'ClassId', :'object_type' => :'ObjectType', :'admin_state' => :'AdminState', :'array_id' => :'ArrayId', :'bank' => :'Bank', :'capacity' => :'Capacity', :'clock' => :'Clock', :'form_factor' => :'FormFactor', :'latency' => :'Latency', :'location' => :'Location', :'oper_power_state' => :'OperPowerState', :'oper_reason' => :'OperReason', :'oper_state' => :'OperState', :'operability' => :'Operability', :'set' => :'Set', :'speed' => :'Speed', :'thermal' => :'Thermal', :'type' => :'Type', :'visibility' => :'Visibility', :'width' => :'Width' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
372 373 374 |
# File 'lib/intersight_client/models/memory_abstract_unit.rb', line 372 def self.build_from_hash(attributes) new.build_from_hash(attributes) end |
.openapi_all_of ⇒ Object
List of class defined in allOf (OpenAPI v3)
170 171 172 173 174 175 |
# File 'lib/intersight_client/models/memory_abstract_unit.rb', line 170 def self.openapi_all_of [ :'EquipmentBase', :'MemoryAbstractUnitAllOf' ] end |
.openapi_discriminator_name ⇒ Object
discriminator’s property name in OpenAPI v3
178 179 180 |
# File 'lib/intersight_client/models/memory_abstract_unit.rb', line 178 def self.openapi_discriminator_name :'ClassId' end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
163 164 165 166 167 |
# File 'lib/intersight_client/models/memory_abstract_unit.rb', line 163 def self.openapi_nullable Set.new([ :'oper_reason', ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 |
# File 'lib/intersight_client/models/memory_abstract_unit.rb', line 137 def self.openapi_types { :'class_id' => :'String', :'object_type' => :'String', :'admin_state' => :'String', :'array_id' => :'Integer', :'bank' => :'Integer', :'capacity' => :'String', :'clock' => :'String', :'form_factor' => :'String', :'latency' => :'String', :'location' => :'String', :'oper_power_state' => :'String', :'oper_reason' => :'Array<String>', :'oper_state' => :'String', :'operability' => :'String', :'set' => :'Integer', :'speed' => :'String', :'thermal' => :'String', :'type' => :'String', :'visibility' => :'String', :'width' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 |
# File 'lib/intersight_client/models/memory_abstract_unit.rb', line 332 def ==(o) return true if self.equal?(o) self.class == o.class && class_id == o.class_id && object_type == o.object_type && admin_state == o.admin_state && array_id == o.array_id && bank == o.bank && capacity == o.capacity && clock == o.clock && form_factor == o.form_factor && latency == o.latency && location == o.location && oper_power_state == o.oper_power_state && oper_reason == o.oper_reason && oper_state == o.oper_state && operability == o.operability && set == o.set && speed == o.speed && thermal == o.thermal && type == o.type && visibility == o.visibility && width == o.width && super(o) end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 434 435 436 437 438 439 440 |
# File 'lib/intersight_client/models/memory_abstract_unit.rb', line 403 def _deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = IntersightClient.const_get(type) klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
474 475 476 477 478 479 480 481 482 483 484 485 486 |
# File 'lib/intersight_client/models/memory_abstract_unit.rb', line 474 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 |
# File 'lib/intersight_client/models/memory_abstract_unit.rb', line 379 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) super(attributes) MemoryAbstractUnit.openapi_types.each_pair do |key, type| if attributes[MemoryAbstractUnit.attribute_map[key]].nil? && MemoryAbstractUnit.openapi_nullable.include?(key) self.send("#{key}=", nil) elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[MemoryAbstractUnit.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[MemoryAbstractUnit.attribute_map[key]].map { |v| _deserialize($1, v) }) end elsif !attributes[MemoryAbstractUnit.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[MemoryAbstractUnit.attribute_map[key]])) end end self end |
#eql?(o) ⇒ Boolean
359 360 361 |
# File 'lib/intersight_client/models/memory_abstract_unit.rb', line 359 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
365 366 367 |
# File 'lib/intersight_client/models/memory_abstract_unit.rb', line 365 def hash [class_id, object_type, admin_state, array_id, bank, capacity, clock, form_factor, latency, location, oper_power_state, oper_reason, oper_state, operability, set, speed, thermal, type, visibility, width].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
285 286 287 288 289 290 291 292 293 294 295 296 |
# File 'lib/intersight_client/models/memory_abstract_unit.rb', line 285 def list_invalid_properties invalid_properties = super if @class_id.nil? invalid_properties.push('invalid value for "class_id", class_id cannot be nil.') end if @object_type.nil? invalid_properties.push('invalid value for "object_type", object_type cannot be nil.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
450 451 452 |
# File 'lib/intersight_client/models/memory_abstract_unit.rb', line 450 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
456 457 458 459 460 461 462 463 464 465 466 467 468 |
# File 'lib/intersight_client/models/memory_abstract_unit.rb', line 456 def to_hash hash = super MemoryAbstractUnit.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = MemoryAbstractUnit.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
444 445 446 |
# File 'lib/intersight_client/models/memory_abstract_unit.rb', line 444 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
300 301 302 303 304 305 306 307 308 |
# File 'lib/intersight_client/models/memory_abstract_unit.rb', line 300 def valid? return false if @class_id.nil? class_id_validator = EnumAttributeValidator.new('String', ["memory.PersistentMemoryUnit", "memory.Unit"]) return false unless class_id_validator.valid?(@class_id) return false if @object_type.nil? object_type_validator = EnumAttributeValidator.new('String', ["memory.PersistentMemoryUnit", "memory.Unit"]) return false unless object_type_validator.valid?(@object_type) true && super end |