Class: IntersightClient::MemoryArray

Inherits:
EquipmentBase show all
Defined in:
lib/intersight_client/models/memory_array.rb

Overview

Holder housing multiple memory units.

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Attributes inherited from EquipmentBase

#model, #presence, #previous_fru, #revision, #serial, #vendor

Attributes inherited from InventoryBase

#device_mo_id, #dn, #rn

Attributes inherited from MoBaseMo

#account_moid, #ancestors, #create_time, #display_names, #domain_group_moid, #mod_time, #moid, #owners, #parent, #permission_resources, #shared_scope, #tags, #version_context

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ MemoryArray

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {}) —

    Model attributes in the form of hash



161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
# File 'lib/intersight_client/models/memory_array.rb', line 161

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `IntersightClient::MemoryArray` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `#{self.class.name}`. Please check the name to make sure it's valid. List of attributes: " + self.class.acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  # call parent's initialize
  super(attributes)

  if attributes.key?(:'class_id')
    self.class_id = attributes[:'class_id']
  else
    self.class_id = 'memory.Array'
  end

  if attributes.key?(:'object_type')
    self.object_type = attributes[:'object_type']
  else
    self.object_type = 'memory.Array'
  end

  if attributes.key?(:'array_id')
    self.array_id = attributes[:'array_id']
  end

  if attributes.key?(:'cpu_id')
    self.cpu_id = attributes[:'cpu_id']
  end

  if attributes.key?(:'current_capacity')
    self.current_capacity = attributes[:'current_capacity']
  end

  if attributes.key?(:'error_correction')
    self.error_correction = attributes[:'error_correction']
  end

  if attributes.key?(:'max_capacity')
    self.max_capacity = attributes[:'max_capacity']
  end

  if attributes.key?(:'max_devices')
    self.max_devices = attributes[:'max_devices']
  end

  if attributes.key?(:'oper_power_state')
    self.oper_power_state = attributes[:'oper_power_state']
  end

  if attributes.key?(:'compute_blade')
    self.compute_blade = attributes[:'compute_blade']
  end

  if attributes.key?(:'compute_board')
    self.compute_board = attributes[:'compute_board']
  end

  if attributes.key?(:'compute_rack_unit')
    self.compute_rack_unit = attributes[:'compute_rack_unit']
  end

  if attributes.key?(:'inventory_device_info')
    self.inventory_device_info = attributes[:'inventory_device_info']
  end

  if attributes.key?(:'persistent_memory_units')
    if (value = attributes[:'persistent_memory_units']).is_a?(Array)
      self.persistent_memory_units = value
    end
  end

  if attributes.key?(:'registered_device')
    self.registered_device = attributes[:'registered_device']
  end

  if attributes.key?(:'units')
    if (value = attributes[:'units']).is_a?(Array)
      self.units = value
    end
  end
end

Instance Attribute Details

#array_id ⇒ Object

The instance number of the memory array.



26
27
28
# File 'lib/intersight_client/models/memory_array.rb', line 26

def array_id
  @array_id
end

#class_id ⇒ Object

The fully-qualified name of the instantiated, concrete type. This property is used as a discriminator to identify the type of the payload when marshaling and unmarshaling data.



20
21
22
# File 'lib/intersight_client/models/memory_array.rb', line 20

def class_id
  @class_id
end

#compute_blade ⇒ Object

Returns the value of attribute compute_blade.



46
47
48
# File 'lib/intersight_client/models/memory_array.rb', line 46

def compute_blade
  @compute_blade
end

#compute_board ⇒ Object

Returns the value of attribute compute_board.



48
49
50
# File 'lib/intersight_client/models/memory_array.rb', line 48

def compute_board
  @compute_board
end

#compute_rack_unit ⇒ Object

Returns the value of attribute compute_rack_unit.



50
51
52
# File 'lib/intersight_client/models/memory_array.rb', line 50

def compute_rack_unit
  @compute_rack_unit
end

#cpu_id ⇒ Object

ID of the CPU that access this memory array.



29
30
31
# File 'lib/intersight_client/models/memory_array.rb', line 29

def cpu_id
  @cpu_id
end

#current_capacity ⇒ Object

Current capacity of all the memory units on a server.



32
33
34
# File 'lib/intersight_client/models/memory_array.rb', line 32

def current_capacity
  @current_capacity
end

#error_correction ⇒ Object

The primary hardware error detection or correction method supported by the memory array.



35
36
37
# File 'lib/intersight_client/models/memory_array.rb', line 35

def error_correction
  @error_correction
end

#inventory_device_info ⇒ Object

Returns the value of attribute inventory_device_info.



52
53
54
# File 'lib/intersight_client/models/memory_array.rb', line 52

def inventory_device_info
  @inventory_device_info
end

#max_capacity ⇒ Object

Maximum capacity of all the memory units on a server.



38
39
40
# File 'lib/intersight_client/models/memory_array.rb', line 38

def max_capacity
  @max_capacity
end

#max_devices ⇒ Object

The maximum number of slots or sockets available for memory devices in the memory array.



41
42
43
# File 'lib/intersight_client/models/memory_array.rb', line 41

def max_devices
  @max_devices
end

#object_type ⇒ Object

The fully-qualified name of the instantiated, concrete type. The value should be the same as the 'ClassId' property.



23
24
25
# File 'lib/intersight_client/models/memory_array.rb', line 23

def object_type
  @object_type
end

#oper_power_state ⇒ Object

The power state indicator of the memory array.



44
45
46
# File 'lib/intersight_client/models/memory_array.rb', line 44

def oper_power_state
  @oper_power_state
end

#persistent_memory_units ⇒ Object

An array of relationships to memoryPersistentMemoryUnit resources.



55
56
57
# File 'lib/intersight_client/models/memory_array.rb', line 55

def persistent_memory_units
  @persistent_memory_units
end

#registered_device ⇒ Object

Returns the value of attribute registered_device.



57
58
59
# File 'lib/intersight_client/models/memory_array.rb', line 57

def registered_device
  @registered_device
end

#units ⇒ Object

An array of relationships to memoryUnit resources.



60
61
62
# File 'lib/intersight_client/models/memory_array.rb', line 60

def units
  @units
end

Class Method Details

.acceptable_attribute_map ⇒ Object

Returns the key-value map of all the JSON attributes this model knows about, including the ones defined in its parent(s)



112
113
114
# File 'lib/intersight_client/models/memory_array.rb', line 112

def self.acceptable_attribute_map
  attribute_map.merge(superclass.acceptable_attribute_map)
end

.acceptable_attributes ⇒ Object

Returns all the JSON keys this model knows about, including the ones defined in its parent(s)



107
108
109
# File 'lib/intersight_client/models/memory_array.rb', line 107

def self.acceptable_attributes
  attribute_map.values.concat(superclass.acceptable_attributes)
end

.attribute_map ⇒ Object

Attribute mapping from ruby-style variable name to JSON key.



85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
# File 'lib/intersight_client/models/memory_array.rb', line 85

def self.attribute_map
  {
    :'class_id' => :'ClassId',
    :'object_type' => :'ObjectType',
    :'array_id' => :'ArrayId',
    :'cpu_id' => :'CpuId',
    :'current_capacity' => :'CurrentCapacity',
    :'error_correction' => :'ErrorCorrection',
    :'max_capacity' => :'MaxCapacity',
    :'max_devices' => :'MaxDevices',
    :'oper_power_state' => :'OperPowerState',
    :'compute_blade' => :'ComputeBlade',
    :'compute_board' => :'ComputeBoard',
    :'compute_rack_unit' => :'ComputeRackUnit',
    :'inventory_device_info' => :'InventoryDeviceInfo',
    :'persistent_memory_units' => :'PersistentMemoryUnits',
    :'registered_device' => :'RegisteredDevice',
    :'units' => :'Units'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash) —

    Model attributes in the form of hash

Returns:

  • (Object) —

    Returns the model itself



335
336
337
# File 'lib/intersight_client/models/memory_array.rb', line 335

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_all_of ⇒ Object

List of class defined in allOf (OpenAPI v3)



147
148
149
150
151
152
# File 'lib/intersight_client/models/memory_array.rb', line 147

def self.openapi_all_of
  [
  :'EquipmentBase',
  :'MemoryArrayAllOf'
  ]
end

.openapi_discriminator_name ⇒ Object

discriminator's property name in OpenAPI v3



155
156
157
# File 'lib/intersight_client/models/memory_array.rb', line 155

def self.openapi_discriminator_name
  :'ClassId'
end

.openapi_nullable ⇒ Object

List of attributes with nullable: true



139
140
141
142
143
144
# File 'lib/intersight_client/models/memory_array.rb', line 139

def self.openapi_nullable
  Set.new([
    :'persistent_memory_units',
    :'units'
  ])
end

.openapi_types ⇒ Object

Attribute type mapping.



117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
# File 'lib/intersight_client/models/memory_array.rb', line 117

def self.openapi_types
  {
    :'class_id' => :'String',
    :'object_type' => :'String',
    :'array_id' => :'Integer',
    :'cpu_id' => :'Integer',
    :'current_capacity' => :'String',
    :'error_correction' => :'String',
    :'max_capacity' => :'String',
    :'max_devices' => :'String',
    :'oper_power_state' => :'String',
    :'compute_blade' => :'ComputeBladeRelationship',
    :'compute_board' => :'ComputeBoardRelationship',
    :'compute_rack_unit' => :'ComputeRackUnitRelationship',
    :'inventory_device_info' => :'InventoryDeviceInfoRelationship',
    :'persistent_memory_units' => :'Array<MemoryPersistentMemoryUnitRelationship>',
    :'registered_device' => :'AssetDeviceRegistrationRelationship',
    :'units' => :'Array<MemoryUnitRelationship>'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object) —

    to be compared



299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
# File 'lib/intersight_client/models/memory_array.rb', line 299

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      class_id == o.class_id &&
      object_type == o.object_type &&
      array_id == o.array_id &&
      cpu_id == o.cpu_id &&
      current_capacity == o.current_capacity &&
      error_correction == o.error_correction &&
      max_capacity == o.max_capacity &&
      max_devices == o.max_devices &&
      oper_power_state == o.oper_power_state &&
      compute_blade == o.compute_blade &&
      compute_board == o.compute_board &&
      compute_rack_unit == o.compute_rack_unit &&
      inventory_device_info == o.inventory_device_info &&
      persistent_memory_units == o.persistent_memory_units &&
      registered_device == o.registered_device &&
      units == o.units && super(o)
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string —

    type Data type

  • string —

    value Value to be deserialized

Returns:

  • (Object) —

    Deserialized data



366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
# File 'lib/intersight_client/models/memory_array.rb', line 366

def _deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = IntersightClient.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object) —

    Any valid value

Returns:

  • (Hash) —

    Returns the value in the form of hash



437
438
439
440
441
442
443
444
445
446
447
448
449
# File 'lib/intersight_client/models/memory_array.rb', line 437

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash) —

    Model attributes in the form of hash

Returns:

  • (Object) —

    Returns the model itself



342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
# File 'lib/intersight_client/models/memory_array.rb', line 342

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  super(attributes)
  MemoryArray.openapi_types.each_pair do |key, type|
    if attributes[MemoryArray.attribute_map[key]].nil? && MemoryArray.openapi_nullable.include?(key)
      self.send("#{key}=", nil)
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[MemoryArray.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[MemoryArray.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[MemoryArray.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[MemoryArray.attribute_map[key]]))
    end
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object) —

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


322
323
324
# File 'lib/intersight_client/models/memory_array.rb', line 322

def eql?(o)
  self == o
end

#hash ⇒ Integer

Calculates hash code according to all attributes.

Returns:

  • (Integer) —

    Hash code



328
329
330
# File 'lib/intersight_client/models/memory_array.rb', line 328

def hash
  [class_id, object_type, array_id, cpu_id, current_capacity, error_correction, max_capacity, max_devices, oper_power_state, compute_blade, compute_board, compute_rack_unit, inventory_device_info, persistent_memory_units, registered_device, units].hash
end

#list_invalid_properties ⇒ Object

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



252
253
254
255
256
257
258
259
260
261
262
263
# File 'lib/intersight_client/models/memory_array.rb', line 252

def list_invalid_properties
  invalid_properties = super
  if @class_id.nil?
    invalid_properties.push('invalid value for "class_id", class_id cannot be nil.')
  end

  if @object_type.nil?
    invalid_properties.push('invalid value for "object_type", object_type cannot be nil.')
  end

  invalid_properties
end

#to_body ⇒ Hash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash) —

    Returns the object in the form of hash



413
414
415
# File 'lib/intersight_client/models/memory_array.rb', line 413

def to_body
  to_hash
end

#to_hash ⇒ Hash

Returns the object in the form of hash

Returns:

  • (Hash) —

    Returns the object in the form of hash



419
420
421
422
423
424
425
426
427
428
429
430
431
# File 'lib/intersight_client/models/memory_array.rb', line 419

def to_hash
  hash = super
  MemoryArray.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = MemoryArray.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_s ⇒ String

Returns the string representation of the object

Returns:

  • (String) —

    String presentation of the object



407
408
409
# File 'lib/intersight_client/models/memory_array.rb', line 407

def to_s
  to_hash.to_s
end

#valid? ⇒ Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean) —

    true if the model is valid



267
268
269
270
271
272
273
274
275
# File 'lib/intersight_client/models/memory_array.rb', line 267

def valid?
  return false if @class_id.nil?
  class_id_validator = EnumAttributeValidator.new('String', ["memory.Array"])
  return false unless class_id_validator.valid?(@class_id)
  return false if @object_type.nil?
  object_type_validator = EnumAttributeValidator.new('String', ["memory.Array"])
  return false unless object_type_validator.valid?(@object_type)
  true && super
end