Class: IntersightClient::MemoryPersistentMemoryConfigResultAllOf

Inherits:
Object
  • Object
show all
Defined in:
lib/intersight_client/models/memory_persistent_memory_config_result_all_of.rb

Overview

Definition of the list of properties defined in ‘memory.PersistentMemoryConfigResult’, excluding properties defined in parent classes.

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ MemoryPersistentMemoryConfigResultAllOf

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
# File 'lib/intersight_client/models/memory_persistent_memory_config_result_all_of.rb', line 119

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `IntersightClient::MemoryPersistentMemoryConfigResultAllOf` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `#{self.class.name}`. Please check the name to make sure it's valid. List of attributes: " + self.class.acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'class_id')
    self.class_id = attributes[:'class_id']
  else
    self.class_id = 'memory.PersistentMemoryConfigResult'
  end

  if attributes.key?(:'object_type')
    self.object_type = attributes[:'object_type']
  else
    self.object_type = 'memory.PersistentMemoryConfigResult'
  end

  if attributes.key?(:'config_error_desc')
    self.config_error_desc = attributes[:'config_error_desc']
  end

  if attributes.key?(:'config_result')
    self.config_result = attributes[:'config_result']
  end

  if attributes.key?(:'config_sequence_no')
    self.config_sequence_no = attributes[:'config_sequence_no']
  end

  if attributes.key?(:'config_state')
    self.config_state = attributes[:'config_state']
  end

  if attributes.key?(:'inventory_device_info')
    self.inventory_device_info = attributes[:'inventory_device_info']
  end

  if attributes.key?(:'memory_persistent_memory_configuration')
    self.memory_persistent_memory_configuration = attributes[:'memory_persistent_memory_configuration']
  end

  if attributes.key?(:'persistent_memory_namespace_config_results')
    if (value = attributes[:'persistent_memory_namespace_config_results']).is_a?(Array)
      self.persistent_memory_namespace_config_results = value
    end
  end

  if attributes.key?(:'registered_device')
    self.registered_device = attributes[:'registered_device']
  end
end

Instance Attribute Details

#class_idObject

The fully-qualified name of the instantiated, concrete type. This property is used as a discriminator to identify the type of the payload when marshaling and unmarshaling data.



20
21
22
# File 'lib/intersight_client/models/memory_persistent_memory_config_result_all_of.rb', line 20

def class_id
  @class_id
end

#config_error_descObject

Error in the result of a previously applied Persistent Memory configuration on a server.



26
27
28
# File 'lib/intersight_client/models/memory_persistent_memory_config_result_all_of.rb', line 26

def config_error_desc
  @config_error_desc
end

#config_resultObject

Result of a previously applied Persistent Memory configuration on a server.



29
30
31
# File 'lib/intersight_client/models/memory_persistent_memory_config_result_all_of.rb', line 29

def config_result
  @config_result
end

#config_sequence_noObject

Sequence number of a previously applied Persistent Memory configuration on a server.



32
33
34
# File 'lib/intersight_client/models/memory_persistent_memory_config_result_all_of.rb', line 32

def config_sequence_no
  @config_sequence_no
end

#config_stateObject

State of a previously applied Persistent Memory configuration on a server.



35
36
37
# File 'lib/intersight_client/models/memory_persistent_memory_config_result_all_of.rb', line 35

def config_state
  @config_state
end

#inventory_device_infoObject

Returns the value of attribute inventory_device_info.



37
38
39
# File 'lib/intersight_client/models/memory_persistent_memory_config_result_all_of.rb', line 37

def inventory_device_info
  @inventory_device_info
end

#memory_persistent_memory_configurationObject

Returns the value of attribute memory_persistent_memory_configuration.



39
40
41
# File 'lib/intersight_client/models/memory_persistent_memory_config_result_all_of.rb', line 39

def memory_persistent_memory_configuration
  @memory_persistent_memory_configuration
end

#object_typeObject

The fully-qualified name of the instantiated, concrete type. The value should be the same as the ‘ClassId’ property.



23
24
25
# File 'lib/intersight_client/models/memory_persistent_memory_config_result_all_of.rb', line 23

def object_type
  @object_type
end

#persistent_memory_namespace_config_resultsObject

An array of relationships to memoryPersistentMemoryNamespaceConfigResult resources.



42
43
44
# File 'lib/intersight_client/models/memory_persistent_memory_config_result_all_of.rb', line 42

def persistent_memory_namespace_config_results
  @persistent_memory_namespace_config_results
end

#registered_deviceObject

Returns the value of attribute registered_device.



44
45
46
# File 'lib/intersight_client/models/memory_persistent_memory_config_result_all_of.rb', line 44

def registered_device
  @registered_device
end

Class Method Details

.acceptable_attribute_mapObject

Returns the key-value map of all the JSON attributes this model knows about



90
91
92
# File 'lib/intersight_client/models/memory_persistent_memory_config_result_all_of.rb', line 90

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



85
86
87
# File 'lib/intersight_client/models/memory_persistent_memory_config_result_all_of.rb', line 85

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



69
70
71
72
73
74
75
76
77
78
79
80
81
82
# File 'lib/intersight_client/models/memory_persistent_memory_config_result_all_of.rb', line 69

def self.attribute_map
  {
    :'class_id' => :'ClassId',
    :'object_type' => :'ObjectType',
    :'config_error_desc' => :'ConfigErrorDesc',
    :'config_result' => :'ConfigResult',
    :'config_sequence_no' => :'ConfigSequenceNo',
    :'config_state' => :'ConfigState',
    :'inventory_device_info' => :'InventoryDeviceInfo',
    :'memory_persistent_memory_configuration' => :'MemoryPersistentMemoryConfiguration',
    :'persistent_memory_namespace_config_results' => :'PersistentMemoryNamespaceConfigResults',
    :'registered_device' => :'RegisteredDevice'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



258
259
260
# File 'lib/intersight_client/models/memory_persistent_memory_config_result_all_of.rb', line 258

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_nullableObject

List of attributes with nullable: true



111
112
113
114
115
# File 'lib/intersight_client/models/memory_persistent_memory_config_result_all_of.rb', line 111

def self.openapi_nullable
  Set.new([
    :'persistent_memory_namespace_config_results',
  ])
end

.openapi_typesObject

Attribute type mapping.



95
96
97
98
99
100
101
102
103
104
105
106
107
108
# File 'lib/intersight_client/models/memory_persistent_memory_config_result_all_of.rb', line 95

def self.openapi_types
  {
    :'class_id' => :'String',
    :'object_type' => :'String',
    :'config_error_desc' => :'String',
    :'config_result' => :'String',
    :'config_sequence_no' => :'Integer',
    :'config_state' => :'String',
    :'inventory_device_info' => :'InventoryDeviceInfoRelationship',
    :'memory_persistent_memory_configuration' => :'MemoryPersistentMemoryConfigurationRelationship',
    :'persistent_memory_namespace_config_results' => :'Array<MemoryPersistentMemoryNamespaceConfigResultRelationship>',
    :'registered_device' => :'AssetDeviceRegistrationRelationship'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



228
229
230
231
232
233
234
235
236
237
238
239
240
241
# File 'lib/intersight_client/models/memory_persistent_memory_config_result_all_of.rb', line 228

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      class_id == o.class_id &&
      object_type == o.object_type &&
      config_error_desc == o.config_error_desc &&
      config_result == o.config_result &&
      config_sequence_no == o.config_sequence_no &&
      config_state == o.config_state &&
      inventory_device_info == o.inventory_device_info &&
      memory_persistent_memory_configuration == o.memory_persistent_memory_configuration &&
      persistent_memory_namespace_config_results == o.persistent_memory_namespace_config_results &&
      registered_device == o.registered_device
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
# File 'lib/intersight_client/models/memory_persistent_memory_config_result_all_of.rb', line 288

def _deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = IntersightClient.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



359
360
361
362
363
364
365
366
367
368
369
370
371
# File 'lib/intersight_client/models/memory_persistent_memory_config_result_all_of.rb', line 359

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
# File 'lib/intersight_client/models/memory_persistent_memory_config_result_all_of.rb', line 265

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  MemoryPersistentMemoryConfigResultAllOf.openapi_types.each_pair do |key, type|
    if attributes[MemoryPersistentMemoryConfigResultAllOf.attribute_map[key]].nil? && MemoryPersistentMemoryConfigResultAllOf.openapi_nullable.include?(key)
      self.send("#{key}=", nil)
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[MemoryPersistentMemoryConfigResultAllOf.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[MemoryPersistentMemoryConfigResultAllOf.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[MemoryPersistentMemoryConfigResultAllOf.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[MemoryPersistentMemoryConfigResultAllOf.attribute_map[key]]))
    end
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


245
246
247
# File 'lib/intersight_client/models/memory_persistent_memory_config_result_all_of.rb', line 245

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



251
252
253
# File 'lib/intersight_client/models/memory_persistent_memory_config_result_all_of.rb', line 251

def hash
  [class_id, object_type, config_error_desc, config_result, config_sequence_no, config_state, inventory_device_info, memory_persistent_memory_configuration, persistent_memory_namespace_config_results, registered_device].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



181
182
183
184
185
186
187
188
189
190
191
192
# File 'lib/intersight_client/models/memory_persistent_memory_config_result_all_of.rb', line 181

def list_invalid_properties
  invalid_properties = Array.new
  if @class_id.nil?
    invalid_properties.push('invalid value for "class_id", class_id cannot be nil.')
  end

  if @object_type.nil?
    invalid_properties.push('invalid value for "object_type", object_type cannot be nil.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



335
336
337
# File 'lib/intersight_client/models/memory_persistent_memory_config_result_all_of.rb', line 335

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



341
342
343
344
345
346
347
348
349
350
351
352
353
# File 'lib/intersight_client/models/memory_persistent_memory_config_result_all_of.rb', line 341

def to_hash
  hash = {}
  MemoryPersistentMemoryConfigResultAllOf.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = MemoryPersistentMemoryConfigResultAllOf.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



329
330
331
# File 'lib/intersight_client/models/memory_persistent_memory_config_result_all_of.rb', line 329

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



196
197
198
199
200
201
202
203
204
# File 'lib/intersight_client/models/memory_persistent_memory_config_result_all_of.rb', line 196

def valid?
  return false if @class_id.nil?
  class_id_validator = EnumAttributeValidator.new('String', ["memory.PersistentMemoryConfigResult"])
  return false unless class_id_validator.valid?(@class_id)
  return false if @object_type.nil?
  object_type_validator = EnumAttributeValidator.new('String', ["memory.PersistentMemoryConfigResult"])
  return false unless object_type_validator.valid?(@object_type)
  true
end