Class: IntersightClient::MemoryPersistentMemoryUnitAllOf

Inherits:
Object
  • Object
show all
Defined in:
lib/intersight_client/models/memory_persistent_memory_unit_all_of.rb

Overview

Definition of the list of properties defined in ‘memory.PersistentMemoryUnit’, excluding properties defined in parent classes.

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ MemoryPersistentMemoryUnitAllOf

Initializes the object

Parameters:

  • (defaults to: {})

    Model attributes in the form of hash



168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
# File 'lib/intersight_client/models/memory_persistent_memory_unit_all_of.rb', line 168

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `IntersightClient::MemoryPersistentMemoryUnitAllOf` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `#{self.class.name}`. Please check the name to make sure it's valid. List of attributes: " + self.class.acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'class_id')
    self.class_id = attributes[:'class_id']
  else
    self.class_id = 'memory.PersistentMemoryUnit'
  end

  if attributes.key?(:'object_type')
    self.object_type = attributes[:'object_type']
  else
    self.object_type = 'memory.PersistentMemoryUnit'
  end

  if attributes.key?(:'app_direct_capacity')
    self.app_direct_capacity = attributes[:'app_direct_capacity']
  end

  if attributes.key?(:'count_status')
    self.count_status = attributes[:'count_status']
  end

  if attributes.key?(:'firmware_version')
    self.firmware_version = attributes[:'firmware_version']
  end

  if attributes.key?(:'frozen_status')
    self.frozen_status = attributes[:'frozen_status']
  end

  if attributes.key?(:'health_state')
    self.health_state = attributes[:'health_state']
  end

  if attributes.key?(:'lock_status')
    self.lock_status = attributes[:'lock_status']
  end

  if attributes.key?(:'memory_capacity')
    self.memory_capacity = attributes[:'memory_capacity']
  end

  if attributes.key?(:'memory_id')
    self.memory_id = attributes[:'memory_id']
  end

  if attributes.key?(:'persistent_memory_capacity')
    self.persistent_memory_capacity = attributes[:'persistent_memory_capacity']
  end

  if attributes.key?(:'reserved_capacity')
    self.reserved_capacity = attributes[:'reserved_capacity']
  end

  if attributes.key?(:'security_status')
    self.security_status = attributes[:'security_status']
  end

  if attributes.key?(:'socket_id')
    self.socket_id = attributes[:'socket_id']
  end

  if attributes.key?(:'socket_memory_id')
    self.socket_memory_id = attributes[:'socket_memory_id']
  end

  if attributes.key?(:'total_capacity')
    self.total_capacity = attributes[:'total_capacity']
  end

  if attributes.key?(:'uid')
    self.uid = attributes[:'uid']
  end

  if attributes.key?(:'inventory_device_info')
    self.inventory_device_info = attributes[:'inventory_device_info']
  end

  if attributes.key?(:'memory_array')
    self.memory_array = attributes[:'memory_array']
  end

  if attributes.key?(:'registered_device')
    self.registered_device = attributes[:'registered_device']
  end
end

Instance Attribute Details

#app_direct_capacityObject

AppDirect capacity in GiB of the Persistent Memory Module on a server.



26
27
28
# File 'lib/intersight_client/models/memory_persistent_memory_unit_all_of.rb', line 26

def app_direct_capacity
  @app_direct_capacity
end

#class_idObject

The fully-qualified name of the instantiated, concrete type. This property is used as a discriminator to identify the type of the payload when marshaling and unmarshaling data.



20
21
22
# File 'lib/intersight_client/models/memory_persistent_memory_unit_all_of.rb', line 20

def class_id
  @class_id
end

#count_statusObject

Count status of the Persistent Memory Module on a server.



29
30
31
# File 'lib/intersight_client/models/memory_persistent_memory_unit_all_of.rb', line 29

def count_status
  @count_status
end

#firmware_versionObject

Firmware version of the firware running on the Persistent Memory Module on a server.



32
33
34
# File 'lib/intersight_client/models/memory_persistent_memory_unit_all_of.rb', line 32

def firmware_version
  @firmware_version
end

#frozen_statusObject

Frozen status of the Persistent Memory Module on a server.



35
36
37
# File 'lib/intersight_client/models/memory_persistent_memory_unit_all_of.rb', line 35

def frozen_status
  @frozen_status
end

#health_stateObject

Health state of the Persistent Memory Module on a server.



38
39
40
# File 'lib/intersight_client/models/memory_persistent_memory_unit_all_of.rb', line 38

def health_state
  @health_state
end

#inventory_device_infoObject

Returns the value of attribute inventory_device_info.



70
71
72
# File 'lib/intersight_client/models/memory_persistent_memory_unit_all_of.rb', line 70

def inventory_device_info
  @inventory_device_info
end

#lock_statusObject

Lock status of the Persistent Memory Module on a server.



41
42
43
# File 'lib/intersight_client/models/memory_persistent_memory_unit_all_of.rb', line 41

def lock_status
  @lock_status
end

#memory_arrayObject

Returns the value of attribute memory_array.



72
73
74
# File 'lib/intersight_client/models/memory_persistent_memory_unit_all_of.rb', line 72

def memory_array
  @memory_array
end

#memory_capacityObject

Memory capacity in GiB of the Persistent Memory Module on a server.



44
45
46
# File 'lib/intersight_client/models/memory_persistent_memory_unit_all_of.rb', line 44

def memory_capacity
  @memory_capacity
end

#memory_idObject

ID of the Persistent Memory Module on a server.



47
48
49
# File 'lib/intersight_client/models/memory_persistent_memory_unit_all_of.rb', line 47

def memory_id
  @memory_id
end

#object_typeObject

The fully-qualified name of the instantiated, concrete type. The value should be the same as the ‘ClassId’ property.



23
24
25
# File 'lib/intersight_client/models/memory_persistent_memory_unit_all_of.rb', line 23

def object_type
  @object_type
end

#persistent_memory_capacityObject

Persistent Memory capacity in GiB of the Persistent Memory Module on a server.



50
51
52
# File 'lib/intersight_client/models/memory_persistent_memory_unit_all_of.rb', line 50

def persistent_memory_capacity
  @persistent_memory_capacity
end

#registered_deviceObject

Returns the value of attribute registered_device.



74
75
76
# File 'lib/intersight_client/models/memory_persistent_memory_unit_all_of.rb', line 74

def registered_device
  @registered_device
end

#reserved_capacityObject

Reserved capacity in GiB of the Persistent Memory Module on a server.



53
54
55
# File 'lib/intersight_client/models/memory_persistent_memory_unit_all_of.rb', line 53

def reserved_capacity
  @reserved_capacity
end

#security_statusObject

Security status of the Persistent Memory Module on a server.



56
57
58
# File 'lib/intersight_client/models/memory_persistent_memory_unit_all_of.rb', line 56

def security_status
  @security_status
end

#socket_idObject

Socket ID of the Persistent Memory Module on a server.



59
60
61
# File 'lib/intersight_client/models/memory_persistent_memory_unit_all_of.rb', line 59

def socket_id
  @socket_id
end

#socket_memory_idObject

Socket Memory ID of the Persistent Memory Module on a server.



62
63
64
# File 'lib/intersight_client/models/memory_persistent_memory_unit_all_of.rb', line 62

def socket_memory_id
  @socket_memory_id
end

#total_capacityObject

Total capacity in GiB of the Persistent Memory Module on a server.



65
66
67
# File 'lib/intersight_client/models/memory_persistent_memory_unit_all_of.rb', line 65

def total_capacity
  @total_capacity
end

#uidObject

UID of the Persistent Memory Module on a server.



68
69
70
# File 'lib/intersight_client/models/memory_persistent_memory_unit_all_of.rb', line 68

def uid
  @uid
end

Class Method Details

.acceptable_attribute_mapObject

Returns the key-value map of all the JSON attributes this model knows about



130
131
132
# File 'lib/intersight_client/models/memory_persistent_memory_unit_all_of.rb', line 130

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



125
126
127
# File 'lib/intersight_client/models/memory_persistent_memory_unit_all_of.rb', line 125

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
# File 'lib/intersight_client/models/memory_persistent_memory_unit_all_of.rb', line 99

def self.attribute_map
  {
    :'class_id' => :'ClassId',
    :'object_type' => :'ObjectType',
    :'app_direct_capacity' => :'AppDirectCapacity',
    :'count_status' => :'CountStatus',
    :'firmware_version' => :'FirmwareVersion',
    :'frozen_status' => :'FrozenStatus',
    :'health_state' => :'HealthState',
    :'lock_status' => :'LockStatus',
    :'memory_capacity' => :'MemoryCapacity',
    :'memory_id' => :'MemoryId',
    :'persistent_memory_capacity' => :'PersistentMemoryCapacity',
    :'reserved_capacity' => :'ReservedCapacity',
    :'security_status' => :'SecurityStatus',
    :'socket_id' => :'SocketId',
    :'socket_memory_id' => :'SocketMemoryId',
    :'total_capacity' => :'TotalCapacity',
    :'uid' => :'Uid',
    :'inventory_device_info' => :'InventoryDeviceInfo',
    :'memory_array' => :'MemoryArray',
    :'registered_device' => :'RegisteredDevice'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • Model attributes in the form of hash

Returns:

  • Returns the model itself



355
356
357
# File 'lib/intersight_client/models/memory_persistent_memory_unit_all_of.rb', line 355

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_nullableObject

List of attributes with nullable: true



161
162
163
164
# File 'lib/intersight_client/models/memory_persistent_memory_unit_all_of.rb', line 161

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
# File 'lib/intersight_client/models/memory_persistent_memory_unit_all_of.rb', line 135

def self.openapi_types
  {
    :'class_id' => :'String',
    :'object_type' => :'String',
    :'app_direct_capacity' => :'String',
    :'count_status' => :'String',
    :'firmware_version' => :'String',
    :'frozen_status' => :'String',
    :'health_state' => :'String',
    :'lock_status' => :'String',
    :'memory_capacity' => :'String',
    :'memory_id' => :'Integer',
    :'persistent_memory_capacity' => :'String',
    :'reserved_capacity' => :'String',
    :'security_status' => :'String',
    :'socket_id' => :'String',
    :'socket_memory_id' => :'String',
    :'total_capacity' => :'String',
    :'uid' => :'String',
    :'inventory_device_info' => :'InventoryDeviceInfoRelationship',
    :'memory_array' => :'MemoryArrayRelationship',
    :'registered_device' => :'AssetDeviceRegistrationRelationship'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • to be compared



315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
# File 'lib/intersight_client/models/memory_persistent_memory_unit_all_of.rb', line 315

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      class_id == o.class_id &&
      object_type == o.object_type &&
      app_direct_capacity == o.app_direct_capacity &&
      count_status == o.count_status &&
      firmware_version == o.firmware_version &&
      frozen_status == o.frozen_status &&
      health_state == o.health_state &&
      lock_status == o.lock_status &&
      memory_capacity == o.memory_capacity &&
      memory_id == o.memory_id &&
      persistent_memory_capacity == o.persistent_memory_capacity &&
      reserved_capacity == o.reserved_capacity &&
      security_status == o.security_status &&
      socket_id == o.socket_id &&
      socket_memory_id == o.socket_memory_id &&
      total_capacity == o.total_capacity &&
      uid == o.uid &&
      inventory_device_info == o.inventory_device_info &&
      memory_array == o.memory_array &&
      registered_device == o.registered_device
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • type Data type

  • value Value to be deserialized

Returns:

  • Deserialized data



385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
410
411
412
413
414
415
416
417
418
419
420
421
422
# File 'lib/intersight_client/models/memory_persistent_memory_unit_all_of.rb', line 385

def _deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = IntersightClient.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • Any valid value

Returns:

  • Returns the value in the form of hash



456
457
458
459
460
461
462
463
464
465
466
467
468
# File 'lib/intersight_client/models/memory_persistent_memory_unit_all_of.rb', line 456

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • Model attributes in the form of hash

Returns:

  • Returns the model itself



362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
# File 'lib/intersight_client/models/memory_persistent_memory_unit_all_of.rb', line 362

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  MemoryPersistentMemoryUnitAllOf.openapi_types.each_pair do |key, type|
    if attributes[MemoryPersistentMemoryUnitAllOf.attribute_map[key]].nil? && MemoryPersistentMemoryUnitAllOf.openapi_nullable.include?(key)
      self.send("#{key}=", nil)
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[MemoryPersistentMemoryUnitAllOf.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[MemoryPersistentMemoryUnitAllOf.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[MemoryPersistentMemoryUnitAllOf.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[MemoryPersistentMemoryUnitAllOf.attribute_map[key]]))
    end
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • to be compared

Returns:

See Also:

  • `==` method


342
343
344
# File 'lib/intersight_client/models/memory_persistent_memory_unit_all_of.rb', line 342

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • Hash code



348
349
350
# File 'lib/intersight_client/models/memory_persistent_memory_unit_all_of.rb', line 348

def hash
  [class_id, object_type, app_direct_capacity, count_status, firmware_version, frozen_status, health_state, lock_status, memory_capacity, memory_id, persistent_memory_capacity, reserved_capacity, security_status, socket_id, socket_memory_id, total_capacity, uid, inventory_device_info, memory_array, registered_device].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



268
269
270
271
272
273
274
275
276
277
278
279
# File 'lib/intersight_client/models/memory_persistent_memory_unit_all_of.rb', line 268

def list_invalid_properties
  invalid_properties = Array.new
  if @class_id.nil?
    invalid_properties.push('invalid value for "class_id", class_id cannot be nil.')
  end

  if @object_type.nil?
    invalid_properties.push('invalid value for "object_type", object_type cannot be nil.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • Returns the object in the form of hash



432
433
434
# File 'lib/intersight_client/models/memory_persistent_memory_unit_all_of.rb', line 432

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • Returns the object in the form of hash



438
439
440
441
442
443
444
445
446
447
448
449
450
# File 'lib/intersight_client/models/memory_persistent_memory_unit_all_of.rb', line 438

def to_hash
  hash = {}
  MemoryPersistentMemoryUnitAllOf.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = MemoryPersistentMemoryUnitAllOf.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • String presentation of the object



426
427
428
# File 'lib/intersight_client/models/memory_persistent_memory_unit_all_of.rb', line 426

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • true if the model is valid



283
284
285
286
287
288
289
290
291
# File 'lib/intersight_client/models/memory_persistent_memory_unit_all_of.rb', line 283

def valid?
  return false if @class_id.nil?
  class_id_validator = EnumAttributeValidator.new('String', ["memory.PersistentMemoryUnit"])
  return false unless class_id_validator.valid?(@class_id)
  return false if @object_type.nil?
  object_type_validator = EnumAttributeValidator.new('String', ["memory.PersistentMemoryUnit"])
  return false unless object_type_validator.valid?(@object_type)
  true
end