Class: IntersightClient::MetaPropDefinitionAllOf

Inherits:
Object
  • Object
show all
Defined in:
lib/intersight_client/models/meta_prop_definition_all_of.rb

Overview

Definition of the list of properties defined in ‘meta.PropDefinition’, excluding properties defined in parent classes.

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ MetaPropDefinitionAllOf

Initializes the object



127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
# File 'lib/intersight_client/models/meta_prop_definition_all_of.rb', line 127

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `IntersightClient::MetaPropDefinitionAllOf` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `#{self.class.name}`. Please check the name to make sure it's valid. List of attributes: " + self.class.acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'class_id')
    self.class_id = attributes[:'class_id']
  else
    self.class_id = 'meta.PropDefinition'
  end

  if attributes.key?(:'object_type')
    self.object_type = attributes[:'object_type']
  else
    self.object_type = 'meta.PropDefinition'
  end

  if attributes.key?(:'api_access')
    self.api_access = attributes[:'api_access']
  else
    self.api_access = 'NoAccess'
  end

  if attributes.key?(:'default')
    self.default = attributes[:'default']
  end

  if attributes.key?(:'is_collection')
    self.is_collection = attributes[:'is_collection']
  end

  if attributes.key?(:'is_complex_type')
    self.is_complex_type = attributes[:'is_complex_type']
  end

  if attributes.key?(:'kind')
    self.kind = attributes[:'kind']
  else
    self.kind = 'Unknown'
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  end

  if attributes.key?(:'op_security')
    self.op_security = attributes[:'op_security']
  else
    self.op_security = 'ClearText'
  end

  if attributes.key?(:'search_weight')
    self.search_weight = attributes[:'search_weight']
  end

  if attributes.key?(:'type')
    self.type = attributes[:'type']
  end
end

Instance Attribute Details

#api_accessObject

API access control for the property. Examples are NoAccess, ReadOnly, CreateOnly etc. * NoAccess - The property is not accessible from the API. * ReadOnly - The value of the property is read-only.An HTTP 4xx status code is returned when the user sends a POST/PUT/PATCH request that containsa ReadOnly property. * CreateOnly - The value of the property can be set when the REST resource is created. It cannot be changed after object creation.An HTTP 4xx status code is returned when the user sends a POST/PUT/PATCH request that containsa CreateOnly property.CreateOnly properties are returned in the response body of HTTP GET requests. * ReadWrite - The property has read/write access. * WriteOnly - The value of the property can be set but it is never returned in the response body of supported HTTP methods.This settings is used for sensitive properties such as passwords. * ReadOnCreate - The value of the property is returned in the HTTP POST response body when the REST resource is created.The property is not writeable and cannot be queried through a GET request after the resource has been created.



26
27
28
# File 'lib/intersight_client/models/meta_prop_definition_all_of.rb', line 26

def api_access
  @api_access
end

#class_idObject

The fully-qualified name of the instantiated, concrete type. This property is used as a discriminator to identify the type of the payload when marshaling and unmarshaling data.



20
21
22
# File 'lib/intersight_client/models/meta_prop_definition_all_of.rb', line 20

def class_id
  @class_id
end

#defaultObject

The default value of the property. Not applicable when IsComplexType is True.



29
30
31
# File 'lib/intersight_client/models/meta_prop_definition_all_of.rb', line 29

def default
  @default
end

#is_collectionObject

Indicates whether the property is a collection (i.e. a JSON array), otherwise it is a single value.



32
33
34
# File 'lib/intersight_client/models/meta_prop_definition_all_of.rb', line 32

def is_collection
  @is_collection
end

#is_complex_typeObject

Indicates whether the property is a complex type, otherwise it is a basic scalar type.



35
36
37
# File 'lib/intersight_client/models/meta_prop_definition_all_of.rb', line 35

def is_complex_type
  @is_complex_type
end

#kindObject

The kind of the property. * Unknown - The property kind is unknown. * Boolean - The ‘Boolean’ kind of property. * String - The ‘String’ kind of property. * Integer - The ‘Integer’ kind of property. * Int32 - The ‘Int32’ kind of property. * Int64 - The ‘Int64’ kind of property. * Float - The ‘Float’ kind of property. * Double - The ‘Double’ kind of property. * Date - The ‘Date’ kind of property. * Duration - The ‘Duration’ kind of property. * Time - The ‘Time’ kind of property. * Json - The ‘JSON’ kind of property. * Binary - The ‘Binary’ kind of property. * EnumString - The ‘EnumString’ kind of property. * EnumInteger - The ‘EnumInteger’ kind of property. * ComplexType - The ‘ComplexType’ kind of property.



38
39
40
# File 'lib/intersight_client/models/meta_prop_definition_all_of.rb', line 38

def kind
  @kind
end

#nameObject

The name of the property.



41
42
43
# File 'lib/intersight_client/models/meta_prop_definition_all_of.rb', line 41

def name
  @name
end

#object_typeObject

The fully-qualified name of the instantiated, concrete type. The value should be the same as the ‘ClassId’ property.



23
24
25
# File 'lib/intersight_client/models/meta_prop_definition_all_of.rb', line 23

def object_type
  @object_type
end

#op_securityObject

The data-at-rest security protection applied to this property when a Managed Object is persisted. For example, Encrypted or Cleartext. * ClearText - Data at rest is not encrypted using account specific keys.Note that data is always protected using volume encryption. ClearText propertiesare queryable and searchable. * Encrypted - The value of the property is encrypted with account-specific cryptographic keys.This setting is used for properties that contain sensitive data. Encrypted propertiesare not queryable and searchable. * Pbkdf2 - The value of the property is hashed using the pbkdf2 key derivation functions thattakes a password, a salt, and a cost factor as inputs then generates a password hash.Its purpose is to make each password guessing trial by an attacker who has obtaineda password hash file expensive and therefore the cost of a guessing attack high or prohibitive. * Bcrypt - The value of the property is hashed using the bcrypt key derivation function. * Sha512crypt - The value of the property is hashed using the sha512crypt key derivation function. * Argon2id - The value of the property is hashed using the argon2id key derivation function.



44
45
46
# File 'lib/intersight_client/models/meta_prop_definition_all_of.rb', line 44

def op_security
  @op_security
end

#search_weightObject

Enables the property to be searchable from global search. A value of 0 means this property is not globally searchable.



47
48
49
# File 'lib/intersight_client/models/meta_prop_definition_all_of.rb', line 47

def search_weight
  @search_weight
end

#typeObject

The type of the property. In case of collection properties the type is that of individual elements.



50
51
52
# File 'lib/intersight_client/models/meta_prop_definition_all_of.rb', line 50

def type
  @type
end

Class Method Details

.acceptable_attribute_mapObject

Returns the key-value map of all the JSON attributes this model knows about



97
98
99
# File 'lib/intersight_client/models/meta_prop_definition_all_of.rb', line 97

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



92
93
94
# File 'lib/intersight_client/models/meta_prop_definition_all_of.rb', line 92

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
# File 'lib/intersight_client/models/meta_prop_definition_all_of.rb', line 75

def self.attribute_map
  {
    :'class_id' => :'ClassId',
    :'object_type' => :'ObjectType',
    :'api_access' => :'ApiAccess',
    :'default' => :'Default',
    :'is_collection' => :'IsCollection',
    :'is_complex_type' => :'IsComplexType',
    :'kind' => :'Kind',
    :'name' => :'Name',
    :'op_security' => :'OpSecurity',
    :'search_weight' => :'SearchWeight',
    :'type' => :'Type'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash



311
312
313
# File 'lib/intersight_client/models/meta_prop_definition_all_of.rb', line 311

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_nullableObject

List of attributes with nullable: true



119
120
121
122
123
# File 'lib/intersight_client/models/meta_prop_definition_all_of.rb', line 119

def self.openapi_nullable
  Set.new([
    :'default',
  ])
end

.openapi_typesObject

Attribute type mapping.



102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
# File 'lib/intersight_client/models/meta_prop_definition_all_of.rb', line 102

def self.openapi_types
  {
    :'class_id' => :'String',
    :'object_type' => :'String',
    :'api_access' => :'String',
    :'default' => :'Object',
    :'is_collection' => :'Boolean',
    :'is_complex_type' => :'Boolean',
    :'kind' => :'String',
    :'name' => :'String',
    :'op_security' => :'String',
    :'search_weight' => :'Float',
    :'type' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.



280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
# File 'lib/intersight_client/models/meta_prop_definition_all_of.rb', line 280

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      class_id == o.class_id &&
      object_type == o.object_type &&
      api_access == o.api_access &&
      default == o.default &&
      is_collection == o.is_collection &&
      is_complex_type == o.is_complex_type &&
      kind == o.kind &&
      name == o.name &&
      op_security == o.op_security &&
      search_weight == o.search_weight &&
      type == o.type
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type



341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
# File 'lib/intersight_client/models/meta_prop_definition_all_of.rb', line 341

def _deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = IntersightClient.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value



412
413
414
415
416
417
418
419
420
421
422
423
424
# File 'lib/intersight_client/models/meta_prop_definition_all_of.rb', line 412

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash



318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
# File 'lib/intersight_client/models/meta_prop_definition_all_of.rb', line 318

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  MetaPropDefinitionAllOf.openapi_types.each_pair do |key, type|
    if attributes[MetaPropDefinitionAllOf.attribute_map[key]].nil? && MetaPropDefinitionAllOf.openapi_nullable.include?(key)
      self.send("#{key}=", nil)
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[MetaPropDefinitionAllOf.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[MetaPropDefinitionAllOf.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[MetaPropDefinitionAllOf.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[MetaPropDefinitionAllOf.attribute_map[key]]))
    end
  end

  self
end

#eql?(o) ⇒ Boolean

See Also:

  • `==` method


298
299
300
# File 'lib/intersight_client/models/meta_prop_definition_all_of.rb', line 298

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.



304
305
306
# File 'lib/intersight_client/models/meta_prop_definition_all_of.rb', line 304

def hash
  [class_id, object_type, api_access, default, is_collection, is_complex_type, kind, name, op_security, search_weight, type].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?



197
198
199
200
201
202
203
204
205
206
207
208
# File 'lib/intersight_client/models/meta_prop_definition_all_of.rb', line 197

def list_invalid_properties
  invalid_properties = Array.new
  if @class_id.nil?
    invalid_properties.push('invalid value for "class_id", class_id cannot be nil.')
  end

  if @object_type.nil?
    invalid_properties.push('invalid value for "object_type", object_type cannot be nil.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)



388
389
390
# File 'lib/intersight_client/models/meta_prop_definition_all_of.rb', line 388

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash



394
395
396
397
398
399
400
401
402
403
404
405
406
# File 'lib/intersight_client/models/meta_prop_definition_all_of.rb', line 394

def to_hash
  hash = {}
  MetaPropDefinitionAllOf.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = MetaPropDefinitionAllOf.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object



382
383
384
# File 'lib/intersight_client/models/meta_prop_definition_all_of.rb', line 382

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid



212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
# File 'lib/intersight_client/models/meta_prop_definition_all_of.rb', line 212

def valid?
  return false if @class_id.nil?
  class_id_validator = EnumAttributeValidator.new('String', ["meta.PropDefinition"])
  return false unless class_id_validator.valid?(@class_id)
  return false if @object_type.nil?
  object_type_validator = EnumAttributeValidator.new('String', ["meta.PropDefinition"])
  return false unless object_type_validator.valid?(@object_type)
  api_access_validator = EnumAttributeValidator.new('String', ["NoAccess", "ReadOnly", "CreateOnly", "ReadWrite", "WriteOnly", "ReadOnCreate"])
  return false unless api_access_validator.valid?(@api_access)
  kind_validator = EnumAttributeValidator.new('String', ["Unknown", "Boolean", "String", "Integer", "Int32", "Int64", "Float", "Double", "Date", "Duration", "Time", "Json", "Binary", "EnumString", "EnumInteger", "ComplexType"])
  return false unless kind_validator.valid?(@kind)
  op_security_validator = EnumAttributeValidator.new('String', ["ClearText", "Encrypted", "Pbkdf2", "Bcrypt", "Sha512crypt", "Argon2id"])
  return false unless op_security_validator.valid?(@op_security)
  true
end