Class: IntersightClient::NiatelemetryEpg
- Defined in:
- lib/intersight_client/models/niatelemetry_epg.rb
Overview
Object is available at End Point Group scope. This currently applies only to the APIC environemt.
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#azure_pack_count ⇒ Object
Azure Pack NAT with ASA feature usage.
-
#class_id ⇒ Object
The fully-qualified name of the instantiated, concrete type.
-
#dn ⇒ Object
Dn value for the End Point Groups present.
-
#epg_delimiter_count ⇒ Object
Number of objects with delimiter value present in EPG Delimiter attribute.
-
#fc_npv_count ⇒ Object
Number of ports with FC path attribute of type FC.
-
#fcoe_count ⇒ Object
Number of FCoE per End Point Group.
-
#fv_rs_dom_att_count ⇒ Object
Number of FvRsDomAtt objects per End Point Group with VMware configuration.
-
#intra_epg_dvs_bm_count ⇒ Object
Intra End Point Group Contract for Distributed Virtual Switch and BM feature usage.
-
#intra_epg_hyperv ⇒ Object
Intra EPG Isolation for Hyper-V, enabled if pcEnfPref attribute is set to enforced.
-
#is_attr_based ⇒ Object
Gets the state of End Point Groups with isAttrBasedEPg value as configured.
-
#microsegmentation ⇒ Object
Gets the state of End Point Groups where microsegmentation is present.
-
#microsoft_useg_count ⇒ Object
Number of FvRsDomAtt objects per End Point Group with Microsoft configuration.
-
#name ⇒ Object
Name value for the End Point Groups present.
-
#object_type ⇒ Object
The fully-qualified name of the instantiated, concrete type.
-
#orchsl_dev_vip_cfg_count ⇒ Object
Number of objects with Simplified Service Graph Integration with Windows Azure Pack.
-
#record_type ⇒ Object
Type of record DCNM / APIC / SE.
-
#record_version ⇒ Object
Version of record being pushed.
-
#registered_device ⇒ Object
Returns the value of attribute registered_device.
-
#site_name ⇒ Object
The Site name represents an APIC cluster.
-
#useg_hyperv_count ⇒ Object
Logical Operators for attribute based microsegmentation in a hypervisor.
Attributes inherited from MoBaseMo
#account_moid, #ancestors, #create_time, #display_names, #domain_group_moid, #mod_time, #moid, #owners, #parent, #permission_resources, #shared_scope, #tags, #version_context
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns the key-value map of all the JSON attributes this model knows about, including the ones defined in its parent(s).
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about, including the ones defined in its parent(s).
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_all_of ⇒ Object
List of class defined in allOf (OpenAPI v3).
-
.openapi_discriminator_name ⇒ Object
discriminator’s property name in OpenAPI v3.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ NiatelemetryEpg
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ NiatelemetryEpg
Initializes the object
183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 |
# File 'lib/intersight_client/models/niatelemetry_epg.rb', line 183 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `IntersightClient::NiatelemetryEpg` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `#{self.class.name}`. Please check the name to make sure it's valid. List of attributes: " + self.class.acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } # call parent's initialize super(attributes) if attributes.key?(:'class_id') self.class_id = attributes[:'class_id'] else self.class_id = 'niatelemetry.Epg' end if attributes.key?(:'object_type') self.object_type = attributes[:'object_type'] else self.object_type = 'niatelemetry.Epg' end if attributes.key?(:'azure_pack_count') self.azure_pack_count = attributes[:'azure_pack_count'] end if attributes.key?(:'dn') self.dn = attributes[:'dn'] end if attributes.key?(:'epg_delimiter_count') self.epg_delimiter_count = attributes[:'epg_delimiter_count'] end if attributes.key?(:'fc_npv_count') self.fc_npv_count = attributes[:'fc_npv_count'] end if attributes.key?(:'fcoe_count') self.fcoe_count = attributes[:'fcoe_count'] end if attributes.key?(:'fv_rs_dom_att_count') self.fv_rs_dom_att_count = attributes[:'fv_rs_dom_att_count'] end if attributes.key?(:'intra_epg_dvs_bm_count') self.intra_epg_dvs_bm_count = attributes[:'intra_epg_dvs_bm_count'] end if attributes.key?(:'intra_epg_hyperv') self.intra_epg_hyperv = attributes[:'intra_epg_hyperv'] end if attributes.key?(:'is_attr_based') self.is_attr_based = attributes[:'is_attr_based'] end if attributes.key?(:'microsegmentation') self.microsegmentation = attributes[:'microsegmentation'] end if attributes.key?(:'microsoft_useg_count') self.microsoft_useg_count = attributes[:'microsoft_useg_count'] end if attributes.key?(:'name') self.name = attributes[:'name'] end if attributes.key?(:'orchsl_dev_vip_cfg_count') self.orchsl_dev_vip_cfg_count = attributes[:'orchsl_dev_vip_cfg_count'] end if attributes.key?(:'record_type') self.record_type = attributes[:'record_type'] end if attributes.key?(:'record_version') self.record_version = attributes[:'record_version'] end if attributes.key?(:'site_name') self.site_name = attributes[:'site_name'] end if attributes.key?(:'useg_hyperv_count') self.useg_hyperv_count = attributes[:'useg_hyperv_count'] end if attributes.key?(:'registered_device') self.registered_device = attributes[:'registered_device'] end end |
Instance Attribute Details
#azure_pack_count ⇒ Object
Azure Pack NAT with ASA feature usage.
26 27 28 |
# File 'lib/intersight_client/models/niatelemetry_epg.rb', line 26 def azure_pack_count @azure_pack_count end |
#class_id ⇒ Object
The fully-qualified name of the instantiated, concrete type. This property is used as a discriminator to identify the type of the payload when marshaling and unmarshaling data.
20 21 22 |
# File 'lib/intersight_client/models/niatelemetry_epg.rb', line 20 def class_id @class_id end |
#dn ⇒ Object
Dn value for the End Point Groups present.
29 30 31 |
# File 'lib/intersight_client/models/niatelemetry_epg.rb', line 29 def dn @dn end |
#epg_delimiter_count ⇒ Object
Number of objects with delimiter value present in EPG Delimiter attribute.
32 33 34 |
# File 'lib/intersight_client/models/niatelemetry_epg.rb', line 32 def epg_delimiter_count @epg_delimiter_count end |
#fc_npv_count ⇒ Object
Number of ports with FC path attribute of type FC.
35 36 37 |
# File 'lib/intersight_client/models/niatelemetry_epg.rb', line 35 def fc_npv_count @fc_npv_count end |
#fcoe_count ⇒ Object
Number of FCoE per End Point Group.
38 39 40 |
# File 'lib/intersight_client/models/niatelemetry_epg.rb', line 38 def fcoe_count @fcoe_count end |
#fv_rs_dom_att_count ⇒ Object
Number of FvRsDomAtt objects per End Point Group with VMware configuration.
41 42 43 |
# File 'lib/intersight_client/models/niatelemetry_epg.rb', line 41 def fv_rs_dom_att_count @fv_rs_dom_att_count end |
#intra_epg_dvs_bm_count ⇒ Object
Intra End Point Group Contract for Distributed Virtual Switch and BM feature usage.
44 45 46 |
# File 'lib/intersight_client/models/niatelemetry_epg.rb', line 44 def intra_epg_dvs_bm_count @intra_epg_dvs_bm_count end |
#intra_epg_hyperv ⇒ Object
Intra EPG Isolation for Hyper-V, enabled if pcEnfPref attribute is set to enforced.
47 48 49 |
# File 'lib/intersight_client/models/niatelemetry_epg.rb', line 47 def intra_epg_hyperv @intra_epg_hyperv end |
#is_attr_based ⇒ Object
Gets the state of End Point Groups with isAttrBasedEPg value as configured.
50 51 52 |
# File 'lib/intersight_client/models/niatelemetry_epg.rb', line 50 def is_attr_based @is_attr_based end |
#microsegmentation ⇒ Object
Gets the state of End Point Groups where microsegmentation is present.
53 54 55 |
# File 'lib/intersight_client/models/niatelemetry_epg.rb', line 53 def microsegmentation @microsegmentation end |
#microsoft_useg_count ⇒ Object
Number of FvRsDomAtt objects per End Point Group with Microsoft configuration.
56 57 58 |
# File 'lib/intersight_client/models/niatelemetry_epg.rb', line 56 def microsoft_useg_count @microsoft_useg_count end |
#name ⇒ Object
Name value for the End Point Groups present.
59 60 61 |
# File 'lib/intersight_client/models/niatelemetry_epg.rb', line 59 def name @name end |
#object_type ⇒ Object
The fully-qualified name of the instantiated, concrete type. The value should be the same as the ‘ClassId’ property.
23 24 25 |
# File 'lib/intersight_client/models/niatelemetry_epg.rb', line 23 def object_type @object_type end |
#orchsl_dev_vip_cfg_count ⇒ Object
Number of objects with Simplified Service Graph Integration with Windows Azure Pack.
62 63 64 |
# File 'lib/intersight_client/models/niatelemetry_epg.rb', line 62 def orchsl_dev_vip_cfg_count @orchsl_dev_vip_cfg_count end |
#record_type ⇒ Object
Type of record DCNM / APIC / SE. This determines the type of platform where inventory was collected.
65 66 67 |
# File 'lib/intersight_client/models/niatelemetry_epg.rb', line 65 def record_type @record_type end |
#record_version ⇒ Object
Version of record being pushed. This determines what was the API version for data available from the device.
68 69 70 |
# File 'lib/intersight_client/models/niatelemetry_epg.rb', line 68 def record_version @record_version end |
#registered_device ⇒ Object
Returns the value of attribute registered_device.
76 77 78 |
# File 'lib/intersight_client/models/niatelemetry_epg.rb', line 76 def registered_device @registered_device end |
#site_name ⇒ Object
The Site name represents an APIC cluster. Service Engine can onboard multiple APIC clusters / sites.
71 72 73 |
# File 'lib/intersight_client/models/niatelemetry_epg.rb', line 71 def site_name @site_name end |
#useg_hyperv_count ⇒ Object
Logical Operators for attribute based microsegmentation in a hypervisor.
74 75 76 |
# File 'lib/intersight_client/models/niatelemetry_epg.rb', line 74 def useg_hyperv_count @useg_hyperv_count end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns the key-value map of all the JSON attributes this model knows about, including the ones defined in its parent(s)
132 133 134 |
# File 'lib/intersight_client/models/niatelemetry_epg.rb', line 132 def self.acceptable_attribute_map attribute_map.merge(superclass.acceptable_attribute_map) end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about, including the ones defined in its parent(s)
127 128 129 |
# File 'lib/intersight_client/models/niatelemetry_epg.rb', line 127 def self.acceptable_attributes attribute_map.values.concat(superclass.acceptable_attributes) end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 |
# File 'lib/intersight_client/models/niatelemetry_epg.rb', line 101 def self.attribute_map { :'class_id' => :'ClassId', :'object_type' => :'ObjectType', :'azure_pack_count' => :'AzurePackCount', :'dn' => :'Dn', :'epg_delimiter_count' => :'EpgDelimiterCount', :'fc_npv_count' => :'FcNpvCount', :'fcoe_count' => :'FcoeCount', :'fv_rs_dom_att_count' => :'FvRsDomAttCount', :'intra_epg_dvs_bm_count' => :'IntraEpgDvsBmCount', :'intra_epg_hyperv' => :'IntraEpgHyperv', :'is_attr_based' => :'IsAttrBased', :'microsegmentation' => :'Microsegmentation', :'microsoft_useg_count' => :'MicrosoftUsegCount', :'name' => :'Name', :'orchsl_dev_vip_cfg_count' => :'OrchslDevVipCfgCount', :'record_type' => :'RecordType', :'record_version' => :'RecordVersion', :'site_name' => :'SiteName', :'useg_hyperv_count' => :'UsegHypervCount', :'registered_device' => :'RegisteredDevice' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
373 374 375 |
# File 'lib/intersight_client/models/niatelemetry_epg.rb', line 373 def self.build_from_hash(attributes) new.build_from_hash(attributes) end |
.openapi_all_of ⇒ Object
List of class defined in allOf (OpenAPI v3)
169 170 171 172 173 174 |
# File 'lib/intersight_client/models/niatelemetry_epg.rb', line 169 def self.openapi_all_of [ :'MoBaseMo', :'NiatelemetryEpgAllOf' ] end |
.openapi_discriminator_name ⇒ Object
discriminator’s property name in OpenAPI v3
177 178 179 |
# File 'lib/intersight_client/models/niatelemetry_epg.rb', line 177 def self.openapi_discriminator_name :'ClassId' end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
163 164 165 166 |
# File 'lib/intersight_client/models/niatelemetry_epg.rb', line 163 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 |
# File 'lib/intersight_client/models/niatelemetry_epg.rb', line 137 def self.openapi_types { :'class_id' => :'String', :'object_type' => :'String', :'azure_pack_count' => :'Integer', :'dn' => :'String', :'epg_delimiter_count' => :'Integer', :'fc_npv_count' => :'Integer', :'fcoe_count' => :'Integer', :'fv_rs_dom_att_count' => :'Integer', :'intra_epg_dvs_bm_count' => :'Integer', :'intra_epg_hyperv' => :'String', :'is_attr_based' => :'String', :'microsegmentation' => :'String', :'microsoft_useg_count' => :'Integer', :'name' => :'String', :'orchsl_dev_vip_cfg_count' => :'Integer', :'record_type' => :'String', :'record_version' => :'String', :'site_name' => :'String', :'useg_hyperv_count' => :'Integer', :'registered_device' => :'AssetDeviceRegistrationRelationship' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 |
# File 'lib/intersight_client/models/niatelemetry_epg.rb', line 333 def ==(o) return true if self.equal?(o) self.class == o.class && class_id == o.class_id && object_type == o.object_type && azure_pack_count == o.azure_pack_count && dn == o.dn && epg_delimiter_count == o.epg_delimiter_count && fc_npv_count == o.fc_npv_count && fcoe_count == o.fcoe_count && fv_rs_dom_att_count == o.fv_rs_dom_att_count && intra_epg_dvs_bm_count == o.intra_epg_dvs_bm_count && intra_epg_hyperv == o.intra_epg_hyperv && is_attr_based == o.is_attr_based && microsegmentation == o.microsegmentation && microsoft_useg_count == o.microsoft_useg_count && name == o.name && orchsl_dev_vip_cfg_count == o.orchsl_dev_vip_cfg_count && record_type == o.record_type && record_version == o.record_version && site_name == o.site_name && useg_hyperv_count == o.useg_hyperv_count && registered_device == o.registered_device && super(o) end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 434 435 436 437 438 439 440 441 |
# File 'lib/intersight_client/models/niatelemetry_epg.rb', line 404 def _deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = IntersightClient.const_get(type) klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
475 476 477 478 479 480 481 482 483 484 485 486 487 |
# File 'lib/intersight_client/models/niatelemetry_epg.rb', line 475 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 |
# File 'lib/intersight_client/models/niatelemetry_epg.rb', line 380 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) super(attributes) NiatelemetryEpg.openapi_types.each_pair do |key, type| if attributes[NiatelemetryEpg.attribute_map[key]].nil? && NiatelemetryEpg.openapi_nullable.include?(key) self.send("#{key}=", nil) elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[NiatelemetryEpg.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[NiatelemetryEpg.attribute_map[key]].map { |v| _deserialize($1, v) }) end elsif !attributes[NiatelemetryEpg.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[NiatelemetryEpg.attribute_map[key]])) end end self end |
#eql?(o) ⇒ Boolean
360 361 362 |
# File 'lib/intersight_client/models/niatelemetry_epg.rb', line 360 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
366 367 368 |
# File 'lib/intersight_client/models/niatelemetry_epg.rb', line 366 def hash [class_id, object_type, azure_pack_count, dn, epg_delimiter_count, fc_npv_count, fcoe_count, fv_rs_dom_att_count, intra_epg_dvs_bm_count, intra_epg_hyperv, is_attr_based, microsegmentation, microsoft_useg_count, name, orchsl_dev_vip_cfg_count, record_type, record_version, site_name, useg_hyperv_count, registered_device].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
286 287 288 289 290 291 292 293 294 295 296 297 |
# File 'lib/intersight_client/models/niatelemetry_epg.rb', line 286 def list_invalid_properties invalid_properties = super if @class_id.nil? invalid_properties.push('invalid value for "class_id", class_id cannot be nil.') end if @object_type.nil? invalid_properties.push('invalid value for "object_type", object_type cannot be nil.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
451 452 453 |
# File 'lib/intersight_client/models/niatelemetry_epg.rb', line 451 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
457 458 459 460 461 462 463 464 465 466 467 468 469 |
# File 'lib/intersight_client/models/niatelemetry_epg.rb', line 457 def to_hash hash = super NiatelemetryEpg.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = NiatelemetryEpg.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
445 446 447 |
# File 'lib/intersight_client/models/niatelemetry_epg.rb', line 445 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
301 302 303 304 305 306 307 308 309 |
# File 'lib/intersight_client/models/niatelemetry_epg.rb', line 301 def valid? return false if @class_id.nil? class_id_validator = EnumAttributeValidator.new('String', ["niatelemetry.Epg"]) return false unless class_id_validator.valid?(@class_id) return false if @object_type.nil? object_type_validator = EnumAttributeValidator.new('String', ["niatelemetry.Epg"]) return false unless object_type_validator.valid?(@object_type) true && super end |