Class: IntersightClient::NiatelemetryNiaInventoryDcnmAllOf
- Inherits:
-
Object
- Object
- IntersightClient::NiatelemetryNiaInventoryDcnmAllOf
- Defined in:
- lib/intersight_client/models/niatelemetry_nia_inventory_dcnm_all_of.rb
Overview
Definition of the list of properties defined in 'niatelemetry.NiaInventoryDcnm', excluding properties defined in parent classes.
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#class_id ⇒ Object
The fully-qualified name of the instantiated, concrete type.
-
#dev ⇒ Object
Returns the value of the dev Field.
-
#epld_image_count ⇒ Object
Number of EPLD images uploaded to DCNM.
-
#ha_enabled ⇒ Object
Returns the value of the haEnabled field.
-
#ha_replication_status ⇒ Object
Returns the value of the haReplicationStatus field.
-
#install ⇒ Object
Returns the value of the install field.
-
#is_isn_configured ⇒ Object
Returns true if ISN is configured.
-
#is_media_controller ⇒ Object
Returns the value of the isMediaController field.
-
#is_smart_license_enabled ⇒ Object
Returns true if the Smart license is enabled and is in use.
-
#num_fabrics ⇒ Object
Returns total number of fabrics in DCNM set-up.
-
#num_fabrics_in_msd ⇒ Object
Returns the number of fabrics in msd.
-
#num_ingress_replication_fabrics ⇒ Object
Returns the number of fabrics that have ingress replication type.
-
#num_local_users ⇒ Object
Returns the number of local users other than admin user.
-
#num_msd ⇒ Object
Returns the number of MSD fabrics.
-
#num_svi_vrf_count ⇒ Object
Returns the number of svi interfaces configured for VRF vlans.
-
#num_trm_enabled_count ⇒ Object
Returns the number of links where TRM is enabled.
-
#num_upg_users ⇒ Object
Number of users who have upgrade privileges excluding the admin.
-
#nxos_image_count ⇒ Object
Number of NXOS images uploaded to DCNM.
-
#object_type ⇒ Object
The fully-qualified name of the instantiated, concrete type.
-
#registered_device ⇒ Object
Returns the value of attribute registered_device.
-
#serial ⇒ Object
Serial number of device being inventoried.
-
#site_name ⇒ Object
Name of fabric domain of the controller.
-
#underlay_peering_active_links_count ⇒ Object
Returns the number of underlay peering active links.
-
#upg_job_count ⇒ Object
Number of upgrade jobs configured on DCNM.
-
#upg_status ⇒ Object
Upgrade status of jobs created on DCNM.
-
#version ⇒ Object
Returns the value of the version field.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns the key-value map of all the JSON attributes this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ NiatelemetryNiaInventoryDcnmAllOf
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ NiatelemetryNiaInventoryDcnmAllOf
Initializes the object
200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 |
# File 'lib/intersight_client/models/niatelemetry_nia_inventory_dcnm_all_of.rb', line 200 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `IntersightClient::NiatelemetryNiaInventoryDcnmAllOf` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `#{self.class.name}`. Please check the name to make sure it's valid. List of attributes: " + self.class.acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'class_id') self.class_id = attributes[:'class_id'] else self.class_id = 'niatelemetry.NiaInventoryDcnm' end if attributes.key?(:'object_type') self.object_type = attributes[:'object_type'] else self.object_type = 'niatelemetry.NiaInventoryDcnm' end if attributes.key?(:'dev') self.dev = attributes[:'dev'] end if attributes.key?(:'epld_image_count') self.epld_image_count = attributes[:'epld_image_count'] end if attributes.key?(:'ha_enabled') self.ha_enabled = attributes[:'ha_enabled'] end if attributes.key?(:'ha_replication_status') self.ha_replication_status = attributes[:'ha_replication_status'] end if attributes.key?(:'install') self.install = attributes[:'install'] end if attributes.key?(:'is_isn_configured') self.is_isn_configured = attributes[:'is_isn_configured'] end if attributes.key?(:'is_media_controller') self.is_media_controller = attributes[:'is_media_controller'] end if attributes.key?(:'is_smart_license_enabled') self.is_smart_license_enabled = attributes[:'is_smart_license_enabled'] end if attributes.key?(:'num_fabrics') self.num_fabrics = attributes[:'num_fabrics'] end if attributes.key?(:'num_fabrics_in_msd') self.num_fabrics_in_msd = attributes[:'num_fabrics_in_msd'] end if attributes.key?(:'num_ingress_replication_fabrics') self.num_ingress_replication_fabrics = attributes[:'num_ingress_replication_fabrics'] end if attributes.key?(:'num_local_users') self.num_local_users = attributes[:'num_local_users'] end if attributes.key?(:'num_msd') self.num_msd = attributes[:'num_msd'] end if attributes.key?(:'num_svi_vrf_count') self.num_svi_vrf_count = attributes[:'num_svi_vrf_count'] end if attributes.key?(:'num_trm_enabled_count') self.num_trm_enabled_count = attributes[:'num_trm_enabled_count'] end if attributes.key?(:'num_upg_users') self.num_upg_users = attributes[:'num_upg_users'] end if attributes.key?(:'nxos_image_count') self.nxos_image_count = attributes[:'nxos_image_count'] end if attributes.key?(:'serial') self.serial = attributes[:'serial'] end if attributes.key?(:'site_name') self.site_name = attributes[:'site_name'] end if attributes.key?(:'underlay_peering_active_links_count') self.underlay_peering_active_links_count = attributes[:'underlay_peering_active_links_count'] end if attributes.key?(:'upg_job_count') self.upg_job_count = attributes[:'upg_job_count'] end if attributes.key?(:'upg_status') self.upg_status = attributes[:'upg_status'] end if attributes.key?(:'version') self.version = attributes[:'version'] end if attributes.key?(:'registered_device') self.registered_device = attributes[:'registered_device'] end end |
Instance Attribute Details
#class_id ⇒ Object
The fully-qualified name of the instantiated, concrete type. This property is used as a discriminator to identify the type of the payload when marshaling and unmarshaling data.
20 21 22 |
# File 'lib/intersight_client/models/niatelemetry_nia_inventory_dcnm_all_of.rb', line 20 def class_id @class_id end |
#dev ⇒ Object
Returns the value of the dev Field.
26 27 28 |
# File 'lib/intersight_client/models/niatelemetry_nia_inventory_dcnm_all_of.rb', line 26 def dev @dev end |
#epld_image_count ⇒ Object
Number of EPLD images uploaded to DCNM.
29 30 31 |
# File 'lib/intersight_client/models/niatelemetry_nia_inventory_dcnm_all_of.rb', line 29 def epld_image_count @epld_image_count end |
#ha_enabled ⇒ Object
Returns the value of the haEnabled field.
32 33 34 |
# File 'lib/intersight_client/models/niatelemetry_nia_inventory_dcnm_all_of.rb', line 32 def ha_enabled @ha_enabled end |
#ha_replication_status ⇒ Object
Returns the value of the haReplicationStatus field.
35 36 37 |
# File 'lib/intersight_client/models/niatelemetry_nia_inventory_dcnm_all_of.rb', line 35 def ha_replication_status @ha_replication_status end |
#install ⇒ Object
Returns the value of the install field.
38 39 40 |
# File 'lib/intersight_client/models/niatelemetry_nia_inventory_dcnm_all_of.rb', line 38 def install @install end |
#is_isn_configured ⇒ Object
Returns true if ISN is configured.
41 42 43 |
# File 'lib/intersight_client/models/niatelemetry_nia_inventory_dcnm_all_of.rb', line 41 def is_isn_configured @is_isn_configured end |
#is_media_controller ⇒ Object
Returns the value of the isMediaController field.
44 45 46 |
# File 'lib/intersight_client/models/niatelemetry_nia_inventory_dcnm_all_of.rb', line 44 def is_media_controller @is_media_controller end |
#is_smart_license_enabled ⇒ Object
Returns true if the Smart license is enabled and is in use.
47 48 49 |
# File 'lib/intersight_client/models/niatelemetry_nia_inventory_dcnm_all_of.rb', line 47 def is_smart_license_enabled @is_smart_license_enabled end |
#num_fabrics ⇒ Object
Returns total number of fabrics in DCNM set-up.
50 51 52 |
# File 'lib/intersight_client/models/niatelemetry_nia_inventory_dcnm_all_of.rb', line 50 def num_fabrics @num_fabrics end |
#num_fabrics_in_msd ⇒ Object
Returns the number of fabrics in msd.
53 54 55 |
# File 'lib/intersight_client/models/niatelemetry_nia_inventory_dcnm_all_of.rb', line 53 def num_fabrics_in_msd @num_fabrics_in_msd end |
#num_ingress_replication_fabrics ⇒ Object
Returns the number of fabrics that have ingress replication type.
56 57 58 |
# File 'lib/intersight_client/models/niatelemetry_nia_inventory_dcnm_all_of.rb', line 56 def num_ingress_replication_fabrics @num_ingress_replication_fabrics end |
#num_local_users ⇒ Object
Returns the number of local users other than admin user.
59 60 61 |
# File 'lib/intersight_client/models/niatelemetry_nia_inventory_dcnm_all_of.rb', line 59 def num_local_users @num_local_users end |
#num_msd ⇒ Object
Returns the number of MSD fabrics.
62 63 64 |
# File 'lib/intersight_client/models/niatelemetry_nia_inventory_dcnm_all_of.rb', line 62 def num_msd @num_msd end |
#num_svi_vrf_count ⇒ Object
Returns the number of svi interfaces configured for VRF vlans.
65 66 67 |
# File 'lib/intersight_client/models/niatelemetry_nia_inventory_dcnm_all_of.rb', line 65 def num_svi_vrf_count @num_svi_vrf_count end |
#num_trm_enabled_count ⇒ Object
Returns the number of links where TRM is enabled.
68 69 70 |
# File 'lib/intersight_client/models/niatelemetry_nia_inventory_dcnm_all_of.rb', line 68 def num_trm_enabled_count @num_trm_enabled_count end |
#num_upg_users ⇒ Object
Number of users who have upgrade privileges excluding the admin.
71 72 73 |
# File 'lib/intersight_client/models/niatelemetry_nia_inventory_dcnm_all_of.rb', line 71 def num_upg_users @num_upg_users end |
#nxos_image_count ⇒ Object
Number of NXOS images uploaded to DCNM.
74 75 76 |
# File 'lib/intersight_client/models/niatelemetry_nia_inventory_dcnm_all_of.rb', line 74 def nxos_image_count @nxos_image_count end |
#object_type ⇒ Object
The fully-qualified name of the instantiated, concrete type. The value should be the same as the 'ClassId' property.
23 24 25 |
# File 'lib/intersight_client/models/niatelemetry_nia_inventory_dcnm_all_of.rb', line 23 def object_type @object_type end |
#registered_device ⇒ Object
Returns the value of attribute registered_device.
94 95 96 |
# File 'lib/intersight_client/models/niatelemetry_nia_inventory_dcnm_all_of.rb', line 94 def registered_device @registered_device end |
#serial ⇒ Object
Serial number of device being inventoried. The serial number is unique per device.
77 78 79 |
# File 'lib/intersight_client/models/niatelemetry_nia_inventory_dcnm_all_of.rb', line 77 def serial @serial end |
#site_name ⇒ Object
Name of fabric domain of the controller.
80 81 82 |
# File 'lib/intersight_client/models/niatelemetry_nia_inventory_dcnm_all_of.rb', line 80 def site_name @site_name end |
#underlay_peering_active_links_count ⇒ Object
Returns the number of underlay peering active links.
83 84 85 |
# File 'lib/intersight_client/models/niatelemetry_nia_inventory_dcnm_all_of.rb', line 83 def underlay_peering_active_links_count @underlay_peering_active_links_count end |
#upg_job_count ⇒ Object
Number of upgrade jobs configured on DCNM.
86 87 88 |
# File 'lib/intersight_client/models/niatelemetry_nia_inventory_dcnm_all_of.rb', line 86 def upg_job_count @upg_job_count end |
#upg_status ⇒ Object
Upgrade status of jobs created on DCNM.
89 90 91 |
# File 'lib/intersight_client/models/niatelemetry_nia_inventory_dcnm_all_of.rb', line 89 def upg_status @upg_status end |
#version ⇒ Object
Returns the value of the version field.
92 93 94 |
# File 'lib/intersight_client/models/niatelemetry_nia_inventory_dcnm_all_of.rb', line 92 def version @version end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns the key-value map of all the JSON attributes this model knows about
156 157 158 |
# File 'lib/intersight_client/models/niatelemetry_nia_inventory_dcnm_all_of.rb', line 156 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
151 152 153 |
# File 'lib/intersight_client/models/niatelemetry_nia_inventory_dcnm_all_of.rb', line 151 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 |
# File 'lib/intersight_client/models/niatelemetry_nia_inventory_dcnm_all_of.rb', line 119 def self.attribute_map { :'class_id' => :'ClassId', :'object_type' => :'ObjectType', :'dev' => :'Dev', :'epld_image_count' => :'EpldImageCount', :'ha_enabled' => :'HaEnabled', :'ha_replication_status' => :'HaReplicationStatus', :'install' => :'Install', :'is_isn_configured' => :'IsIsnConfigured', :'is_media_controller' => :'IsMediaController', :'is_smart_license_enabled' => :'IsSmartLicenseEnabled', :'num_fabrics' => :'NumFabrics', :'num_fabrics_in_msd' => :'NumFabricsInMsd', :'num_ingress_replication_fabrics' => :'NumIngressReplicationFabrics', :'num_local_users' => :'NumLocalUsers', :'num_msd' => :'NumMsd', :'num_svi_vrf_count' => :'NumSviVrfCount', :'num_trm_enabled_count' => :'NumTrmEnabledCount', :'num_upg_users' => :'NumUpgUsers', :'nxos_image_count' => :'NxosImageCount', :'serial' => :'Serial', :'site_name' => :'SiteName', :'underlay_peering_active_links_count' => :'UnderlayPeeringActiveLinksCount', :'upg_job_count' => :'UpgJobCount', :'upg_status' => :'UpgStatus', :'version' => :'Version', :'registered_device' => :'RegisteredDevice' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
417 418 419 |
# File 'lib/intersight_client/models/niatelemetry_nia_inventory_dcnm_all_of.rb', line 417 def self.build_from_hash(attributes) new.build_from_hash(attributes) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
193 194 195 196 |
# File 'lib/intersight_client/models/niatelemetry_nia_inventory_dcnm_all_of.rb', line 193 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 |
# File 'lib/intersight_client/models/niatelemetry_nia_inventory_dcnm_all_of.rb', line 161 def self.openapi_types { :'class_id' => :'String', :'object_type' => :'String', :'dev' => :'Boolean', :'epld_image_count' => :'Integer', :'ha_enabled' => :'Boolean', :'ha_replication_status' => :'String', :'install' => :'String', :'is_isn_configured' => :'Boolean', :'is_media_controller' => :'Boolean', :'is_smart_license_enabled' => :'Boolean', :'num_fabrics' => :'Integer', :'num_fabrics_in_msd' => :'Integer', :'num_ingress_replication_fabrics' => :'Integer', :'num_local_users' => :'Integer', :'num_msd' => :'Integer', :'num_svi_vrf_count' => :'Integer', :'num_trm_enabled_count' => :'Integer', :'num_upg_users' => :'Integer', :'nxos_image_count' => :'Integer', :'serial' => :'String', :'site_name' => :'String', :'underlay_peering_active_links_count' => :'Integer', :'upg_job_count' => :'Integer', :'upg_status' => :'String', :'version' => :'String', :'registered_device' => :'AssetDeviceRegistrationRelationship' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 |
# File 'lib/intersight_client/models/niatelemetry_nia_inventory_dcnm_all_of.rb', line 371 def ==(o) return true if self.equal?(o) self.class == o.class && class_id == o.class_id && object_type == o.object_type && dev == o.dev && epld_image_count == o.epld_image_count && ha_enabled == o.ha_enabled && ha_replication_status == o.ha_replication_status && install == o.install && is_isn_configured == o.is_isn_configured && is_media_controller == o.is_media_controller && is_smart_license_enabled == o.is_smart_license_enabled && num_fabrics == o.num_fabrics && num_fabrics_in_msd == o.num_fabrics_in_msd && num_ingress_replication_fabrics == o.num_ingress_replication_fabrics && num_local_users == o.num_local_users && num_msd == o.num_msd && num_svi_vrf_count == o.num_svi_vrf_count && num_trm_enabled_count == o.num_trm_enabled_count && num_upg_users == o.num_upg_users && nxos_image_count == o.nxos_image_count && serial == o.serial && site_name == o.site_name && underlay_peering_active_links_count == o.underlay_peering_active_links_count && upg_job_count == o.upg_job_count && upg_status == o.upg_status && version == o.version && registered_device == o.registered_device end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
447 448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 463 464 465 466 467 468 469 470 471 472 473 474 475 476 477 478 479 480 481 482 483 484 |
# File 'lib/intersight_client/models/niatelemetry_nia_inventory_dcnm_all_of.rb', line 447 def _deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = IntersightClient.const_get(type) klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
518 519 520 521 522 523 524 525 526 527 528 529 530 |
# File 'lib/intersight_client/models/niatelemetry_nia_inventory_dcnm_all_of.rb', line 518 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
424 425 426 427 428 429 430 431 432 433 434 435 436 437 438 439 440 441 |
# File 'lib/intersight_client/models/niatelemetry_nia_inventory_dcnm_all_of.rb', line 424 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) NiatelemetryNiaInventoryDcnmAllOf.openapi_types.each_pair do |key, type| if attributes[NiatelemetryNiaInventoryDcnmAllOf.attribute_map[key]].nil? && NiatelemetryNiaInventoryDcnmAllOf.openapi_nullable.include?(key) self.send("#{key}=", nil) elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[NiatelemetryNiaInventoryDcnmAllOf.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[NiatelemetryNiaInventoryDcnmAllOf.attribute_map[key]].map { |v| _deserialize($1, v) }) end elsif !attributes[NiatelemetryNiaInventoryDcnmAllOf.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[NiatelemetryNiaInventoryDcnmAllOf.attribute_map[key]])) end end self end |
#eql?(o) ⇒ Boolean
404 405 406 |
# File 'lib/intersight_client/models/niatelemetry_nia_inventory_dcnm_all_of.rb', line 404 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
410 411 412 |
# File 'lib/intersight_client/models/niatelemetry_nia_inventory_dcnm_all_of.rb', line 410 def hash [class_id, object_type, dev, epld_image_count, ha_enabled, ha_replication_status, install, is_isn_configured, is_media_controller, is_smart_license_enabled, num_fabrics, num_fabrics_in_msd, num_ingress_replication_fabrics, num_local_users, num_msd, num_svi_vrf_count, num_trm_enabled_count, num_upg_users, nxos_image_count, serial, site_name, underlay_peering_active_links_count, upg_job_count, upg_status, version, registered_device].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
324 325 326 327 328 329 330 331 332 333 334 335 |
# File 'lib/intersight_client/models/niatelemetry_nia_inventory_dcnm_all_of.rb', line 324 def list_invalid_properties invalid_properties = Array.new if @class_id.nil? invalid_properties.push('invalid value for "class_id", class_id cannot be nil.') end if @object_type.nil? invalid_properties.push('invalid value for "object_type", object_type cannot be nil.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
494 495 496 |
# File 'lib/intersight_client/models/niatelemetry_nia_inventory_dcnm_all_of.rb', line 494 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
500 501 502 503 504 505 506 507 508 509 510 511 512 |
# File 'lib/intersight_client/models/niatelemetry_nia_inventory_dcnm_all_of.rb', line 500 def to_hash hash = {} NiatelemetryNiaInventoryDcnmAllOf.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = NiatelemetryNiaInventoryDcnmAllOf.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
488 489 490 |
# File 'lib/intersight_client/models/niatelemetry_nia_inventory_dcnm_all_of.rb', line 488 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
339 340 341 342 343 344 345 346 347 |
# File 'lib/intersight_client/models/niatelemetry_nia_inventory_dcnm_all_of.rb', line 339 def valid? return false if @class_id.nil? class_id_validator = EnumAttributeValidator.new('String', ["niatelemetry.NiaInventoryDcnm"]) return false unless class_id_validator.valid?(@class_id) return false if @object_type.nil? object_type_validator = EnumAttributeValidator.new('String', ["niatelemetry.NiaInventoryDcnm"]) return false unless object_type_validator.valid?(@object_type) true end |