Class: IntersightClient::OnpremImagePackage

Inherits:
MoBaseComplexType show all
Defined in:
lib/intersight_client/models/onprem_image_package.rb

Overview

ImagePackage encapsulates a software image package. ImagePackage can be a docker image, a UI web image, an endpoint (e.g. UCSM) image, a device connector image or an ansible scripts package.

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ OnpremImagePackage

Initializes the object



134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
# File 'lib/intersight_client/models/onprem_image_package.rb', line 134

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `IntersightClient::OnpremImagePackage` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `#{self.class.name}`. Please check the name to make sure it's valid. List of attributes: " + self.class.acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  # call parent's initialize
  super(attributes)

  if attributes.key?(:'class_id')
    self.class_id = attributes[:'class_id']
  else
    self.class_id = 'onprem.ImagePackage'
  end

  if attributes.key?(:'object_type')
    self.object_type = attributes[:'object_type']
  else
    self.object_type = 'onprem.ImagePackage'
  end

  if attributes.key?(:'file_path')
    self.file_path = attributes[:'file_path']
  end

  if attributes.key?(:'file_sha')
    self.file_sha = attributes[:'file_sha']
  end

  if attributes.key?(:'file_size')
    self.file_size = attributes[:'file_size']
  end

  if attributes.key?(:'file_time')
    self.file_time = attributes[:'file_time']
  end

  if attributes.key?(:'filename')
    self.filename = attributes[:'filename']
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  end

  if attributes.key?(:'package_type')
    self.package_type = attributes[:'package_type']
  end

  if attributes.key?(:'version')
    self.version = attributes[:'version']
  end
end

Instance Attribute Details

#class_idObject

The fully-qualified name of the instantiated, concrete type. This property is used as a discriminator to identify the type of the payload when marshaling and unmarshaling data.



20
21
22
# File 'lib/intersight_client/models/onprem_image_package.rb', line 20

def class_id
  @class_id
end

#file_pathObject

Optional file path of the image package.



26
27
28
# File 'lib/intersight_client/models/onprem_image_package.rb', line 26

def file_path
  @file_path
end

#file_shaObject

Image file’s fingerprint. Fingerprint is calculated using SHA256 algorithm.



29
30
31
# File 'lib/intersight_client/models/onprem_image_package.rb', line 29

def file_sha
  @file_sha
end

#file_sizeObject

Image file size in bytes.



32
33
34
# File 'lib/intersight_client/models/onprem_image_package.rb', line 32

def file_size
  @file_size
end

#file_timeObject

Image file’s last modified date and time.



35
36
37
# File 'lib/intersight_client/models/onprem_image_package.rb', line 35

def file_time
  @file_time
end

#filenameObject

Filename of the image package.



38
39
40
# File 'lib/intersight_client/models/onprem_image_package.rb', line 38

def filename
  @filename
end

#nameObject

Name of the software image package.



41
42
43
# File 'lib/intersight_client/models/onprem_image_package.rb', line 41

def name
  @name
end

#object_typeObject

The fully-qualified name of the instantiated, concrete type. The value should be the same as the ‘ClassId’ property.



23
24
25
# File 'lib/intersight_client/models/onprem_image_package.rb', line 23

def object_type
  @object_type
end

#package_typeObject

Image package type (e.g. service, system etc.).



44
45
46
# File 'lib/intersight_client/models/onprem_image_package.rb', line 44

def package_type
  @package_type
end

#versionObject

Image package version string.



47
48
49
# File 'lib/intersight_client/models/onprem_image_package.rb', line 47

def version
  @version
end

Class Method Details

.acceptable_attribute_mapObject

Returns the key-value map of all the JSON attributes this model knows about, including the ones defined in its parent(s)



93
94
95
# File 'lib/intersight_client/models/onprem_image_package.rb', line 93

def self.acceptable_attribute_map
  attribute_map.merge(superclass.acceptable_attribute_map)
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about, including the ones defined in its parent(s)



88
89
90
# File 'lib/intersight_client/models/onprem_image_package.rb', line 88

def self.acceptable_attributes
  attribute_map.values.concat(superclass.acceptable_attributes)
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



72
73
74
75
76
77
78
79
80
81
82
83
84
85
# File 'lib/intersight_client/models/onprem_image_package.rb', line 72

def self.attribute_map
  {
    :'class_id' => :'ClassId',
    :'object_type' => :'ObjectType',
    :'file_path' => :'FilePath',
    :'file_sha' => :'FileSha',
    :'file_size' => :'FileSize',
    :'file_time' => :'FileTime',
    :'filename' => :'Filename',
    :'name' => :'Name',
    :'package_type' => :'PackageType',
    :'version' => :'Version'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash



274
275
276
# File 'lib/intersight_client/models/onprem_image_package.rb', line 274

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_all_ofObject

List of class defined in allOf (OpenAPI v3)



120
121
122
123
124
125
# File 'lib/intersight_client/models/onprem_image_package.rb', line 120

def self.openapi_all_of
  [
  :'MoBaseComplexType',
  :'OnpremImagePackageAllOf'
  ]
end

.openapi_discriminator_nameObject

discriminator’s property name in OpenAPI v3



128
129
130
# File 'lib/intersight_client/models/onprem_image_package.rb', line 128

def self.openapi_discriminator_name
  :'ClassId'
end

.openapi_nullableObject

List of attributes with nullable: true



114
115
116
117
# File 'lib/intersight_client/models/onprem_image_package.rb', line 114

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



98
99
100
101
102
103
104
105
106
107
108
109
110
111
# File 'lib/intersight_client/models/onprem_image_package.rb', line 98

def self.openapi_types
  {
    :'class_id' => :'String',
    :'object_type' => :'String',
    :'file_path' => :'String',
    :'file_sha' => :'String',
    :'file_size' => :'Integer',
    :'file_time' => :'Time',
    :'filename' => :'String',
    :'name' => :'String',
    :'package_type' => :'String',
    :'version' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.



244
245
246
247
248
249
250
251
252
253
254
255
256
257
# File 'lib/intersight_client/models/onprem_image_package.rb', line 244

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      class_id == o.class_id &&
      object_type == o.object_type &&
      file_path == o.file_path &&
      file_sha == o.file_sha &&
      file_size == o.file_size &&
      file_time == o.file_time &&
      filename == o.filename &&
      name == o.name &&
      package_type == o.package_type &&
      version == o.version && super(o)
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type



305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
# File 'lib/intersight_client/models/onprem_image_package.rb', line 305

def _deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = IntersightClient.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value



376
377
378
379
380
381
382
383
384
385
386
387
388
# File 'lib/intersight_client/models/onprem_image_package.rb', line 376

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash



281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
# File 'lib/intersight_client/models/onprem_image_package.rb', line 281

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  super(attributes)
  OnpremImagePackage.openapi_types.each_pair do |key, type|
    if attributes[OnpremImagePackage.attribute_map[key]].nil? && OnpremImagePackage.openapi_nullable.include?(key)
      self.send("#{key}=", nil)
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[OnpremImagePackage.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[OnpremImagePackage.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[OnpremImagePackage.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[OnpremImagePackage.attribute_map[key]]))
    end
  end

  self
end

#eql?(o) ⇒ Boolean

See Also:

  • `==` method


261
262
263
# File 'lib/intersight_client/models/onprem_image_package.rb', line 261

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.



267
268
269
# File 'lib/intersight_client/models/onprem_image_package.rb', line 267

def hash
  [class_id, object_type, file_path, file_sha, file_size, file_time, filename, name, package_type, version].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?



197
198
199
200
201
202
203
204
205
206
207
208
# File 'lib/intersight_client/models/onprem_image_package.rb', line 197

def list_invalid_properties
  invalid_properties = super
  if @class_id.nil?
    invalid_properties.push('invalid value for "class_id", class_id cannot be nil.')
  end

  if @object_type.nil?
    invalid_properties.push('invalid value for "object_type", object_type cannot be nil.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)



352
353
354
# File 'lib/intersight_client/models/onprem_image_package.rb', line 352

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash



358
359
360
361
362
363
364
365
366
367
368
369
370
# File 'lib/intersight_client/models/onprem_image_package.rb', line 358

def to_hash
  hash = super
  OnpremImagePackage.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = OnpremImagePackage.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object



346
347
348
# File 'lib/intersight_client/models/onprem_image_package.rb', line 346

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid



212
213
214
215
216
217
218
219
220
# File 'lib/intersight_client/models/onprem_image_package.rb', line 212

def valid?
  return false if @class_id.nil?
  class_id_validator = EnumAttributeValidator.new('String', ["onprem.ImagePackage"])
  return false unless class_id_validator.valid?(@class_id)
  return false if @object_type.nil?
  object_type_validator = EnumAttributeValidator.new('String', ["onprem.ImagePackage"])
  return false unless object_type_validator.valid?(@object_type)
  true && super
end