Class: IntersightClient::OnpremSchedule
- Inherits:
-
MoBaseComplexType
- Object
- MoBaseComplexType
- IntersightClient::OnpremSchedule
- Defined in:
- lib/intersight_client/models/onprem_schedule.rb
Overview
Schedule is used by Intersight Appliance services to store task scheduling information. For example, appliance backup service uses Schedule to store the backup schedule of the Intersight Appliance. The Upgrade service uses Schedule to store the user-defined schedule for software upgrades of the Intersight Appliance.
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#class_id ⇒ Object
The fully-qualified name of the instantiated, concrete type.
-
#day_of_month ⇒ Object
Schedule a task on a specific day of the month.
-
#day_of_week ⇒ Object
Schedule a task on a specific day of the week.
-
#month_of_year ⇒ Object
Schedule a task on a specific month of the year.
-
#object_type ⇒ Object
The fully-qualified name of the instantiated, concrete type.
-
#repeat_interval ⇒ Object
Schedule a task to run periodically at an interval.
-
#time_of_day ⇒ Object
Time of the day in seconds.
-
#time_zone ⇒ Object
Timezone to use for the schedule calculation.
-
#week_of_month ⇒ Object
Schedule a task on a specific week of the month.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns the key-value map of all the JSON attributes this model knows about, including the ones defined in its parent(s).
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about, including the ones defined in its parent(s).
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_all_of ⇒ Object
List of class defined in allOf (OpenAPI v3).
-
.openapi_discriminator_name ⇒ Object
discriminator’s property name in OpenAPI v3.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ OnpremSchedule
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ OnpremSchedule
Initializes the object
129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 |
# File 'lib/intersight_client/models/onprem_schedule.rb', line 129 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `IntersightClient::OnpremSchedule` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `#{self.class.name}`. Please check the name to make sure it's valid. List of attributes: " + self.class.acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } # call parent's initialize super(attributes) if attributes.key?(:'class_id') self.class_id = attributes[:'class_id'] else self.class_id = 'onprem.Schedule' end if attributes.key?(:'object_type') self.object_type = attributes[:'object_type'] else self.object_type = 'onprem.Schedule' end if attributes.key?(:'day_of_month') self.day_of_month = attributes[:'day_of_month'] end if attributes.key?(:'day_of_week') self.day_of_week = attributes[:'day_of_week'] end if attributes.key?(:'month_of_year') self.month_of_year = attributes[:'month_of_year'] end if attributes.key?(:'repeat_interval') self.repeat_interval = attributes[:'repeat_interval'] end if attributes.key?(:'time_of_day') self.time_of_day = attributes[:'time_of_day'] end if attributes.key?(:'time_zone') self.time_zone = attributes[:'time_zone'] else self.time_zone = 'Pacific/Niue' end if attributes.key?(:'week_of_month') self.week_of_month = attributes[:'week_of_month'] end end |
Instance Attribute Details
#class_id ⇒ Object
The fully-qualified name of the instantiated, concrete type. This property is used as a discriminator to identify the type of the payload when marshaling and unmarshaling data.
20 21 22 |
# File 'lib/intersight_client/models/onprem_schedule.rb', line 20 def class_id @class_id end |
#day_of_month ⇒ Object
Schedule a task on a specific day of the month. Valid values are 1 through 31. If monthOfYear is specified, then dayOfMonth value must be valid for that month. DayOfMonth may not be set when dayOfWeek is specfied.
26 27 28 |
# File 'lib/intersight_client/models/onprem_schedule.rb', line 26 def day_of_month @day_of_month end |
#day_of_week ⇒ Object
Schedule a task on a specific day of the week. Valid values are 1 through 7, with 1 being Sunday. DayOfWeek may not be specfied when dayOfMonth is specified.
29 30 31 |
# File 'lib/intersight_client/models/onprem_schedule.rb', line 29 def day_of_week @day_of_week end |
#month_of_year ⇒ Object
Schedule a task on a specific month of the year. Valid values are 1 through 12, with 1 being January.
32 33 34 |
# File 'lib/intersight_client/models/onprem_schedule.rb', line 32 def month_of_year @month_of_year end |
#object_type ⇒ Object
The fully-qualified name of the instantiated, concrete type. The value should be the same as the ‘ClassId’ property.
23 24 25 |
# File 'lib/intersight_client/models/onprem_schedule.rb', line 23 def object_type @object_type end |
#repeat_interval ⇒ Object
Schedule a task to run periodically at an interval. Default unit of the RepeatInterval is in minutes. If the RepeateInterval value is set, then all other properties are ignored by the scheduler. RepeateInterval constraints are enforced by the services that use the schedule. Each service has pre-configured service specific properties for enforcing minimum and maximum values of the RepeatInterval.
35 36 37 |
# File 'lib/intersight_client/models/onprem_schedule.rb', line 35 def repeat_interval @repeat_interval end |
#time_of_day ⇒ Object
Time of the day in seconds. TimeOfDay is required for all schedule configurations, except when the RepeateInterval field is specified.
38 39 40 |
# File 'lib/intersight_client/models/onprem_schedule.rb', line 38 def time_of_day @time_of_day end |
#time_zone ⇒ Object
Timezone to use for the schedule calculation. If a timezone value is not speficied, then the schedule calculation will be based on UTC. * Pacific/Niue - * Pacific/Pago_Pago - * Pacific/Honolulu - * Pacific/Rarotonga - * Pacific/Tahiti - * Pacific/Marquesas - * America/Anchorage - * Pacific/Gambier - * America/Los_Angeles - * America/Tijuana - * America/Vancouver - * America/Whitehorse - * Pacific/Pitcairn - * America/Dawson_Creek - * America/Denver - * America/Edmonton - * America/Hermosillo - * America/Mazatlan - * America/Phoenix - * America/Yellowknife - * America/Belize - * America/Chicago - * America/Costa_Rica - * America/El_Salvador - * America/Guatemala - * America/Managua - * America/Mexico_City - * America/Regina - * America/Tegucigalpa - * America/Winnipeg - * Pacific/Galapagos - * America/Bogota - * America/Cancun - * America/Cayman - * America/Guayaquil - * America/Havana - * America/Iqaluit - * America/Jamaica - * America/Lima - * America/Nassau - * America/New_York - * America/Panama - * America/Port-au-Prince - * America/Rio_Branco - * America/Toronto - * Pacific/Easter - * America/Caracas - * America/Asuncion - * America/Barbados - * America/Boa_Vista - * America/Campo_Grande - * America/Cuiaba - * America/Curacao - * America/Grand_Turk - * America/Guyana - * America/Halifax - * America/La_Paz - * America/Manaus - * America/Martinique - * America/Port_of_Spain - * America/Porto_Velho - * America/Puerto_Rico - * America/Santo_Domingo - * America/Thule - * Atlantic/Bermuda - * America/St_Johns - * America/Araguaina - * America/Argentina/Buenos_Aires - * America/Bahia - * America/Belem - * America/Cayenne - * America/Fortaleza - * America/Godthab - * America/Maceio - * America/Miquelon - * America/Montevideo - * America/Paramaribo - * America/Recife - * America/Santiago - * America/Sao_Paulo - * Antarctica/Palmer - * Antarctica/Rothera - * Atlantic/Stanley - * America/Noronha - * Atlantic/South_Georgia - * America/Scoresbysund - * Atlantic/Azores - * Atlantic/Cape_Verde - * Africa/Abidjan - * Africa/Accra - * Africa/Bissau - * Africa/Casablanca - * Africa/El_Aaiun - * Africa/Monrovia - * America/Danmarkshavn - * Atlantic/Canary - * Atlantic/Faroe - * Atlantic/Reykjavik - * Etc/GMT - * Europe/Dublin - * Europe/Lisbon - * Europe/London - * Africa/Algiers - * Africa/Ceuta - * Africa/Lagos - * Africa/Ndjamena - * Africa/Tunis - * Africa/Windhoek - * Europe/Amsterdam - * Europe/Andorra - * Europe/Belgrade - * Europe/Berlin - * Europe/Brussels - * Europe/Budapest - * Europe/Copenhagen - * Europe/Gibraltar - * Europe/Luxembourg - * Europe/Madrid - * Europe/Malta - * Europe/Monaco - * Europe/Oslo - * Europe/Paris - * Europe/Prague - * Europe/Rome - * Europe/Stockholm - * Europe/Tirane - * Europe/Vienna - * Europe/Warsaw - * Europe/Zurich - * Africa/Cairo - * Africa/Johannesburg - * Africa/Maputo - * Africa/Tripoli - * Asia/Amman - * Asia/Beirut - * Asia/Damascus - * Asia/Gaza - * Asia/Jerusalem - * Asia/Nicosia - * Europe/Athens - * Europe/Bucharest - * Europe/Chisinau - * Europe/Helsinki - * Europe/Istanbul - * Europe/Kaliningrad - * Europe/Kiev - * Europe/Riga - * Europe/Sofia - * Europe/Tallinn - * Europe/Vilnius - * Africa/Khartoum - * Africa/Nairobi - * Antarctica/Syowa - * Asia/Baghdad - * Asia/Qatar - * Asia/Riyadh - * Europe/Minsk - * Europe/Moscow - * Asia/Tehran - * Asia/Baku - * Asia/Dubai - * Asia/Tbilisi - * Asia/Yerevan - * Europe/Samara - * Indian/Mahe - * Indian/Mauritius - * Indian/Reunion - * Asia/Kabul - * Antarctica/Mawson - * Asia/Aqtau - * Asia/Aqtobe - * Asia/Ashgabat - * Asia/Dushanbe - * Asia/Karachi - * Asia/Tashkent - * Asia/Yekaterinburg - * Indian/Kerguelen - * Indian/Maldives - * Asia/Calcutta - * Asia/Kolkata - * Asia/Colombo - * Asia/Katmandu - * Antarctica/Vostok - * Asia/Almaty - * Asia/Bishkek - * Asia/Dhaka - * Asia/Omsk - * Asia/Thimphu - * Indian/Chagos - * Asia/Rangoon - * Indian/Cocos - * Antarctica/Davis - * Asia/Bangkok - * Asia/Hovd - * Asia/Jakarta - * Asia/Krasnoyarsk - * Asia/Saigon - * Indian/Christmas - * Antarctica/Casey - * Asia/Brunei - * Asia/Choibalsan - * Asia/Hong_Kong - * Asia/Irkutsk - * Asia/Kuala_Lumpur - * Asia/Macau - * Asia/Makassar - * Asia/Manila - * Asia/Shanghai - * Asia/Singapore - * Asia/Taipei - * Asia/Ulaanbaatar - * Australia/Perth - * Asia/Pyongyang - * Asia/Dili - * Asia/Jayapura - * Asia/Seoul - * Asia/Tokyo - * Asia/Yakutsk - * Pacific/Palau - * Australia/Adelaide - * Australia/Darwin - * Antarctica/DumontDUrville - * Asia/Magadan - * Asia/Vladivostok - * Australia/Brisbane - * Australia/Hobart - * Australia/Sydney - * Pacific/Chuuk - * Pacific/Guam - * Pacific/Port_Moresby - * Pacific/Efate - * Pacific/Guadalcanal - * Pacific/Kosrae - * Pacific/Norfolk - * Pacific/Noumea - * Pacific/Pohnpei - * Asia/Kamchatka - * Pacific/Auckland - * Pacific/Fiji - * Pacific/Funafuti - * Pacific/Kwajalein - * Pacific/Majuro - * Pacific/Nauru - * Pacific/Tarawa - * Pacific/Wake - * Pacific/Wallis - * Pacific/Apia - * Pacific/Enderbury - * Pacific/Fakaofo - * Pacific/Tongatapu - * Pacific/Kiritimati -
41 42 43 |
# File 'lib/intersight_client/models/onprem_schedule.rb', line 41 def time_zone @time_zone end |
#week_of_month ⇒ Object
Schedule a task on a specific week of the month. Valid values are 1 through 5. Value of 5 means last week of the month. WeekOfMonth may not be set when dayOfMonth is specified.
44 45 46 |
# File 'lib/intersight_client/models/onprem_schedule.rb', line 44 def week_of_month @week_of_month end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns the key-value map of all the JSON attributes this model knows about, including the ones defined in its parent(s)
89 90 91 |
# File 'lib/intersight_client/models/onprem_schedule.rb', line 89 def self.acceptable_attribute_map attribute_map.merge(superclass.acceptable_attribute_map) end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about, including the ones defined in its parent(s)
84 85 86 |
# File 'lib/intersight_client/models/onprem_schedule.rb', line 84 def self.acceptable_attributes attribute_map.values.concat(superclass.acceptable_attributes) end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
69 70 71 72 73 74 75 76 77 78 79 80 81 |
# File 'lib/intersight_client/models/onprem_schedule.rb', line 69 def self.attribute_map { :'class_id' => :'ClassId', :'object_type' => :'ObjectType', :'day_of_month' => :'DayOfMonth', :'day_of_week' => :'DayOfWeek', :'month_of_year' => :'MonthOfYear', :'repeat_interval' => :'RepeatInterval', :'time_of_day' => :'TimeOfDay', :'time_zone' => :'TimeZone', :'week_of_month' => :'WeekOfMonth' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
398 399 400 |
# File 'lib/intersight_client/models/onprem_schedule.rb', line 398 def self.build_from_hash(attributes) new.build_from_hash(attributes) end |
.openapi_all_of ⇒ Object
List of class defined in allOf (OpenAPI v3)
115 116 117 118 119 120 |
# File 'lib/intersight_client/models/onprem_schedule.rb', line 115 def self.openapi_all_of [ :'MoBaseComplexType', :'OnpremScheduleAllOf' ] end |
.openapi_discriminator_name ⇒ Object
discriminator’s property name in OpenAPI v3
123 124 125 |
# File 'lib/intersight_client/models/onprem_schedule.rb', line 123 def self.openapi_discriminator_name :'ClassId' end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
109 110 111 112 |
# File 'lib/intersight_client/models/onprem_schedule.rb', line 109 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
94 95 96 97 98 99 100 101 102 103 104 105 106 |
# File 'lib/intersight_client/models/onprem_schedule.rb', line 94 def self.openapi_types { :'class_id' => :'String', :'object_type' => :'String', :'day_of_month' => :'Integer', :'day_of_week' => :'Integer', :'month_of_year' => :'Integer', :'repeat_interval' => :'Integer', :'time_of_day' => :'Integer', :'time_zone' => :'String', :'week_of_month' => :'Integer' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
369 370 371 372 373 374 375 376 377 378 379 380 381 |
# File 'lib/intersight_client/models/onprem_schedule.rb', line 369 def ==(o) return true if self.equal?(o) self.class == o.class && class_id == o.class_id && object_type == o.object_type && day_of_month == o.day_of_month && day_of_week == o.day_of_week && month_of_year == o.month_of_year && repeat_interval == o.repeat_interval && time_of_day == o.time_of_day && time_zone == o.time_zone && week_of_month == o.week_of_month && super(o) end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
429 430 431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 463 464 465 466 |
# File 'lib/intersight_client/models/onprem_schedule.rb', line 429 def _deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = IntersightClient.const_get(type) klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
500 501 502 503 504 505 506 507 508 509 510 511 512 |
# File 'lib/intersight_client/models/onprem_schedule.rb', line 500 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 |
# File 'lib/intersight_client/models/onprem_schedule.rb', line 405 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) super(attributes) OnpremSchedule.openapi_types.each_pair do |key, type| if attributes[OnpremSchedule.attribute_map[key]].nil? && OnpremSchedule.openapi_nullable.include?(key) self.send("#{key}=", nil) elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[OnpremSchedule.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[OnpremSchedule.attribute_map[key]].map { |v| _deserialize($1, v) }) end elsif !attributes[OnpremSchedule.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[OnpremSchedule.attribute_map[key]])) end end self end |
#eql?(o) ⇒ Boolean
385 386 387 |
# File 'lib/intersight_client/models/onprem_schedule.rb', line 385 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
391 392 393 |
# File 'lib/intersight_client/models/onprem_schedule.rb', line 391 def hash [class_id, object_type, day_of_month, day_of_week, month_of_year, repeat_interval, time_of_day, time_zone, week_of_month].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 |
# File 'lib/intersight_client/models/onprem_schedule.rb', line 190 def list_invalid_properties invalid_properties = super if @class_id.nil? invalid_properties.push('invalid value for "class_id", class_id cannot be nil.') end if @object_type.nil? invalid_properties.push('invalid value for "object_type", object_type cannot be nil.') end if !@day_of_month.nil? && @day_of_month > 31 invalid_properties.push('invalid value for "day_of_month", must be smaller than or equal to 31.') end if !@day_of_month.nil? && @day_of_month < 0 invalid_properties.push('invalid value for "day_of_month", must be greater than or equal to 0.') end if !@day_of_week.nil? && @day_of_week > 7 invalid_properties.push('invalid value for "day_of_week", must be smaller than or equal to 7.') end if !@day_of_week.nil? && @day_of_week < 0 invalid_properties.push('invalid value for "day_of_week", must be greater than or equal to 0.') end if !@month_of_year.nil? && @month_of_year > 12 invalid_properties.push('invalid value for "month_of_year", must be smaller than or equal to 12.') end if !@month_of_year.nil? && @month_of_year < 0 invalid_properties.push('invalid value for "month_of_year", must be greater than or equal to 0.') end if !@time_of_day.nil? && @time_of_day > 86399 invalid_properties.push('invalid value for "time_of_day", must be smaller than or equal to 86399.') end if !@time_of_day.nil? && @time_of_day < 0 invalid_properties.push('invalid value for "time_of_day", must be greater than or equal to 0.') end if !@week_of_month.nil? && @week_of_month > 5 invalid_properties.push('invalid value for "week_of_month", must be smaller than or equal to 5.') end if !@week_of_month.nil? && @week_of_month < 0 invalid_properties.push('invalid value for "week_of_month", must be greater than or equal to 0.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
476 477 478 |
# File 'lib/intersight_client/models/onprem_schedule.rb', line 476 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
482 483 484 485 486 487 488 489 490 491 492 493 494 |
# File 'lib/intersight_client/models/onprem_schedule.rb', line 482 def to_hash hash = super OnpremSchedule.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = OnpremSchedule.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
470 471 472 |
# File 'lib/intersight_client/models/onprem_schedule.rb', line 470 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 |
# File 'lib/intersight_client/models/onprem_schedule.rb', line 245 def valid? return false if @class_id.nil? class_id_validator = EnumAttributeValidator.new('String', ["onprem.Schedule"]) return false unless class_id_validator.valid?(@class_id) return false if @object_type.nil? object_type_validator = EnumAttributeValidator.new('String', ["onprem.Schedule"]) return false unless object_type_validator.valid?(@object_type) return false if !@day_of_month.nil? && @day_of_month > 31 return false if !@day_of_month.nil? && @day_of_month < 0 return false if !@day_of_week.nil? && @day_of_week > 7 return false if !@day_of_week.nil? && @day_of_week < 0 return false if !@month_of_year.nil? && @month_of_year > 12 return false if !@month_of_year.nil? && @month_of_year < 0 return false if !@time_of_day.nil? && @time_of_day > 86399 return false if !@time_of_day.nil? && @time_of_day < 0 time_zone_validator = EnumAttributeValidator.new('String', ["Pacific/Niue", "Pacific/Pago_Pago", "Pacific/Honolulu", "Pacific/Rarotonga", "Pacific/Tahiti", "Pacific/Marquesas", "America/Anchorage", "Pacific/Gambier", "America/Los_Angeles", "America/Tijuana", "America/Vancouver", "America/Whitehorse", "Pacific/Pitcairn", "America/Dawson_Creek", "America/Denver", "America/Edmonton", "America/Hermosillo", "America/Mazatlan", "America/Phoenix", "America/Yellowknife", "America/Belize", "America/Chicago", "America/Costa_Rica", "America/El_Salvador", "America/Guatemala", "America/Managua", "America/Mexico_City", "America/Regina", "America/Tegucigalpa", "America/Winnipeg", "Pacific/Galapagos", "America/Bogota", "America/Cancun", "America/Cayman", "America/Guayaquil", "America/Havana", "America/Iqaluit", "America/Jamaica", "America/Lima", "America/Nassau", "America/New_York", "America/Panama", "America/Port-au-Prince", "America/Rio_Branco", "America/Toronto", "Pacific/Easter", "America/Caracas", "America/Asuncion", "America/Barbados", "America/Boa_Vista", "America/Campo_Grande", "America/Cuiaba", "America/Curacao", "America/Grand_Turk", "America/Guyana", "America/Halifax", "America/La_Paz", "America/Manaus", "America/Martinique", "America/Port_of_Spain", "America/Porto_Velho", "America/Puerto_Rico", "America/Santo_Domingo", "America/Thule", "Atlantic/Bermuda", "America/St_Johns", "America/Araguaina", "America/Argentina/Buenos_Aires", "America/Bahia", "America/Belem", "America/Cayenne", "America/Fortaleza", "America/Godthab", "America/Maceio", "America/Miquelon", "America/Montevideo", "America/Paramaribo", "America/Recife", "America/Santiago", "America/Sao_Paulo", "Antarctica/Palmer", "Antarctica/Rothera", "Atlantic/Stanley", "America/Noronha", "Atlantic/South_Georgia", "America/Scoresbysund", "Atlantic/Azores", "Atlantic/Cape_Verde", "Africa/Abidjan", "Africa/Accra", "Africa/Bissau", "Africa/Casablanca", "Africa/El_Aaiun", "Africa/Monrovia", "America/Danmarkshavn", "Atlantic/Canary", "Atlantic/Faroe", "Atlantic/Reykjavik", "Etc/GMT", "Europe/Dublin", "Europe/Lisbon", "Europe/London", "Africa/Algiers", "Africa/Ceuta", "Africa/Lagos", "Africa/Ndjamena", "Africa/Tunis", "Africa/Windhoek", "Europe/Amsterdam", "Europe/Andorra", "Europe/Belgrade", "Europe/Berlin", "Europe/Brussels", "Europe/Budapest", "Europe/Copenhagen", "Europe/Gibraltar", "Europe/Luxembourg", "Europe/Madrid", "Europe/Malta", "Europe/Monaco", "Europe/Oslo", "Europe/Paris", "Europe/Prague", "Europe/Rome", "Europe/Stockholm", "Europe/Tirane", "Europe/Vienna", "Europe/Warsaw", "Europe/Zurich", "Africa/Cairo", "Africa/Johannesburg", "Africa/Maputo", "Africa/Tripoli", "Asia/Amman", "Asia/Beirut", "Asia/Damascus", "Asia/Gaza", "Asia/Jerusalem", "Asia/Nicosia", "Europe/Athens", "Europe/Bucharest", "Europe/Chisinau", "Europe/Helsinki", "Europe/Istanbul", "Europe/Kaliningrad", "Europe/Kiev", "Europe/Riga", "Europe/Sofia", "Europe/Tallinn", "Europe/Vilnius", "Africa/Khartoum", "Africa/Nairobi", "Antarctica/Syowa", "Asia/Baghdad", "Asia/Qatar", "Asia/Riyadh", "Europe/Minsk", "Europe/Moscow", "Asia/Tehran", "Asia/Baku", "Asia/Dubai", "Asia/Tbilisi", "Asia/Yerevan", "Europe/Samara", "Indian/Mahe", "Indian/Mauritius", "Indian/Reunion", "Asia/Kabul", "Antarctica/Mawson", "Asia/Aqtau", "Asia/Aqtobe", "Asia/Ashgabat", "Asia/Dushanbe", "Asia/Karachi", "Asia/Tashkent", "Asia/Yekaterinburg", "Indian/Kerguelen", "Indian/Maldives", "Asia/Calcutta", "Asia/Kolkata", "Asia/Colombo", "Asia/Katmandu", "Antarctica/Vostok", "Asia/Almaty", "Asia/Bishkek", "Asia/Dhaka", "Asia/Omsk", "Asia/Thimphu", "Indian/Chagos", "Asia/Rangoon", "Indian/Cocos", "Antarctica/Davis", "Asia/Bangkok", "Asia/Hovd", "Asia/Jakarta", "Asia/Krasnoyarsk", "Asia/Saigon", "Indian/Christmas", "Antarctica/Casey", "Asia/Brunei", "Asia/Choibalsan", "Asia/Hong_Kong", "Asia/Irkutsk", "Asia/Kuala_Lumpur", "Asia/Macau", "Asia/Makassar", "Asia/Manila", "Asia/Shanghai", "Asia/Singapore", "Asia/Taipei", "Asia/Ulaanbaatar", "Australia/Perth", "Asia/Pyongyang", "Asia/Dili", "Asia/Jayapura", "Asia/Seoul", "Asia/Tokyo", "Asia/Yakutsk", "Pacific/Palau", "Australia/Adelaide", "Australia/Darwin", "Antarctica/DumontDUrville", "Asia/Magadan", "Asia/Vladivostok", "Australia/Brisbane", "Australia/Hobart", "Australia/Sydney", "Pacific/Chuuk", "Pacific/Guam", "Pacific/Port_Moresby", "Pacific/Efate", "Pacific/Guadalcanal", "Pacific/Kosrae", "Pacific/Norfolk", "Pacific/Noumea", "Pacific/Pohnpei", "Asia/Kamchatka", "Pacific/Auckland", "Pacific/Fiji", "Pacific/Funafuti", "Pacific/Kwajalein", "Pacific/Majuro", "Pacific/Nauru", "Pacific/Tarawa", "Pacific/Wake", "Pacific/Wallis", "Pacific/Apia", "Pacific/Enderbury", "Pacific/Fakaofo", "Pacific/Tongatapu", "Pacific/Kiritimati"]) return false unless time_zone_validator.valid?(@time_zone) return false if !@week_of_month.nil? && @week_of_month > 5 return false if !@week_of_month.nil? && @week_of_month < 0 true && super end |