Class: IntersightClient::PortMacBinding
- Inherits:
-
InventoryBase
- Object
- MoBaseMo
- InventoryBase
- IntersightClient::PortMacBinding
- Defined in:
- lib/intersight_client/models/port_mac_binding.rb
Overview
Establishes relationship between the ports and connected end points based on LLDP TLVs.
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#aggregate_port_id ⇒ Object
Aggregate Port ID of the local Switch Interface.
-
#chassis_id ⇒ Object
Chassis/FEX device idetifier that is local to a cluster.
-
#chassis_model ⇒ Object
Chassis/Rack Model that is associated with the Switch/FEX interface.
-
#chassis_serial ⇒ Object
Chassis/Rack Serial that is associated with the Switch/FEX interface.
-
#chassis_vendor ⇒ Object
Chassis/Rack Vendor that is associated with the Switch/FEX interface.
-
#class_id ⇒ Object
The fully-qualified name of the instantiated, concrete type.
-
#device_mac ⇒ Object
Device ID value that is advertised and available as a part of LLDP TLV.
-
#module_mode ⇒ Object
IOM/SIOC/Adapter Mode that is associated with the Switch/FEX interface.
-
#module_model ⇒ Object
IOM/SIOC/Adapter Model that is associated with the Switch/FEX interface.
-
#module_port_id ⇒ Object
Uplink port identifier of the VIC that is associated with the Switch/FEX interface.
-
#module_serial ⇒ Object
IOM/SIOC/Adapter Serial that is associated with the Switch/FEX interface.
-
#module_side ⇒ Object
IOM/SIOC/Adapter Side that is associated with the Switch/FEX interface.
-
#module_slot ⇒ Object
IOM/SIOC/Adapter Slot that is associated with the Switch/FEX interface.
-
#module_vendor ⇒ Object
IOM/SIOC/Adapter Vendor that is associated with the Switch/FEX interface.
-
#network_element ⇒ Object
Returns the value of attribute network_element.
-
#object_type ⇒ Object
The fully-qualified name of the instantiated, concrete type.
-
#port_id ⇒ Object
Port ID of the local Switch Interface.
-
#port_mac ⇒ Object
Port ID value that is advertised and available as a part of LLDP TLV.
-
#registered_device ⇒ Object
Returns the value of attribute registered_device.
-
#slot_id ⇒ Object
Slot ID of the local Switch slot Interface.
-
#switch_id ⇒ Object
Switch Identifier that is local to a cluster.
Attributes inherited from InventoryBase
Attributes inherited from MoBaseMo
#account_moid, #ancestors, #create_time, #display_names, #domain_group_moid, #mod_time, #moid, #owners, #parent, #permission_resources, #shared_scope, #tags, #version_context
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns the key-value map of all the JSON attributes this model knows about, including the ones defined in its parent(s).
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about, including the ones defined in its parent(s).
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_all_of ⇒ Object
List of class defined in allOf (OpenAPI v3).
-
.openapi_discriminator_name ⇒ Object
discriminator’s property name in OpenAPI v3.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ PortMacBinding
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ PortMacBinding
Initializes the object
187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 |
# File 'lib/intersight_client/models/port_mac_binding.rb', line 187 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `IntersightClient::PortMacBinding` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `#{self.class.name}`. Please check the name to make sure it's valid. List of attributes: " + self.class.acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } # call parent's initialize super(attributes) if attributes.key?(:'class_id') self.class_id = attributes[:'class_id'] else self.class_id = 'port.MacBinding' end if attributes.key?(:'object_type') self.object_type = attributes[:'object_type'] else self.object_type = 'port.MacBinding' end if attributes.key?(:'aggregate_port_id') self.aggregate_port_id = attributes[:'aggregate_port_id'] end if attributes.key?(:'chassis_id') self.chassis_id = attributes[:'chassis_id'] end if attributes.key?(:'chassis_model') self.chassis_model = attributes[:'chassis_model'] end if attributes.key?(:'chassis_serial') self.chassis_serial = attributes[:'chassis_serial'] end if attributes.key?(:'chassis_vendor') self.chassis_vendor = attributes[:'chassis_vendor'] end if attributes.key?(:'device_mac') self.device_mac = attributes[:'device_mac'] end if attributes.key?(:'module_mode') self.module_mode = attributes[:'module_mode'] end if attributes.key?(:'module_model') self.module_model = attributes[:'module_model'] end if attributes.key?(:'module_port_id') self.module_port_id = attributes[:'module_port_id'] end if attributes.key?(:'module_serial') self.module_serial = attributes[:'module_serial'] end if attributes.key?(:'module_side') self.module_side = attributes[:'module_side'] end if attributes.key?(:'module_slot') self.module_slot = attributes[:'module_slot'] end if attributes.key?(:'module_vendor') self.module_vendor = attributes[:'module_vendor'] end if attributes.key?(:'port_id') self.port_id = attributes[:'port_id'] end if attributes.key?(:'port_mac') self.port_mac = attributes[:'port_mac'] end if attributes.key?(:'slot_id') self.slot_id = attributes[:'slot_id'] end if attributes.key?(:'switch_id') self.switch_id = attributes[:'switch_id'] end if attributes.key?(:'network_element') self.network_element = attributes[:'network_element'] end if attributes.key?(:'registered_device') self.registered_device = attributes[:'registered_device'] end end |
Instance Attribute Details
#aggregate_port_id ⇒ Object
Aggregate Port ID of the local Switch Interface.
26 27 28 |
# File 'lib/intersight_client/models/port_mac_binding.rb', line 26 def aggregate_port_id @aggregate_port_id end |
#chassis_id ⇒ Object
Chassis/FEX device idetifier that is local to a cluster.
29 30 31 |
# File 'lib/intersight_client/models/port_mac_binding.rb', line 29 def chassis_id @chassis_id end |
#chassis_model ⇒ Object
Chassis/Rack Model that is associated with the Switch/FEX interface.
32 33 34 |
# File 'lib/intersight_client/models/port_mac_binding.rb', line 32 def chassis_model @chassis_model end |
#chassis_serial ⇒ Object
Chassis/Rack Serial that is associated with the Switch/FEX interface.
35 36 37 |
# File 'lib/intersight_client/models/port_mac_binding.rb', line 35 def chassis_serial @chassis_serial end |
#chassis_vendor ⇒ Object
Chassis/Rack Vendor that is associated with the Switch/FEX interface.
38 39 40 |
# File 'lib/intersight_client/models/port_mac_binding.rb', line 38 def chassis_vendor @chassis_vendor end |
#class_id ⇒ Object
The fully-qualified name of the instantiated, concrete type. This property is used as a discriminator to identify the type of the payload when marshaling and unmarshaling data.
20 21 22 |
# File 'lib/intersight_client/models/port_mac_binding.rb', line 20 def class_id @class_id end |
#device_mac ⇒ Object
Device ID value that is advertised and available as a part of LLDP TLV.
41 42 43 |
# File 'lib/intersight_client/models/port_mac_binding.rb', line 41 def device_mac @device_mac end |
#module_mode ⇒ Object
IOM/SIOC/Adapter Mode that is associated with the Switch/FEX interface.
44 45 46 |
# File 'lib/intersight_client/models/port_mac_binding.rb', line 44 def module_mode @module_mode end |
#module_model ⇒ Object
IOM/SIOC/Adapter Model that is associated with the Switch/FEX interface.
47 48 49 |
# File 'lib/intersight_client/models/port_mac_binding.rb', line 47 def module_model @module_model end |
#module_port_id ⇒ Object
Uplink port identifier of the VIC that is associated with the Switch/FEX interface.
50 51 52 |
# File 'lib/intersight_client/models/port_mac_binding.rb', line 50 def module_port_id @module_port_id end |
#module_serial ⇒ Object
IOM/SIOC/Adapter Serial that is associated with the Switch/FEX interface.
53 54 55 |
# File 'lib/intersight_client/models/port_mac_binding.rb', line 53 def module_serial @module_serial end |
#module_side ⇒ Object
IOM/SIOC/Adapter Side that is associated with the Switch/FEX interface.
56 57 58 |
# File 'lib/intersight_client/models/port_mac_binding.rb', line 56 def module_side @module_side end |
#module_slot ⇒ Object
IOM/SIOC/Adapter Slot that is associated with the Switch/FEX interface.
59 60 61 |
# File 'lib/intersight_client/models/port_mac_binding.rb', line 59 def module_slot @module_slot end |
#module_vendor ⇒ Object
IOM/SIOC/Adapter Vendor that is associated with the Switch/FEX interface.
62 63 64 |
# File 'lib/intersight_client/models/port_mac_binding.rb', line 62 def module_vendor @module_vendor end |
#network_element ⇒ Object
Returns the value of attribute network_element.
76 77 78 |
# File 'lib/intersight_client/models/port_mac_binding.rb', line 76 def network_element @network_element end |
#object_type ⇒ Object
The fully-qualified name of the instantiated, concrete type. The value should be the same as the ‘ClassId’ property.
23 24 25 |
# File 'lib/intersight_client/models/port_mac_binding.rb', line 23 def object_type @object_type end |
#port_id ⇒ Object
Port ID of the local Switch Interface.
65 66 67 |
# File 'lib/intersight_client/models/port_mac_binding.rb', line 65 def port_id @port_id end |
#port_mac ⇒ Object
Port ID value that is advertised and available as a part of LLDP TLV.
68 69 70 |
# File 'lib/intersight_client/models/port_mac_binding.rb', line 68 def port_mac @port_mac end |
#registered_device ⇒ Object
Returns the value of attribute registered_device.
78 79 80 |
# File 'lib/intersight_client/models/port_mac_binding.rb', line 78 def registered_device @registered_device end |
#slot_id ⇒ Object
Slot ID of the local Switch slot Interface.
71 72 73 |
# File 'lib/intersight_client/models/port_mac_binding.rb', line 71 def slot_id @slot_id end |
#switch_id ⇒ Object
Switch Identifier that is local to a cluster.
74 75 76 |
# File 'lib/intersight_client/models/port_mac_binding.rb', line 74 def switch_id @switch_id end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns the key-value map of all the JSON attributes this model knows about, including the ones defined in its parent(s)
135 136 137 |
# File 'lib/intersight_client/models/port_mac_binding.rb', line 135 def self.acceptable_attribute_map attribute_map.merge(superclass.acceptable_attribute_map) end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about, including the ones defined in its parent(s)
130 131 132 |
# File 'lib/intersight_client/models/port_mac_binding.rb', line 130 def self.acceptable_attributes attribute_map.values.concat(superclass.acceptable_attributes) end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 |
# File 'lib/intersight_client/models/port_mac_binding.rb', line 103 def self.attribute_map { :'class_id' => :'ClassId', :'object_type' => :'ObjectType', :'aggregate_port_id' => :'AggregatePortId', :'chassis_id' => :'ChassisId', :'chassis_model' => :'ChassisModel', :'chassis_serial' => :'ChassisSerial', :'chassis_vendor' => :'ChassisVendor', :'device_mac' => :'DeviceMac', :'module_mode' => :'ModuleMode', :'module_model' => :'ModuleModel', :'module_port_id' => :'ModulePortId', :'module_serial' => :'ModuleSerial', :'module_side' => :'ModuleSide', :'module_slot' => :'ModuleSlot', :'module_vendor' => :'ModuleVendor', :'port_id' => :'PortId', :'port_mac' => :'PortMac', :'slot_id' => :'SlotId', :'switch_id' => :'SwitchId', :'network_element' => :'NetworkElement', :'registered_device' => :'RegisteredDevice' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
382 383 384 |
# File 'lib/intersight_client/models/port_mac_binding.rb', line 382 def self.build_from_hash(attributes) new.build_from_hash(attributes) end |
.openapi_all_of ⇒ Object
List of class defined in allOf (OpenAPI v3)
173 174 175 176 177 178 |
# File 'lib/intersight_client/models/port_mac_binding.rb', line 173 def self.openapi_all_of [ :'InventoryBase', :'PortMacBindingAllOf' ] end |
.openapi_discriminator_name ⇒ Object
discriminator’s property name in OpenAPI v3
181 182 183 |
# File 'lib/intersight_client/models/port_mac_binding.rb', line 181 def self.openapi_discriminator_name :'ClassId' end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
167 168 169 170 |
# File 'lib/intersight_client/models/port_mac_binding.rb', line 167 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 |
# File 'lib/intersight_client/models/port_mac_binding.rb', line 140 def self.openapi_types { :'class_id' => :'String', :'object_type' => :'String', :'aggregate_port_id' => :'Integer', :'chassis_id' => :'Integer', :'chassis_model' => :'String', :'chassis_serial' => :'String', :'chassis_vendor' => :'String', :'device_mac' => :'String', :'module_mode' => :'Integer', :'module_model' => :'String', :'module_port_id' => :'Integer', :'module_serial' => :'String', :'module_side' => :'Integer', :'module_slot' => :'Integer', :'module_vendor' => :'String', :'port_id' => :'Integer', :'port_mac' => :'String', :'slot_id' => :'Integer', :'switch_id' => :'Integer', :'network_element' => :'NetworkElementRelationship', :'registered_device' => :'AssetDeviceRegistrationRelationship' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 |
# File 'lib/intersight_client/models/port_mac_binding.rb', line 341 def ==(o) return true if self.equal?(o) self.class == o.class && class_id == o.class_id && object_type == o.object_type && aggregate_port_id == o.aggregate_port_id && chassis_id == o.chassis_id && chassis_model == o.chassis_model && chassis_serial == o.chassis_serial && chassis_vendor == o.chassis_vendor && device_mac == o.device_mac && module_mode == o.module_mode && module_model == o.module_model && module_port_id == o.module_port_id && module_serial == o.module_serial && module_side == o.module_side && module_slot == o.module_slot && module_vendor == o.module_vendor && port_id == o.port_id && port_mac == o.port_mac && slot_id == o.slot_id && switch_id == o.switch_id && network_element == o.network_element && registered_device == o.registered_device && super(o) end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 450 |
# File 'lib/intersight_client/models/port_mac_binding.rb', line 413 def _deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = IntersightClient.const_get(type) klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
484 485 486 487 488 489 490 491 492 493 494 495 496 |
# File 'lib/intersight_client/models/port_mac_binding.rb', line 484 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 |
# File 'lib/intersight_client/models/port_mac_binding.rb', line 389 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) super(attributes) PortMacBinding.openapi_types.each_pair do |key, type| if attributes[PortMacBinding.attribute_map[key]].nil? && PortMacBinding.openapi_nullable.include?(key) self.send("#{key}=", nil) elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[PortMacBinding.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[PortMacBinding.attribute_map[key]].map { |v| _deserialize($1, v) }) end elsif !attributes[PortMacBinding.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[PortMacBinding.attribute_map[key]])) end end self end |
#eql?(o) ⇒ Boolean
369 370 371 |
# File 'lib/intersight_client/models/port_mac_binding.rb', line 369 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
375 376 377 |
# File 'lib/intersight_client/models/port_mac_binding.rb', line 375 def hash [class_id, object_type, aggregate_port_id, chassis_id, chassis_model, chassis_serial, chassis_vendor, device_mac, module_mode, module_model, module_port_id, module_serial, module_side, module_slot, module_vendor, port_id, port_mac, slot_id, switch_id, network_element, registered_device].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
294 295 296 297 298 299 300 301 302 303 304 305 |
# File 'lib/intersight_client/models/port_mac_binding.rb', line 294 def list_invalid_properties invalid_properties = super if @class_id.nil? invalid_properties.push('invalid value for "class_id", class_id cannot be nil.') end if @object_type.nil? invalid_properties.push('invalid value for "object_type", object_type cannot be nil.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
460 461 462 |
# File 'lib/intersight_client/models/port_mac_binding.rb', line 460 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
466 467 468 469 470 471 472 473 474 475 476 477 478 |
# File 'lib/intersight_client/models/port_mac_binding.rb', line 466 def to_hash hash = super PortMacBinding.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = PortMacBinding.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
454 455 456 |
# File 'lib/intersight_client/models/port_mac_binding.rb', line 454 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
309 310 311 312 313 314 315 316 317 |
# File 'lib/intersight_client/models/port_mac_binding.rb', line 309 def valid? return false if @class_id.nil? class_id_validator = EnumAttributeValidator.new('String', ["port.MacBinding"]) return false unless class_id_validator.valid?(@class_id) return false if @object_type.nil? object_type_validator = EnumAttributeValidator.new('String', ["port.MacBinding"]) return false unless object_type_validator.valid?(@object_type) true && super end |