Class: IntersightClient::PortPhysicalAllOf

Inherits:
Object
  • Object
show all
Defined in:
lib/intersight_client/models/port_physical_all_of.rb

Overview

Definition of the list of properties defined in ‘port.Physical’, excluding properties defined in parent classes.

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ PortPhysicalAllOf

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
# File 'lib/intersight_client/models/port_physical_all_of.rb', line 111

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `IntersightClient::PortPhysicalAllOf` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `#{self.class.name}`. Please check the name to make sure it's valid. List of attributes: " + self.class.acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'class_id')
    self.class_id = attributes[:'class_id']
  end

  if attributes.key?(:'object_type')
    self.object_type = attributes[:'object_type']
  end

  if attributes.key?(:'oper_state')
    self.oper_state = attributes[:'oper_state']
  end

  if attributes.key?(:'oper_state_qual')
    self.oper_state_qual = attributes[:'oper_state_qual']
  end

  if attributes.key?(:'port_id')
    self.port_id = attributes[:'port_id']
  end

  if attributes.key?(:'role')
    self.role = attributes[:'role']
  end

  if attributes.key?(:'slot_id')
    self.slot_id = attributes[:'slot_id']
  end

  if attributes.key?(:'switch_id')
    self.switch_id = attributes[:'switch_id']
  end
end

Instance Attribute Details

#class_idObject

The fully-qualified name of the instantiated, concrete type. This property is used as a discriminator to identify the type of the payload when marshaling and unmarshaling data. The enum values provides the list of concrete types that can be instantiated from this abstract type.



20
21
22
# File 'lib/intersight_client/models/port_physical_all_of.rb', line 20

def class_id
  @class_id
end

#object_typeObject

The fully-qualified name of the instantiated, concrete type. The value should be the same as the ‘ClassId’ property. The enum values provides the list of concrete types that can be instantiated from this abstract type.



23
24
25
# File 'lib/intersight_client/models/port_physical_all_of.rb', line 23

def object_type
  @object_type
end

#oper_stateObject

Operational state of this port (enabled/disabled).



26
27
28
# File 'lib/intersight_client/models/port_physical_all_of.rb', line 26

def oper_state
  @oper_state
end

#oper_state_qualObject

Reason for this port’s Operational state.



29
30
31
# File 'lib/intersight_client/models/port_physical_all_of.rb', line 29

def oper_state_qual
  @oper_state_qual
end

#port_idObject

Switch physical port identifier.



32
33
34
# File 'lib/intersight_client/models/port_physical_all_of.rb', line 32

def port_id
  @port_id
end

#roleObject

The role assigned to this port.



35
36
37
# File 'lib/intersight_client/models/port_physical_all_of.rb', line 35

def role
  @role
end

#slot_idObject

Switch expansion slot module identifier.



38
39
40
# File 'lib/intersight_client/models/port_physical_all_of.rb', line 38

def slot_id
  @slot_id
end

#switch_idObject

Switch Identifier that is local to a cluster.



41
42
43
# File 'lib/intersight_client/models/port_physical_all_of.rb', line 41

def switch_id
  @switch_id
end

Class Method Details

.acceptable_attribute_mapObject

Returns the key-value map of all the JSON attributes this model knows about



85
86
87
# File 'lib/intersight_client/models/port_physical_all_of.rb', line 85

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



80
81
82
# File 'lib/intersight_client/models/port_physical_all_of.rb', line 80

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



66
67
68
69
70
71
72
73
74
75
76
77
# File 'lib/intersight_client/models/port_physical_all_of.rb', line 66

def self.attribute_map
  {
    :'class_id' => :'ClassId',
    :'object_type' => :'ObjectType',
    :'oper_state' => :'OperState',
    :'oper_state_qual' => :'OperStateQual',
    :'port_id' => :'PortId',
    :'role' => :'Role',
    :'slot_id' => :'SlotId',
    :'switch_id' => :'SwitchId'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



234
235
236
# File 'lib/intersight_client/models/port_physical_all_of.rb', line 234

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_nullableObject

List of attributes with nullable: true



104
105
106
107
# File 'lib/intersight_client/models/port_physical_all_of.rb', line 104

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



90
91
92
93
94
95
96
97
98
99
100
101
# File 'lib/intersight_client/models/port_physical_all_of.rb', line 90

def self.openapi_types
  {
    :'class_id' => :'String',
    :'object_type' => :'String',
    :'oper_state' => :'String',
    :'oper_state_qual' => :'String',
    :'port_id' => :'Integer',
    :'role' => :'String',
    :'slot_id' => :'Integer',
    :'switch_id' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



206
207
208
209
210
211
212
213
214
215
216
217
# File 'lib/intersight_client/models/port_physical_all_of.rb', line 206

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      class_id == o.class_id &&
      object_type == o.object_type &&
      oper_state == o.oper_state &&
      oper_state_qual == o.oper_state_qual &&
      port_id == o.port_id &&
      role == o.role &&
      slot_id == o.slot_id &&
      switch_id == o.switch_id
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
# File 'lib/intersight_client/models/port_physical_all_of.rb', line 264

def _deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = IntersightClient.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



335
336
337
338
339
340
341
342
343
344
345
346
347
# File 'lib/intersight_client/models/port_physical_all_of.rb', line 335

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
# File 'lib/intersight_client/models/port_physical_all_of.rb', line 241

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  PortPhysicalAllOf.openapi_types.each_pair do |key, type|
    if attributes[PortPhysicalAllOf.attribute_map[key]].nil? && PortPhysicalAllOf.openapi_nullable.include?(key)
      self.send("#{key}=", nil)
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[PortPhysicalAllOf.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[PortPhysicalAllOf.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[PortPhysicalAllOf.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[PortPhysicalAllOf.attribute_map[key]]))
    end
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


221
222
223
# File 'lib/intersight_client/models/port_physical_all_of.rb', line 221

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



227
228
229
# File 'lib/intersight_client/models/port_physical_all_of.rb', line 227

def hash
  [class_id, object_type, oper_state, oper_state_qual, port_id, role, slot_id, switch_id].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



159
160
161
162
163
164
165
166
167
168
169
170
# File 'lib/intersight_client/models/port_physical_all_of.rb', line 159

def list_invalid_properties
  invalid_properties = Array.new
  if @class_id.nil?
    invalid_properties.push('invalid value for "class_id", class_id cannot be nil.')
  end

  if @object_type.nil?
    invalid_properties.push('invalid value for "object_type", object_type cannot be nil.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



311
312
313
# File 'lib/intersight_client/models/port_physical_all_of.rb', line 311

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



317
318
319
320
321
322
323
324
325
326
327
328
329
# File 'lib/intersight_client/models/port_physical_all_of.rb', line 317

def to_hash
  hash = {}
  PortPhysicalAllOf.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = PortPhysicalAllOf.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



305
306
307
# File 'lib/intersight_client/models/port_physical_all_of.rb', line 305

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



174
175
176
177
178
179
180
181
182
# File 'lib/intersight_client/models/port_physical_all_of.rb', line 174

def valid?
  return false if @class_id.nil?
  class_id_validator = EnumAttributeValidator.new('String', ["ether.HostPort", "ether.PhysicalPort", "fc.PhysicalPort"])
  return false unless class_id_validator.valid?(@class_id)
  return false if @object_type.nil?
  object_type_validator = EnumAttributeValidator.new('String', ["ether.HostPort", "ether.PhysicalPort", "fc.PhysicalPort"])
  return false unless object_type_validator.valid?(@object_type)
  true
end