Class: IntersightClient::ResourceReservation
- Defined in:
- lib/intersight_client/models/resource_reservation.rb
Overview
A Reservation is used to reserve a place for a new resource in the resource groups.
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#account ⇒ Object
Returns the value of attribute account.
-
#class_id ⇒ Object
The fully-qualified name of the instantiated, concrete type.
-
#expiration ⇒ Object
Expiration of the resource Reservation.
-
#groups ⇒ Object
An array of relationships to resourceGroup resources.
-
#mark_fail ⇒ Object
MarkFail is used to set the reservation status to Failed.
-
#object_type ⇒ Object
The fully-qualified name of the instantiated, concrete type.
-
#resource_moids ⇒ Object
Returns the value of attribute resource_moids.
-
#resource_type ⇒ Object
Type of resources which will get filled into the resource groups.
-
#status ⇒ Object
Status of the Reservation.
-
#user_moid ⇒ Object
Moid of the user who created the reservation.
Attributes inherited from MoBaseMo
#account_moid, #ancestors, #create_time, #display_names, #domain_group_moid, #mod_time, #moid, #owners, #parent, #permission_resources, #shared_scope, #tags, #version_context
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns the key-value map of all the JSON attributes this model knows about, including the ones defined in its parent(s).
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about, including the ones defined in its parent(s).
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_all_of ⇒ Object
List of class defined in allOf (OpenAPI v3).
-
.openapi_discriminator_name ⇒ Object
discriminator’s property name in OpenAPI v3.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ResourceReservation
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ ResourceReservation
Initializes the object
134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 |
# File 'lib/intersight_client/models/resource_reservation.rb', line 134 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `IntersightClient::ResourceReservation` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `#{self.class.name}`. Please check the name to make sure it's valid. List of attributes: " + self.class.acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } # call parent's initialize super(attributes) if attributes.key?(:'class_id') self.class_id = attributes[:'class_id'] else self.class_id = 'resource.Reservation' end if attributes.key?(:'object_type') self.object_type = attributes[:'object_type'] else self.object_type = 'resource.Reservation' end if attributes.key?(:'expiration') self.expiration = attributes[:'expiration'] end if attributes.key?(:'mark_fail') self.mark_fail = attributes[:'mark_fail'] end if attributes.key?(:'resource_moids') if (value = attributes[:'resource_moids']).is_a?(Array) self.resource_moids = value end end if attributes.key?(:'resource_type') self.resource_type = attributes[:'resource_type'] end if attributes.key?(:'status') self.status = attributes[:'status'] else self.status = 'Created' end if attributes.key?(:'user_moid') self.user_moid = attributes[:'user_moid'] end if attributes.key?(:'account') self.account = attributes[:'account'] end if attributes.key?(:'groups') if (value = attributes[:'groups']).is_a?(Array) self.groups = value end end end |
Instance Attribute Details
#account ⇒ Object
Returns the value of attribute account.
42 43 44 |
# File 'lib/intersight_client/models/resource_reservation.rb', line 42 def account @account end |
#class_id ⇒ Object
The fully-qualified name of the instantiated, concrete type. This property is used as a discriminator to identify the type of the payload when marshaling and unmarshaling data.
20 21 22 |
# File 'lib/intersight_client/models/resource_reservation.rb', line 20 def class_id @class_id end |
#expiration ⇒ Object
Expiration of the resource Reservation.
26 27 28 |
# File 'lib/intersight_client/models/resource_reservation.rb', line 26 def expiration @expiration end |
#groups ⇒ Object
An array of relationships to resourceGroup resources.
45 46 47 |
# File 'lib/intersight_client/models/resource_reservation.rb', line 45 def groups @groups end |
#mark_fail ⇒ Object
MarkFail is used to set the reservation status to Failed.
29 30 31 |
# File 'lib/intersight_client/models/resource_reservation.rb', line 29 def mark_fail @mark_fail end |
#object_type ⇒ Object
The fully-qualified name of the instantiated, concrete type. The value should be the same as the ‘ClassId’ property.
23 24 25 |
# File 'lib/intersight_client/models/resource_reservation.rb', line 23 def object_type @object_type end |
#resource_moids ⇒ Object
Returns the value of attribute resource_moids.
31 32 33 |
# File 'lib/intersight_client/models/resource_reservation.rb', line 31 def resource_moids @resource_moids end |
#resource_type ⇒ Object
Type of resources which will get filled into the resource groups.
34 35 36 |
# File 'lib/intersight_client/models/resource_reservation.rb', line 34 def resource_type @resource_type end |
#status ⇒ Object
Status of the Reservation. * Created - By default, a reservation is in Created status. * Processing - A reservation is changed to Processing status for appliance mode resource claim requests. * Failed - A reservation is changed to Failed status if the validations on resources, resource groups fails. * Finished - A reservation is changed to Finished status if the validations on resources, resource groups are successful. The resource moids in reservation will be added to resource groups using OData filters.
37 38 39 |
# File 'lib/intersight_client/models/resource_reservation.rb', line 37 def status @status end |
#user_moid ⇒ Object
Moid of the user who created the reservation.
40 41 42 |
# File 'lib/intersight_client/models/resource_reservation.rb', line 40 def user_moid @user_moid end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns the key-value map of all the JSON attributes this model knows about, including the ones defined in its parent(s)
91 92 93 |
# File 'lib/intersight_client/models/resource_reservation.rb', line 91 def self.acceptable_attribute_map attribute_map.merge(superclass.acceptable_attribute_map) end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about, including the ones defined in its parent(s)
86 87 88 |
# File 'lib/intersight_client/models/resource_reservation.rb', line 86 def self.acceptable_attributes attribute_map.values.concat(superclass.acceptable_attributes) end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
70 71 72 73 74 75 76 77 78 79 80 81 82 83 |
# File 'lib/intersight_client/models/resource_reservation.rb', line 70 def self.attribute_map { :'class_id' => :'ClassId', :'object_type' => :'ObjectType', :'expiration' => :'Expiration', :'mark_fail' => :'MarkFail', :'resource_moids' => :'ResourceMoids', :'resource_type' => :'ResourceType', :'status' => :'Status', :'user_moid' => :'UserMoid', :'account' => :'Account', :'groups' => :'Groups' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
292 293 294 |
# File 'lib/intersight_client/models/resource_reservation.rb', line 292 def self.build_from_hash(attributes) new.build_from_hash(attributes) end |
.openapi_all_of ⇒ Object
List of class defined in allOf (OpenAPI v3)
120 121 122 123 124 125 |
# File 'lib/intersight_client/models/resource_reservation.rb', line 120 def self.openapi_all_of [ :'MoBaseMo', :'ResourceReservationAllOf' ] end |
.openapi_discriminator_name ⇒ Object
discriminator’s property name in OpenAPI v3
128 129 130 |
# File 'lib/intersight_client/models/resource_reservation.rb', line 128 def self.openapi_discriminator_name :'ClassId' end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
112 113 114 115 116 117 |
# File 'lib/intersight_client/models/resource_reservation.rb', line 112 def self.openapi_nullable Set.new([ :'resource_moids', :'groups' ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
96 97 98 99 100 101 102 103 104 105 106 107 108 109 |
# File 'lib/intersight_client/models/resource_reservation.rb', line 96 def self.openapi_types { :'class_id' => :'String', :'object_type' => :'String', :'expiration' => :'Time', :'mark_fail' => :'Boolean', :'resource_moids' => :'Array<String>', :'resource_type' => :'String', :'status' => :'String', :'user_moid' => :'String', :'account' => :'IamAccountRelationship', :'groups' => :'Array<ResourceGroupRelationship>' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
262 263 264 265 266 267 268 269 270 271 272 273 274 275 |
# File 'lib/intersight_client/models/resource_reservation.rb', line 262 def ==(o) return true if self.equal?(o) self.class == o.class && class_id == o.class_id && object_type == o.object_type && expiration == o.expiration && mark_fail == o.mark_fail && resource_moids == o.resource_moids && resource_type == o.resource_type && status == o.status && user_moid == o.user_moid && account == o.account && groups == o.groups && super(o) end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 |
# File 'lib/intersight_client/models/resource_reservation.rb', line 323 def _deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = IntersightClient.const_get(type) klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
394 395 396 397 398 399 400 401 402 403 404 405 406 |
# File 'lib/intersight_client/models/resource_reservation.rb', line 394 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 |
# File 'lib/intersight_client/models/resource_reservation.rb', line 299 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) super(attributes) ResourceReservation.openapi_types.each_pair do |key, type| if attributes[ResourceReservation.attribute_map[key]].nil? && ResourceReservation.openapi_nullable.include?(key) self.send("#{key}=", nil) elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[ResourceReservation.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[ResourceReservation.attribute_map[key]].map { |v| _deserialize($1, v) }) end elsif !attributes[ResourceReservation.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[ResourceReservation.attribute_map[key]])) end end self end |
#eql?(o) ⇒ Boolean
279 280 281 |
# File 'lib/intersight_client/models/resource_reservation.rb', line 279 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
285 286 287 |
# File 'lib/intersight_client/models/resource_reservation.rb', line 285 def hash [class_id, object_type, expiration, mark_fail, resource_moids, resource_type, status, user_moid, account, groups].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
203 204 205 206 207 208 209 210 211 212 213 214 |
# File 'lib/intersight_client/models/resource_reservation.rb', line 203 def list_invalid_properties invalid_properties = super if @class_id.nil? invalid_properties.push('invalid value for "class_id", class_id cannot be nil.') end if @object_type.nil? invalid_properties.push('invalid value for "object_type", object_type cannot be nil.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
370 371 372 |
# File 'lib/intersight_client/models/resource_reservation.rb', line 370 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
376 377 378 379 380 381 382 383 384 385 386 387 388 |
# File 'lib/intersight_client/models/resource_reservation.rb', line 376 def to_hash hash = super ResourceReservation.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = ResourceReservation.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
364 365 366 |
# File 'lib/intersight_client/models/resource_reservation.rb', line 364 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
218 219 220 221 222 223 224 225 226 227 228 |
# File 'lib/intersight_client/models/resource_reservation.rb', line 218 def valid? return false if @class_id.nil? class_id_validator = EnumAttributeValidator.new('String', ["resource.Reservation"]) return false unless class_id_validator.valid?(@class_id) return false if @object_type.nil? object_type_validator = EnumAttributeValidator.new('String', ["resource.Reservation"]) return false unless object_type_validator.valid?(@object_type) status_validator = EnumAttributeValidator.new('String', ["Created", "Processing", "Failed", "Finished"]) return false unless status_validator.valid?(@status) true && super end |