Class: IntersightClient::ResourcepoolLeaseAllOf

Inherits:
Object
  • Object
show all
Defined in:
lib/intersight_client/models/resourcepool_lease_all_of.rb

Overview

Definition of the list of properties defined in ‘resourcepool.Lease’, excluding properties defined in parent classes.

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ ResourcepoolLeaseAllOf

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
# File 'lib/intersight_client/models/resourcepool_lease_all_of.rb', line 125

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `IntersightClient::ResourcepoolLeaseAllOf` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `#{self.class.name}`. Please check the name to make sure it's valid. List of attributes: " + self.class.acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'class_id')
    self.class_id = attributes[:'class_id']
  else
    self.class_id = 'resourcepool.Lease'
  end

  if attributes.key?(:'object_type')
    self.object_type = attributes[:'object_type']
  else
    self.object_type = 'resourcepool.Lease'
  end

  if attributes.key?(:'condition')
    if (value = attributes[:'condition']).is_a?(Array)
      self.condition = value
    end
  end

  if attributes.key?(:'feature')
    self.feature = attributes[:'feature']
  end

  if attributes.key?(:'lease_parameters')
    self.lease_parameters = attributes[:'lease_parameters']
  end

  if attributes.key?(:'resource')
    self.resource = attributes[:'resource']
  end

  if attributes.key?(:'resource_type')
    self.resource_type = attributes[:'resource_type']
  else
    self.resource_type = 'None'
  end

  if attributes.key?(:'assigned_to_entity')
    self.assigned_to_entity = attributes[:'assigned_to_entity']
  end

  if attributes.key?(:'leased_resource')
    self.leased_resource = attributes[:'leased_resource']
  end

  if attributes.key?(:'pool')
    self.pool = attributes[:'pool']
  end

  if attributes.key?(:'pool_member')
    self.pool_member = attributes[:'pool_member']
  end

  if attributes.key?(:'universe')
    self.universe = attributes[:'universe']
  end
end

Instance Attribute Details

#assigned_to_entityObject

Returns the value of attribute assigned_to_entity.



37
38
39
# File 'lib/intersight_client/models/resourcepool_lease_all_of.rb', line 37

def assigned_to_entity
  @assigned_to_entity
end

#class_idObject

The fully-qualified name of the instantiated, concrete type. This property is used as a discriminator to identify the type of the payload when marshaling and unmarshaling data.



20
21
22
# File 'lib/intersight_client/models/resourcepool_lease_all_of.rb', line 20

def class_id
  @class_id
end

#conditionObject

Returns the value of attribute condition.



25
26
27
# File 'lib/intersight_client/models/resourcepool_lease_all_of.rb', line 25

def condition
  @condition
end

#featureObject

Lease opertion applied for the feature.



28
29
30
# File 'lib/intersight_client/models/resourcepool_lease_all_of.rb', line 28

def feature
  @feature
end

#lease_parametersObject

Returns the value of attribute lease_parameters.



30
31
32
# File 'lib/intersight_client/models/resourcepool_lease_all_of.rb', line 30

def lease_parameters
  @lease_parameters
end

#leased_resourceObject

Returns the value of attribute leased_resource.



39
40
41
# File 'lib/intersight_client/models/resourcepool_lease_all_of.rb', line 39

def leased_resource
  @leased_resource
end

#object_typeObject

The fully-qualified name of the instantiated, concrete type. The value should be the same as the ‘ClassId’ property.



23
24
25
# File 'lib/intersight_client/models/resourcepool_lease_all_of.rb', line 23

def object_type
  @object_type
end

#poolObject

Returns the value of attribute pool.



41
42
43
# File 'lib/intersight_client/models/resourcepool_lease_all_of.rb', line 41

def pool
  @pool
end

#pool_memberObject

Returns the value of attribute pool_member.



43
44
45
# File 'lib/intersight_client/models/resourcepool_lease_all_of.rb', line 43

def pool_member
  @pool_member
end

#resourceObject

Returns the value of attribute resource.



32
33
34
# File 'lib/intersight_client/models/resourcepool_lease_all_of.rb', line 32

def resource
  @resource
end

#resource_typeObject

The type of the resource present in the pool, example ‘server’ its combination of RackUnit and Blade. * None - The resource cannot consider for Resource Pool. * Server - Resource Pool holds the server kind of resources, example - RackServer, Blade.



35
36
37
# File 'lib/intersight_client/models/resourcepool_lease_all_of.rb', line 35

def resource_type
  @resource_type
end

#universeObject

Returns the value of attribute universe.



45
46
47
# File 'lib/intersight_client/models/resourcepool_lease_all_of.rb', line 45

def universe
  @universe
end

Class Method Details

.acceptable_attribute_mapObject

Returns the key-value map of all the JSON attributes this model knows about



93
94
95
# File 'lib/intersight_client/models/resourcepool_lease_all_of.rb', line 93

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



88
89
90
# File 'lib/intersight_client/models/resourcepool_lease_all_of.rb', line 88

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
# File 'lib/intersight_client/models/resourcepool_lease_all_of.rb', line 70

def self.attribute_map
  {
    :'class_id' => :'ClassId',
    :'object_type' => :'ObjectType',
    :'condition' => :'Condition',
    :'feature' => :'Feature',
    :'lease_parameters' => :'LeaseParameters',
    :'resource' => :'Resource',
    :'resource_type' => :'ResourceType',
    :'assigned_to_entity' => :'AssignedToEntity',
    :'leased_resource' => :'LeasedResource',
    :'pool' => :'Pool',
    :'pool_member' => :'PoolMember',
    :'universe' => :'Universe'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



288
289
290
# File 'lib/intersight_client/models/resourcepool_lease_all_of.rb', line 288

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_nullableObject

List of attributes with nullable: true



116
117
118
119
120
121
# File 'lib/intersight_client/models/resourcepool_lease_all_of.rb', line 116

def self.openapi_nullable
  Set.new([
    :'condition',
    :'lease_parameters',
  ])
end

.openapi_typesObject

Attribute type mapping.



98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
# File 'lib/intersight_client/models/resourcepool_lease_all_of.rb', line 98

def self.openapi_types
  {
    :'class_id' => :'String',
    :'object_type' => :'String',
    :'condition' => :'Array<ResourceSelector>',
    :'feature' => :'String',
    :'lease_parameters' => :'ResourcepoolLeaseParameters',
    :'resource' => :'MoBaseMo',
    :'resource_type' => :'String',
    :'assigned_to_entity' => :'MoBaseMoRelationship',
    :'leased_resource' => :'ResourcepoolLeaseResourceRelationship',
    :'pool' => :'ResourcepoolPoolRelationship',
    :'pool_member' => :'ResourcepoolPoolMemberRelationship',
    :'universe' => :'ResourcepoolUniverseRelationship'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
# File 'lib/intersight_client/models/resourcepool_lease_all_of.rb', line 256

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      class_id == o.class_id &&
      object_type == o.object_type &&
      condition == o.condition &&
      feature == o.feature &&
      lease_parameters == o.lease_parameters &&
      resource == o.resource &&
      resource_type == o.resource_type &&
      assigned_to_entity == o.assigned_to_entity &&
      leased_resource == o.leased_resource &&
      pool == o.pool &&
      pool_member == o.pool_member &&
      universe == o.universe
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
# File 'lib/intersight_client/models/resourcepool_lease_all_of.rb', line 318

def _deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = IntersightClient.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



389
390
391
392
393
394
395
396
397
398
399
400
401
# File 'lib/intersight_client/models/resourcepool_lease_all_of.rb', line 389

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
# File 'lib/intersight_client/models/resourcepool_lease_all_of.rb', line 295

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  ResourcepoolLeaseAllOf.openapi_types.each_pair do |key, type|
    if attributes[ResourcepoolLeaseAllOf.attribute_map[key]].nil? && ResourcepoolLeaseAllOf.openapi_nullable.include?(key)
      self.send("#{key}=", nil)
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[ResourcepoolLeaseAllOf.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[ResourcepoolLeaseAllOf.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[ResourcepoolLeaseAllOf.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[ResourcepoolLeaseAllOf.attribute_map[key]]))
    end
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


275
276
277
# File 'lib/intersight_client/models/resourcepool_lease_all_of.rb', line 275

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



281
282
283
# File 'lib/intersight_client/models/resourcepool_lease_all_of.rb', line 281

def hash
  [class_id, object_type, condition, feature, lease_parameters, resource, resource_type, assigned_to_entity, leased_resource, pool, pool_member, universe].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



197
198
199
200
201
202
203
204
205
206
207
208
# File 'lib/intersight_client/models/resourcepool_lease_all_of.rb', line 197

def list_invalid_properties
  invalid_properties = Array.new
  if @class_id.nil?
    invalid_properties.push('invalid value for "class_id", class_id cannot be nil.')
  end

  if @object_type.nil?
    invalid_properties.push('invalid value for "object_type", object_type cannot be nil.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



365
366
367
# File 'lib/intersight_client/models/resourcepool_lease_all_of.rb', line 365

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



371
372
373
374
375
376
377
378
379
380
381
382
383
# File 'lib/intersight_client/models/resourcepool_lease_all_of.rb', line 371

def to_hash
  hash = {}
  ResourcepoolLeaseAllOf.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = ResourcepoolLeaseAllOf.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



359
360
361
# File 'lib/intersight_client/models/resourcepool_lease_all_of.rb', line 359

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



212
213
214
215
216
217
218
219
220
221
222
# File 'lib/intersight_client/models/resourcepool_lease_all_of.rb', line 212

def valid?
  return false if @class_id.nil?
  class_id_validator = EnumAttributeValidator.new('String', ["resourcepool.Lease"])
  return false unless class_id_validator.valid?(@class_id)
  return false if @object_type.nil?
  object_type_validator = EnumAttributeValidator.new('String', ["resourcepool.Lease"])
  return false unless object_type_validator.valid?(@object_type)
  resource_type_validator = EnumAttributeValidator.new('String', ["None", "Server"])
  return false unless resource_type_validator.valid?(@resource_type)
  true
end