Class: IntersightClient::SoftwarerepositoryCachedImage
- Inherits:
-
ConnectorDownloadStatus
- Object
- MoBaseMo
- ConnectorDownloadStatus
- IntersightClient::SoftwarerepositoryCachedImage
- Defined in:
- lib/intersight_client/models/softwarerepository_cached_image.rb
Overview
The image cached in the customer’s datacenter.
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#action ⇒ Object
The action to be performed on the imported file.
-
#cache_state ⇒ Object
The state of this file in the endpoint The importState is updated during the cache operation and as part of the cache monitoring process.
-
#cached_time ⇒ Object
The time when the image or file was cached into the FI storage.
-
#class_id ⇒ Object
The fully-qualified name of the instantiated, concrete type.
-
#file ⇒ Object
Returns the value of attribute file.
-
#last_access_time ⇒ Object
Used by the cache monitoring process to determine the files that are to be evicted from the cache.
-
#md5sum ⇒ Object
The MD5 sum of the firmware image that will be used by the endpoint to validate the integrity of the image.
-
#network_element ⇒ Object
Returns the value of attribute network_element.
-
#object_type ⇒ Object
The fully-qualified name of the instantiated, concrete type.
-
#original_sha512sum ⇒ Object
The actual sha512sum of the cached image.
-
#path ⇒ Object
The absolute path of the imported file in the endpoint.
-
#registered_workflows ⇒ Object
Returns the value of attribute registered_workflows.
-
#used_count ⇒ Object
The number of times this file has been used to copy or upgrade or install actions.
Attributes inherited from ConnectorDownloadStatus
#checksum, #download_error, #download_progress, #download_retries, #sha256checksum
Attributes inherited from MoBaseMo
#account_moid, #ancestors, #create_time, #display_names, #domain_group_moid, #mod_time, #moid, #owners, #parent, #permission_resources, #shared_scope, #tags, #version_context
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns the key-value map of all the JSON attributes this model knows about, including the ones defined in its parent(s).
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about, including the ones defined in its parent(s).
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_all_of ⇒ Object
List of class defined in allOf (OpenAPI v3).
-
.openapi_discriminator_name ⇒ Object
discriminator’s property name in OpenAPI v3.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ SoftwarerepositoryCachedImage
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ SoftwarerepositoryCachedImage
Initializes the object
147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 |
# File 'lib/intersight_client/models/softwarerepository_cached_image.rb', line 147 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `IntersightClient::SoftwarerepositoryCachedImage` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `#{self.class.name}`. Please check the name to make sure it's valid. List of attributes: " + self.class.acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } # call parent's initialize super(attributes) if attributes.key?(:'class_id') self.class_id = attributes[:'class_id'] else self.class_id = 'softwarerepository.CachedImage' end if attributes.key?(:'object_type') self.object_type = attributes[:'object_type'] else self.object_type = 'softwarerepository.CachedImage' end if attributes.key?(:'action') self.action = attributes[:'action'] else self.action = 'None' end if attributes.key?(:'cache_state') self.cache_state = attributes[:'cache_state'] else self.cache_state = 'ReadyForImport' end if attributes.key?(:'cached_time') self.cached_time = attributes[:'cached_time'] end if attributes.key?(:'last_access_time') self.last_access_time = attributes[:'last_access_time'] end if attributes.key?(:'md5sum') self.md5sum = attributes[:'md5sum'] end if attributes.key?(:'original_sha512sum') self.original_sha512sum = attributes[:'original_sha512sum'] end if attributes.key?(:'path') self.path = attributes[:'path'] end if attributes.key?(:'registered_workflows') if (value = attributes[:'registered_workflows']).is_a?(Array) self.registered_workflows = value end end if attributes.key?(:'used_count') self.used_count = attributes[:'used_count'] end if attributes.key?(:'file') self.file = attributes[:'file'] end if attributes.key?(:'network_element') self.network_element = attributes[:'network_element'] end end |
Instance Attribute Details
#action ⇒ Object
The action to be performed on the imported file. If ‘PreCache’ is set, the image will be cached in endpoint. If ‘Evict’ is set, the cached file will be removed. Applicable in Intersight appliance deployment. If ‘Cancel’ is set, the ImportState is marked as ‘Failed’. Applicable for local machine source. * None - No action should be taken on the imported file. * GeneratePreSignedUploadUrl - Generate pre signed URL of file for importing into the repository. * GeneratePreSignedDownloadUrl - Generate pre signed URL of file in the repository to download. * CompleteImportProcess - Mark that the import process of the file into the repository is complete. * MarkImportFailed - Mark to indicate that the import process of the file into the repository failed. * PreCache - Cache the file into the Intersight Appliance. * Cancel - The cancel import process for the file into the repository. * Extract - The action to extract the file in the external repository. * Evict - Evict the cached file from the Intersight Appliance.
26 27 28 |
# File 'lib/intersight_client/models/softwarerepository_cached_image.rb', line 26 def action @action end |
#cache_state ⇒ Object
The state of this file in the endpoint The importState is updated during the cache operation and as part of the cache monitoring process. * ReadyForImport - The image is ready to be imported into the repository. * Importing - The image is being imported into the repository. * Imported - The image has been extracted and imported into the repository. * PendingExtraction - Indicates that the image has been imported but not extracted in the repository. * Extracting - Indicates that the image is being extracted into the repository. * Extracted - Indicates that the image has been extracted into the repository. * Failed - The image import from an external source to the repository has failed. * MetaOnly - The image is present in an external repository. * ReadyForCache - The image is ready to be cached into the Intersight Appliance. * Caching - Indicates that the image is being cached into the Intersight Appliance or endpoint cache. * Cached - Indicates that the image has been cached into the Intersight Appliance or endpoint cache. * CachingFailed - Indicates that the image caching into the Intersight Appliance failed or endpoint cache. * Corrupted - Indicates that the image in the local repository (or endpoint cache) has been corrupted after it was cached. * Evicted - Indicates that the image has been evicted from the Intersight Appliance (or endpoint cache) to reclaim storage space. * Invalid - Indicates that the corresponding distributable MO has been removed from the backend. This can be due to unpublishing of an image.
29 30 31 |
# File 'lib/intersight_client/models/softwarerepository_cached_image.rb', line 29 def cache_state @cache_state end |
#cached_time ⇒ Object
The time when the image or file was cached into the FI storage.
32 33 34 |
# File 'lib/intersight_client/models/softwarerepository_cached_image.rb', line 32 def cached_time @cached_time end |
#class_id ⇒ Object
The fully-qualified name of the instantiated, concrete type. This property is used as a discriminator to identify the type of the payload when marshaling and unmarshaling data.
20 21 22 |
# File 'lib/intersight_client/models/softwarerepository_cached_image.rb', line 20 def class_id @class_id end |
#file ⇒ Object
Returns the value of attribute file.
51 52 53 |
# File 'lib/intersight_client/models/softwarerepository_cached_image.rb', line 51 def file @file end |
#last_access_time ⇒ Object
Used by the cache monitoring process to determine the files that are to be evicted from the cache.
35 36 37 |
# File 'lib/intersight_client/models/softwarerepository_cached_image.rb', line 35 def last_access_time @last_access_time end |
#md5sum ⇒ Object
The MD5 sum of the firmware image that will be used by the endpoint to validate the integrity of the image.
38 39 40 |
# File 'lib/intersight_client/models/softwarerepository_cached_image.rb', line 38 def md5sum @md5sum end |
#network_element ⇒ Object
Returns the value of attribute network_element.
53 54 55 |
# File 'lib/intersight_client/models/softwarerepository_cached_image.rb', line 53 def network_element @network_element end |
#object_type ⇒ Object
The fully-qualified name of the instantiated, concrete type. The value should be the same as the ‘ClassId’ property.
23 24 25 |
# File 'lib/intersight_client/models/softwarerepository_cached_image.rb', line 23 def object_type @object_type end |
#original_sha512sum ⇒ Object
The actual sha512sum of the cached image.
41 42 43 |
# File 'lib/intersight_client/models/softwarerepository_cached_image.rb', line 41 def original_sha512sum @original_sha512sum end |
#path ⇒ Object
The absolute path of the imported file in the endpoint.
44 45 46 |
# File 'lib/intersight_client/models/softwarerepository_cached_image.rb', line 44 def path @path end |
#registered_workflows ⇒ Object
Returns the value of attribute registered_workflows.
46 47 48 |
# File 'lib/intersight_client/models/softwarerepository_cached_image.rb', line 46 def registered_workflows @registered_workflows end |
#used_count ⇒ Object
The number of times this file has been used to copy or upgrade or install actions. Used by the cache monitoring process to determine the files to be evicted from the cache.
49 50 51 |
# File 'lib/intersight_client/models/softwarerepository_cached_image.rb', line 49 def used_count @used_count end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns the key-value map of all the JSON attributes this model knows about, including the ones defined in its parent(s)
102 103 104 |
# File 'lib/intersight_client/models/softwarerepository_cached_image.rb', line 102 def self.acceptable_attribute_map attribute_map.merge(superclass.acceptable_attribute_map) end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about, including the ones defined in its parent(s)
97 98 99 |
# File 'lib/intersight_client/models/softwarerepository_cached_image.rb', line 97 def self.acceptable_attributes attribute_map.values.concat(superclass.acceptable_attributes) end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 |
# File 'lib/intersight_client/models/softwarerepository_cached_image.rb', line 78 def self.attribute_map { :'class_id' => :'ClassId', :'object_type' => :'ObjectType', :'action' => :'Action', :'cache_state' => :'CacheState', :'cached_time' => :'CachedTime', :'last_access_time' => :'LastAccessTime', :'md5sum' => :'Md5sum', :'original_sha512sum' => :'OriginalSha512sum', :'path' => :'Path', :'registered_workflows' => :'RegisteredWorkflows', :'used_count' => :'UsedCount', :'file' => :'File', :'network_element' => :'NetworkElement' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
332 333 334 |
# File 'lib/intersight_client/models/softwarerepository_cached_image.rb', line 332 def self.build_from_hash(attributes) new.build_from_hash(attributes) end |
.openapi_all_of ⇒ Object
List of class defined in allOf (OpenAPI v3)
133 134 135 136 137 138 |
# File 'lib/intersight_client/models/softwarerepository_cached_image.rb', line 133 def self.openapi_all_of [ :'ConnectorDownloadStatus', :'SoftwarerepositoryCachedImageAllOf' ] end |
.openapi_discriminator_name ⇒ Object
discriminator’s property name in OpenAPI v3
141 142 143 |
# File 'lib/intersight_client/models/softwarerepository_cached_image.rb', line 141 def self.openapi_discriminator_name :'ClassId' end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
126 127 128 129 130 |
# File 'lib/intersight_client/models/softwarerepository_cached_image.rb', line 126 def self.openapi_nullable Set.new([ :'registered_workflows', ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 |
# File 'lib/intersight_client/models/softwarerepository_cached_image.rb', line 107 def self.openapi_types { :'class_id' => :'String', :'object_type' => :'String', :'action' => :'String', :'cache_state' => :'String', :'cached_time' => :'Time', :'last_access_time' => :'Time', :'md5sum' => :'String', :'original_sha512sum' => :'String', :'path' => :'String', :'registered_workflows' => :'Array<String>', :'used_count' => :'Integer', :'file' => :'SoftwarerepositoryFileRelationship', :'network_element' => :'NetworkElementRelationship' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 |
# File 'lib/intersight_client/models/softwarerepository_cached_image.rb', line 299 def ==(o) return true if self.equal?(o) self.class == o.class && class_id == o.class_id && object_type == o.object_type && action == o.action && cache_state == o.cache_state && cached_time == o.cached_time && last_access_time == o.last_access_time && md5sum == o.md5sum && original_sha512sum == o.original_sha512sum && path == o.path && registered_workflows == o.registered_workflows && used_count == o.used_count && file == o.file && network_element == o.network_element && super(o) end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 |
# File 'lib/intersight_client/models/softwarerepository_cached_image.rb', line 363 def _deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = IntersightClient.const_get(type) klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
434 435 436 437 438 439 440 441 442 443 444 445 446 |
# File 'lib/intersight_client/models/softwarerepository_cached_image.rb', line 434 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 |
# File 'lib/intersight_client/models/softwarerepository_cached_image.rb', line 339 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) super(attributes) SoftwarerepositoryCachedImage.openapi_types.each_pair do |key, type| if attributes[SoftwarerepositoryCachedImage.attribute_map[key]].nil? && SoftwarerepositoryCachedImage.openapi_nullable.include?(key) self.send("#{key}=", nil) elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[SoftwarerepositoryCachedImage.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[SoftwarerepositoryCachedImage.attribute_map[key]].map { |v| _deserialize($1, v) }) end elsif !attributes[SoftwarerepositoryCachedImage.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[SoftwarerepositoryCachedImage.attribute_map[key]])) end end self end |
#eql?(o) ⇒ Boolean
319 320 321 |
# File 'lib/intersight_client/models/softwarerepository_cached_image.rb', line 319 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
325 326 327 |
# File 'lib/intersight_client/models/softwarerepository_cached_image.rb', line 325 def hash [class_id, object_type, action, cache_state, cached_time, last_access_time, md5sum, original_sha512sum, path, registered_workflows, used_count, file, network_element].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
228 229 230 231 232 233 234 235 236 237 238 239 |
# File 'lib/intersight_client/models/softwarerepository_cached_image.rb', line 228 def list_invalid_properties invalid_properties = super if @class_id.nil? invalid_properties.push('invalid value for "class_id", class_id cannot be nil.') end if @object_type.nil? invalid_properties.push('invalid value for "object_type", object_type cannot be nil.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
410 411 412 |
# File 'lib/intersight_client/models/softwarerepository_cached_image.rb', line 410 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
416 417 418 419 420 421 422 423 424 425 426 427 428 |
# File 'lib/intersight_client/models/softwarerepository_cached_image.rb', line 416 def to_hash hash = super SoftwarerepositoryCachedImage.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = SoftwarerepositoryCachedImage.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
404 405 406 |
# File 'lib/intersight_client/models/softwarerepository_cached_image.rb', line 404 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
243 244 245 246 247 248 249 250 251 252 253 254 255 |
# File 'lib/intersight_client/models/softwarerepository_cached_image.rb', line 243 def valid? return false if @class_id.nil? class_id_validator = EnumAttributeValidator.new('String', ["softwarerepository.CachedImage"]) return false unless class_id_validator.valid?(@class_id) return false if @object_type.nil? object_type_validator = EnumAttributeValidator.new('String', ["softwarerepository.CachedImage"]) return false unless object_type_validator.valid?(@object_type) action_validator = EnumAttributeValidator.new('String', ["None", "GeneratePreSignedUploadUrl", "GeneratePreSignedDownloadUrl", "CompleteImportProcess", "MarkImportFailed", "PreCache", "Cancel", "Extract", "Evict"]) return false unless action_validator.valid?(@action) cache_state_validator = EnumAttributeValidator.new('String', ["ReadyForImport", "Importing", "Imported", "PendingExtraction", "Extracting", "Extracted", "Failed", "MetaOnly", "ReadyForCache", "Caching", "Cached", "CachingFailed", "Corrupted", "Evicted", "Invalid"]) return false unless cache_state_validator.valid?(@cache_state) true && super end |