Class: IntersightClient::StorageAutomaticDriveGroupAllOf
- Inherits:
-
Object
- Object
- IntersightClient::StorageAutomaticDriveGroupAllOf
- Defined in:
- lib/intersight_client/models/storage_automatic_drive_group_all_of.rb
Overview
Definition of the list of properties defined in ‘storage.AutomaticDriveGroup’, excluding properties defined in parent classes.
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#class_id ⇒ Object
The fully-qualified name of the instantiated, concrete type.
-
#drive_type ⇒ Object
Type of drive that should be used for this RAID group.
-
#drives_per_span ⇒ Object
Number of drives within this span group.
-
#minimum_drive_size ⇒ Object
Minimum size of the drive to be used for creating this RAID group.
-
#num_dedicated_hot_spares ⇒ Object
Number of dedicated hot spare disks for this RAID group.
-
#number_of_spans ⇒ Object
Number of span groups to be created for this RAID group.
-
#object_type ⇒ Object
The fully-qualified name of the instantiated, concrete type.
-
#use_remaining_drives ⇒ Object
This flag enables the drive group to use all the remaining drives on the server.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns the key-value map of all the JSON attributes this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ StorageAutomaticDriveGroupAllOf
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ StorageAutomaticDriveGroupAllOf
Initializes the object
111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 |
# File 'lib/intersight_client/models/storage_automatic_drive_group_all_of.rb', line 111 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `IntersightClient::StorageAutomaticDriveGroupAllOf` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `#{self.class.name}`. Please check the name to make sure it's valid. List of attributes: " + self.class.acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'class_id') self.class_id = attributes[:'class_id'] else self.class_id = 'storage.AutomaticDriveGroup' end if attributes.key?(:'object_type') self.object_type = attributes[:'object_type'] else self.object_type = 'storage.AutomaticDriveGroup' end if attributes.key?(:'drive_type') self.drive_type = attributes[:'drive_type'] else self.drive_type = 'Any' end if attributes.key?(:'drives_per_span') self.drives_per_span = attributes[:'drives_per_span'] end if attributes.key?(:'minimum_drive_size') self.minimum_drive_size = attributes[:'minimum_drive_size'] end if attributes.key?(:'num_dedicated_hot_spares') self.num_dedicated_hot_spares = attributes[:'num_dedicated_hot_spares'] end if attributes.key?(:'number_of_spans') self.number_of_spans = attributes[:'number_of_spans'] else self.number_of_spans = 0 end if attributes.key?(:'use_remaining_drives') self.use_remaining_drives = attributes[:'use_remaining_drives'] end end |
Instance Attribute Details
#class_id ⇒ Object
The fully-qualified name of the instantiated, concrete type. This property is used as a discriminator to identify the type of the payload when marshaling and unmarshaling data.
20 21 22 |
# File 'lib/intersight_client/models/storage_automatic_drive_group_all_of.rb', line 20 def class_id @class_id end |
#drive_type ⇒ Object
Type of drive that should be used for this RAID group. * Any - Any type of drive can be used for virtual drive creation. * HDD - Hard disk drives should be used for virtual drive creation. * SSD - Solid state drives should be used for virtual drive creation.
26 27 28 |
# File 'lib/intersight_client/models/storage_automatic_drive_group_all_of.rb', line 26 def drive_type @drive_type end |
#drives_per_span ⇒ Object
Number of drives within this span group. The minimum number of disks needed in a span group varies based on RAID level. RAID0 requires at least one disk. RAID1 and RAID10 requires at least 2 and in multiples of . RAID5 and RAID50 require at least 3 disks in a span group. RAID6 and RAID60 require atleast 4 disks in a span.
29 30 31 |
# File 'lib/intersight_client/models/storage_automatic_drive_group_all_of.rb', line 29 def drives_per_span @drives_per_span end |
#minimum_drive_size ⇒ Object
Minimum size of the drive to be used for creating this RAID group.
32 33 34 |
# File 'lib/intersight_client/models/storage_automatic_drive_group_all_of.rb', line 32 def minimum_drive_size @minimum_drive_size end |
#num_dedicated_hot_spares ⇒ Object
Number of dedicated hot spare disks for this RAID group. Allowed value is a comma or hyphen separated number range.
35 36 37 |
# File 'lib/intersight_client/models/storage_automatic_drive_group_all_of.rb', line 35 def num_dedicated_hot_spares @num_dedicated_hot_spares end |
#number_of_spans ⇒ Object
Number of span groups to be created for this RAID group. Non-nested RAID levels have a single span.
38 39 40 |
# File 'lib/intersight_client/models/storage_automatic_drive_group_all_of.rb', line 38 def number_of_spans @number_of_spans end |
#object_type ⇒ Object
The fully-qualified name of the instantiated, concrete type. The value should be the same as the ‘ClassId’ property.
23 24 25 |
# File 'lib/intersight_client/models/storage_automatic_drive_group_all_of.rb', line 23 def object_type @object_type end |
#use_remaining_drives ⇒ Object
This flag enables the drive group to use all the remaining drives on the server.
41 42 43 |
# File 'lib/intersight_client/models/storage_automatic_drive_group_all_of.rb', line 41 def use_remaining_drives @use_remaining_drives end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns the key-value map of all the JSON attributes this model knows about
85 86 87 |
# File 'lib/intersight_client/models/storage_automatic_drive_group_all_of.rb', line 85 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
80 81 82 |
# File 'lib/intersight_client/models/storage_automatic_drive_group_all_of.rb', line 80 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
66 67 68 69 70 71 72 73 74 75 76 77 |
# File 'lib/intersight_client/models/storage_automatic_drive_group_all_of.rb', line 66 def self.attribute_map { :'class_id' => :'ClassId', :'object_type' => :'ObjectType', :'drive_type' => :'DriveType', :'drives_per_span' => :'DrivesPerSpan', :'minimum_drive_size' => :'MinimumDriveSize', :'num_dedicated_hot_spares' => :'NumDedicatedHotSpares', :'number_of_spans' => :'NumberOfSpans', :'use_remaining_drives' => :'UseRemainingDrives' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
319 320 321 |
# File 'lib/intersight_client/models/storage_automatic_drive_group_all_of.rb', line 319 def self.build_from_hash(attributes) new.build_from_hash(attributes) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
104 105 106 107 |
# File 'lib/intersight_client/models/storage_automatic_drive_group_all_of.rb', line 104 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
90 91 92 93 94 95 96 97 98 99 100 101 |
# File 'lib/intersight_client/models/storage_automatic_drive_group_all_of.rb', line 90 def self.openapi_types { :'class_id' => :'String', :'object_type' => :'String', :'drive_type' => :'String', :'drives_per_span' => :'Integer', :'minimum_drive_size' => :'Integer', :'num_dedicated_hot_spares' => :'String', :'number_of_spans' => :'Integer', :'use_remaining_drives' => :'Boolean' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
291 292 293 294 295 296 297 298 299 300 301 302 |
# File 'lib/intersight_client/models/storage_automatic_drive_group_all_of.rb', line 291 def ==(o) return true if self.equal?(o) self.class == o.class && class_id == o.class_id && object_type == o.object_type && drive_type == o.drive_type && drives_per_span == o.drives_per_span && minimum_drive_size == o.minimum_drive_size && num_dedicated_hot_spares == o.num_dedicated_hot_spares && number_of_spans == o.number_of_spans && use_remaining_drives == o.use_remaining_drives end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 |
# File 'lib/intersight_client/models/storage_automatic_drive_group_all_of.rb', line 349 def _deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = IntersightClient.const_get(type) klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
420 421 422 423 424 425 426 427 428 429 430 431 432 |
# File 'lib/intersight_client/models/storage_automatic_drive_group_all_of.rb', line 420 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 |
# File 'lib/intersight_client/models/storage_automatic_drive_group_all_of.rb', line 326 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) StorageAutomaticDriveGroupAllOf.openapi_types.each_pair do |key, type| if attributes[StorageAutomaticDriveGroupAllOf.attribute_map[key]].nil? && StorageAutomaticDriveGroupAllOf.openapi_nullable.include?(key) self.send("#{key}=", nil) elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[StorageAutomaticDriveGroupAllOf.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[StorageAutomaticDriveGroupAllOf.attribute_map[key]].map { |v| _deserialize($1, v) }) end elsif !attributes[StorageAutomaticDriveGroupAllOf.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[StorageAutomaticDriveGroupAllOf.attribute_map[key]])) end end self end |
#eql?(o) ⇒ Boolean
306 307 308 |
# File 'lib/intersight_client/models/storage_automatic_drive_group_all_of.rb', line 306 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
312 313 314 |
# File 'lib/intersight_client/models/storage_automatic_drive_group_all_of.rb', line 312 def hash [class_id, object_type, drive_type, drives_per_span, minimum_drive_size, num_dedicated_hot_spares, number_of_spans, use_remaining_drives].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 |
# File 'lib/intersight_client/models/storage_automatic_drive_group_all_of.rb', line 167 def list_invalid_properties invalid_properties = Array.new if @class_id.nil? invalid_properties.push('invalid value for "class_id", class_id cannot be nil.') end if @object_type.nil? invalid_properties.push('invalid value for "object_type", object_type cannot be nil.') end if !@drives_per_span.nil? && @drives_per_span > 100 invalid_properties.push('invalid value for "drives_per_span", must be smaller than or equal to 100.') end if !@drives_per_span.nil? && @drives_per_span < 1 invalid_properties.push('invalid value for "drives_per_span", must be greater than or equal to 1.') end pattern = Regexp.new(/^$|^((\d+\-\d+)|(\d+))(,((\d+\-\d+)|(\d+)))*$/) if !@num_dedicated_hot_spares.nil? && @num_dedicated_hot_spares !~ pattern invalid_properties.push("invalid value for \"num_dedicated_hot_spares\", must conform to the pattern #{pattern}.") end if !@number_of_spans.nil? && @number_of_spans > 8 invalid_properties.push('invalid value for "number_of_spans", must be smaller than or equal to 8.') end if !@number_of_spans.nil? && @number_of_spans < 0 invalid_properties.push('invalid value for "number_of_spans", must be greater than or equal to 0.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
396 397 398 |
# File 'lib/intersight_client/models/storage_automatic_drive_group_all_of.rb', line 396 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
402 403 404 405 406 407 408 409 410 411 412 413 414 |
# File 'lib/intersight_client/models/storage_automatic_drive_group_all_of.rb', line 402 def to_hash hash = {} StorageAutomaticDriveGroupAllOf.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = StorageAutomaticDriveGroupAllOf.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
390 391 392 |
# File 'lib/intersight_client/models/storage_automatic_drive_group_all_of.rb', line 390 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 |
# File 'lib/intersight_client/models/storage_automatic_drive_group_all_of.rb', line 203 def valid? return false if @class_id.nil? class_id_validator = EnumAttributeValidator.new('String', ["storage.AutomaticDriveGroup"]) return false unless class_id_validator.valid?(@class_id) return false if @object_type.nil? object_type_validator = EnumAttributeValidator.new('String', ["storage.AutomaticDriveGroup"]) return false unless object_type_validator.valid?(@object_type) drive_type_validator = EnumAttributeValidator.new('String', ["Any", "HDD", "SSD"]) return false unless drive_type_validator.valid?(@drive_type) return false if !@drives_per_span.nil? && @drives_per_span > 100 return false if !@drives_per_span.nil? && @drives_per_span < 1 return false if !@num_dedicated_hot_spares.nil? && @num_dedicated_hot_spares !~ Regexp.new(/^$|^((\d+\-\d+)|(\d+))(,((\d+\-\d+)|(\d+)))*$/) return false if !@number_of_spans.nil? && @number_of_spans > 8 return false if !@number_of_spans.nil? && @number_of_spans < 0 true end |