Class: IntersightClient::StorageFlexFlashControllerAllOf

Inherits:
Object
  • Object
show all
Defined in:
lib/intersight_client/models/storage_flex_flash_controller_all_of.rb

Overview

Definition of the list of properties defined in ‘storage.FlexFlashController’, excluding properties defined in parent classes.

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ StorageFlexFlashControllerAllOf

Initializes the object



127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
# File 'lib/intersight_client/models/storage_flex_flash_controller_all_of.rb', line 127

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `IntersightClient::StorageFlexFlashControllerAllOf` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `#{self.class.name}`. Please check the name to make sure it's valid. List of attributes: " + self.class.acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'class_id')
    self.class_id = attributes[:'class_id']
  else
    self.class_id = 'storage.FlexFlashController'
  end

  if attributes.key?(:'object_type')
    self.object_type = attributes[:'object_type']
  else
    self.object_type = 'storage.FlexFlashController'
  end

  if attributes.key?(:'controller_state')
    self.controller_state = attributes[:'controller_state']
  end

  if attributes.key?(:'ff_controller_id')
    self.ff_controller_id = attributes[:'ff_controller_id']
  end

  if attributes.key?(:'compute_board')
    self.compute_board = attributes[:'compute_board']
  end

  if attributes.key?(:'flex_flash_controller_props')
    if (value = attributes[:'flex_flash_controller_props']).is_a?(Array)
      self.flex_flash_controller_props = value
    end
  end

  if attributes.key?(:'flex_flash_physical_drives')
    if (value = attributes[:'flex_flash_physical_drives']).is_a?(Array)
      self.flex_flash_physical_drives = value
    end
  end

  if attributes.key?(:'flex_flash_virtual_drives')
    if (value = attributes[:'flex_flash_virtual_drives']).is_a?(Array)
      self.flex_flash_virtual_drives = value
    end
  end

  if attributes.key?(:'inventory_device_info')
    self.inventory_device_info = attributes[:'inventory_device_info']
  end

  if attributes.key?(:'registered_device')
    self.registered_device = attributes[:'registered_device']
  end

  if attributes.key?(:'running_firmware')
    if (value = attributes[:'running_firmware']).is_a?(Array)
      self.running_firmware = value
    end
  end
end

Instance Attribute Details

#class_idObject

The fully-qualified name of the instantiated, concrete type. This property is used as a discriminator to identify the type of the payload when marshaling and unmarshaling data.



20
21
22
# File 'lib/intersight_client/models/storage_flex_flash_controller_all_of.rb', line 20

def class_id
  @class_id
end

#compute_boardObject

Returns the value of attribute compute_board.



31
32
33
# File 'lib/intersight_client/models/storage_flex_flash_controller_all_of.rb', line 31

def compute_board
  @compute_board
end

#controller_stateObject

State of the Flex Flash Storage Controller.



26
27
28
# File 'lib/intersight_client/models/storage_flex_flash_controller_all_of.rb', line 26

def controller_state
  @controller_state
end

#ff_controller_idObject

Identifier for the Flex Flash Storage Controller.



29
30
31
# File 'lib/intersight_client/models/storage_flex_flash_controller_all_of.rb', line 29

def ff_controller_id
  @ff_controller_id
end

#flex_flash_controller_propsObject

An array of relationships to storageFlexFlashControllerProps resources.



34
35
36
# File 'lib/intersight_client/models/storage_flex_flash_controller_all_of.rb', line 34

def flex_flash_controller_props
  @flex_flash_controller_props
end

#flex_flash_physical_drivesObject

An array of relationships to storageFlexFlashPhysicalDrive resources.



37
38
39
# File 'lib/intersight_client/models/storage_flex_flash_controller_all_of.rb', line 37

def flex_flash_physical_drives
  @flex_flash_physical_drives
end

#flex_flash_virtual_drivesObject

An array of relationships to storageFlexFlashVirtualDrive resources.



40
41
42
# File 'lib/intersight_client/models/storage_flex_flash_controller_all_of.rb', line 40

def flex_flash_virtual_drives
  @flex_flash_virtual_drives
end

#inventory_device_infoObject

Returns the value of attribute inventory_device_info.



42
43
44
# File 'lib/intersight_client/models/storage_flex_flash_controller_all_of.rb', line 42

def inventory_device_info
  @inventory_device_info
end

#object_typeObject

The fully-qualified name of the instantiated, concrete type. The value should be the same as the ‘ClassId’ property.



23
24
25
# File 'lib/intersight_client/models/storage_flex_flash_controller_all_of.rb', line 23

def object_type
  @object_type
end

#registered_deviceObject

Returns the value of attribute registered_device.



44
45
46
# File 'lib/intersight_client/models/storage_flex_flash_controller_all_of.rb', line 44

def registered_device
  @registered_device
end

#running_firmwareObject

An array of relationships to firmwareRunningFirmware resources.



47
48
49
# File 'lib/intersight_client/models/storage_flex_flash_controller_all_of.rb', line 47

def running_firmware
  @running_firmware
end

Class Method Details

.acceptable_attribute_mapObject

Returns the key-value map of all the JSON attributes this model knows about



94
95
96
# File 'lib/intersight_client/models/storage_flex_flash_controller_all_of.rb', line 94

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



89
90
91
# File 'lib/intersight_client/models/storage_flex_flash_controller_all_of.rb', line 89

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
# File 'lib/intersight_client/models/storage_flex_flash_controller_all_of.rb', line 72

def self.attribute_map
  {
    :'class_id' => :'ClassId',
    :'object_type' => :'ObjectType',
    :'controller_state' => :'ControllerState',
    :'ff_controller_id' => :'FfControllerId',
    :'compute_board' => :'ComputeBoard',
    :'flex_flash_controller_props' => :'FlexFlashControllerProps',
    :'flex_flash_physical_drives' => :'FlexFlashPhysicalDrives',
    :'flex_flash_virtual_drives' => :'FlexFlashVirtualDrives',
    :'inventory_device_info' => :'InventoryDeviceInfo',
    :'registered_device' => :'RegisteredDevice',
    :'running_firmware' => :'RunningFirmware'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash



277
278
279
# File 'lib/intersight_client/models/storage_flex_flash_controller_all_of.rb', line 277

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_nullableObject

List of attributes with nullable: true



116
117
118
119
120
121
122
123
# File 'lib/intersight_client/models/storage_flex_flash_controller_all_of.rb', line 116

def self.openapi_nullable
  Set.new([
    :'flex_flash_controller_props',
    :'flex_flash_physical_drives',
    :'flex_flash_virtual_drives',
    :'running_firmware'
  ])
end

.openapi_typesObject

Attribute type mapping.



99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
# File 'lib/intersight_client/models/storage_flex_flash_controller_all_of.rb', line 99

def self.openapi_types
  {
    :'class_id' => :'String',
    :'object_type' => :'String',
    :'controller_state' => :'String',
    :'ff_controller_id' => :'String',
    :'compute_board' => :'ComputeBoardRelationship',
    :'flex_flash_controller_props' => :'Array<StorageFlexFlashControllerPropsRelationship>',
    :'flex_flash_physical_drives' => :'Array<StorageFlexFlashPhysicalDriveRelationship>',
    :'flex_flash_virtual_drives' => :'Array<StorageFlexFlashVirtualDriveRelationship>',
    :'inventory_device_info' => :'InventoryDeviceInfoRelationship',
    :'registered_device' => :'AssetDeviceRegistrationRelationship',
    :'running_firmware' => :'Array<FirmwareRunningFirmwareRelationship>'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.



246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
# File 'lib/intersight_client/models/storage_flex_flash_controller_all_of.rb', line 246

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      class_id == o.class_id &&
      object_type == o.object_type &&
      controller_state == o.controller_state &&
      ff_controller_id == o.ff_controller_id &&
      compute_board == o.compute_board &&
      flex_flash_controller_props == o.flex_flash_controller_props &&
      flex_flash_physical_drives == o.flex_flash_physical_drives &&
      flex_flash_virtual_drives == o.flex_flash_virtual_drives &&
      inventory_device_info == o.inventory_device_info &&
      registered_device == o.registered_device &&
      running_firmware == o.running_firmware
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type



307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
# File 'lib/intersight_client/models/storage_flex_flash_controller_all_of.rb', line 307

def _deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = IntersightClient.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value



378
379
380
381
382
383
384
385
386
387
388
389
390
# File 'lib/intersight_client/models/storage_flex_flash_controller_all_of.rb', line 378

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash



284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
# File 'lib/intersight_client/models/storage_flex_flash_controller_all_of.rb', line 284

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  StorageFlexFlashControllerAllOf.openapi_types.each_pair do |key, type|
    if attributes[StorageFlexFlashControllerAllOf.attribute_map[key]].nil? && StorageFlexFlashControllerAllOf.openapi_nullable.include?(key)
      self.send("#{key}=", nil)
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[StorageFlexFlashControllerAllOf.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[StorageFlexFlashControllerAllOf.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[StorageFlexFlashControllerAllOf.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[StorageFlexFlashControllerAllOf.attribute_map[key]]))
    end
  end

  self
end

#eql?(o) ⇒ Boolean

See Also:

  • `==` method


264
265
266
# File 'lib/intersight_client/models/storage_flex_flash_controller_all_of.rb', line 264

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.



270
271
272
# File 'lib/intersight_client/models/storage_flex_flash_controller_all_of.rb', line 270

def hash
  [class_id, object_type, controller_state, ff_controller_id, compute_board, flex_flash_controller_props, flex_flash_physical_drives, flex_flash_virtual_drives, inventory_device_info, registered_device, running_firmware].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?



199
200
201
202
203
204
205
206
207
208
209
210
# File 'lib/intersight_client/models/storage_flex_flash_controller_all_of.rb', line 199

def list_invalid_properties
  invalid_properties = Array.new
  if @class_id.nil?
    invalid_properties.push('invalid value for "class_id", class_id cannot be nil.')
  end

  if @object_type.nil?
    invalid_properties.push('invalid value for "object_type", object_type cannot be nil.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)



354
355
356
# File 'lib/intersight_client/models/storage_flex_flash_controller_all_of.rb', line 354

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash



360
361
362
363
364
365
366
367
368
369
370
371
372
# File 'lib/intersight_client/models/storage_flex_flash_controller_all_of.rb', line 360

def to_hash
  hash = {}
  StorageFlexFlashControllerAllOf.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = StorageFlexFlashControllerAllOf.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object



348
349
350
# File 'lib/intersight_client/models/storage_flex_flash_controller_all_of.rb', line 348

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid



214
215
216
217
218
219
220
221
222
# File 'lib/intersight_client/models/storage_flex_flash_controller_all_of.rb', line 214

def valid?
  return false if @class_id.nil?
  class_id_validator = EnumAttributeValidator.new('String', ["storage.FlexFlashController"])
  return false unless class_id_validator.valid?(@class_id)
  return false if @object_type.nil?
  object_type_validator = EnumAttributeValidator.new('String', ["storage.FlexFlashController"])
  return false unless object_type_validator.valid?(@object_type)
  true
end