Class: IntersightClient::StorageFlexUtilController

Inherits:
InventoryBase show all
Defined in:
lib/intersight_client/models/storage_flex_util_controller.rb

Overview

Storage Flex Util Adapter.

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Attributes inherited from InventoryBase

#device_mo_id, #dn, #rn

Attributes inherited from MoBaseMo

#account_moid, #ancestors, #create_time, #display_names, #domain_group_moid, #mod_time, #moid, #owners, #parent, #permission_resources, #shared_scope, #tags, #version_context

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ StorageFlexUtilController

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
# File 'lib/intersight_client/models/storage_flex_util_controller.rb', line 138

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `IntersightClient::StorageFlexUtilController` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `#{self.class.name}`. Please check the name to make sure it's valid. List of attributes: " + self.class.acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  # call parent's initialize
  super(attributes)

  if attributes.key?(:'class_id')
    self.class_id = attributes[:'class_id']
  else
    self.class_id = 'storage.FlexUtilController'
  end

  if attributes.key?(:'object_type')
    self.object_type = attributes[:'object_type']
  else
    self.object_type = 'storage.FlexUtilController'
  end

  if attributes.key?(:'controller_name')
    self.controller_name = attributes[:'controller_name']
  end

  if attributes.key?(:'controller_status')
    self.controller_status = attributes[:'controller_status']
  end

  if attributes.key?(:'ff_controller_id')
    self.ff_controller_id = attributes[:'ff_controller_id']
  end

  if attributes.key?(:'internal_state')
    self.internal_state = attributes[:'internal_state']
  end

  if attributes.key?(:'compute_board')
    self.compute_board = attributes[:'compute_board']
  end

  if attributes.key?(:'flex_util_physical_drives')
    if (value = attributes[:'flex_util_physical_drives']).is_a?(Array)
      self.flex_util_physical_drives = value
    end
  end

  if attributes.key?(:'flex_util_virtual_drives')
    if (value = attributes[:'flex_util_virtual_drives']).is_a?(Array)
      self.flex_util_virtual_drives = value
    end
  end

  if attributes.key?(:'inventory_device_info')
    self.inventory_device_info = attributes[:'inventory_device_info']
  end

  if attributes.key?(:'registered_device')
    self.registered_device = attributes[:'registered_device']
  end
end

Instance Attribute Details

#class_idObject

The fully-qualified name of the instantiated, concrete type. This property is used as a discriminator to identify the type of the payload when marshaling and unmarshaling data.



20
21
22
# File 'lib/intersight_client/models/storage_flex_util_controller.rb', line 20

def class_id
  @class_id
end

#compute_boardObject

Returns the value of attribute compute_board.



37
38
39
# File 'lib/intersight_client/models/storage_flex_util_controller.rb', line 37

def compute_board
  @compute_board
end

#controller_nameObject

Name of the Flex Util Controller.



26
27
28
# File 'lib/intersight_client/models/storage_flex_util_controller.rb', line 26

def controller_name
  @controller_name
end

#controller_statusObject

The current status of the controller.



29
30
31
# File 'lib/intersight_client/models/storage_flex_util_controller.rb', line 29

def controller_status
  @controller_status
end

#ff_controller_idObject

Identifier for the Storage Flex Util Controller.



32
33
34
# File 'lib/intersight_client/models/storage_flex_util_controller.rb', line 32

def ff_controller_id
  @ff_controller_id
end

#flex_util_physical_drivesObject

An array of relationships to storageFlexUtilPhysicalDrive resources.



40
41
42
# File 'lib/intersight_client/models/storage_flex_util_controller.rb', line 40

def flex_util_physical_drives
  @flex_util_physical_drives
end

#flex_util_virtual_drivesObject

An array of relationships to storageFlexUtilVirtualDrive resources.



43
44
45
# File 'lib/intersight_client/models/storage_flex_util_controller.rb', line 43

def flex_util_virtual_drives
  @flex_util_virtual_drives
end

#internal_stateObject

The internal state of the controller.



35
36
37
# File 'lib/intersight_client/models/storage_flex_util_controller.rb', line 35

def internal_state
  @internal_state
end

#inventory_device_infoObject

Returns the value of attribute inventory_device_info.



45
46
47
# File 'lib/intersight_client/models/storage_flex_util_controller.rb', line 45

def inventory_device_info
  @inventory_device_info
end

#object_typeObject

The fully-qualified name of the instantiated, concrete type. The value should be the same as the ‘ClassId’ property.



23
24
25
# File 'lib/intersight_client/models/storage_flex_util_controller.rb', line 23

def object_type
  @object_type
end

#registered_deviceObject

Returns the value of attribute registered_device.



47
48
49
# File 'lib/intersight_client/models/storage_flex_util_controller.rb', line 47

def registered_device
  @registered_device
end

Class Method Details

.acceptable_attribute_mapObject

Returns the key-value map of all the JSON attributes this model knows about, including the ones defined in its parent(s)



94
95
96
# File 'lib/intersight_client/models/storage_flex_util_controller.rb', line 94

def self.acceptable_attribute_map
  attribute_map.merge(superclass.acceptable_attribute_map)
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about, including the ones defined in its parent(s)



89
90
91
# File 'lib/intersight_client/models/storage_flex_util_controller.rb', line 89

def self.acceptable_attributes
  attribute_map.values.concat(superclass.acceptable_attributes)
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
# File 'lib/intersight_client/models/storage_flex_util_controller.rb', line 72

def self.attribute_map
  {
    :'class_id' => :'ClassId',
    :'object_type' => :'ObjectType',
    :'controller_name' => :'ControllerName',
    :'controller_status' => :'ControllerStatus',
    :'ff_controller_id' => :'FfControllerId',
    :'internal_state' => :'InternalState',
    :'compute_board' => :'ComputeBoard',
    :'flex_util_physical_drives' => :'FlexUtilPhysicalDrives',
    :'flex_util_virtual_drives' => :'FlexUtilVirtualDrives',
    :'inventory_device_info' => :'InventoryDeviceInfo',
    :'registered_device' => :'RegisteredDevice'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



287
288
289
# File 'lib/intersight_client/models/storage_flex_util_controller.rb', line 287

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_all_ofObject

List of class defined in allOf (OpenAPI v3)



124
125
126
127
128
129
# File 'lib/intersight_client/models/storage_flex_util_controller.rb', line 124

def self.openapi_all_of
  [
  :'InventoryBase',
  :'StorageFlexUtilControllerAllOf'
  ]
end

.openapi_discriminator_nameObject

discriminator’s property name in OpenAPI v3



132
133
134
# File 'lib/intersight_client/models/storage_flex_util_controller.rb', line 132

def self.openapi_discriminator_name
  :'ClassId'
end

.openapi_nullableObject

List of attributes with nullable: true



116
117
118
119
120
121
# File 'lib/intersight_client/models/storage_flex_util_controller.rb', line 116

def self.openapi_nullable
  Set.new([
    :'flex_util_physical_drives',
    :'flex_util_virtual_drives',
  ])
end

.openapi_typesObject

Attribute type mapping.



99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
# File 'lib/intersight_client/models/storage_flex_util_controller.rb', line 99

def self.openapi_types
  {
    :'class_id' => :'String',
    :'object_type' => :'String',
    :'controller_name' => :'String',
    :'controller_status' => :'String',
    :'ff_controller_id' => :'String',
    :'internal_state' => :'String',
    :'compute_board' => :'ComputeBoardRelationship',
    :'flex_util_physical_drives' => :'Array<StorageFlexUtilPhysicalDriveRelationship>',
    :'flex_util_virtual_drives' => :'Array<StorageFlexUtilVirtualDriveRelationship>',
    :'inventory_device_info' => :'InventoryDeviceInfoRelationship',
    :'registered_device' => :'AssetDeviceRegistrationRelationship'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
# File 'lib/intersight_client/models/storage_flex_util_controller.rb', line 256

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      class_id == o.class_id &&
      object_type == o.object_type &&
      controller_name == o.controller_name &&
      controller_status == o.controller_status &&
      ff_controller_id == o.ff_controller_id &&
      internal_state == o.internal_state &&
      compute_board == o.compute_board &&
      flex_util_physical_drives == o.flex_util_physical_drives &&
      flex_util_virtual_drives == o.flex_util_virtual_drives &&
      inventory_device_info == o.inventory_device_info &&
      registered_device == o.registered_device && super(o)
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
# File 'lib/intersight_client/models/storage_flex_util_controller.rb', line 318

def _deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = IntersightClient.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



389
390
391
392
393
394
395
396
397
398
399
400
401
# File 'lib/intersight_client/models/storage_flex_util_controller.rb', line 389

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
# File 'lib/intersight_client/models/storage_flex_util_controller.rb', line 294

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  super(attributes)
  StorageFlexUtilController.openapi_types.each_pair do |key, type|
    if attributes[StorageFlexUtilController.attribute_map[key]].nil? && StorageFlexUtilController.openapi_nullable.include?(key)
      self.send("#{key}=", nil)
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[StorageFlexUtilController.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[StorageFlexUtilController.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[StorageFlexUtilController.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[StorageFlexUtilController.attribute_map[key]]))
    end
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


274
275
276
# File 'lib/intersight_client/models/storage_flex_util_controller.rb', line 274

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



280
281
282
# File 'lib/intersight_client/models/storage_flex_util_controller.rb', line 280

def hash
  [class_id, object_type, controller_name, controller_status, ff_controller_id, internal_state, compute_board, flex_util_physical_drives, flex_util_virtual_drives, inventory_device_info, registered_device].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



209
210
211
212
213
214
215
216
217
218
219
220
# File 'lib/intersight_client/models/storage_flex_util_controller.rb', line 209

def list_invalid_properties
  invalid_properties = super
  if @class_id.nil?
    invalid_properties.push('invalid value for "class_id", class_id cannot be nil.')
  end

  if @object_type.nil?
    invalid_properties.push('invalid value for "object_type", object_type cannot be nil.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



365
366
367
# File 'lib/intersight_client/models/storage_flex_util_controller.rb', line 365

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



371
372
373
374
375
376
377
378
379
380
381
382
383
# File 'lib/intersight_client/models/storage_flex_util_controller.rb', line 371

def to_hash
  hash = super
  StorageFlexUtilController.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = StorageFlexUtilController.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



359
360
361
# File 'lib/intersight_client/models/storage_flex_util_controller.rb', line 359

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



224
225
226
227
228
229
230
231
232
# File 'lib/intersight_client/models/storage_flex_util_controller.rb', line 224

def valid?
  return false if @class_id.nil?
  class_id_validator = EnumAttributeValidator.new('String', ["storage.FlexUtilController"])
  return false unless class_id_validator.valid?(@class_id)
  return false if @object_type.nil?
  object_type_validator = EnumAttributeValidator.new('String', ["storage.FlexUtilController"])
  return false unless object_type_validator.valid?(@object_type)
  true && super
end