Class: IntersightClient::StorageFlexUtilVirtualDrive
- Inherits:
-
InventoryBase
- Object
- MoBaseMo
- InventoryBase
- IntersightClient::StorageFlexUtilVirtualDrive
- Defined in:
- lib/intersight_client/models/storage_flex_util_virtual_drive.rb
Overview
Storage Flex Util Virtual Drive.
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#class_id ⇒ Object
The fully-qualified name of the instantiated, concrete type.
-
#drive_status ⇒ Object
Status of the Flex Util virtual drive.
-
#drive_type ⇒ Object
Type of virtual drive managed by flex util controller.
-
#inventory_device_info ⇒ Object
Returns the value of attribute inventory_device_info.
-
#object_type ⇒ Object
The fully-qualified name of the instantiated, concrete type.
-
#partition_id ⇒ Object
Disk Partition Id of virtual drive managed by flex util controller.
-
#partition_name ⇒ Object
Partition name of the Flex Util virtual drive.
-
#registered_device ⇒ Object
Returns the value of attribute registered_device.
-
#resident_image ⇒ Object
The resident image on the flex util virtual Drive.
-
#size ⇒ Object
Size of the Flex Util virtual drive.
-
#storage_flex_util_controller ⇒ Object
Returns the value of attribute storage_flex_util_controller.
-
#virtual_drive ⇒ Object
Virtual drive on the Flex Util controller.
Attributes inherited from InventoryBase
Attributes inherited from MoBaseMo
#account_moid, #ancestors, #create_time, #display_names, #domain_group_moid, #mod_time, #moid, #owners, #parent, #permission_resources, #shared_scope, #tags, #version_context
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns the key-value map of all the JSON attributes this model knows about, including the ones defined in its parent(s).
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about, including the ones defined in its parent(s).
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_all_of ⇒ Object
List of class defined in allOf (OpenAPI v3).
-
.openapi_discriminator_name ⇒ Object
discriminator’s property name in OpenAPI v3.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ StorageFlexUtilVirtualDrive
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ StorageFlexUtilVirtualDrive
Initializes the object
141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 |
# File 'lib/intersight_client/models/storage_flex_util_virtual_drive.rb', line 141 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `IntersightClient::StorageFlexUtilVirtualDrive` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `#{self.class.name}`. Please check the name to make sure it's valid. List of attributes: " + self.class.acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } # call parent's initialize super(attributes) if attributes.key?(:'class_id') self.class_id = attributes[:'class_id'] else self.class_id = 'storage.FlexUtilVirtualDrive' end if attributes.key?(:'object_type') self.object_type = attributes[:'object_type'] else self.object_type = 'storage.FlexUtilVirtualDrive' end if attributes.key?(:'drive_status') self.drive_status = attributes[:'drive_status'] end if attributes.key?(:'drive_type') self.drive_type = attributes[:'drive_type'] end if attributes.key?(:'partition_id') self.partition_id = attributes[:'partition_id'] end if attributes.key?(:'partition_name') self.partition_name = attributes[:'partition_name'] end if attributes.key?(:'resident_image') self.resident_image = attributes[:'resident_image'] end if attributes.key?(:'size') self.size = attributes[:'size'] end if attributes.key?(:'virtual_drive') self.virtual_drive = attributes[:'virtual_drive'] end if attributes.key?(:'inventory_device_info') self.inventory_device_info = attributes[:'inventory_device_info'] end if attributes.key?(:'registered_device') self.registered_device = attributes[:'registered_device'] end if attributes.key?(:'storage_flex_util_controller') self.storage_flex_util_controller = attributes[:'storage_flex_util_controller'] end end |
Instance Attribute Details
#class_id ⇒ Object
The fully-qualified name of the instantiated, concrete type. This property is used as a discriminator to identify the type of the payload when marshaling and unmarshaling data.
20 21 22 |
# File 'lib/intersight_client/models/storage_flex_util_virtual_drive.rb', line 20 def class_id @class_id end |
#drive_status ⇒ Object
Status of the Flex Util virtual drive.
26 27 28 |
# File 'lib/intersight_client/models/storage_flex_util_virtual_drive.rb', line 26 def drive_status @drive_status end |
#drive_type ⇒ Object
Type of virtual drive managed by flex util controller.
29 30 31 |
# File 'lib/intersight_client/models/storage_flex_util_virtual_drive.rb', line 29 def drive_type @drive_type end |
#inventory_device_info ⇒ Object
Returns the value of attribute inventory_device_info.
46 47 48 |
# File 'lib/intersight_client/models/storage_flex_util_virtual_drive.rb', line 46 def inventory_device_info @inventory_device_info end |
#object_type ⇒ Object
The fully-qualified name of the instantiated, concrete type. The value should be the same as the ‘ClassId’ property.
23 24 25 |
# File 'lib/intersight_client/models/storage_flex_util_virtual_drive.rb', line 23 def object_type @object_type end |
#partition_id ⇒ Object
Disk Partition Id of virtual drive managed by flex util controller.
32 33 34 |
# File 'lib/intersight_client/models/storage_flex_util_virtual_drive.rb', line 32 def partition_id @partition_id end |
#partition_name ⇒ Object
Partition name of the Flex Util virtual drive.
35 36 37 |
# File 'lib/intersight_client/models/storage_flex_util_virtual_drive.rb', line 35 def partition_name @partition_name end |
#registered_device ⇒ Object
Returns the value of attribute registered_device.
48 49 50 |
# File 'lib/intersight_client/models/storage_flex_util_virtual_drive.rb', line 48 def registered_device @registered_device end |
#resident_image ⇒ Object
The resident image on the flex util virtual Drive.
38 39 40 |
# File 'lib/intersight_client/models/storage_flex_util_virtual_drive.rb', line 38 def resident_image @resident_image end |
#size ⇒ Object
Size of the Flex Util virtual drive.
41 42 43 |
# File 'lib/intersight_client/models/storage_flex_util_virtual_drive.rb', line 41 def size @size end |
#storage_flex_util_controller ⇒ Object
Returns the value of attribute storage_flex_util_controller.
50 51 52 |
# File 'lib/intersight_client/models/storage_flex_util_virtual_drive.rb', line 50 def storage_flex_util_controller @storage_flex_util_controller end |
#virtual_drive ⇒ Object
Virtual drive on the Flex Util controller.
44 45 46 |
# File 'lib/intersight_client/models/storage_flex_util_virtual_drive.rb', line 44 def virtual_drive @virtual_drive end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns the key-value map of all the JSON attributes this model knows about, including the ones defined in its parent(s)
98 99 100 |
# File 'lib/intersight_client/models/storage_flex_util_virtual_drive.rb', line 98 def self.acceptable_attribute_map attribute_map.merge(superclass.acceptable_attribute_map) end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about, including the ones defined in its parent(s)
93 94 95 |
# File 'lib/intersight_client/models/storage_flex_util_virtual_drive.rb', line 93 def self.acceptable_attributes attribute_map.values.concat(superclass.acceptable_attributes) end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 |
# File 'lib/intersight_client/models/storage_flex_util_virtual_drive.rb', line 75 def self.attribute_map { :'class_id' => :'ClassId', :'object_type' => :'ObjectType', :'drive_status' => :'DriveStatus', :'drive_type' => :'DriveType', :'partition_id' => :'PartitionId', :'partition_name' => :'PartitionName', :'resident_image' => :'ResidentImage', :'size' => :'Size', :'virtual_drive' => :'VirtualDrive', :'inventory_device_info' => :'InventoryDeviceInfo', :'registered_device' => :'RegisteredDevice', :'storage_flex_util_controller' => :'StorageFlexUtilController' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
291 292 293 |
# File 'lib/intersight_client/models/storage_flex_util_virtual_drive.rb', line 291 def self.build_from_hash(attributes) new.build_from_hash(attributes) end |
.openapi_all_of ⇒ Object
List of class defined in allOf (OpenAPI v3)
127 128 129 130 131 132 |
# File 'lib/intersight_client/models/storage_flex_util_virtual_drive.rb', line 127 def self.openapi_all_of [ :'InventoryBase', :'StorageFlexUtilVirtualDriveAllOf' ] end |
.openapi_discriminator_name ⇒ Object
discriminator’s property name in OpenAPI v3
135 136 137 |
# File 'lib/intersight_client/models/storage_flex_util_virtual_drive.rb', line 135 def self.openapi_discriminator_name :'ClassId' end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
121 122 123 124 |
# File 'lib/intersight_client/models/storage_flex_util_virtual_drive.rb', line 121 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 |
# File 'lib/intersight_client/models/storage_flex_util_virtual_drive.rb', line 103 def self.openapi_types { :'class_id' => :'String', :'object_type' => :'String', :'drive_status' => :'String', :'drive_type' => :'String', :'partition_id' => :'String', :'partition_name' => :'String', :'resident_image' => :'String', :'size' => :'String', :'virtual_drive' => :'String', :'inventory_device_info' => :'InventoryDeviceInfoRelationship', :'registered_device' => :'AssetDeviceRegistrationRelationship', :'storage_flex_util_controller' => :'StorageFlexUtilControllerRelationship' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 |
# File 'lib/intersight_client/models/storage_flex_util_virtual_drive.rb', line 259 def ==(o) return true if self.equal?(o) self.class == o.class && class_id == o.class_id && object_type == o.object_type && drive_status == o.drive_status && drive_type == o.drive_type && partition_id == o.partition_id && partition_name == o.partition_name && resident_image == o.resident_image && size == o.size && virtual_drive == o.virtual_drive && inventory_device_info == o.inventory_device_info && registered_device == o.registered_device && storage_flex_util_controller == o.storage_flex_util_controller && super(o) end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 |
# File 'lib/intersight_client/models/storage_flex_util_virtual_drive.rb', line 322 def _deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = IntersightClient.const_get(type) klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
393 394 395 396 397 398 399 400 401 402 403 404 405 |
# File 'lib/intersight_client/models/storage_flex_util_virtual_drive.rb', line 393 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 |
# File 'lib/intersight_client/models/storage_flex_util_virtual_drive.rb', line 298 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) super(attributes) StorageFlexUtilVirtualDrive.openapi_types.each_pair do |key, type| if attributes[StorageFlexUtilVirtualDrive.attribute_map[key]].nil? && StorageFlexUtilVirtualDrive.openapi_nullable.include?(key) self.send("#{key}=", nil) elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[StorageFlexUtilVirtualDrive.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[StorageFlexUtilVirtualDrive.attribute_map[key]].map { |v| _deserialize($1, v) }) end elsif !attributes[StorageFlexUtilVirtualDrive.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[StorageFlexUtilVirtualDrive.attribute_map[key]])) end end self end |
#eql?(o) ⇒ Boolean
278 279 280 |
# File 'lib/intersight_client/models/storage_flex_util_virtual_drive.rb', line 278 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
284 285 286 |
# File 'lib/intersight_client/models/storage_flex_util_virtual_drive.rb', line 284 def hash [class_id, object_type, drive_status, drive_type, partition_id, partition_name, resident_image, size, virtual_drive, inventory_device_info, registered_device, storage_flex_util_controller].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
212 213 214 215 216 217 218 219 220 221 222 223 |
# File 'lib/intersight_client/models/storage_flex_util_virtual_drive.rb', line 212 def list_invalid_properties invalid_properties = super if @class_id.nil? invalid_properties.push('invalid value for "class_id", class_id cannot be nil.') end if @object_type.nil? invalid_properties.push('invalid value for "object_type", object_type cannot be nil.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
369 370 371 |
# File 'lib/intersight_client/models/storage_flex_util_virtual_drive.rb', line 369 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
375 376 377 378 379 380 381 382 383 384 385 386 387 |
# File 'lib/intersight_client/models/storage_flex_util_virtual_drive.rb', line 375 def to_hash hash = super StorageFlexUtilVirtualDrive.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = StorageFlexUtilVirtualDrive.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
363 364 365 |
# File 'lib/intersight_client/models/storage_flex_util_virtual_drive.rb', line 363 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
227 228 229 230 231 232 233 234 235 |
# File 'lib/intersight_client/models/storage_flex_util_virtual_drive.rb', line 227 def valid? return false if @class_id.nil? class_id_validator = EnumAttributeValidator.new('String', ["storage.FlexUtilVirtualDrive"]) return false unless class_id_validator.valid?(@class_id) return false if @object_type.nil? object_type_validator = EnumAttributeValidator.new('String', ["storage.FlexUtilVirtualDrive"]) return false unless object_type_validator.valid?(@object_type) true && super end |