Class: IntersightClient::StorageNetAppEthernetPortLag
- Inherits:
-
MoBaseComplexType
- Object
- MoBaseComplexType
- IntersightClient::StorageNetAppEthernetPortLag
- Defined in:
- lib/intersight_client/models/storage_net_app_ethernet_port_lag.rb
Overview
Storage port of type lag.
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#active_ports ⇒ Object
Returns the value of attribute active_ports.
-
#class_id ⇒ Object
The fully-qualified name of the instantiated, concrete type.
-
#distribution_policy ⇒ Object
Policy for mapping flows to ports for outbound packets through a LAG (ifgrp).
-
#member_ports ⇒ Object
Returns the value of attribute member_ports.
-
#mode ⇒ Object
Determines how the ports interact with the switch.
-
#object_type ⇒ Object
The fully-qualified name of the instantiated, concrete type.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns the key-value map of all the JSON attributes this model knows about, including the ones defined in its parent(s).
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about, including the ones defined in its parent(s).
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_all_of ⇒ Object
List of class defined in allOf (OpenAPI v3).
-
.openapi_discriminator_name ⇒ Object
discriminator’s property name in OpenAPI v3.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ StorageNetAppEthernetPortLag
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ StorageNetAppEthernetPortLag
Initializes the object
114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 |
# File 'lib/intersight_client/models/storage_net_app_ethernet_port_lag.rb', line 114 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `IntersightClient::StorageNetAppEthernetPortLag` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `#{self.class.name}`. Please check the name to make sure it's valid. List of attributes: " + self.class.acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } # call parent's initialize super(attributes) if attributes.key?(:'class_id') self.class_id = attributes[:'class_id'] else self.class_id = 'storage.NetAppEthernetPortLag' end if attributes.key?(:'object_type') self.object_type = attributes[:'object_type'] else self.object_type = 'storage.NetAppEthernetPortLag' end if attributes.key?(:'active_ports') if (value = attributes[:'active_ports']).is_a?(Array) self.active_ports = value end end if attributes.key?(:'distribution_policy') self.distribution_policy = attributes[:'distribution_policy'] else self.distribution_policy = 'none' end if attributes.key?(:'member_ports') if (value = attributes[:'member_ports']).is_a?(Array) self.member_ports = value end end if attributes.key?(:'mode') self.mode = attributes[:'mode'] else self.mode = 'none' end end |
Instance Attribute Details
#active_ports ⇒ Object
Returns the value of attribute active_ports.
25 26 27 |
# File 'lib/intersight_client/models/storage_net_app_ethernet_port_lag.rb', line 25 def active_ports @active_ports end |
#class_id ⇒ Object
The fully-qualified name of the instantiated, concrete type. This property is used as a discriminator to identify the type of the payload when marshaling and unmarshaling data.
20 21 22 |
# File 'lib/intersight_client/models/storage_net_app_ethernet_port_lag.rb', line 20 def class_id @class_id end |
#distribution_policy ⇒ Object
Policy for mapping flows to ports for outbound packets through a LAG (ifgrp). * none - Default unknown distribution policy type. * port - Network traffic is distributed based on the transport layer (TCP/UDP) ports. * ip - Network traffic is distributed based on IP addresses. * mac - Network traffic is distributed based on MAC addresses. * sequential - Network traffic is distributed in round-robin fashion from the list of configured, available ports.
28 29 30 |
# File 'lib/intersight_client/models/storage_net_app_ethernet_port_lag.rb', line 28 def distribution_policy @distribution_policy end |
#member_ports ⇒ Object
Returns the value of attribute member_ports.
30 31 32 |
# File 'lib/intersight_client/models/storage_net_app_ethernet_port_lag.rb', line 30 def member_ports @member_ports end |
#mode ⇒ Object
Determines how the ports interact with the switch. * none - Default unknown lag mode type. * multimode_lacp - Bundle multiple member ports of the interface group using Link Aggregation Control Protocol. * multimode - Bundle multiple member ports of the interface group to act as a single trunked port. * singlemode - Provide port redundancy using member ports of the interface group for failover.
33 34 35 |
# File 'lib/intersight_client/models/storage_net_app_ethernet_port_lag.rb', line 33 def mode @mode end |
#object_type ⇒ Object
The fully-qualified name of the instantiated, concrete type. The value should be the same as the ‘ClassId’ property.
23 24 25 |
# File 'lib/intersight_client/models/storage_net_app_ethernet_port_lag.rb', line 23 def object_type @object_type end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns the key-value map of all the JSON attributes this model knows about, including the ones defined in its parent(s)
75 76 77 |
# File 'lib/intersight_client/models/storage_net_app_ethernet_port_lag.rb', line 75 def self.acceptable_attribute_map attribute_map.merge(superclass.acceptable_attribute_map) end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about, including the ones defined in its parent(s)
70 71 72 |
# File 'lib/intersight_client/models/storage_net_app_ethernet_port_lag.rb', line 70 def self.acceptable_attributes attribute_map.values.concat(superclass.acceptable_attributes) end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
58 59 60 61 62 63 64 65 66 67 |
# File 'lib/intersight_client/models/storage_net_app_ethernet_port_lag.rb', line 58 def self.attribute_map { :'class_id' => :'ClassId', :'object_type' => :'ObjectType', :'active_ports' => :'ActivePorts', :'distribution_policy' => :'DistributionPolicy', :'member_ports' => :'MemberPorts', :'mode' => :'Mode' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
266 267 268 |
# File 'lib/intersight_client/models/storage_net_app_ethernet_port_lag.rb', line 266 def self.build_from_hash(attributes) new.build_from_hash(attributes) end |
.openapi_all_of ⇒ Object
List of class defined in allOf (OpenAPI v3)
100 101 102 103 104 105 |
# File 'lib/intersight_client/models/storage_net_app_ethernet_port_lag.rb', line 100 def self.openapi_all_of [ :'MoBaseComplexType', :'StorageNetAppEthernetPortLagAllOf' ] end |
.openapi_discriminator_name ⇒ Object
discriminator’s property name in OpenAPI v3
108 109 110 |
# File 'lib/intersight_client/models/storage_net_app_ethernet_port_lag.rb', line 108 def self.openapi_discriminator_name :'ClassId' end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
92 93 94 95 96 97 |
# File 'lib/intersight_client/models/storage_net_app_ethernet_port_lag.rb', line 92 def self.openapi_nullable Set.new([ :'active_ports', :'member_ports', ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
80 81 82 83 84 85 86 87 88 89 |
# File 'lib/intersight_client/models/storage_net_app_ethernet_port_lag.rb', line 80 def self.openapi_types { :'class_id' => :'String', :'object_type' => :'String', :'active_ports' => :'Array<StorageNetAppPort>', :'distribution_policy' => :'String', :'member_ports' => :'Array<StorageNetAppPort>', :'mode' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
240 241 242 243 244 245 246 247 248 249 |
# File 'lib/intersight_client/models/storage_net_app_ethernet_port_lag.rb', line 240 def ==(o) return true if self.equal?(o) self.class == o.class && class_id == o.class_id && object_type == o.object_type && active_ports == o.active_ports && distribution_policy == o.distribution_policy && member_ports == o.member_ports && mode == o.mode && super(o) end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 |
# File 'lib/intersight_client/models/storage_net_app_ethernet_port_lag.rb', line 297 def _deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = IntersightClient.const_get(type) klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
368 369 370 371 372 373 374 375 376 377 378 379 380 |
# File 'lib/intersight_client/models/storage_net_app_ethernet_port_lag.rb', line 368 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 |
# File 'lib/intersight_client/models/storage_net_app_ethernet_port_lag.rb', line 273 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) super(attributes) StorageNetAppEthernetPortLag.openapi_types.each_pair do |key, type| if attributes[StorageNetAppEthernetPortLag.attribute_map[key]].nil? && StorageNetAppEthernetPortLag.openapi_nullable.include?(key) self.send("#{key}=", nil) elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[StorageNetAppEthernetPortLag.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[StorageNetAppEthernetPortLag.attribute_map[key]].map { |v| _deserialize($1, v) }) end elsif !attributes[StorageNetAppEthernetPortLag.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[StorageNetAppEthernetPortLag.attribute_map[key]])) end end self end |
#eql?(o) ⇒ Boolean
253 254 255 |
# File 'lib/intersight_client/models/storage_net_app_ethernet_port_lag.rb', line 253 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
259 260 261 |
# File 'lib/intersight_client/models/storage_net_app_ethernet_port_lag.rb', line 259 def hash [class_id, object_type, active_ports, distribution_policy, member_ports, mode].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
169 170 171 172 173 174 175 176 177 178 179 180 |
# File 'lib/intersight_client/models/storage_net_app_ethernet_port_lag.rb', line 169 def list_invalid_properties invalid_properties = super if @class_id.nil? invalid_properties.push('invalid value for "class_id", class_id cannot be nil.') end if @object_type.nil? invalid_properties.push('invalid value for "object_type", object_type cannot be nil.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
344 345 346 |
# File 'lib/intersight_client/models/storage_net_app_ethernet_port_lag.rb', line 344 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
350 351 352 353 354 355 356 357 358 359 360 361 362 |
# File 'lib/intersight_client/models/storage_net_app_ethernet_port_lag.rb', line 350 def to_hash hash = super StorageNetAppEthernetPortLag.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = StorageNetAppEthernetPortLag.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
338 339 340 |
# File 'lib/intersight_client/models/storage_net_app_ethernet_port_lag.rb', line 338 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
184 185 186 187 188 189 190 191 192 193 194 195 196 |
# File 'lib/intersight_client/models/storage_net_app_ethernet_port_lag.rb', line 184 def valid? return false if @class_id.nil? class_id_validator = EnumAttributeValidator.new('String', ["storage.NetAppEthernetPortLag"]) return false unless class_id_validator.valid?(@class_id) return false if @object_type.nil? object_type_validator = EnumAttributeValidator.new('String', ["storage.NetAppEthernetPortLag"]) return false unless object_type_validator.valid?(@object_type) distribution_policy_validator = EnumAttributeValidator.new('String', ["none", "port", "ip", "mac", "sequential"]) return false unless distribution_policy_validator.valid?(@distribution_policy) mode_validator = EnumAttributeValidator.new('String', ["none", "multimode_lacp", "multimode", "singlemode"]) return false unless mode_validator.valid?(@mode) true && super end |