Class: IntersightClient::StorageNetAppExportPolicy

Inherits:
StorageBaseNfsExport show all
Defined in:
lib/intersight_client/models/storage_net_app_export_policy.rb

Overview

NetApp export policies enable client access control to volumes. Clients that match specific IP addresses and/or specific authentication types are granted access.

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Attributes inherited from StorageBaseNfsExport

#name, #uuid

Attributes inherited from MoBaseMo

#account_moid, #ancestors, #create_time, #display_names, #domain_group_moid, #mod_time, #moid, #owners, #parent, #permission_resources, #shared_scope, #tags, #version_context

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ StorageNetAppExportPolicy

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
# File 'lib/intersight_client/models/storage_net_app_export_policy.rb', line 117

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `IntersightClient::StorageNetAppExportPolicy` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `#{self.class.name}`. Please check the name to make sure it's valid. List of attributes: " + self.class.acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  # call parent's initialize
  super(attributes)

  if attributes.key?(:'class_id')
    self.class_id = attributes[:'class_id']
  else
    self.class_id = 'storage.NetAppExportPolicy'
  end

  if attributes.key?(:'object_type')
    self.object_type = attributes[:'object_type']
  else
    self.object_type = 'storage.NetAppExportPolicy'
  end

  if attributes.key?(:'cluster_uuid')
    self.cluster_uuid = attributes[:'cluster_uuid']
  end

  if attributes.key?(:'net_app_export_policy_rule')
    if (value = attributes[:'net_app_export_policy_rule']).is_a?(Array)
      self.net_app_export_policy_rule = value
    end
  end

  if attributes.key?(:'policy_id')
    self.policy_id = attributes[:'policy_id']
  end

  if attributes.key?(:'array')
    self.array = attributes[:'array']
  end

  if attributes.key?(:'tenant')
    self.tenant = attributes[:'tenant']
  end
end

Instance Attribute Details

#arrayObject

Returns the value of attribute array.



33
34
35
# File 'lib/intersight_client/models/storage_net_app_export_policy.rb', line 33

def array
  @array
end

#class_idObject

The fully-qualified name of the instantiated, concrete type. This property is used as a discriminator to identify the type of the payload when marshaling and unmarshaling data.



20
21
22
# File 'lib/intersight_client/models/storage_net_app_export_policy.rb', line 20

def class_id
  @class_id
end

#cluster_uuidObject

Unique identity of the device.



26
27
28
# File 'lib/intersight_client/models/storage_net_app_export_policy.rb', line 26

def cluster_uuid
  @cluster_uuid
end

#net_app_export_policy_ruleObject

Returns the value of attribute net_app_export_policy_rule.



28
29
30
# File 'lib/intersight_client/models/storage_net_app_export_policy.rb', line 28

def net_app_export_policy_rule
  @net_app_export_policy_rule
end

#object_typeObject

The fully-qualified name of the instantiated, concrete type. The value should be the same as the ‘ClassId’ property.



23
24
25
# File 'lib/intersight_client/models/storage_net_app_export_policy.rb', line 23

def object_type
  @object_type
end

#policy_idObject

ID for the Export Policy.



31
32
33
# File 'lib/intersight_client/models/storage_net_app_export_policy.rb', line 31

def policy_id
  @policy_id
end

#tenantObject

Returns the value of attribute tenant.



35
36
37
# File 'lib/intersight_client/models/storage_net_app_export_policy.rb', line 35

def tenant
  @tenant
end

Class Method Details

.acceptable_attribute_mapObject

Returns the key-value map of all the JSON attributes this model knows about, including the ones defined in its parent(s)



78
79
80
# File 'lib/intersight_client/models/storage_net_app_export_policy.rb', line 78

def self.acceptable_attribute_map
  attribute_map.merge(superclass.acceptable_attribute_map)
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about, including the ones defined in its parent(s)



73
74
75
# File 'lib/intersight_client/models/storage_net_app_export_policy.rb', line 73

def self.acceptable_attributes
  attribute_map.values.concat(superclass.acceptable_attributes)
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



60
61
62
63
64
65
66
67
68
69
70
# File 'lib/intersight_client/models/storage_net_app_export_policy.rb', line 60

def self.attribute_map
  {
    :'class_id' => :'ClassId',
    :'object_type' => :'ObjectType',
    :'cluster_uuid' => :'ClusterUuid',
    :'net_app_export_policy_rule' => :'NetAppExportPolicyRule',
    :'policy_id' => :'PolicyId',
    :'array' => :'Array',
    :'tenant' => :'Tenant'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



261
262
263
# File 'lib/intersight_client/models/storage_net_app_export_policy.rb', line 261

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_all_ofObject

List of class defined in allOf (OpenAPI v3)



103
104
105
106
107
108
# File 'lib/intersight_client/models/storage_net_app_export_policy.rb', line 103

def self.openapi_all_of
  [
  :'StorageBaseNfsExport',
  :'StorageNetAppExportPolicyAllOf'
  ]
end

.openapi_discriminator_nameObject

discriminator’s property name in OpenAPI v3



111
112
113
# File 'lib/intersight_client/models/storage_net_app_export_policy.rb', line 111

def self.openapi_discriminator_name
  :'ClassId'
end

.openapi_nullableObject

List of attributes with nullable: true



96
97
98
99
100
# File 'lib/intersight_client/models/storage_net_app_export_policy.rb', line 96

def self.openapi_nullable
  Set.new([
    :'net_app_export_policy_rule',
  ])
end

.openapi_typesObject

Attribute type mapping.



83
84
85
86
87
88
89
90
91
92
93
# File 'lib/intersight_client/models/storage_net_app_export_policy.rb', line 83

def self.openapi_types
  {
    :'class_id' => :'String',
    :'object_type' => :'String',
    :'cluster_uuid' => :'String',
    :'net_app_export_policy_rule' => :'Array<StorageNetAppExportPolicyRule>',
    :'policy_id' => :'Integer',
    :'array' => :'StorageNetAppClusterRelationship',
    :'tenant' => :'StorageNetAppStorageVmRelationship'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



234
235
236
237
238
239
240
241
242
243
244
# File 'lib/intersight_client/models/storage_net_app_export_policy.rb', line 234

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      class_id == o.class_id &&
      object_type == o.object_type &&
      cluster_uuid == o.cluster_uuid &&
      net_app_export_policy_rule == o.net_app_export_policy_rule &&
      policy_id == o.policy_id &&
      array == o.array &&
      tenant == o.tenant && super(o)
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
# File 'lib/intersight_client/models/storage_net_app_export_policy.rb', line 292

def _deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = IntersightClient.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



363
364
365
366
367
368
369
370
371
372
373
374
375
# File 'lib/intersight_client/models/storage_net_app_export_policy.rb', line 363

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
# File 'lib/intersight_client/models/storage_net_app_export_policy.rb', line 268

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  super(attributes)
  StorageNetAppExportPolicy.openapi_types.each_pair do |key, type|
    if attributes[StorageNetAppExportPolicy.attribute_map[key]].nil? && StorageNetAppExportPolicy.openapi_nullable.include?(key)
      self.send("#{key}=", nil)
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[StorageNetAppExportPolicy.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[StorageNetAppExportPolicy.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[StorageNetAppExportPolicy.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[StorageNetAppExportPolicy.attribute_map[key]]))
    end
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


248
249
250
# File 'lib/intersight_client/models/storage_net_app_export_policy.rb', line 248

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



254
255
256
# File 'lib/intersight_client/models/storage_net_app_export_policy.rb', line 254

def hash
  [class_id, object_type, cluster_uuid, net_app_export_policy_rule, policy_id, array, tenant].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
# File 'lib/intersight_client/models/storage_net_app_export_policy.rb', line 170

def list_invalid_properties
  invalid_properties = super
  if @class_id.nil?
    invalid_properties.push('invalid value for "class_id", class_id cannot be nil.')
  end

  if @object_type.nil?
    invalid_properties.push('invalid value for "object_type", object_type cannot be nil.')
  end

  pattern = Regexp.new(/^$|^[0-9a-fA-F]{8}-[0-9a-fA-F]{4}-[0-9a-fA-F]{4}-[0-9a-fA-F]{4}-[0-9a-fA-F]{12}$/)
  if !@cluster_uuid.nil? && @cluster_uuid !~ pattern
    invalid_properties.push("invalid value for \"cluster_uuid\", must conform to the pattern #{pattern}.")
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



339
340
341
# File 'lib/intersight_client/models/storage_net_app_export_policy.rb', line 339

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



345
346
347
348
349
350
351
352
353
354
355
356
357
# File 'lib/intersight_client/models/storage_net_app_export_policy.rb', line 345

def to_hash
  hash = super
  StorageNetAppExportPolicy.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = StorageNetAppExportPolicy.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



333
334
335
# File 'lib/intersight_client/models/storage_net_app_export_policy.rb', line 333

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



190
191
192
193
194
195
196
197
198
199
# File 'lib/intersight_client/models/storage_net_app_export_policy.rb', line 190

def valid?
  return false if @class_id.nil?
  class_id_validator = EnumAttributeValidator.new('String', ["storage.NetAppExportPolicy"])
  return false unless class_id_validator.valid?(@class_id)
  return false if @object_type.nil?
  object_type_validator = EnumAttributeValidator.new('String', ["storage.NetAppExportPolicy"])
  return false unless object_type_validator.valid?(@object_type)
  return false if !@cluster_uuid.nil? && @cluster_uuid !~ Regexp.new(/^$|^[0-9a-fA-F]{8}-[0-9a-fA-F]{4}-[0-9a-fA-F]{4}-[0-9a-fA-F]{4}-[0-9a-fA-F]{12}$/)
  true && super
end