Class: IntersightClient::StorageNetAppNodeAllOf
- Inherits:
-
Object
- Object
- IntersightClient::StorageNetAppNodeAllOf
- Defined in:
- lib/intersight_client/models/storage_net_app_node_all_of.rb
Overview
Definition of the list of properties defined in ‘storage.NetAppNode’, excluding properties defined in parent classes.
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#array ⇒ Object
Returns the value of attribute array.
-
#avg_performance_metrics ⇒ Object
Returns the value of attribute avg_performance_metrics.
-
#class_id ⇒ Object
The fully-qualified name of the instantiated, concrete type.
-
#health ⇒ Object
The health of the NetApp Node.
-
#high_availability ⇒ Object
Returns the value of attribute high_availability.
-
#key ⇒ Object
Unique identifier of NetApp Node across data center.
-
#object_type ⇒ Object
The fully-qualified name of the instantiated, concrete type.
-
#systemid ⇒ Object
The system id of the NetApp Node.
-
#uuid ⇒ Object
Universally unique identifier of NetApp Node.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns the key-value map of all the JSON attributes this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ StorageNetAppNodeAllOf
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ StorageNetAppNodeAllOf
Initializes the object
114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 |
# File 'lib/intersight_client/models/storage_net_app_node_all_of.rb', line 114 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `IntersightClient::StorageNetAppNodeAllOf` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `#{self.class.name}`. Please check the name to make sure it's valid. List of attributes: " + self.class.acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'class_id') self.class_id = attributes[:'class_id'] else self.class_id = 'storage.NetAppNode' end if attributes.key?(:'object_type') self.object_type = attributes[:'object_type'] else self.object_type = 'storage.NetAppNode' end if attributes.key?(:'avg_performance_metrics') self.avg_performance_metrics = attributes[:'avg_performance_metrics'] end if attributes.key?(:'health') self.health = attributes[:'health'] end if attributes.key?(:'high_availability') self.high_availability = attributes[:'high_availability'] end if attributes.key?(:'key') self.key = attributes[:'key'] end if attributes.key?(:'systemid') self.systemid = attributes[:'systemid'] end if attributes.key?(:'uuid') self.uuid = attributes[:'uuid'] end if attributes.key?(:'array') self.array = attributes[:'array'] end end |
Instance Attribute Details
#array ⇒ Object
Returns the value of attribute array.
41 42 43 |
# File 'lib/intersight_client/models/storage_net_app_node_all_of.rb', line 41 def array @array end |
#avg_performance_metrics ⇒ Object
Returns the value of attribute avg_performance_metrics.
25 26 27 |
# File 'lib/intersight_client/models/storage_net_app_node_all_of.rb', line 25 def avg_performance_metrics @avg_performance_metrics end |
#class_id ⇒ Object
The fully-qualified name of the instantiated, concrete type. This property is used as a discriminator to identify the type of the payload when marshaling and unmarshaling data.
20 21 22 |
# File 'lib/intersight_client/models/storage_net_app_node_all_of.rb', line 20 def class_id @class_id end |
#health ⇒ Object
The health of the NetApp Node.
28 29 30 |
# File 'lib/intersight_client/models/storage_net_app_node_all_of.rb', line 28 def health @health end |
#high_availability ⇒ Object
Returns the value of attribute high_availability.
30 31 32 |
# File 'lib/intersight_client/models/storage_net_app_node_all_of.rb', line 30 def high_availability @high_availability end |
#key ⇒ Object
Unique identifier of NetApp Node across data center.
33 34 35 |
# File 'lib/intersight_client/models/storage_net_app_node_all_of.rb', line 33 def key @key end |
#object_type ⇒ Object
The fully-qualified name of the instantiated, concrete type. The value should be the same as the ‘ClassId’ property.
23 24 25 |
# File 'lib/intersight_client/models/storage_net_app_node_all_of.rb', line 23 def object_type @object_type end |
#systemid ⇒ Object
The system id of the NetApp Node.
36 37 38 |
# File 'lib/intersight_client/models/storage_net_app_node_all_of.rb', line 36 def systemid @systemid end |
#uuid ⇒ Object
Universally unique identifier of NetApp Node.
39 40 41 |
# File 'lib/intersight_client/models/storage_net_app_node_all_of.rb', line 39 def uuid @uuid end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns the key-value map of all the JSON attributes this model knows about
86 87 88 |
# File 'lib/intersight_client/models/storage_net_app_node_all_of.rb', line 86 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
81 82 83 |
# File 'lib/intersight_client/models/storage_net_app_node_all_of.rb', line 81 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
66 67 68 69 70 71 72 73 74 75 76 77 78 |
# File 'lib/intersight_client/models/storage_net_app_node_all_of.rb', line 66 def self.attribute_map { :'class_id' => :'ClassId', :'object_type' => :'ObjectType', :'avg_performance_metrics' => :'AvgPerformanceMetrics', :'health' => :'Health', :'high_availability' => :'HighAvailability', :'key' => :'Key', :'systemid' => :'Systemid', :'uuid' => :'Uuid', :'array' => :'Array' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
263 264 265 |
# File 'lib/intersight_client/models/storage_net_app_node_all_of.rb', line 263 def self.build_from_hash(attributes) new.build_from_hash(attributes) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
106 107 108 109 110 |
# File 'lib/intersight_client/models/storage_net_app_node_all_of.rb', line 106 def self.openapi_nullable Set.new([ :'high_availability', ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
91 92 93 94 95 96 97 98 99 100 101 102 103 |
# File 'lib/intersight_client/models/storage_net_app_node_all_of.rb', line 91 def self.openapi_types { :'class_id' => :'String', :'object_type' => :'String', :'avg_performance_metrics' => :'StorageNetAppPerformanceMetricsAverage', :'health' => :'Boolean', :'high_availability' => :'StorageNetAppHighAvailability', :'key' => :'String', :'systemid' => :'String', :'uuid' => :'String', :'array' => :'StorageNetAppClusterRelationship' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
234 235 236 237 238 239 240 241 242 243 244 245 246 |
# File 'lib/intersight_client/models/storage_net_app_node_all_of.rb', line 234 def ==(o) return true if self.equal?(o) self.class == o.class && class_id == o.class_id && object_type == o.object_type && avg_performance_metrics == o.avg_performance_metrics && health == o.health && high_availability == o.high_availability && key == o.key && systemid == o.systemid && uuid == o.uuid && array == o.array end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 |
# File 'lib/intersight_client/models/storage_net_app_node_all_of.rb', line 293 def _deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = IntersightClient.const_get(type) klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
364 365 366 367 368 369 370 371 372 373 374 375 376 |
# File 'lib/intersight_client/models/storage_net_app_node_all_of.rb', line 364 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 |
# File 'lib/intersight_client/models/storage_net_app_node_all_of.rb', line 270 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) StorageNetAppNodeAllOf.openapi_types.each_pair do |key, type| if attributes[StorageNetAppNodeAllOf.attribute_map[key]].nil? && StorageNetAppNodeAllOf.openapi_nullable.include?(key) self.send("#{key}=", nil) elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[StorageNetAppNodeAllOf.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[StorageNetAppNodeAllOf.attribute_map[key]].map { |v| _deserialize($1, v) }) end elsif !attributes[StorageNetAppNodeAllOf.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[StorageNetAppNodeAllOf.attribute_map[key]])) end end self end |
#eql?(o) ⇒ Boolean
250 251 252 |
# File 'lib/intersight_client/models/storage_net_app_node_all_of.rb', line 250 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
256 257 258 |
# File 'lib/intersight_client/models/storage_net_app_node_all_of.rb', line 256 def hash [class_id, object_type, avg_performance_metrics, health, high_availability, key, systemid, uuid, array].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 |
# File 'lib/intersight_client/models/storage_net_app_node_all_of.rb', line 170 def list_invalid_properties invalid_properties = Array.new if @class_id.nil? invalid_properties.push('invalid value for "class_id", class_id cannot be nil.') end if @object_type.nil? invalid_properties.push('invalid value for "object_type", object_type cannot be nil.') end pattern = Regexp.new(/^$|^[0-9a-fA-F]{8}-[0-9a-fA-F]{4}-[0-9a-fA-F]{4}-[0-9a-fA-F]{4}-[0-9a-fA-F]{12}$/) if !@uuid.nil? && @uuid !~ pattern invalid_properties.push("invalid value for \"uuid\", must conform to the pattern #{pattern}.") end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
340 341 342 |
# File 'lib/intersight_client/models/storage_net_app_node_all_of.rb', line 340 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
346 347 348 349 350 351 352 353 354 355 356 357 358 |
# File 'lib/intersight_client/models/storage_net_app_node_all_of.rb', line 346 def to_hash hash = {} StorageNetAppNodeAllOf.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = StorageNetAppNodeAllOf.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
334 335 336 |
# File 'lib/intersight_client/models/storage_net_app_node_all_of.rb', line 334 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
190 191 192 193 194 195 196 197 198 199 |
# File 'lib/intersight_client/models/storage_net_app_node_all_of.rb', line 190 def valid? return false if @class_id.nil? class_id_validator = EnumAttributeValidator.new('String', ["storage.NetAppNode"]) return false unless class_id_validator.valid?(@class_id) return false if @object_type.nil? object_type_validator = EnumAttributeValidator.new('String', ["storage.NetAppNode"]) return false unless object_type_validator.valid?(@object_type) return false if !@uuid.nil? && @uuid !~ Regexp.new(/^$|^[0-9a-fA-F]{8}-[0-9a-fA-F]{4}-[0-9a-fA-F]{4}-[0-9a-fA-F]{4}-[0-9a-fA-F]{12}$/) true end |