Class: IntersightClient::StorageVdMemberEpAllOf
- Inherits:
-
Object
- Object
- IntersightClient::StorageVdMemberEpAllOf
- Defined in:
- lib/intersight_client/models/storage_vd_member_ep_all_of.rb
Overview
Definition of the list of properties defined in ‘storage.VdMemberEp’, excluding properties defined in parent classes.
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#class_id ⇒ Object
The fully-qualified name of the instantiated, concrete type.
-
#inventory_device_info ⇒ Object
Returns the value of attribute inventory_device_info.
-
#object_type ⇒ Object
The fully-qualified name of the instantiated, concrete type.
-
#oper_qualifier_reason ⇒ Object
For certain states, indicates the reason why the operState is in that state.
-
#presence ⇒ Object
The presence state of the local disk.
-
#registered_device ⇒ Object
Returns the value of attribute registered_device.
-
#role ⇒ Object
Role of the disk normal or hot-spare, used by virtual-drive.
-
#span_id ⇒ Object
The span id number of the virtual drive.
-
#storage_virtual_drive ⇒ Object
Returns the value of attribute storage_virtual_drive.
-
#vd_member_ep_id ⇒ Object
The local disk slot number as id.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns the key-value map of all the JSON attributes this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ StorageVdMemberEpAllOf
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ StorageVdMemberEpAllOf
Initializes the object
118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 |
# File 'lib/intersight_client/models/storage_vd_member_ep_all_of.rb', line 118 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `IntersightClient::StorageVdMemberEpAllOf` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `#{self.class.name}`. Please check the name to make sure it's valid. List of attributes: " + self.class.acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'class_id') self.class_id = attributes[:'class_id'] else self.class_id = 'storage.VdMemberEp' end if attributes.key?(:'object_type') self.object_type = attributes[:'object_type'] else self.object_type = 'storage.VdMemberEp' end if attributes.key?(:'oper_qualifier_reason') self.oper_qualifier_reason = attributes[:'oper_qualifier_reason'] end if attributes.key?(:'presence') self.presence = attributes[:'presence'] end if attributes.key?(:'role') self.role = attributes[:'role'] end if attributes.key?(:'span_id') self.span_id = attributes[:'span_id'] end if attributes.key?(:'vd_member_ep_id') self.vd_member_ep_id = attributes[:'vd_member_ep_id'] end if attributes.key?(:'inventory_device_info') self.inventory_device_info = attributes[:'inventory_device_info'] end if attributes.key?(:'registered_device') self.registered_device = attributes[:'registered_device'] end if attributes.key?(:'storage_virtual_drive') self.storage_virtual_drive = attributes[:'storage_virtual_drive'] end end |
Instance Attribute Details
#class_id ⇒ Object
The fully-qualified name of the instantiated, concrete type. This property is used as a discriminator to identify the type of the payload when marshaling and unmarshaling data.
20 21 22 |
# File 'lib/intersight_client/models/storage_vd_member_ep_all_of.rb', line 20 def class_id @class_id end |
#inventory_device_info ⇒ Object
Returns the value of attribute inventory_device_info.
40 41 42 |
# File 'lib/intersight_client/models/storage_vd_member_ep_all_of.rb', line 40 def inventory_device_info @inventory_device_info end |
#object_type ⇒ Object
The fully-qualified name of the instantiated, concrete type. The value should be the same as the ‘ClassId’ property.
23 24 25 |
# File 'lib/intersight_client/models/storage_vd_member_ep_all_of.rb', line 23 def object_type @object_type end |
#oper_qualifier_reason ⇒ Object
For certain states, indicates the reason why the operState is in that state.
26 27 28 |
# File 'lib/intersight_client/models/storage_vd_member_ep_all_of.rb', line 26 def oper_qualifier_reason @oper_qualifier_reason end |
#presence ⇒ Object
The presence state of the local disk.
29 30 31 |
# File 'lib/intersight_client/models/storage_vd_member_ep_all_of.rb', line 29 def presence @presence end |
#registered_device ⇒ Object
Returns the value of attribute registered_device.
42 43 44 |
# File 'lib/intersight_client/models/storage_vd_member_ep_all_of.rb', line 42 def registered_device @registered_device end |
#role ⇒ Object
Role of the disk normal or hot-spare, used by virtual-drive.
32 33 34 |
# File 'lib/intersight_client/models/storage_vd_member_ep_all_of.rb', line 32 def role @role end |
#span_id ⇒ Object
The span id number of the virtual drive.
35 36 37 |
# File 'lib/intersight_client/models/storage_vd_member_ep_all_of.rb', line 35 def span_id @span_id end |
#storage_virtual_drive ⇒ Object
Returns the value of attribute storage_virtual_drive.
44 45 46 |
# File 'lib/intersight_client/models/storage_vd_member_ep_all_of.rb', line 44 def storage_virtual_drive @storage_virtual_drive end |
#vd_member_ep_id ⇒ Object
The local disk slot number as id.
38 39 40 |
# File 'lib/intersight_client/models/storage_vd_member_ep_all_of.rb', line 38 def vd_member_ep_id @vd_member_ep_id end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns the key-value map of all the JSON attributes this model knows about
90 91 92 |
# File 'lib/intersight_client/models/storage_vd_member_ep_all_of.rb', line 90 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
85 86 87 |
# File 'lib/intersight_client/models/storage_vd_member_ep_all_of.rb', line 85 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
69 70 71 72 73 74 75 76 77 78 79 80 81 82 |
# File 'lib/intersight_client/models/storage_vd_member_ep_all_of.rb', line 69 def self.attribute_map { :'class_id' => :'ClassId', :'object_type' => :'ObjectType', :'oper_qualifier_reason' => :'OperQualifierReason', :'presence' => :'Presence', :'role' => :'Role', :'span_id' => :'SpanId', :'vd_member_ep_id' => :'VdMemberEpId', :'inventory_device_info' => :'InventoryDeviceInfo', :'registered_device' => :'RegisteredDevice', :'storage_virtual_drive' => :'StorageVirtualDrive' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
255 256 257 |
# File 'lib/intersight_client/models/storage_vd_member_ep_all_of.rb', line 255 def self.build_from_hash(attributes) new.build_from_hash(attributes) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
111 112 113 114 |
# File 'lib/intersight_client/models/storage_vd_member_ep_all_of.rb', line 111 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
95 96 97 98 99 100 101 102 103 104 105 106 107 108 |
# File 'lib/intersight_client/models/storage_vd_member_ep_all_of.rb', line 95 def self.openapi_types { :'class_id' => :'String', :'object_type' => :'String', :'oper_qualifier_reason' => :'String', :'presence' => :'String', :'role' => :'String', :'span_id' => :'String', :'vd_member_ep_id' => :'Integer', :'inventory_device_info' => :'InventoryDeviceInfoRelationship', :'registered_device' => :'AssetDeviceRegistrationRelationship', :'storage_virtual_drive' => :'StorageVirtualDriveRelationship' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
225 226 227 228 229 230 231 232 233 234 235 236 237 238 |
# File 'lib/intersight_client/models/storage_vd_member_ep_all_of.rb', line 225 def ==(o) return true if self.equal?(o) self.class == o.class && class_id == o.class_id && object_type == o.object_type && oper_qualifier_reason == o.oper_qualifier_reason && presence == o.presence && role == o.role && span_id == o.span_id && vd_member_ep_id == o.vd_member_ep_id && inventory_device_info == o.inventory_device_info && registered_device == o.registered_device && storage_virtual_drive == o.storage_virtual_drive end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 |
# File 'lib/intersight_client/models/storage_vd_member_ep_all_of.rb', line 285 def _deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = IntersightClient.const_get(type) klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
356 357 358 359 360 361 362 363 364 365 366 367 368 |
# File 'lib/intersight_client/models/storage_vd_member_ep_all_of.rb', line 356 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 |
# File 'lib/intersight_client/models/storage_vd_member_ep_all_of.rb', line 262 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) StorageVdMemberEpAllOf.openapi_types.each_pair do |key, type| if attributes[StorageVdMemberEpAllOf.attribute_map[key]].nil? && StorageVdMemberEpAllOf.openapi_nullable.include?(key) self.send("#{key}=", nil) elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[StorageVdMemberEpAllOf.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[StorageVdMemberEpAllOf.attribute_map[key]].map { |v| _deserialize($1, v) }) end elsif !attributes[StorageVdMemberEpAllOf.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[StorageVdMemberEpAllOf.attribute_map[key]])) end end self end |
#eql?(o) ⇒ Boolean
242 243 244 |
# File 'lib/intersight_client/models/storage_vd_member_ep_all_of.rb', line 242 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
248 249 250 |
# File 'lib/intersight_client/models/storage_vd_member_ep_all_of.rb', line 248 def hash [class_id, object_type, oper_qualifier_reason, presence, role, span_id, vd_member_ep_id, inventory_device_info, registered_device, storage_virtual_drive].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
178 179 180 181 182 183 184 185 186 187 188 189 |
# File 'lib/intersight_client/models/storage_vd_member_ep_all_of.rb', line 178 def list_invalid_properties invalid_properties = Array.new if @class_id.nil? invalid_properties.push('invalid value for "class_id", class_id cannot be nil.') end if @object_type.nil? invalid_properties.push('invalid value for "object_type", object_type cannot be nil.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
332 333 334 |
# File 'lib/intersight_client/models/storage_vd_member_ep_all_of.rb', line 332 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
338 339 340 341 342 343 344 345 346 347 348 349 350 |
# File 'lib/intersight_client/models/storage_vd_member_ep_all_of.rb', line 338 def to_hash hash = {} StorageVdMemberEpAllOf.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = StorageVdMemberEpAllOf.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
326 327 328 |
# File 'lib/intersight_client/models/storage_vd_member_ep_all_of.rb', line 326 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
193 194 195 196 197 198 199 200 201 |
# File 'lib/intersight_client/models/storage_vd_member_ep_all_of.rb', line 193 def valid? return false if @class_id.nil? class_id_validator = EnumAttributeValidator.new('String', ["storage.VdMemberEp"]) return false unless class_id_validator.valid?(@class_id) return false if @object_type.nil? object_type_validator = EnumAttributeValidator.new('String', ["storage.VdMemberEp"]) return false unless object_type_validator.valid?(@object_type) true end |