Class: IntersightClient::StorageVirtualDriveExtension
- Inherits:
-
InventoryBase
- Object
- MoBaseMo
- InventoryBase
- IntersightClient::StorageVirtualDriveExtension
- Defined in:
- lib/intersight_client/models/storage_virtual_drive_extension.rb
Overview
Information of virtual drives as reported by a storage controller. In certain cases like S-series servers, virtual drive information will be reported by the controller separately and this represents such information.
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#bootable ⇒ Object
The ability to boot from the virtual drive.
-
#class_id ⇒ Object
The fully-qualified name of the instantiated, concrete type.
-
#container_id ⇒ Object
The container id of the virtual drive.
-
#drive_state ⇒ Object
The state of the virtual drive.
-
#inventory_device_info ⇒ Object
Returns the value of attribute inventory_device_info.
-
#name ⇒ Object
The name of the Virtual drive.
-
#object_type ⇒ Object
The fully-qualified name of the instantiated, concrete type.
-
#oper_device_id ⇒ Object
The operational device id of the virtual drive.
-
#registered_device ⇒ Object
Returns the value of attribute registered_device.
-
#storage_controller ⇒ Object
Returns the value of attribute storage_controller.
-
#uuid ⇒ Object
The UUID assigned to the virtual drive.
-
#vendor_uuid ⇒ Object
The UUID value of the vendor assigned to the virtual drive.
-
#virtual_drive ⇒ Object
Returns the value of attribute virtual_drive.
-
#virtual_drive_dn ⇒ Object
The distinguished name of the virtual drive for which the extended data is provided.
-
#virtual_drive_id ⇒ Object
The Id of the virtual drive.
Attributes inherited from InventoryBase
Attributes inherited from MoBaseMo
#account_moid, #ancestors, #create_time, #display_names, #domain_group_moid, #mod_time, #moid, #owners, #parent, #permission_resources, #shared_scope, #tags, #version_context
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns the key-value map of all the JSON attributes this model knows about, including the ones defined in its parent(s).
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about, including the ones defined in its parent(s).
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_all_of ⇒ Object
List of class defined in allOf (OpenAPI v3).
-
.openapi_discriminator_name ⇒ Object
discriminator’s property name in OpenAPI v3.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ StorageVirtualDriveExtension
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ StorageVirtualDriveExtension
Initializes the object
155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 |
# File 'lib/intersight_client/models/storage_virtual_drive_extension.rb', line 155 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `IntersightClient::StorageVirtualDriveExtension` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `#{self.class.name}`. Please check the name to make sure it's valid. List of attributes: " + self.class.acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } # call parent's initialize super(attributes) if attributes.key?(:'class_id') self.class_id = attributes[:'class_id'] else self.class_id = 'storage.VirtualDriveExtension' end if attributes.key?(:'object_type') self.object_type = attributes[:'object_type'] else self.object_type = 'storage.VirtualDriveExtension' end if attributes.key?(:'bootable') self.bootable = attributes[:'bootable'] end if attributes.key?(:'container_id') self.container_id = attributes[:'container_id'] end if attributes.key?(:'drive_state') self.drive_state = attributes[:'drive_state'] end if attributes.key?(:'name') self.name = attributes[:'name'] end if attributes.key?(:'oper_device_id') self.oper_device_id = attributes[:'oper_device_id'] end if attributes.key?(:'uuid') self.uuid = attributes[:'uuid'] end if attributes.key?(:'vendor_uuid') self.vendor_uuid = attributes[:'vendor_uuid'] end if attributes.key?(:'virtual_drive_dn') self.virtual_drive_dn = attributes[:'virtual_drive_dn'] end if attributes.key?(:'virtual_drive_id') self.virtual_drive_id = attributes[:'virtual_drive_id'] end if attributes.key?(:'inventory_device_info') self.inventory_device_info = attributes[:'inventory_device_info'] end if attributes.key?(:'registered_device') self.registered_device = attributes[:'registered_device'] end if attributes.key?(:'storage_controller') self.storage_controller = attributes[:'storage_controller'] end if attributes.key?(:'virtual_drive') self.virtual_drive = attributes[:'virtual_drive'] end end |
Instance Attribute Details
#bootable ⇒ Object
The ability to boot from the virtual drive.
26 27 28 |
# File 'lib/intersight_client/models/storage_virtual_drive_extension.rb', line 26 def bootable @bootable end |
#class_id ⇒ Object
The fully-qualified name of the instantiated, concrete type. This property is used as a discriminator to identify the type of the payload when marshaling and unmarshaling data.
20 21 22 |
# File 'lib/intersight_client/models/storage_virtual_drive_extension.rb', line 20 def class_id @class_id end |
#container_id ⇒ Object
The container id of the virtual drive.
29 30 31 |
# File 'lib/intersight_client/models/storage_virtual_drive_extension.rb', line 29 def container_id @container_id end |
#drive_state ⇒ Object
The state of the virtual drive.
32 33 34 |
# File 'lib/intersight_client/models/storage_virtual_drive_extension.rb', line 32 def drive_state @drive_state end |
#inventory_device_info ⇒ Object
Returns the value of attribute inventory_device_info.
52 53 54 |
# File 'lib/intersight_client/models/storage_virtual_drive_extension.rb', line 52 def inventory_device_info @inventory_device_info end |
#name ⇒ Object
The name of the Virtual drive.
35 36 37 |
# File 'lib/intersight_client/models/storage_virtual_drive_extension.rb', line 35 def name @name end |
#object_type ⇒ Object
The fully-qualified name of the instantiated, concrete type. The value should be the same as the ‘ClassId’ property.
23 24 25 |
# File 'lib/intersight_client/models/storage_virtual_drive_extension.rb', line 23 def object_type @object_type end |
#oper_device_id ⇒ Object
The operational device id of the virtual drive.
38 39 40 |
# File 'lib/intersight_client/models/storage_virtual_drive_extension.rb', line 38 def oper_device_id @oper_device_id end |
#registered_device ⇒ Object
Returns the value of attribute registered_device.
54 55 56 |
# File 'lib/intersight_client/models/storage_virtual_drive_extension.rb', line 54 def registered_device @registered_device end |
#storage_controller ⇒ Object
Returns the value of attribute storage_controller.
56 57 58 |
# File 'lib/intersight_client/models/storage_virtual_drive_extension.rb', line 56 def storage_controller @storage_controller end |
#uuid ⇒ Object
The UUID assigned to the virtual drive.
41 42 43 |
# File 'lib/intersight_client/models/storage_virtual_drive_extension.rb', line 41 def uuid @uuid end |
#vendor_uuid ⇒ Object
The UUID value of the vendor assigned to the virtual drive.
44 45 46 |
# File 'lib/intersight_client/models/storage_virtual_drive_extension.rb', line 44 def vendor_uuid @vendor_uuid end |
#virtual_drive ⇒ Object
Returns the value of attribute virtual_drive.
58 59 60 |
# File 'lib/intersight_client/models/storage_virtual_drive_extension.rb', line 58 def virtual_drive @virtual_drive end |
#virtual_drive_dn ⇒ Object
The distinguished name of the virtual drive for which the extended data is provided.
47 48 49 |
# File 'lib/intersight_client/models/storage_virtual_drive_extension.rb', line 47 def virtual_drive_dn @virtual_drive_dn end |
#virtual_drive_id ⇒ Object
The Id of the virtual drive.
50 51 52 |
# File 'lib/intersight_client/models/storage_virtual_drive_extension.rb', line 50 def virtual_drive_id @virtual_drive_id end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns the key-value map of all the JSON attributes this model knows about, including the ones defined in its parent(s)
109 110 111 |
# File 'lib/intersight_client/models/storage_virtual_drive_extension.rb', line 109 def self.acceptable_attribute_map attribute_map.merge(superclass.acceptable_attribute_map) end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about, including the ones defined in its parent(s)
104 105 106 |
# File 'lib/intersight_client/models/storage_virtual_drive_extension.rb', line 104 def self.acceptable_attributes attribute_map.values.concat(superclass.acceptable_attributes) end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 |
# File 'lib/intersight_client/models/storage_virtual_drive_extension.rb', line 83 def self.attribute_map { :'class_id' => :'ClassId', :'object_type' => :'ObjectType', :'bootable' => :'Bootable', :'container_id' => :'ContainerId', :'drive_state' => :'DriveState', :'name' => :'Name', :'oper_device_id' => :'OperDeviceId', :'uuid' => :'Uuid', :'vendor_uuid' => :'VendorUuid', :'virtual_drive_dn' => :'VirtualDriveDn', :'virtual_drive_id' => :'VirtualDriveId', :'inventory_device_info' => :'InventoryDeviceInfo', :'registered_device' => :'RegisteredDevice', :'storage_controller' => :'StorageController', :'virtual_drive' => :'VirtualDrive' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
320 321 322 |
# File 'lib/intersight_client/models/storage_virtual_drive_extension.rb', line 320 def self.build_from_hash(attributes) new.build_from_hash(attributes) end |
.openapi_all_of ⇒ Object
List of class defined in allOf (OpenAPI v3)
141 142 143 144 145 146 |
# File 'lib/intersight_client/models/storage_virtual_drive_extension.rb', line 141 def self.openapi_all_of [ :'InventoryBase', :'StorageVirtualDriveExtensionAllOf' ] end |
.openapi_discriminator_name ⇒ Object
discriminator’s property name in OpenAPI v3
149 150 151 |
# File 'lib/intersight_client/models/storage_virtual_drive_extension.rb', line 149 def self.openapi_discriminator_name :'ClassId' end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
135 136 137 138 |
# File 'lib/intersight_client/models/storage_virtual_drive_extension.rb', line 135 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 |
# File 'lib/intersight_client/models/storage_virtual_drive_extension.rb', line 114 def self.openapi_types { :'class_id' => :'String', :'object_type' => :'String', :'bootable' => :'String', :'container_id' => :'Integer', :'drive_state' => :'String', :'name' => :'String', :'oper_device_id' => :'String', :'uuid' => :'String', :'vendor_uuid' => :'String', :'virtual_drive_dn' => :'String', :'virtual_drive_id' => :'String', :'inventory_device_info' => :'InventoryDeviceInfoRelationship', :'registered_device' => :'AssetDeviceRegistrationRelationship', :'storage_controller' => :'StorageControllerRelationship', :'virtual_drive' => :'StorageVirtualDriveRelationship' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 |
# File 'lib/intersight_client/models/storage_virtual_drive_extension.rb', line 285 def ==(o) return true if self.equal?(o) self.class == o.class && class_id == o.class_id && object_type == o.object_type && bootable == o.bootable && container_id == o.container_id && drive_state == o.drive_state && name == o.name && oper_device_id == o.oper_device_id && uuid == o.uuid && vendor_uuid == o.vendor_uuid && virtual_drive_dn == o.virtual_drive_dn && virtual_drive_id == o.virtual_drive_id && inventory_device_info == o.inventory_device_info && registered_device == o.registered_device && storage_controller == o.storage_controller && virtual_drive == o.virtual_drive && super(o) end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 |
# File 'lib/intersight_client/models/storage_virtual_drive_extension.rb', line 351 def _deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = IntersightClient.const_get(type) klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
422 423 424 425 426 427 428 429 430 431 432 433 434 |
# File 'lib/intersight_client/models/storage_virtual_drive_extension.rb', line 422 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 |
# File 'lib/intersight_client/models/storage_virtual_drive_extension.rb', line 327 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) super(attributes) StorageVirtualDriveExtension.openapi_types.each_pair do |key, type| if attributes[StorageVirtualDriveExtension.attribute_map[key]].nil? && StorageVirtualDriveExtension.openapi_nullable.include?(key) self.send("#{key}=", nil) elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[StorageVirtualDriveExtension.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[StorageVirtualDriveExtension.attribute_map[key]].map { |v| _deserialize($1, v) }) end elsif !attributes[StorageVirtualDriveExtension.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[StorageVirtualDriveExtension.attribute_map[key]])) end end self end |
#eql?(o) ⇒ Boolean
307 308 309 |
# File 'lib/intersight_client/models/storage_virtual_drive_extension.rb', line 307 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
313 314 315 |
# File 'lib/intersight_client/models/storage_virtual_drive_extension.rb', line 313 def hash [class_id, object_type, bootable, container_id, drive_state, name, oper_device_id, uuid, vendor_uuid, virtual_drive_dn, virtual_drive_id, inventory_device_info, registered_device, storage_controller, virtual_drive].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
238 239 240 241 242 243 244 245 246 247 248 249 |
# File 'lib/intersight_client/models/storage_virtual_drive_extension.rb', line 238 def list_invalid_properties invalid_properties = super if @class_id.nil? invalid_properties.push('invalid value for "class_id", class_id cannot be nil.') end if @object_type.nil? invalid_properties.push('invalid value for "object_type", object_type cannot be nil.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
398 399 400 |
# File 'lib/intersight_client/models/storage_virtual_drive_extension.rb', line 398 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
404 405 406 407 408 409 410 411 412 413 414 415 416 |
# File 'lib/intersight_client/models/storage_virtual_drive_extension.rb', line 404 def to_hash hash = super StorageVirtualDriveExtension.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = StorageVirtualDriveExtension.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
392 393 394 |
# File 'lib/intersight_client/models/storage_virtual_drive_extension.rb', line 392 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
253 254 255 256 257 258 259 260 261 |
# File 'lib/intersight_client/models/storage_virtual_drive_extension.rb', line 253 def valid? return false if @class_id.nil? class_id_validator = EnumAttributeValidator.new('String', ["storage.VirtualDriveExtension"]) return false unless class_id_validator.valid?(@class_id) return false if @object_type.nil? object_type_validator = EnumAttributeValidator.new('String', ["storage.VirtualDriveExtension"]) return false unless object_type_validator.valid?(@object_type) true && super end |