Class: IntersightClient::StorageVirtualDrivePolicy
- Inherits:
-
MoBaseComplexType
- Object
- MoBaseComplexType
- IntersightClient::StorageVirtualDrivePolicy
- Defined in:
- lib/intersight_client/models/storage_virtual_drive_policy.rb
Overview
This models the manual drive selection configuration.
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#access_policy ⇒ Object
Access policy that host has on this virtual drive.
-
#class_id ⇒ Object
The fully-qualified name of the instantiated, concrete type.
-
#drive_cache ⇒ Object
Disk cache policy for the virtual drive.
-
#object_type ⇒ Object
The fully-qualified name of the instantiated, concrete type.
-
#read_policy ⇒ Object
Read ahead mode to be used to read data from this virtual drive.
-
#strip_size ⇒ Object
Desired strip size - Allowed values are 64KiB, 128KiB, 256KiB, 512KiB, 1024KiB.
-
#write_policy ⇒ Object
Write mode to be used to write data to this virtual drive.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns the key-value map of all the JSON attributes this model knows about, including the ones defined in its parent(s).
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about, including the ones defined in its parent(s).
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_all_of ⇒ Object
List of class defined in allOf (OpenAPI v3).
-
.openapi_discriminator_name ⇒ Object
discriminator’s property name in OpenAPI v3.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ StorageVirtualDrivePolicy
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ StorageVirtualDrivePolicy
Initializes the object
119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 |
# File 'lib/intersight_client/models/storage_virtual_drive_policy.rb', line 119 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `IntersightClient::StorageVirtualDrivePolicy` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `#{self.class.name}`. Please check the name to make sure it's valid. List of attributes: " + self.class.acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } # call parent's initialize super(attributes) if attributes.key?(:'class_id') self.class_id = attributes[:'class_id'] else self.class_id = 'storage.VirtualDrivePolicy' end if attributes.key?(:'object_type') self.object_type = attributes[:'object_type'] else self.object_type = 'storage.VirtualDrivePolicy' end if attributes.key?(:'access_policy') self.access_policy = attributes[:'access_policy'] else self.access_policy = 'Default' end if attributes.key?(:'drive_cache') self.drive_cache = attributes[:'drive_cache'] else self.drive_cache = 'Default' end if attributes.key?(:'read_policy') self.read_policy = attributes[:'read_policy'] else self.read_policy = 'Default' end if attributes.key?(:'strip_size') self.strip_size = attributes[:'strip_size'] else self.strip_size = STRIP_SIZE::N64 end if attributes.key?(:'write_policy') self.write_policy = attributes[:'write_policy'] else self.write_policy = 'Default' end end |
Instance Attribute Details
#access_policy ⇒ Object
Access policy that host has on this virtual drive. * Default - Use platform default access mode. * ReadWrite - Enables host to perform read-write on the VD. * ReadOnly - Host can only read from the VD. * Blocked - Host can neither read nor write to the VD.
26 27 28 |
# File 'lib/intersight_client/models/storage_virtual_drive_policy.rb', line 26 def access_policy @access_policy end |
#class_id ⇒ Object
The fully-qualified name of the instantiated, concrete type. This property is used as a discriminator to identify the type of the payload when marshaling and unmarshaling data.
20 21 22 |
# File 'lib/intersight_client/models/storage_virtual_drive_policy.rb', line 20 def class_id @class_id end |
#drive_cache ⇒ Object
Disk cache policy for the virtual drive. * Default - Use platform default drive cache mode. * NoChange - Drive cache policy is unchanged. * Enable - Enables IO caching on the drive. * Disable - Disables IO caching on the drive.
29 30 31 |
# File 'lib/intersight_client/models/storage_virtual_drive_policy.rb', line 29 def drive_cache @drive_cache end |
#object_type ⇒ Object
The fully-qualified name of the instantiated, concrete type. The value should be the same as the ‘ClassId’ property.
23 24 25 |
# File 'lib/intersight_client/models/storage_virtual_drive_policy.rb', line 23 def object_type @object_type end |
#read_policy ⇒ Object
Read ahead mode to be used to read data from this virtual drive. * Default - Use platform default read ahead mode. * ReadAhead - Use read ahead mode for the policy. * NoReadAhead - Do not use read ahead mode for the policy.
32 33 34 |
# File 'lib/intersight_client/models/storage_virtual_drive_policy.rb', line 32 def read_policy @read_policy end |
#strip_size ⇒ Object
Desired strip size - Allowed values are 64KiB, 128KiB, 256KiB, 512KiB, 1024KiB. * 64 - Number of bytes in a strip is 64 Kibibytes. * 128 - Number of bytes in a strip is 128 Kibibytes. * 256 - Number of bytes in a strip is 256 Kibibytes. * 512 - Number of bytes in a strip is 512 Kibibytes. * 1024 - Number of bytes in a strip is 1024 Kibibytes or 1 Mebibyte.
35 36 37 |
# File 'lib/intersight_client/models/storage_virtual_drive_policy.rb', line 35 def strip_size @strip_size end |
#write_policy ⇒ Object
Write mode to be used to write data to this virtual drive. * Default - Use platform default write mode. * WriteThrough - Data is written through the cache and to the physical drives. Performance is improved, because subsequent reads of that data can be satisfied from the cache. * WriteBackGoodBbu - Data is stored in the cache, and is only written to the physical drives when space in the cache is needed. Virtual drives requesting this policy fall back to Write Through caching when the battery backup unit (BBU) cannot guarantee the safety of the cache in the event of a power failure. * AlwaysWriteBack - With this policy, write caching remains Write Back even if the battery backup unit is defective or discharged.
38 39 40 |
# File 'lib/intersight_client/models/storage_virtual_drive_policy.rb', line 38 def write_policy @write_policy end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns the key-value map of all the JSON attributes this model knows about, including the ones defined in its parent(s)
81 82 83 |
# File 'lib/intersight_client/models/storage_virtual_drive_policy.rb', line 81 def self.acceptable_attribute_map attribute_map.merge(superclass.acceptable_attribute_map) end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about, including the ones defined in its parent(s)
76 77 78 |
# File 'lib/intersight_client/models/storage_virtual_drive_policy.rb', line 76 def self.acceptable_attributes attribute_map.values.concat(superclass.acceptable_attributes) end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
63 64 65 66 67 68 69 70 71 72 73 |
# File 'lib/intersight_client/models/storage_virtual_drive_policy.rb', line 63 def self.attribute_map { :'class_id' => :'ClassId', :'object_type' => :'ObjectType', :'access_policy' => :'AccessPolicy', :'drive_cache' => :'DriveCache', :'read_policy' => :'ReadPolicy', :'strip_size' => :'StripSize', :'write_policy' => :'WritePolicy' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
314 315 316 |
# File 'lib/intersight_client/models/storage_virtual_drive_policy.rb', line 314 def self.build_from_hash(attributes) new.build_from_hash(attributes) end |
.openapi_all_of ⇒ Object
List of class defined in allOf (OpenAPI v3)
105 106 107 108 109 110 |
# File 'lib/intersight_client/models/storage_virtual_drive_policy.rb', line 105 def self.openapi_all_of [ :'MoBaseComplexType', :'StorageVirtualDrivePolicyAllOf' ] end |
.openapi_discriminator_name ⇒ Object
discriminator’s property name in OpenAPI v3
113 114 115 |
# File 'lib/intersight_client/models/storage_virtual_drive_policy.rb', line 113 def self.openapi_discriminator_name :'ClassId' end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
99 100 101 102 |
# File 'lib/intersight_client/models/storage_virtual_drive_policy.rb', line 99 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
86 87 88 89 90 91 92 93 94 95 96 |
# File 'lib/intersight_client/models/storage_virtual_drive_policy.rb', line 86 def self.openapi_types { :'class_id' => :'String', :'object_type' => :'String', :'access_policy' => :'String', :'drive_cache' => :'String', :'read_policy' => :'String', :'strip_size' => :'Integer', :'write_policy' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
287 288 289 290 291 292 293 294 295 296 297 |
# File 'lib/intersight_client/models/storage_virtual_drive_policy.rb', line 287 def ==(o) return true if self.equal?(o) self.class == o.class && class_id == o.class_id && object_type == o.object_type && access_policy == o.access_policy && drive_cache == o.drive_cache && read_policy == o.read_policy && strip_size == o.strip_size && write_policy == o.write_policy && super(o) end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 |
# File 'lib/intersight_client/models/storage_virtual_drive_policy.rb', line 345 def _deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = IntersightClient.const_get(type) klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
416 417 418 419 420 421 422 423 424 425 426 427 428 |
# File 'lib/intersight_client/models/storage_virtual_drive_policy.rb', line 416 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 |
# File 'lib/intersight_client/models/storage_virtual_drive_policy.rb', line 321 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) super(attributes) StorageVirtualDrivePolicy.openapi_types.each_pair do |key, type| if attributes[StorageVirtualDrivePolicy.attribute_map[key]].nil? && StorageVirtualDrivePolicy.openapi_nullable.include?(key) self.send("#{key}=", nil) elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[StorageVirtualDrivePolicy.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[StorageVirtualDrivePolicy.attribute_map[key]].map { |v| _deserialize($1, v) }) end elsif !attributes[StorageVirtualDrivePolicy.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[StorageVirtualDrivePolicy.attribute_map[key]])) end end self end |
#eql?(o) ⇒ Boolean
301 302 303 |
# File 'lib/intersight_client/models/storage_virtual_drive_policy.rb', line 301 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
307 308 309 |
# File 'lib/intersight_client/models/storage_virtual_drive_policy.rb', line 307 def hash [class_id, object_type, access_policy, drive_cache, read_policy, strip_size, write_policy].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
180 181 182 183 184 185 186 187 188 189 190 191 |
# File 'lib/intersight_client/models/storage_virtual_drive_policy.rb', line 180 def list_invalid_properties invalid_properties = super if @class_id.nil? invalid_properties.push('invalid value for "class_id", class_id cannot be nil.') end if @object_type.nil? invalid_properties.push('invalid value for "object_type", object_type cannot be nil.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
392 393 394 |
# File 'lib/intersight_client/models/storage_virtual_drive_policy.rb', line 392 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
398 399 400 401 402 403 404 405 406 407 408 409 410 |
# File 'lib/intersight_client/models/storage_virtual_drive_policy.rb', line 398 def to_hash hash = super StorageVirtualDrivePolicy.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = StorageVirtualDrivePolicy.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
386 387 388 |
# File 'lib/intersight_client/models/storage_virtual_drive_policy.rb', line 386 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 |
# File 'lib/intersight_client/models/storage_virtual_drive_policy.rb', line 195 def valid? return false if @class_id.nil? class_id_validator = EnumAttributeValidator.new('String', ["storage.VirtualDrivePolicy"]) return false unless class_id_validator.valid?(@class_id) return false if @object_type.nil? object_type_validator = EnumAttributeValidator.new('String', ["storage.VirtualDrivePolicy"]) return false unless object_type_validator.valid?(@object_type) access_policy_validator = EnumAttributeValidator.new('String', ["Default", "ReadWrite", "ReadOnly", "Blocked"]) return false unless access_policy_validator.valid?(@access_policy) drive_cache_validator = EnumAttributeValidator.new('String', ["Default", "NoChange", "Enable", "Disable"]) return false unless drive_cache_validator.valid?(@drive_cache) read_policy_validator = EnumAttributeValidator.new('String', ["Default", "ReadAhead", "NoReadAhead"]) return false unless read_policy_validator.valid?(@read_policy) strip_size_validator = EnumAttributeValidator.new('Integer', [64, 128, 256, 512, 1024]) return false unless strip_size_validator.valid?(@strip_size) write_policy_validator = EnumAttributeValidator.new('String', ["Default", "WriteThrough", "WriteBackGoodBbu", "AlwaysWriteBack"]) return false unless write_policy_validator.valid?(@write_policy) true && super end |