Class: IntersightClient::TamActionAllOf

Inherits:
Object
  • Object
show all
Defined in:
lib/intersight_client/models/tam_action_all_of.rb

Overview

Definition of the list of properties defined in ‘tam.Action’, excluding properties defined in parent classes.

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ TamActionAllOf

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
# File 'lib/intersight_client/models/tam_action_all_of.rb', line 116

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `IntersightClient::TamActionAllOf` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `#{self.class.name}`. Please check the name to make sure it's valid. List of attributes: " + self.class.acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'class_id')
    self.class_id = attributes[:'class_id']
  else
    self.class_id = 'tam.Action'
  end

  if attributes.key?(:'object_type')
    self.object_type = attributes[:'object_type']
  else
    self.object_type = 'tam.Action'
  end

  if attributes.key?(:'affected_object_type')
    self.affected_object_type = attributes[:'affected_object_type']
  end

  if attributes.key?(:'alert_type')
    self.alert_type = attributes[:'alert_type']
  else
    self.alert_type = 'psirt'
  end

  if attributes.key?(:'identifiers')
    if (value = attributes[:'identifiers']).is_a?(Array)
      self.identifiers = value
    end
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  end

  if attributes.key?(:'operation_type')
    self.operation_type = attributes[:'operation_type']
  else
    self.operation_type = 'create'
  end

  if attributes.key?(:'queries')
    if (value = attributes[:'queries']).is_a?(Array)
      self.queries = value
    end
  end

  if attributes.key?(:'type')
    self.type = attributes[:'type']
  else
    self.type = 'restApi'
  end
end

Instance Attribute Details

#affected_object_typeObject

Type of the managed object that should be marked with an instance of the Alert (when operation type is create) or that should have an alert instance removed (when operation type is remove).



26
27
28
# File 'lib/intersight_client/models/tam_action_all_of.rb', line 26

def affected_object_type
  @affected_object_type
end

#alert_typeObject

Alert type is used to denote the category of an Intersight alert (FieldNotice, equipment Fault etc.). * psirt - Respresents the psirt alert type (tools.cisco.com/security/center/publicationListing.x). * fieldNotice - Respresents the field notice alert type (www.cisco.com/c/en/us/support/web/tsd-products-field-notice-summary.html).



29
30
31
# File 'lib/intersight_client/models/tam_action_all_of.rb', line 29

def alert_type
  @alert_type
end

#class_idObject

The fully-qualified name of the instantiated, concrete type. This property is used as a discriminator to identify the type of the payload when marshaling and unmarshaling data.



20
21
22
# File 'lib/intersight_client/models/tam_action_all_of.rb', line 20

def class_id
  @class_id
end

#identifiersObject

Returns the value of attribute identifiers.



31
32
33
# File 'lib/intersight_client/models/tam_action_all_of.rb', line 31

def identifiers
  @identifiers
end

#nameObject

Uniquely identifies a given action among the set of actions corresponding to an advisory. Primarily used to store and compare results of subsequent iterations corresponding to the action queries.



34
35
36
# File 'lib/intersight_client/models/tam_action_all_of.rb', line 34

def name
  @name
end

#object_typeObject

The fully-qualified name of the instantiated, concrete type. The value should be the same as the ‘ClassId’ property.



23
24
25
# File 'lib/intersight_client/models/tam_action_all_of.rb', line 23

def object_type
  @object_type
end

#operation_typeObject

Operation type for the alert action. An action is used to carry out the process of "reacting" to an alert condition. For e.g.in case of a fieldNotice alert, the intention may be to create a new alert (if the condition matches and there is no existing alert) or to remove an existing alert when the alert condition has been remedied. * create - Create an instance of AdvisoryInstance. * remove - Remove an instance of AdvisoryInstance.



37
38
39
# File 'lib/intersight_client/models/tam_action_all_of.rb', line 37

def operation_type
  @operation_type
end

#queriesObject

Returns the value of attribute queries.



39
40
41
# File 'lib/intersight_client/models/tam_action_all_of.rb', line 39

def queries
  @queries
end

#typeObject

Type of Intersight alert. An alert in Intersight could be one of several kinds (FieldNotice, PSIRT etc.). Primarily used for filtering alerts based on the type. * restApi - Repesents the use of REST API for carrying out alert actions.



42
43
44
# File 'lib/intersight_client/models/tam_action_all_of.rb', line 42

def type
  @type
end

Class Method Details

.acceptable_attribute_mapObject

Returns the key-value map of all the JSON attributes this model knows about



87
88
89
# File 'lib/intersight_client/models/tam_action_all_of.rb', line 87

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



82
83
84
# File 'lib/intersight_client/models/tam_action_all_of.rb', line 82

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



67
68
69
70
71
72
73
74
75
76
77
78
79
# File 'lib/intersight_client/models/tam_action_all_of.rb', line 67

def self.attribute_map
  {
    :'class_id' => :'ClassId',
    :'object_type' => :'ObjectType',
    :'affected_object_type' => :'AffectedObjectType',
    :'alert_type' => :'AlertType',
    :'identifiers' => :'Identifiers',
    :'name' => :'Name',
    :'operation_type' => :'OperationType',
    :'queries' => :'Queries',
    :'type' => :'Type'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



294
295
296
# File 'lib/intersight_client/models/tam_action_all_of.rb', line 294

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_nullableObject

List of attributes with nullable: true



107
108
109
110
111
112
# File 'lib/intersight_client/models/tam_action_all_of.rb', line 107

def self.openapi_nullable
  Set.new([
    :'identifiers',
    :'queries',
  ])
end

.openapi_typesObject

Attribute type mapping.



92
93
94
95
96
97
98
99
100
101
102
103
104
# File 'lib/intersight_client/models/tam_action_all_of.rb', line 92

def self.openapi_types
  {
    :'class_id' => :'String',
    :'object_type' => :'String',
    :'affected_object_type' => :'String',
    :'alert_type' => :'String',
    :'identifiers' => :'Array<TamIdentifiers>',
    :'name' => :'String',
    :'operation_type' => :'String',
    :'queries' => :'Array<TamQueryEntry>',
    :'type' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



265
266
267
268
269
270
271
272
273
274
275
276
277
# File 'lib/intersight_client/models/tam_action_all_of.rb', line 265

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      class_id == o.class_id &&
      object_type == o.object_type &&
      affected_object_type == o.affected_object_type &&
      alert_type == o.alert_type &&
      identifiers == o.identifiers &&
      name == o.name &&
      operation_type == o.operation_type &&
      queries == o.queries &&
      type == o.type
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
# File 'lib/intersight_client/models/tam_action_all_of.rb', line 324

def _deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = IntersightClient.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



395
396
397
398
399
400
401
402
403
404
405
406
407
# File 'lib/intersight_client/models/tam_action_all_of.rb', line 395

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
# File 'lib/intersight_client/models/tam_action_all_of.rb', line 301

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  TamActionAllOf.openapi_types.each_pair do |key, type|
    if attributes[TamActionAllOf.attribute_map[key]].nil? && TamActionAllOf.openapi_nullable.include?(key)
      self.send("#{key}=", nil)
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[TamActionAllOf.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[TamActionAllOf.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[TamActionAllOf.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[TamActionAllOf.attribute_map[key]]))
    end
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


281
282
283
# File 'lib/intersight_client/models/tam_action_all_of.rb', line 281

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



287
288
289
# File 'lib/intersight_client/models/tam_action_all_of.rb', line 287

def hash
  [class_id, object_type, affected_object_type, alert_type, identifiers, name, operation_type, queries, type].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



182
183
184
185
186
187
188
189
190
191
192
193
# File 'lib/intersight_client/models/tam_action_all_of.rb', line 182

def list_invalid_properties
  invalid_properties = Array.new
  if @class_id.nil?
    invalid_properties.push('invalid value for "class_id", class_id cannot be nil.')
  end

  if @object_type.nil?
    invalid_properties.push('invalid value for "object_type", object_type cannot be nil.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



371
372
373
# File 'lib/intersight_client/models/tam_action_all_of.rb', line 371

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



377
378
379
380
381
382
383
384
385
386
387
388
389
# File 'lib/intersight_client/models/tam_action_all_of.rb', line 377

def to_hash
  hash = {}
  TamActionAllOf.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = TamActionAllOf.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



365
366
367
# File 'lib/intersight_client/models/tam_action_all_of.rb', line 365

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
# File 'lib/intersight_client/models/tam_action_all_of.rb', line 197

def valid?
  return false if @class_id.nil?
  class_id_validator = EnumAttributeValidator.new('String', ["tam.Action"])
  return false unless class_id_validator.valid?(@class_id)
  return false if @object_type.nil?
  object_type_validator = EnumAttributeValidator.new('String', ["tam.Action"])
  return false unless object_type_validator.valid?(@object_type)
  alert_type_validator = EnumAttributeValidator.new('String', ["psirt", "fieldNotice"])
  return false unless alert_type_validator.valid?(@alert_type)
  operation_type_validator = EnumAttributeValidator.new('String', ["create", "remove"])
  return false unless operation_type_validator.valid?(@operation_type)
  type_validator = EnumAttributeValidator.new('String', ["restApi"])
  return false unless type_validator.valid?(@type)
  true
end