Class: IntersightClient::TamSecurityAdvisoryDetails

Inherits:
TamBaseAdvisoryDetails show all
Defined in:
lib/intersight_client/models/tam_security_advisory_details.rb

Overview

Details pertaining to a security advisory defined by a given advisory.

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Attributes inherited from TamBaseAdvisoryDetails

#description

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ TamSecurityAdvisoryDetails

Initializes the object

Parameters:

  • (defaults to: {})

    Model attributes in the form of hash



119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
# File 'lib/intersight_client/models/tam_security_advisory_details.rb', line 119

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `IntersightClient::TamSecurityAdvisoryDetails` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `#{self.class.name}`. Please check the name to make sure it's valid. List of attributes: " + self.class.acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  # call parent's initialize
  super(attributes)

  if attributes.key?(:'class_id')
    self.class_id = attributes[:'class_id']
  else
    self.class_id = 'tam.SecurityAdvisoryDetails'
  end

  if attributes.key?(:'object_type')
    self.object_type = attributes[:'object_type']
  else
    self.object_type = 'tam.SecurityAdvisoryDetails'
  end

  if attributes.key?(:'base_score')
    self.base_score = attributes[:'base_score']
  end

  if attributes.key?(:'cve_ids')
    if (value = attributes[:'cve_ids']).is_a?(Array)
      self.cve_ids = value
    end
  end

  if attributes.key?(:'environmental_score')
    self.environmental_score = attributes[:'environmental_score']
  end

  if attributes.key?(:'status')
    self.status = attributes[:'status']
  else
    self.status = 'interim'
  end

  if attributes.key?(:'temporal_score')
    self.temporal_score = attributes[:'temporal_score']
  end
end

Instance Attribute Details

#base_scoreObject

CVSS version 3 base score for the security Advisory.



26
27
28
# File 'lib/intersight_client/models/tam_security_advisory_details.rb', line 26

def base_score
  @base_score
end

#class_idObject

The fully-qualified name of the instantiated, concrete type. This property is used as a discriminator to identify the type of the payload when marshaling and unmarshaling data.



20
21
22
# File 'lib/intersight_client/models/tam_security_advisory_details.rb', line 20

def class_id
  @class_id
end

#cve_idsObject

Returns the value of attribute cve_ids.



28
29
30
# File 'lib/intersight_client/models/tam_security_advisory_details.rb', line 28

def cve_ids
  @cve_ids
end

#environmental_scoreObject

CVSS version 3 environmental score for the security Advisory.



31
32
33
# File 'lib/intersight_client/models/tam_security_advisory_details.rb', line 31

def environmental_score
  @environmental_score
end

#object_typeObject

The fully-qualified name of the instantiated, concrete type. The value should be the same as the ‘ClassId’ property.



23
24
25
# File 'lib/intersight_client/models/tam_security_advisory_details.rb', line 23

def object_type
  @object_type
end

#statusObject

Cisco assigned status of the published advisory. Depends on whether the investigation is complete or on-going. * interim - The Cisco investigation for the advisory is ongoing. Cisco will issue revisions to the advisory when additional information, including fixed software release data, becomes available. * final - Cisco has completed its evaluation of the vulnerability described in the advisory. There will be no further updates unless there is a material change in the nature of the vulnerability.



34
35
36
# File 'lib/intersight_client/models/tam_security_advisory_details.rb', line 34

def status
  @status
end

#temporal_scoreObject

CVSS version 3 temporal score for the security Advisory.



37
38
39
# File 'lib/intersight_client/models/tam_security_advisory_details.rb', line 37

def temporal_score
  @temporal_score
end

Class Method Details

.acceptable_attribute_mapObject

Returns the key-value map of all the JSON attributes this model knows about, including the ones defined in its parent(s)



80
81
82
# File 'lib/intersight_client/models/tam_security_advisory_details.rb', line 80

def self.acceptable_attribute_map
  attribute_map.merge(superclass.acceptable_attribute_map)
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about, including the ones defined in its parent(s)



75
76
77
# File 'lib/intersight_client/models/tam_security_advisory_details.rb', line 75

def self.acceptable_attributes
  attribute_map.values.concat(superclass.acceptable_attributes)
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



62
63
64
65
66
67
68
69
70
71
72
# File 'lib/intersight_client/models/tam_security_advisory_details.rb', line 62

def self.attribute_map
  {
    :'class_id' => :'ClassId',
    :'object_type' => :'ObjectType',
    :'base_score' => :'BaseScore',
    :'cve_ids' => :'CveIds',
    :'environmental_score' => :'EnvironmentalScore',
    :'status' => :'Status',
    :'temporal_score' => :'TemporalScore'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • Model attributes in the form of hash

Returns:

  • Returns the model itself



332
333
334
# File 'lib/intersight_client/models/tam_security_advisory_details.rb', line 332

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_all_ofObject

List of class defined in allOf (OpenAPI v3)



105
106
107
108
109
110
# File 'lib/intersight_client/models/tam_security_advisory_details.rb', line 105

def self.openapi_all_of
  [
  :'TamBaseAdvisoryDetails',
  :'TamSecurityAdvisoryDetailsAllOf'
  ]
end

.openapi_discriminator_nameObject

discriminator’s property name in OpenAPI v3



113
114
115
# File 'lib/intersight_client/models/tam_security_advisory_details.rb', line 113

def self.openapi_discriminator_name
  :'ClassId'
end

.openapi_nullableObject

List of attributes with nullable: true



98
99
100
101
102
# File 'lib/intersight_client/models/tam_security_advisory_details.rb', line 98

def self.openapi_nullable
  Set.new([
    :'cve_ids',
  ])
end

.openapi_typesObject

Attribute type mapping.



85
86
87
88
89
90
91
92
93
94
95
# File 'lib/intersight_client/models/tam_security_advisory_details.rb', line 85

def self.openapi_types
  {
    :'class_id' => :'String',
    :'object_type' => :'String',
    :'base_score' => :'Float',
    :'cve_ids' => :'Array<String>',
    :'environmental_score' => :'Float',
    :'status' => :'String',
    :'temporal_score' => :'Float'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • to be compared



305
306
307
308
309
310
311
312
313
314
315
# File 'lib/intersight_client/models/tam_security_advisory_details.rb', line 305

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      class_id == o.class_id &&
      object_type == o.object_type &&
      base_score == o.base_score &&
      cve_ids == o.cve_ids &&
      environmental_score == o.environmental_score &&
      status == o.status &&
      temporal_score == o.temporal_score && super(o)
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • type Data type

  • value Value to be deserialized

Returns:

  • Deserialized data



363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
# File 'lib/intersight_client/models/tam_security_advisory_details.rb', line 363

def _deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = IntersightClient.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • Any valid value

Returns:

  • Returns the value in the form of hash



434
435
436
437
438
439
440
441
442
443
444
445
446
# File 'lib/intersight_client/models/tam_security_advisory_details.rb', line 434

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • Model attributes in the form of hash

Returns:

  • Returns the model itself



339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
# File 'lib/intersight_client/models/tam_security_advisory_details.rb', line 339

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  super(attributes)
  TamSecurityAdvisoryDetails.openapi_types.each_pair do |key, type|
    if attributes[TamSecurityAdvisoryDetails.attribute_map[key]].nil? && TamSecurityAdvisoryDetails.openapi_nullable.include?(key)
      self.send("#{key}=", nil)
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[TamSecurityAdvisoryDetails.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[TamSecurityAdvisoryDetails.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[TamSecurityAdvisoryDetails.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[TamSecurityAdvisoryDetails.attribute_map[key]]))
    end
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • to be compared

Returns:

See Also:

  • `==` method


319
320
321
# File 'lib/intersight_client/models/tam_security_advisory_details.rb', line 319

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • Hash code



325
326
327
# File 'lib/intersight_client/models/tam_security_advisory_details.rb', line 325

def hash
  [class_id, object_type, base_score, cve_ids, environmental_score, status, temporal_score].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
# File 'lib/intersight_client/models/tam_security_advisory_details.rb', line 174

def list_invalid_properties
  invalid_properties = super
  if @class_id.nil?
    invalid_properties.push('invalid value for "class_id", class_id cannot be nil.')
  end

  if @object_type.nil?
    invalid_properties.push('invalid value for "object_type", object_type cannot be nil.')
  end

  if !@base_score.nil? && @base_score > 10.0
    invalid_properties.push('invalid value for "base_score", must be smaller than or equal to 10.0.')
  end

  if !@base_score.nil? && @base_score < 0.0
    invalid_properties.push('invalid value for "base_score", must be greater than or equal to 0.0.')
  end

  if !@environmental_score.nil? && @environmental_score > 10.0
    invalid_properties.push('invalid value for "environmental_score", must be smaller than or equal to 10.0.')
  end

  if !@environmental_score.nil? && @environmental_score < 0.0
    invalid_properties.push('invalid value for "environmental_score", must be greater than or equal to 0.0.')
  end

  if !@temporal_score.nil? && @temporal_score > 10.0
    invalid_properties.push('invalid value for "temporal_score", must be smaller than or equal to 10.0.')
  end

  if !@temporal_score.nil? && @temporal_score < 0.0
    invalid_properties.push('invalid value for "temporal_score", must be greater than or equal to 0.0.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • Returns the object in the form of hash



410
411
412
# File 'lib/intersight_client/models/tam_security_advisory_details.rb', line 410

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • Returns the object in the form of hash



416
417
418
419
420
421
422
423
424
425
426
427
428
# File 'lib/intersight_client/models/tam_security_advisory_details.rb', line 416

def to_hash
  hash = super
  TamSecurityAdvisoryDetails.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = TamSecurityAdvisoryDetails.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • String presentation of the object



404
405
406
# File 'lib/intersight_client/models/tam_security_advisory_details.rb', line 404

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • true if the model is valid



213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
# File 'lib/intersight_client/models/tam_security_advisory_details.rb', line 213

def valid?
  return false if @class_id.nil?
  class_id_validator = EnumAttributeValidator.new('String', ["tam.SecurityAdvisoryDetails"])
  return false unless class_id_validator.valid?(@class_id)
  return false if @object_type.nil?
  object_type_validator = EnumAttributeValidator.new('String', ["tam.SecurityAdvisoryDetails"])
  return false unless object_type_validator.valid?(@object_type)
  return false if !@base_score.nil? && @base_score > 10.0
  return false if !@base_score.nil? && @base_score < 0.0
  return false if !@environmental_score.nil? && @environmental_score > 10.0
  return false if !@environmental_score.nil? && @environmental_score < 0.0
  status_validator = EnumAttributeValidator.new('String', ["interim", "final"])
  return false unless status_validator.valid?(@status)
  return false if !@temporal_score.nil? && @temporal_score > 10.0
  return false if !@temporal_score.nil? && @temporal_score < 0.0
  true && super
end