Class: IntersightClient::TelemetryDruidScanRequestAllOf
- Inherits:
-
Object
- Object
- IntersightClient::TelemetryDruidScanRequestAllOf
- Defined in:
- lib/intersight_client/models/telemetry_druid_scan_request_all_of.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#batch_size ⇒ Object
The maximum number of rows buffered before being returned to the client.
-
#columns ⇒ Object
A String array of dimensions and metrics to scan.
-
#context ⇒ Object
Returns the value of attribute context.
-
#data_source ⇒ Object
Returns the value of attribute data_source.
-
#filter ⇒ Object
Returns the value of attribute filter.
-
#intervals ⇒ Object
A JSON Object representing ISO-8601 Intervals.
-
#legacy ⇒ Object
Return results consistent with the legacy "scan-query" contrib extension.
-
#limit ⇒ Object
How many rows to return.
-
#order ⇒ Object
The ordering of returned rows based on timestamp.
-
#result_format ⇒ Object
How the results are represented, list, compactedList or valueVector.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns the key-value map of all the JSON attributes this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ TelemetryDruidScanRequestAllOf
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ TelemetryDruidScanRequestAllOf
Initializes the object
117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 |
# File 'lib/intersight_client/models/telemetry_druid_scan_request_all_of.rb', line 117 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `IntersightClient::TelemetryDruidScanRequestAllOf` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `#{self.class.name}`. Please check the name to make sure it's valid. List of attributes: " + self.class.acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'data_source') self.data_source = attributes[:'data_source'] end if attributes.key?(:'intervals') if (value = attributes[:'intervals']).is_a?(Array) self.intervals = value end end if attributes.key?(:'result_format') self.result_format = attributes[:'result_format'] else self.result_format = 'list' end if attributes.key?(:'filter') self.filter = attributes[:'filter'] end if attributes.key?(:'columns') if (value = attributes[:'columns']).is_a?(Array) self.columns = value end end if attributes.key?(:'batch_size') self.batch_size = attributes[:'batch_size'] else self.batch_size = 20480 end if attributes.key?(:'limit') self.limit = attributes[:'limit'] end if attributes.key?(:'order') self.order = attributes[:'order'] else self.order = 'none' end if attributes.key?(:'legacy') self.legacy = attributes[:'legacy'] else self.legacy = false end if attributes.key?(:'context') self.context = attributes[:'context'] end end |
Instance Attribute Details
#batch_size ⇒ Object
The maximum number of rows buffered before being returned to the client.
32 33 34 |
# File 'lib/intersight_client/models/telemetry_druid_scan_request_all_of.rb', line 32 def batch_size @batch_size end |
#columns ⇒ Object
A String array of dimensions and metrics to scan. If left empty, all dimensions and metrics are returned.
29 30 31 |
# File 'lib/intersight_client/models/telemetry_druid_scan_request_all_of.rb', line 29 def columns @columns end |
#context ⇒ Object
Returns the value of attribute context.
43 44 45 |
# File 'lib/intersight_client/models/telemetry_druid_scan_request_all_of.rb', line 43 def context @context end |
#data_source ⇒ Object
Returns the value of attribute data_source.
18 19 20 |
# File 'lib/intersight_client/models/telemetry_druid_scan_request_all_of.rb', line 18 def data_source @data_source end |
#filter ⇒ Object
Returns the value of attribute filter.
26 27 28 |
# File 'lib/intersight_client/models/telemetry_druid_scan_request_all_of.rb', line 26 def filter @filter end |
#intervals ⇒ Object
A JSON Object representing ISO-8601 Intervals. This defines the time ranges to run the query over.
21 22 23 |
# File 'lib/intersight_client/models/telemetry_druid_scan_request_all_of.rb', line 21 def intervals @intervals end |
#legacy ⇒ Object
Return results consistent with the legacy "scan-query" contrib extension. Defaults to the value set by druid.query.scan.legacy, which in turn defaults to false.
41 42 43 |
# File 'lib/intersight_client/models/telemetry_druid_scan_request_all_of.rb', line 41 def legacy @legacy end |
#limit ⇒ Object
How many rows to return. If not specified, all rows will be returned.
35 36 37 |
# File 'lib/intersight_client/models/telemetry_druid_scan_request_all_of.rb', line 35 def limit @limit end |
#order ⇒ Object
The ordering of returned rows based on timestamp. "ascending", "descending", and "none" (default) are supported. Currently, "ascending" and "descending" are only supported for queries where the __time column is included in the columns field and the requirements outlined in the time ordering section are met.
38 39 40 |
# File 'lib/intersight_client/models/telemetry_druid_scan_request_all_of.rb', line 38 def order @order end |
#result_format ⇒ Object
How the results are represented, list, compactedList or valueVector. Currently only list is supported.
24 25 26 |
# File 'lib/intersight_client/models/telemetry_druid_scan_request_all_of.rb', line 24 def result_format @result_format end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns the key-value map of all the JSON attributes this model knows about
89 90 91 |
# File 'lib/intersight_client/models/telemetry_druid_scan_request_all_of.rb', line 89 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
84 85 86 |
# File 'lib/intersight_client/models/telemetry_druid_scan_request_all_of.rb', line 84 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
68 69 70 71 72 73 74 75 76 77 78 79 80 81 |
# File 'lib/intersight_client/models/telemetry_druid_scan_request_all_of.rb', line 68 def self.attribute_map { :'data_source' => :'dataSource', :'intervals' => :'intervals', :'result_format' => :'resultFormat', :'filter' => :'filter', :'columns' => :'columns', :'batch_size' => :'batchSize', :'limit' => :'limit', :'order' => :'order', :'legacy' => :'legacy', :'context' => :'context' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
262 263 264 |
# File 'lib/intersight_client/models/telemetry_druid_scan_request_all_of.rb', line 262 def self.build_from_hash(attributes) new.build_from_hash(attributes) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
110 111 112 113 |
# File 'lib/intersight_client/models/telemetry_druid_scan_request_all_of.rb', line 110 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
94 95 96 97 98 99 100 101 102 103 104 105 106 107 |
# File 'lib/intersight_client/models/telemetry_druid_scan_request_all_of.rb', line 94 def self.openapi_types { :'data_source' => :'TelemetryDruidDataSource', :'intervals' => :'Array<String>', :'result_format' => :'String', :'filter' => :'TelemetryDruidFilter', :'columns' => :'Array<String>', :'batch_size' => :'Integer', :'limit' => :'Integer', :'order' => :'String', :'legacy' => :'Boolean', :'context' => :'TelemetryDruidQueryContext' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
232 233 234 235 236 237 238 239 240 241 242 243 244 245 |
# File 'lib/intersight_client/models/telemetry_druid_scan_request_all_of.rb', line 232 def ==(o) return true if self.equal?(o) self.class == o.class && data_source == o.data_source && intervals == o.intervals && result_format == o.result_format && filter == o.filter && columns == o.columns && batch_size == o.batch_size && limit == o.limit && order == o.order && legacy == o.legacy && context == o.context end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 |
# File 'lib/intersight_client/models/telemetry_druid_scan_request_all_of.rb', line 292 def _deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = IntersightClient.const_get(type) klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
363 364 365 366 367 368 369 370 371 372 373 374 375 |
# File 'lib/intersight_client/models/telemetry_druid_scan_request_all_of.rb', line 363 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 |
# File 'lib/intersight_client/models/telemetry_druid_scan_request_all_of.rb', line 269 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) TelemetryDruidScanRequestAllOf.openapi_types.each_pair do |key, type| if attributes[TelemetryDruidScanRequestAllOf.attribute_map[key]].nil? && TelemetryDruidScanRequestAllOf.openapi_nullable.include?(key) self.send("#{key}=", nil) elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[TelemetryDruidScanRequestAllOf.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[TelemetryDruidScanRequestAllOf.attribute_map[key]].map { |v| _deserialize($1, v) }) end elsif !attributes[TelemetryDruidScanRequestAllOf.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[TelemetryDruidScanRequestAllOf.attribute_map[key]])) end end self end |
#eql?(o) ⇒ Boolean
249 250 251 |
# File 'lib/intersight_client/models/telemetry_druid_scan_request_all_of.rb', line 249 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
255 256 257 |
# File 'lib/intersight_client/models/telemetry_druid_scan_request_all_of.rb', line 255 def hash [data_source, intervals, result_format, filter, columns, batch_size, limit, order, legacy, context].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
185 186 187 188 189 190 191 192 193 194 195 196 |
# File 'lib/intersight_client/models/telemetry_druid_scan_request_all_of.rb', line 185 def list_invalid_properties invalid_properties = Array.new if @data_source.nil? invalid_properties.push('invalid value for "data_source", data_source cannot be nil.') end if @intervals.nil? invalid_properties.push('invalid value for "intervals", intervals cannot be nil.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
339 340 341 |
# File 'lib/intersight_client/models/telemetry_druid_scan_request_all_of.rb', line 339 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
345 346 347 348 349 350 351 352 353 354 355 356 357 |
# File 'lib/intersight_client/models/telemetry_druid_scan_request_all_of.rb', line 345 def to_hash hash = {} TelemetryDruidScanRequestAllOf.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = TelemetryDruidScanRequestAllOf.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
333 334 335 |
# File 'lib/intersight_client/models/telemetry_druid_scan_request_all_of.rb', line 333 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
200 201 202 203 204 205 206 207 208 |
# File 'lib/intersight_client/models/telemetry_druid_scan_request_all_of.rb', line 200 def valid? return false if @data_source.nil? return false if @intervals.nil? result_format_validator = EnumAttributeValidator.new('String', ["list"]) return false unless result_format_validator.valid?(@result_format) order_validator = EnumAttributeValidator.new('String', ["none", "ascending", "descending"]) return false unless order_validator.valid?(@order) true end |