Class: IntersightClient::TelemetryDruidSegmentMetadataRequestAllOf

Inherits:
Object
  • Object
show all
Defined in:
lib/intersight_client/models/telemetry_druid_segment_metadata_request_all_of.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ TelemetryDruidSegmentMetadataRequestAllOf

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
# File 'lib/intersight_client/models/telemetry_druid_segment_metadata_request_all_of.rb', line 81

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `IntersightClient::TelemetryDruidSegmentMetadataRequestAllOf` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `#{self.class.name}`. Please check the name to make sure it's valid. List of attributes: " + self.class.acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'data_source')
    self.data_source = attributes[:'data_source']
  end

  if attributes.key?(:'intervals')
    if (value = attributes[:'intervals']).is_a?(Array)
      self.intervals = value
    end
  end

  if attributes.key?(:'to_include')
    self.to_include = attributes[:'to_include']
  end

  if attributes.key?(:'merge')
    self.merge = attributes[:'merge']
  end

  if attributes.key?(:'context')
    self.context = attributes[:'context']
  end

  if attributes.key?(:'analysis_types')
    if (value = attributes[:'analysis_types']).is_a?(Array)
      self.analysis_types = value
    end
  end

  if attributes.key?(:'lenient_aggregator_merge')
    self.lenient_aggregator_merge = attributes[:'lenient_aggregator_merge']
  end
end

Instance Attribute Details

#analysis_typesObject

A list of Strings specifying what column properties (e.g. cardinality, size) should be calculated and returned in the result. Defaults to [\“cardinality\”, \“interval\”, \“minmax\”], but can be overridden with using the segment metadata query config. * cardinality - in the result will return the estimated floor of cardinality for each column. Only relevant for dimension columns. * minmax - Estimated min/max values for each column. Only relevant for dimension columns. * size - in the result will contain the estimated total segment byte size as if the data were stored in text format. * intervals - in the result will contain the list of intervals associated with the queried segments. * timestampSpec - in the result will contain timestampSpec of data stored in segments. This can be null if timestampSpec of segments was unknown or unmergeable (if merging is enabled). * queryGranularity - in the result will contain query granularity of data stored in segments. This can be null if query granularity of segments was unknown or unmergeable (if merging is enabled). * aggregators - in the result will contain the list of aggregators usable for querying metric columns. This may be null if the aggregators are unknown or unmergeable (if merging is enabled). Merging can be strict or lenient. The form of the result is a map of column name to aggregator. * rollup - in the result is true/false/null. When merging is enabled, if some are rollup, others are not, result is null.



32
33
34
# File 'lib/intersight_client/models/telemetry_druid_segment_metadata_request_all_of.rb', line 32

def analysis_types
  @analysis_types
end

#contextObject

Returns the value of attribute context.



29
30
31
# File 'lib/intersight_client/models/telemetry_druid_segment_metadata_request_all_of.rb', line 29

def context
  @context
end

#data_sourceObject

Returns the value of attribute data_source.



18
19
20
# File 'lib/intersight_client/models/telemetry_druid_segment_metadata_request_all_of.rb', line 18

def data_source
  @data_source
end

#intervalsObject

A JSON Object representing ISO-8601 Intervals. This defines the time ranges to run the query over. If an interval is not specified, the query will use a default interval that spans a configurable period before the end time of the most recent segment.



21
22
23
# File 'lib/intersight_client/models/telemetry_druid_segment_metadata_request_all_of.rb', line 21

def intervals
  @intervals
end

#lenient_aggregator_mergeObject

If true, and if the \“aggregators\” analysisType is enabled, aggregators will be merged leniently.



35
36
37
# File 'lib/intersight_client/models/telemetry_druid_segment_metadata_request_all_of.rb', line 35

def lenient_aggregator_merge
  @lenient_aggregator_merge
end

#mergeObject

Merge all individual segment metadata results into a single result.



27
28
29
# File 'lib/intersight_client/models/telemetry_druid_segment_metadata_request_all_of.rb', line 27

def merge
  @merge
end

#to_includeObject

A JSON Object representing what columns should be included in the result. Defaults to \“all\”.



24
25
26
# File 'lib/intersight_client/models/telemetry_druid_segment_metadata_request_all_of.rb', line 24

def to_include
  @to_include
end

Class Method Details

.acceptable_attribute_mapObject

Returns the key-value map of all the JSON attributes this model knows about



56
57
58
# File 'lib/intersight_client/models/telemetry_druid_segment_metadata_request_all_of.rb', line 56

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



51
52
53
# File 'lib/intersight_client/models/telemetry_druid_segment_metadata_request_all_of.rb', line 51

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



38
39
40
41
42
43
44
45
46
47
48
# File 'lib/intersight_client/models/telemetry_druid_segment_metadata_request_all_of.rb', line 38

def self.attribute_map
  {
    :'data_source' => :'dataSource',
    :'intervals' => :'intervals',
    :'to_include' => :'toInclude',
    :'merge' => :'merge',
    :'context' => :'context',
    :'analysis_types' => :'analysisTypes',
    :'lenient_aggregator_merge' => :'lenientAggregatorMerge'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



174
175
176
# File 'lib/intersight_client/models/telemetry_druid_segment_metadata_request_all_of.rb', line 174

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_nullableObject

List of attributes with nullable: true



74
75
76
77
# File 'lib/intersight_client/models/telemetry_druid_segment_metadata_request_all_of.rb', line 74

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



61
62
63
64
65
66
67
68
69
70
71
# File 'lib/intersight_client/models/telemetry_druid_segment_metadata_request_all_of.rb', line 61

def self.openapi_types
  {
    :'data_source' => :'TelemetryDruidDataSource',
    :'intervals' => :'Array<String>',
    :'to_include' => :'Object',
    :'merge' => :'Boolean',
    :'context' => :'TelemetryDruidQueryContext',
    :'analysis_types' => :'Array<String>',
    :'lenient_aggregator_merge' => :'Boolean'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



147
148
149
150
151
152
153
154
155
156
157
# File 'lib/intersight_client/models/telemetry_druid_segment_metadata_request_all_of.rb', line 147

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      data_source == o.data_source &&
      intervals == o.intervals &&
      to_include == o.to_include &&
      merge == o.merge &&
      context == o.context &&
      analysis_types == o.analysis_types &&
      lenient_aggregator_merge == o.lenient_aggregator_merge
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
# File 'lib/intersight_client/models/telemetry_druid_segment_metadata_request_all_of.rb', line 204

def _deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = IntersightClient.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



275
276
277
278
279
280
281
282
283
284
285
286
287
# File 'lib/intersight_client/models/telemetry_druid_segment_metadata_request_all_of.rb', line 275

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
# File 'lib/intersight_client/models/telemetry_druid_segment_metadata_request_all_of.rb', line 181

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  TelemetryDruidSegmentMetadataRequestAllOf.openapi_types.each_pair do |key, type|
    if attributes[TelemetryDruidSegmentMetadataRequestAllOf.attribute_map[key]].nil? && TelemetryDruidSegmentMetadataRequestAllOf.openapi_nullable.include?(key)
      self.send("#{key}=", nil)
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[TelemetryDruidSegmentMetadataRequestAllOf.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[TelemetryDruidSegmentMetadataRequestAllOf.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[TelemetryDruidSegmentMetadataRequestAllOf.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[TelemetryDruidSegmentMetadataRequestAllOf.attribute_map[key]]))
    end
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


161
162
163
# File 'lib/intersight_client/models/telemetry_druid_segment_metadata_request_all_of.rb', line 161

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



167
168
169
# File 'lib/intersight_client/models/telemetry_druid_segment_metadata_request_all_of.rb', line 167

def hash
  [data_source, intervals, to_include, merge, context, analysis_types, lenient_aggregator_merge].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



129
130
131
132
133
134
135
136
# File 'lib/intersight_client/models/telemetry_druid_segment_metadata_request_all_of.rb', line 129

def list_invalid_properties
  invalid_properties = Array.new
  if @data_source.nil?
    invalid_properties.push('invalid value for "data_source", data_source cannot be nil.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



251
252
253
# File 'lib/intersight_client/models/telemetry_druid_segment_metadata_request_all_of.rb', line 251

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



257
258
259
260
261
262
263
264
265
266
267
268
269
# File 'lib/intersight_client/models/telemetry_druid_segment_metadata_request_all_of.rb', line 257

def to_hash
  hash = {}
  TelemetryDruidSegmentMetadataRequestAllOf.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = TelemetryDruidSegmentMetadataRequestAllOf.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



245
246
247
# File 'lib/intersight_client/models/telemetry_druid_segment_metadata_request_all_of.rb', line 245

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



140
141
142
143
# File 'lib/intersight_client/models/telemetry_druid_segment_metadata_request_all_of.rb', line 140

def valid?
  return false if @data_source.nil?
  true
end