Class: IntersightClient::VirtualizationCloudVmConfiguration

Inherits:
VirtualizationBaseVmConfiguration show all
Defined in:
lib/intersight_client/models/virtualization_cloud_vm_configuration.rb

Overview

Specify Aws virtual machine configuration data.

Direct Known Subclasses

VirtualizationAwsVmConfiguration

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ VirtualizationCloudVmConfiguration

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
# File 'lib/intersight_client/models/virtualization_cloud_vm_configuration.rb', line 139

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `IntersightClient::VirtualizationCloudVmConfiguration` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `#{self.class.name}`. Please check the name to make sure it's valid. List of attributes: " + self.class.acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  # call parent's initialize
  super(attributes)

  if attributes.key?(:'class_id')
    self.class_id = attributes[:'class_id']
  else
    self.class_id = 'virtualization.AwsVmConfiguration'
  end

  if attributes.key?(:'object_type')
    self.object_type = attributes[:'object_type']
  else
    self.object_type = 'virtualization.AwsVmConfiguration'
  end

  if attributes.key?(:'availability_zone_id')
    self.availability_zone_id = attributes[:'availability_zone_id']
  end

  if attributes.key?(:'compute')
    self.compute = attributes[:'compute']
  end

  if attributes.key?(:'image_id')
    self.image_id = attributes[:'image_id']
  end

  if attributes.key?(:'key_pair_name')
    self.key_pair_name = attributes[:'key_pair_name']
  end

  if attributes.key?(:'network')
    self.network = attributes[:'network']
  end

  if attributes.key?(:'region_id')
    self.region_id = attributes[:'region_id']
  end

  if attributes.key?(:'security_groups')
    if (value = attributes[:'security_groups']).is_a?(Array)
      self.security_groups = value
    end
  end

  if attributes.key?(:'storage')
    self.storage = attributes[:'storage']
  end

  if attributes.key?(:'vm_id')
    self.vm_id = attributes[:'vm_id']
  end
end

Instance Attribute Details

#availability_zone_idObject

Availability zone for the VM.



26
27
28
# File 'lib/intersight_client/models/virtualization_cloud_vm_configuration.rb', line 26

def availability_zone_id
  @availability_zone_id
end

#class_idObject

The fully-qualified name of the instantiated, concrete type. This property is used as a discriminator to identify the type of the payload when marshaling and unmarshaling data. The enum values provides the list of concrete types that can be instantiated from this abstract type.



20
21
22
# File 'lib/intersight_client/models/virtualization_cloud_vm_configuration.rb', line 20

def class_id
  @class_id
end

#computeObject

Returns the value of attribute compute.



28
29
30
# File 'lib/intersight_client/models/virtualization_cloud_vm_configuration.rb', line 28

def compute
  @compute
end

#image_idObject

Virtual machine image used by this VM.



31
32
33
# File 'lib/intersight_client/models/virtualization_cloud_vm_configuration.rb', line 31

def image_id
  @image_id
end

#key_pair_nameObject

Keypair for accessing the VM.



34
35
36
# File 'lib/intersight_client/models/virtualization_cloud_vm_configuration.rb', line 34

def key_pair_name
  @key_pair_name
end

#networkObject

Returns the value of attribute network.



36
37
38
# File 'lib/intersight_client/models/virtualization_cloud_vm_configuration.rb', line 36

def network
  @network
end

#object_typeObject

The fully-qualified name of the instantiated, concrete type. The value should be the same as the ‘ClassId’ property. The enum values provides the list of concrete types that can be instantiated from this abstract type.



23
24
25
# File 'lib/intersight_client/models/virtualization_cloud_vm_configuration.rb', line 23

def object_type
  @object_type
end

#region_idObject

Region where the VM instance is created.



39
40
41
# File 'lib/intersight_client/models/virtualization_cloud_vm_configuration.rb', line 39

def region_id
  @region_id
end

#security_groupsObject

Returns the value of attribute security_groups.



41
42
43
# File 'lib/intersight_client/models/virtualization_cloud_vm_configuration.rb', line 41

def security_groups
  @security_groups
end

#storageObject

Returns the value of attribute storage.



43
44
45
# File 'lib/intersight_client/models/virtualization_cloud_vm_configuration.rb', line 43

def storage
  @storage
end

#vm_idObject

Unique Identifier of the cloud VM.



46
47
48
# File 'lib/intersight_client/models/virtualization_cloud_vm_configuration.rb', line 46

def vm_id
  @vm_id
end

Class Method Details

.acceptable_attribute_mapObject

Returns the key-value map of all the JSON attributes this model knows about, including the ones defined in its parent(s)



93
94
95
# File 'lib/intersight_client/models/virtualization_cloud_vm_configuration.rb', line 93

def self.acceptable_attribute_map
  attribute_map.merge(superclass.acceptable_attribute_map)
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about, including the ones defined in its parent(s)



88
89
90
# File 'lib/intersight_client/models/virtualization_cloud_vm_configuration.rb', line 88

def self.acceptable_attributes
  attribute_map.values.concat(superclass.acceptable_attributes)
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
# File 'lib/intersight_client/models/virtualization_cloud_vm_configuration.rb', line 71

def self.attribute_map
  {
    :'class_id' => :'ClassId',
    :'object_type' => :'ObjectType',
    :'availability_zone_id' => :'AvailabilityZoneId',
    :'compute' => :'Compute',
    :'image_id' => :'ImageId',
    :'key_pair_name' => :'KeyPairName',
    :'network' => :'Network',
    :'region_id' => :'RegionId',
    :'security_groups' => :'SecurityGroups',
    :'storage' => :'Storage',
    :'vm_id' => :'VmId'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



286
287
288
# File 'lib/intersight_client/models/virtualization_cloud_vm_configuration.rb', line 286

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_all_ofObject

List of class defined in allOf (OpenAPI v3)



125
126
127
128
129
130
# File 'lib/intersight_client/models/virtualization_cloud_vm_configuration.rb', line 125

def self.openapi_all_of
  [
  :'VirtualizationBaseVmConfiguration',
  :'VirtualizationCloudVmConfigurationAllOf'
  ]
end

.openapi_discriminator_nameObject

discriminator’s property name in OpenAPI v3



133
134
135
# File 'lib/intersight_client/models/virtualization_cloud_vm_configuration.rb', line 133

def self.openapi_discriminator_name
  :'ClassId'
end

.openapi_nullableObject

List of attributes with nullable: true



115
116
117
118
119
120
121
122
# File 'lib/intersight_client/models/virtualization_cloud_vm_configuration.rb', line 115

def self.openapi_nullable
  Set.new([
    :'compute',
    :'network',
    :'security_groups',
    :'storage',
  ])
end

.openapi_typesObject

Attribute type mapping.



98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
# File 'lib/intersight_client/models/virtualization_cloud_vm_configuration.rb', line 98

def self.openapi_types
  {
    :'class_id' => :'String',
    :'object_type' => :'String',
    :'availability_zone_id' => :'String',
    :'compute' => :'VirtualizationCloudVmComputeConfiguration',
    :'image_id' => :'String',
    :'key_pair_name' => :'String',
    :'network' => :'VirtualizationCloudVmNetworkConfiguration',
    :'region_id' => :'String',
    :'security_groups' => :'Array<String>',
    :'storage' => :'VirtualizationCloudVmStorageConfiguration',
    :'vm_id' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
# File 'lib/intersight_client/models/virtualization_cloud_vm_configuration.rb', line 255

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      class_id == o.class_id &&
      object_type == o.object_type &&
      availability_zone_id == o.availability_zone_id &&
      compute == o.compute &&
      image_id == o.image_id &&
      key_pair_name == o.key_pair_name &&
      network == o.network &&
      region_id == o.region_id &&
      security_groups == o.security_groups &&
      storage == o.storage &&
      vm_id == o.vm_id && super(o)
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
# File 'lib/intersight_client/models/virtualization_cloud_vm_configuration.rb', line 317

def _deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = IntersightClient.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



388
389
390
391
392
393
394
395
396
397
398
399
400
# File 'lib/intersight_client/models/virtualization_cloud_vm_configuration.rb', line 388

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
# File 'lib/intersight_client/models/virtualization_cloud_vm_configuration.rb', line 293

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  super(attributes)
  VirtualizationCloudVmConfiguration.openapi_types.each_pair do |key, type|
    if attributes[VirtualizationCloudVmConfiguration.attribute_map[key]].nil? && VirtualizationCloudVmConfiguration.openapi_nullable.include?(key)
      self.send("#{key}=", nil)
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[VirtualizationCloudVmConfiguration.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[VirtualizationCloudVmConfiguration.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[VirtualizationCloudVmConfiguration.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[VirtualizationCloudVmConfiguration.attribute_map[key]]))
    end
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


273
274
275
# File 'lib/intersight_client/models/virtualization_cloud_vm_configuration.rb', line 273

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



279
280
281
# File 'lib/intersight_client/models/virtualization_cloud_vm_configuration.rb', line 279

def hash
  [class_id, object_type, availability_zone_id, compute, image_id, key_pair_name, network, region_id, security_groups, storage, vm_id].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



208
209
210
211
212
213
214
215
216
217
218
219
# File 'lib/intersight_client/models/virtualization_cloud_vm_configuration.rb', line 208

def list_invalid_properties
  invalid_properties = super
  if @class_id.nil?
    invalid_properties.push('invalid value for "class_id", class_id cannot be nil.')
  end

  if @object_type.nil?
    invalid_properties.push('invalid value for "object_type", object_type cannot be nil.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



364
365
366
# File 'lib/intersight_client/models/virtualization_cloud_vm_configuration.rb', line 364

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



370
371
372
373
374
375
376
377
378
379
380
381
382
# File 'lib/intersight_client/models/virtualization_cloud_vm_configuration.rb', line 370

def to_hash
  hash = super
  VirtualizationCloudVmConfiguration.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = VirtualizationCloudVmConfiguration.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



358
359
360
# File 'lib/intersight_client/models/virtualization_cloud_vm_configuration.rb', line 358

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



223
224
225
226
227
228
229
230
231
# File 'lib/intersight_client/models/virtualization_cloud_vm_configuration.rb', line 223

def valid?
  return false if @class_id.nil?
  class_id_validator = EnumAttributeValidator.new('String', ["virtualization.AwsVmConfiguration"])
  return false unless class_id_validator.valid?(@class_id)
  return false if @object_type.nil?
  object_type_validator = EnumAttributeValidator.new('String', ["virtualization.AwsVmConfiguration"])
  return false unless object_type_validator.valid?(@object_type)
  true && super
end