Class: IntersightClient::VirtualizationVirtualMachineDisk

Inherits:
MoBaseComplexType show all
Defined in:
lib/intersight_client/models/virtualization_virtual_machine_disk.rb

Overview

Virtual machine disk configuration data.

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ VirtualizationVirtualMachineDisk

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
# File 'lib/intersight_client/models/virtualization_virtual_machine_disk.rb', line 124

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `IntersightClient::VirtualizationVirtualMachineDisk` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `#{self.class.name}`. Please check the name to make sure it's valid. List of attributes: " + self.class.acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  # call parent's initialize
  super(attributes)

  if attributes.key?(:'class_id')
    self.class_id = attributes[:'class_id']
  else
    self.class_id = 'virtualization.VirtualMachineDisk'
  end

  if attributes.key?(:'object_type')
    self.object_type = attributes[:'object_type']
  else
    self.object_type = 'virtualization.VirtualMachineDisk'
  end

  if attributes.key?(:'bus')
    self.bus = attributes[:'bus']
  else
    self.bus = 'virtio'
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  end

  if attributes.key?(:'order')
    self.order = attributes[:'order']
  end

  if attributes.key?(:'type')
    self.type = attributes[:'type']
  else
    self.type = 'hdd'
  end

  if attributes.key?(:'virtual_disk')
    self.virtual_disk = attributes[:'virtual_disk']
  end

  if attributes.key?(:'virtual_disk_reference')
    self.virtual_disk_reference = attributes[:'virtual_disk_reference']
  end
end

Instance Attribute Details

#busObject

Disk bus name given for a virtual machine. * virtio - Disk uses the same paths as a bare-metal system. This simplifies physical-to-virtual and virtual-to-virtual migration. * sata - Serial ATA (SATA, abbreviated from Serial AT Attachment) is a computer bus interface that connects host bus adapters to mass storage devices such as hard disk drives, optical drives, and solid-state drives. * scsi - SCSI (Small Computer System Interface) bus used..



26
27
28
# File 'lib/intersight_client/models/virtualization_virtual_machine_disk.rb', line 26

def bus
  @bus
end

#class_idObject

The fully-qualified name of the instantiated, concrete type. This property is used as a discriminator to identify the type of the payload when marshaling and unmarshaling data.



20
21
22
# File 'lib/intersight_client/models/virtualization_virtual_machine_disk.rb', line 20

def class_id
  @class_id
end

#nameObject

Virtual machine network bridge name.



29
30
31
# File 'lib/intersight_client/models/virtualization_virtual_machine_disk.rb', line 29

def name
  @name
end

#object_typeObject

The fully-qualified name of the instantiated, concrete type. The value should be the same as the ‘ClassId’ property.



23
24
25
# File 'lib/intersight_client/models/virtualization_virtual_machine_disk.rb', line 23

def object_type
  @object_type
end

#orderObject

Priority order of the disk.



32
33
34
# File 'lib/intersight_client/models/virtualization_virtual_machine_disk.rb', line 32

def order
  @order
end

#typeObject

Disk type hdd or cdrom for a virtual machine. * hdd - Allows the virtual machine to mount disk from hard disk drive (hdd) image. * cdrom - Allows the virtual machine to mount disk from compact disk (cd) image.



35
36
37
# File 'lib/intersight_client/models/virtualization_virtual_machine_disk.rb', line 35

def type
  @type
end

#virtual_diskObject

Returns the value of attribute virtual_disk.



37
38
39
# File 'lib/intersight_client/models/virtualization_virtual_machine_disk.rb', line 37

def virtual_disk
  @virtual_disk
end

#virtual_disk_referenceObject

Name of the existing virtual disk to be attached to the Virtual Machine.



40
41
42
# File 'lib/intersight_client/models/virtualization_virtual_machine_disk.rb', line 40

def virtual_disk_reference
  @virtual_disk_reference
end

Class Method Details

.acceptable_attribute_mapObject

Returns the key-value map of all the JSON attributes this model knows about, including the ones defined in its parent(s)



84
85
86
# File 'lib/intersight_client/models/virtualization_virtual_machine_disk.rb', line 84

def self.acceptable_attribute_map
  attribute_map.merge(superclass.acceptable_attribute_map)
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about, including the ones defined in its parent(s)



79
80
81
# File 'lib/intersight_client/models/virtualization_virtual_machine_disk.rb', line 79

def self.acceptable_attributes
  attribute_map.values.concat(superclass.acceptable_attributes)
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



65
66
67
68
69
70
71
72
73
74
75
76
# File 'lib/intersight_client/models/virtualization_virtual_machine_disk.rb', line 65

def self.attribute_map
  {
    :'class_id' => :'ClassId',
    :'object_type' => :'ObjectType',
    :'bus' => :'Bus',
    :'name' => :'Name',
    :'order' => :'Order',
    :'type' => :'Type',
    :'virtual_disk' => :'VirtualDisk',
    :'virtual_disk_reference' => :'VirtualDiskReference'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



297
298
299
# File 'lib/intersight_client/models/virtualization_virtual_machine_disk.rb', line 297

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_all_ofObject

List of class defined in allOf (OpenAPI v3)



110
111
112
113
114
115
# File 'lib/intersight_client/models/virtualization_virtual_machine_disk.rb', line 110

def self.openapi_all_of
  [
  :'MoBaseComplexType',
  :'VirtualizationVirtualMachineDiskAllOf'
  ]
end

.openapi_discriminator_nameObject

discriminator’s property name in OpenAPI v3



118
119
120
# File 'lib/intersight_client/models/virtualization_virtual_machine_disk.rb', line 118

def self.openapi_discriminator_name
  :'ClassId'
end

.openapi_nullableObject

List of attributes with nullable: true



103
104
105
106
107
# File 'lib/intersight_client/models/virtualization_virtual_machine_disk.rb', line 103

def self.openapi_nullable
  Set.new([
    :'virtual_disk',
  ])
end

.openapi_typesObject

Attribute type mapping.



89
90
91
92
93
94
95
96
97
98
99
100
# File 'lib/intersight_client/models/virtualization_virtual_machine_disk.rb', line 89

def self.openapi_types
  {
    :'class_id' => :'String',
    :'object_type' => :'String',
    :'bus' => :'String',
    :'name' => :'String',
    :'order' => :'Integer',
    :'type' => :'String',
    :'virtual_disk' => :'VirtualizationVirtualDiskConfig',
    :'virtual_disk_reference' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



269
270
271
272
273
274
275
276
277
278
279
280
# File 'lib/intersight_client/models/virtualization_virtual_machine_disk.rb', line 269

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      class_id == o.class_id &&
      object_type == o.object_type &&
      bus == o.bus &&
      name == o.name &&
      order == o.order &&
      type == o.type &&
      virtual_disk == o.virtual_disk &&
      virtual_disk_reference == o.virtual_disk_reference && super(o)
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
# File 'lib/intersight_client/models/virtualization_virtual_machine_disk.rb', line 328

def _deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = IntersightClient.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



399
400
401
402
403
404
405
406
407
408
409
410
411
# File 'lib/intersight_client/models/virtualization_virtual_machine_disk.rb', line 399

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
# File 'lib/intersight_client/models/virtualization_virtual_machine_disk.rb', line 304

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  super(attributes)
  VirtualizationVirtualMachineDisk.openapi_types.each_pair do |key, type|
    if attributes[VirtualizationVirtualMachineDisk.attribute_map[key]].nil? && VirtualizationVirtualMachineDisk.openapi_nullable.include?(key)
      self.send("#{key}=", nil)
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[VirtualizationVirtualMachineDisk.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[VirtualizationVirtualMachineDisk.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[VirtualizationVirtualMachineDisk.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[VirtualizationVirtualMachineDisk.attribute_map[key]]))
    end
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


284
285
286
# File 'lib/intersight_client/models/virtualization_virtual_machine_disk.rb', line 284

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



290
291
292
# File 'lib/intersight_client/models/virtualization_virtual_machine_disk.rb', line 290

def hash
  [class_id, object_type, bus, name, order, type, virtual_disk, virtual_disk_reference].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
# File 'lib/intersight_client/models/virtualization_virtual_machine_disk.rb', line 183

def list_invalid_properties
  invalid_properties = super
  if @class_id.nil?
    invalid_properties.push('invalid value for "class_id", class_id cannot be nil.')
  end

  if @object_type.nil?
    invalid_properties.push('invalid value for "object_type", object_type cannot be nil.')
  end

  if !@order.nil? && @order < 1
    invalid_properties.push('invalid value for "order", must be greater than or equal to 1.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



375
376
377
# File 'lib/intersight_client/models/virtualization_virtual_machine_disk.rb', line 375

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



381
382
383
384
385
386
387
388
389
390
391
392
393
# File 'lib/intersight_client/models/virtualization_virtual_machine_disk.rb', line 381

def to_hash
  hash = super
  VirtualizationVirtualMachineDisk.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = VirtualizationVirtualMachineDisk.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



369
370
371
# File 'lib/intersight_client/models/virtualization_virtual_machine_disk.rb', line 369

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



202
203
204
205
206
207
208
209
210
211
212
213
214
215
# File 'lib/intersight_client/models/virtualization_virtual_machine_disk.rb', line 202

def valid?
  return false if @class_id.nil?
  class_id_validator = EnumAttributeValidator.new('String', ["virtualization.VirtualMachineDisk"])
  return false unless class_id_validator.valid?(@class_id)
  return false if @object_type.nil?
  object_type_validator = EnumAttributeValidator.new('String', ["virtualization.VirtualMachineDisk"])
  return false unless object_type_validator.valid?(@object_type)
  bus_validator = EnumAttributeValidator.new('String', ["virtio", "sata", "scsi"])
  return false unless bus_validator.valid?(@bus)
  return false if !@order.nil? && @order < 1
  type_validator = EnumAttributeValidator.new('String', ["hdd", "cdrom"])
  return false unless type_validator.valid?(@type)
  true && super
end