Class: IntersightClient::VirtualizationVmwareDatastoreCluster

Inherits:
VirtualizationBaseDatastoreCluster show all
Defined in:
lib/intersight_client/models/virtualization_vmware_datastore_cluster.rb

Overview

The VMware Datastore cluster entity with its attributes. Datastore cluster is a collection of datastores with shared resources and a shared management interface.

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Attributes inherited from VirtualizationBaseDatastoreCluster

#capacity, #datastore_count, #host_count, #identity, #name, #type, #vm_count

Attributes inherited from VirtualizationBaseSourceDevice

#registered_device

Attributes inherited from MoBaseMo

#account_moid, #ancestors, #create_time, #display_names, #domain_group_moid, #mod_time, #moid, #owners, #parent, #permission_resources, #shared_scope, #tags, #version_context

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ VirtualizationVmwareDatastoreCluster

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
# File 'lib/intersight_client/models/virtualization_vmware_datastore_cluster.rb', line 183

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `IntersightClient::VirtualizationVmwareDatastoreCluster` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `#{self.class.name}`. Please check the name to make sure it's valid. List of attributes: " + self.class.acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  # call parent's initialize
  super(attributes)

  if attributes.key?(:'class_id')
    self.class_id = attributes[:'class_id']
  else
    self.class_id = 'virtualization.VmwareDatastoreCluster'
  end

  if attributes.key?(:'object_type')
    self.object_type = attributes[:'object_type']
  else
    self.object_type = 'virtualization.VmwareDatastoreCluster'
  end

  if attributes.key?(:'automation_level')
    self.automation_level = attributes[:'automation_level']
  end

  if attributes.key?(:'free_space_threshold')
    self.free_space_threshold = attributes[:'free_space_threshold']
  end

  if attributes.key?(:'inventory_path')
    self.inventory_path = attributes[:'inventory_path']
  end

  if attributes.key?(:'io_latency_threshold')
    self.io_latency_threshold = attributes[:'io_latency_threshold']
  end

  if attributes.key?(:'io_load_balance_automation_mode')
    self.io_load_balance_automation_mode = attributes[:'io_load_balance_automation_mode']
  end

  if attributes.key?(:'io_load_imbalance_threshold')
    self.io_load_imbalance_threshold = attributes[:'io_load_imbalance_threshold']
  end

  if attributes.key?(:'io_metrics_enabled')
    self.io_metrics_enabled = attributes[:'io_metrics_enabled']
  end

  if attributes.key?(:'min_space_utilization_difference')
    self.min_space_utilization_difference = attributes[:'min_space_utilization_difference']
  end

  if attributes.key?(:'policy_enforcement_automation_mode')
    self.policy_enforcement_automation_mode = attributes[:'policy_enforcement_automation_mode']
  end

  if attributes.key?(:'reservable_percent_threshold')
    self.reservable_percent_threshold = attributes[:'reservable_percent_threshold']
  end

  if attributes.key?(:'rule_enforcement_automation_mode')
    self.rule_enforcement_automation_mode = attributes[:'rule_enforcement_automation_mode']
  end

  if attributes.key?(:'space_load_balance_automation_mode')
    self.space_load_balance_automation_mode = attributes[:'space_load_balance_automation_mode']
  end

  if attributes.key?(:'space_threshold_mode')
    self.space_threshold_mode = attributes[:'space_threshold_mode']
  end

  if attributes.key?(:'status')
    self.status = attributes[:'status']
  else
    self.status = 'Unknown'
  end

  if attributes.key?(:'storage_drs_enabled')
    self.storage_drs_enabled = attributes[:'storage_drs_enabled']
  end

  if attributes.key?(:'utilized_space_threshold')
    self.utilized_space_threshold = attributes[:'utilized_space_threshold']
  end

  if attributes.key?(:'vm_evacuation_automation_mode')
    self.vm_evacuation_automation_mode = attributes[:'vm_evacuation_automation_mode']
  end

  if attributes.key?(:'datacenter')
    self.datacenter = attributes[:'datacenter']
  end
end

Instance Attribute Details

#automation_levelObject

The global automation level for all virtual machines in this datastore cluster.



26
27
28
# File 'lib/intersight_client/models/virtualization_vmware_datastore_cluster.rb', line 26

def automation_level
  @automation_level
end

#class_idObject

The fully-qualified name of the instantiated, concrete type. This property is used as a discriminator to identify the type of the payload when marshaling and unmarshaling data.



20
21
22
# File 'lib/intersight_client/models/virtualization_vmware_datastore_cluster.rb', line 20

def class_id
  @class_id
end

#datacenterObject

Returns the value of attribute datacenter.



76
77
78
# File 'lib/intersight_client/models/virtualization_vmware_datastore_cluster.rb', line 76

def datacenter
  @datacenter
end

#free_space_thresholdObject

Minimum level of free space for each datastore that is the threshold for action.



29
30
31
# File 'lib/intersight_client/models/virtualization_vmware_datastore_cluster.rb', line 29

def free_space_threshold
  @free_space_threshold
end

#inventory_pathObject

Inventory path of the Datastore Cluster.



32
33
34
# File 'lib/intersight_client/models/virtualization_vmware_datastore_cluster.rb', line 32

def inventory_path
  @inventory_path
end

#io_latency_thresholdObject

Minimum I/O latency for each datastore below which I/O load balancing moves are not considered.



35
36
37
# File 'lib/intersight_client/models/virtualization_vmware_datastore_cluster.rb', line 35

def io_latency_threshold
  @io_latency_threshold
end

#io_load_balance_automation_modeObject

Storage DRS behavior when it generates recommendations for correcting I/O load imbalance in a datastore cluster.



38
39
40
# File 'lib/intersight_client/models/virtualization_vmware_datastore_cluster.rb', line 38

def io_load_balance_automation_mode
  @io_load_balance_automation_mode
end

#io_load_imbalance_thresholdObject

Amount of imbalance that Storage DRS should tolerate.



41
42
43
# File 'lib/intersight_client/models/virtualization_vmware_datastore_cluster.rb', line 41

def io_load_imbalance_threshold
  @io_load_imbalance_threshold
end

#io_metrics_enabledObject

Is I/O Metrics enabled for this datastore cluster.



44
45
46
# File 'lib/intersight_client/models/virtualization_vmware_datastore_cluster.rb', line 44

def io_metrics_enabled
  @io_metrics_enabled
end

#min_space_utilization_differenceObject

Specify how much of an improvement DRS should look for before making a recommendation or performing a migration.



47
48
49
# File 'lib/intersight_client/models/virtualization_vmware_datastore_cluster.rb', line 47

def min_space_utilization_difference
  @min_space_utilization_difference
end

#object_typeObject

The fully-qualified name of the instantiated, concrete type. The value should be the same as the ‘ClassId’ property.



23
24
25
# File 'lib/intersight_client/models/virtualization_vmware_datastore_cluster.rb', line 23

def object_type
  @object_type
end

#policy_enforcement_automation_modeObject

Storage DRS behavior when it generates recommendations for correcting storage and VM policy violations in a datastore cluster.



50
51
52
# File 'lib/intersight_client/models/virtualization_vmware_datastore_cluster.rb', line 50

def policy_enforcement_automation_mode
  @policy_enforcement_automation_mode
end

#reservable_percent_thresholdObject

Storage DRS makes storage migration recommendations if total IOPs reservation of all VMs running on a datastore is higher than the specified threshold.



53
54
55
# File 'lib/intersight_client/models/virtualization_vmware_datastore_cluster.rb', line 53

def reservable_percent_threshold
  @reservable_percent_threshold
end

#rule_enforcement_automation_modeObject

Storage DRS behavior when it generates recommendations for correcting affinity rule violations in a datastore cluster.



56
57
58
# File 'lib/intersight_client/models/virtualization_vmware_datastore_cluster.rb', line 56

def rule_enforcement_automation_mode
  @rule_enforcement_automation_mode
end

#space_load_balance_automation_modeObject

Storage DRS behavior when it generates recommendations for correcting space load imbalance in a datastore cluster.



59
60
61
# File 'lib/intersight_client/models/virtualization_vmware_datastore_cluster.rb', line 59

def space_load_balance_automation_mode
  @space_load_balance_automation_mode
end

#space_threshold_modeObject

Runtime thresholds govern when Storage DRS performs or recommends migrations.



62
63
64
# File 'lib/intersight_client/models/virtualization_vmware_datastore_cluster.rb', line 62

def space_threshold_mode
  @space_threshold_mode
end

#statusObject

Datastore cluster health status, as reported by the hypervisor platform. * Unknown - Entity status is unknown. * Degraded - State is degraded, and might impact normal operation of the entity. * Critical - Entity is in a critical state, impacting operations. * Ok - Entity status is in a stable state, operating normally.



65
66
67
# File 'lib/intersight_client/models/virtualization_vmware_datastore_cluster.rb', line 65

def status
  @status
end

#storage_drs_enabledObject

Is Storage DRS enabled for this datastore cluster.



68
69
70
# File 'lib/intersight_client/models/virtualization_vmware_datastore_cluster.rb', line 68

def storage_drs_enabled
  @storage_drs_enabled
end

#utilized_space_thresholdObject

Minimum level of consumed space for each datastore that is the threshold for action.



71
72
73
# File 'lib/intersight_client/models/virtualization_vmware_datastore_cluster.rb', line 71

def utilized_space_threshold
  @utilized_space_threshold
end

#vm_evacuation_automation_modeObject

Storage DRS behavior when it generates recommendations for VM evacuations from datastores in a datastore cluster.



74
75
76
# File 'lib/intersight_client/models/virtualization_vmware_datastore_cluster.rb', line 74

def vm_evacuation_automation_mode
  @vm_evacuation_automation_mode
end

Class Method Details

.acceptable_attribute_mapObject

Returns the key-value map of all the JSON attributes this model knows about, including the ones defined in its parent(s)



132
133
134
# File 'lib/intersight_client/models/virtualization_vmware_datastore_cluster.rb', line 132

def self.acceptable_attribute_map
  attribute_map.merge(superclass.acceptable_attribute_map)
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about, including the ones defined in its parent(s)



127
128
129
# File 'lib/intersight_client/models/virtualization_vmware_datastore_cluster.rb', line 127

def self.acceptable_attributes
  attribute_map.values.concat(superclass.acceptable_attributes)
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
# File 'lib/intersight_client/models/virtualization_vmware_datastore_cluster.rb', line 101

def self.attribute_map
  {
    :'class_id' => :'ClassId',
    :'object_type' => :'ObjectType',
    :'automation_level' => :'AutomationLevel',
    :'free_space_threshold' => :'FreeSpaceThreshold',
    :'inventory_path' => :'InventoryPath',
    :'io_latency_threshold' => :'IoLatencyThreshold',
    :'io_load_balance_automation_mode' => :'IoLoadBalanceAutomationMode',
    :'io_load_imbalance_threshold' => :'IoLoadImbalanceThreshold',
    :'io_metrics_enabled' => :'IoMetricsEnabled',
    :'min_space_utilization_difference' => :'MinSpaceUtilizationDifference',
    :'policy_enforcement_automation_mode' => :'PolicyEnforcementAutomationMode',
    :'reservable_percent_threshold' => :'ReservablePercentThreshold',
    :'rule_enforcement_automation_mode' => :'RuleEnforcementAutomationMode',
    :'space_load_balance_automation_mode' => :'SpaceLoadBalanceAutomationMode',
    :'space_threshold_mode' => :'SpaceThresholdMode',
    :'status' => :'Status',
    :'storage_drs_enabled' => :'StorageDrsEnabled',
    :'utilized_space_threshold' => :'UtilizedSpaceThreshold',
    :'vm_evacuation_automation_mode' => :'VmEvacuationAutomationMode',
    :'datacenter' => :'Datacenter'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



387
388
389
# File 'lib/intersight_client/models/virtualization_vmware_datastore_cluster.rb', line 387

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_all_ofObject

List of class defined in allOf (OpenAPI v3)



169
170
171
172
173
174
# File 'lib/intersight_client/models/virtualization_vmware_datastore_cluster.rb', line 169

def self.openapi_all_of
  [
  :'VirtualizationBaseDatastoreCluster',
  :'VirtualizationVmwareDatastoreClusterAllOf'
  ]
end

.openapi_discriminator_nameObject

discriminator’s property name in OpenAPI v3



177
178
179
# File 'lib/intersight_client/models/virtualization_vmware_datastore_cluster.rb', line 177

def self.openapi_discriminator_name
  :'ClassId'
end

.openapi_nullableObject

List of attributes with nullable: true



163
164
165
166
# File 'lib/intersight_client/models/virtualization_vmware_datastore_cluster.rb', line 163

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
# File 'lib/intersight_client/models/virtualization_vmware_datastore_cluster.rb', line 137

def self.openapi_types
  {
    :'class_id' => :'String',
    :'object_type' => :'String',
    :'automation_level' => :'String',
    :'free_space_threshold' => :'Integer',
    :'inventory_path' => :'String',
    :'io_latency_threshold' => :'Integer',
    :'io_load_balance_automation_mode' => :'String',
    :'io_load_imbalance_threshold' => :'Integer',
    :'io_metrics_enabled' => :'Boolean',
    :'min_space_utilization_difference' => :'Integer',
    :'policy_enforcement_automation_mode' => :'String',
    :'reservable_percent_threshold' => :'Integer',
    :'rule_enforcement_automation_mode' => :'String',
    :'space_load_balance_automation_mode' => :'String',
    :'space_threshold_mode' => :'String',
    :'status' => :'String',
    :'storage_drs_enabled' => :'Boolean',
    :'utilized_space_threshold' => :'Integer',
    :'vm_evacuation_automation_mode' => :'String',
    :'datacenter' => :'VirtualizationVmwareDatacenterRelationship'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
# File 'lib/intersight_client/models/virtualization_vmware_datastore_cluster.rb', line 347

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      class_id == o.class_id &&
      object_type == o.object_type &&
      automation_level == o.automation_level &&
      free_space_threshold == o.free_space_threshold &&
      inventory_path == o.inventory_path &&
      io_latency_threshold == o.io_latency_threshold &&
      io_load_balance_automation_mode == o.io_load_balance_automation_mode &&
      io_load_imbalance_threshold == o.io_load_imbalance_threshold &&
      io_metrics_enabled == o.io_metrics_enabled &&
      min_space_utilization_difference == o.min_space_utilization_difference &&
      policy_enforcement_automation_mode == o.policy_enforcement_automation_mode &&
      reservable_percent_threshold == o.reservable_percent_threshold &&
      rule_enforcement_automation_mode == o.rule_enforcement_automation_mode &&
      space_load_balance_automation_mode == o.space_load_balance_automation_mode &&
      space_threshold_mode == o.space_threshold_mode &&
      status == o.status &&
      storage_drs_enabled == o.storage_drs_enabled &&
      utilized_space_threshold == o.utilized_space_threshold &&
      vm_evacuation_automation_mode == o.vm_evacuation_automation_mode &&
      datacenter == o.datacenter && super(o)
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



418
419
420
421
422
423
424
425
426
427
428
429
430
431
432
433
434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
453
454
455
# File 'lib/intersight_client/models/virtualization_vmware_datastore_cluster.rb', line 418

def _deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = IntersightClient.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



489
490
491
492
493
494
495
496
497
498
499
500
501
# File 'lib/intersight_client/models/virtualization_vmware_datastore_cluster.rb', line 489

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
410
411
412
# File 'lib/intersight_client/models/virtualization_vmware_datastore_cluster.rb', line 394

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  super(attributes)
  VirtualizationVmwareDatastoreCluster.openapi_types.each_pair do |key, type|
    if attributes[VirtualizationVmwareDatastoreCluster.attribute_map[key]].nil? && VirtualizationVmwareDatastoreCluster.openapi_nullable.include?(key)
      self.send("#{key}=", nil)
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[VirtualizationVmwareDatastoreCluster.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[VirtualizationVmwareDatastoreCluster.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[VirtualizationVmwareDatastoreCluster.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[VirtualizationVmwareDatastoreCluster.attribute_map[key]]))
    end
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


374
375
376
# File 'lib/intersight_client/models/virtualization_vmware_datastore_cluster.rb', line 374

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



380
381
382
# File 'lib/intersight_client/models/virtualization_vmware_datastore_cluster.rb', line 380

def hash
  [class_id, object_type, automation_level, free_space_threshold, inventory_path, io_latency_threshold, io_load_balance_automation_mode, io_load_imbalance_threshold, io_metrics_enabled, min_space_utilization_difference, policy_enforcement_automation_mode, reservable_percent_threshold, rule_enforcement_automation_mode, space_load_balance_automation_mode, space_threshold_mode, status, storage_drs_enabled, utilized_space_threshold, vm_evacuation_automation_mode, datacenter].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



288
289
290
291
292
293
294
295
296
297
298
299
# File 'lib/intersight_client/models/virtualization_vmware_datastore_cluster.rb', line 288

def list_invalid_properties
  invalid_properties = super
  if @class_id.nil?
    invalid_properties.push('invalid value for "class_id", class_id cannot be nil.')
  end

  if @object_type.nil?
    invalid_properties.push('invalid value for "object_type", object_type cannot be nil.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



465
466
467
# File 'lib/intersight_client/models/virtualization_vmware_datastore_cluster.rb', line 465

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



471
472
473
474
475
476
477
478
479
480
481
482
483
# File 'lib/intersight_client/models/virtualization_vmware_datastore_cluster.rb', line 471

def to_hash
  hash = super
  VirtualizationVmwareDatastoreCluster.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = VirtualizationVmwareDatastoreCluster.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



459
460
461
# File 'lib/intersight_client/models/virtualization_vmware_datastore_cluster.rb', line 459

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



303
304
305
306
307
308
309
310
311
312
313
# File 'lib/intersight_client/models/virtualization_vmware_datastore_cluster.rb', line 303

def valid?
  return false if @class_id.nil?
  class_id_validator = EnumAttributeValidator.new('String', ["virtualization.VmwareDatastoreCluster"])
  return false unless class_id_validator.valid?(@class_id)
  return false if @object_type.nil?
  object_type_validator = EnumAttributeValidator.new('String', ["virtualization.VmwareDatastoreCluster"])
  return false unless object_type_validator.valid?(@object_type)
  status_validator = EnumAttributeValidator.new('String', ["Unknown", "Degraded", "Critical", "Ok"])
  return false unless status_validator.valid?(@status)
  true && super
end