Class: IntersightClient::VirtualizationVmwareNetworkAllOf
- Inherits:
-
Object
- Object
- IntersightClient::VirtualizationVmwareNetworkAllOf
- Defined in:
- lib/intersight_client/models/virtualization_vmware_network_all_of.rb
Overview
Definition of the list of properties defined in ‘virtualization.VmwareNetwork’, excluding properties defined in parent classes.
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#class_id ⇒ Object
The fully-qualified name of the instantiated, concrete type.
-
#forged_transmits ⇒ Object
If forgedTransmits property value is set to reject, outbound frames with source MAC address different from the one set on the adapter are dropped.
-
#host ⇒ Object
Returns the value of attribute host.
-
#mac_address_changes ⇒ Object
If macAddressChanges property value is set to reject and the MAC address of the adapter is changed to a value other than the one specified in .vmx configuration file, all inbound frames are dropped.
-
#nic_teaming_and_failover ⇒ Object
Returns the value of attribute nic_teaming_and_failover.
-
#object_type ⇒ Object
The fully-qualified name of the instantiated, concrete type.
-
#promiscuous_mode ⇒ Object
If promiscuousMode property value is set to reject, incoming traffic only targeted to that network will be visible.
-
#virtual_switch ⇒ Object
Returns the value of attribute virtual_switch.
-
#vlan_id ⇒ Object
VLAN id with which the network is associated.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns the key-value map of all the JSON attributes this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ VirtualizationVmwareNetworkAllOf
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ VirtualizationVmwareNetworkAllOf
Initializes the object
114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 |
# File 'lib/intersight_client/models/virtualization_vmware_network_all_of.rb', line 114 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `IntersightClient::VirtualizationVmwareNetworkAllOf` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `#{self.class.name}`. Please check the name to make sure it's valid. List of attributes: " + self.class.acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'class_id') self.class_id = attributes[:'class_id'] else self.class_id = 'virtualization.VmwareNetwork' end if attributes.key?(:'object_type') self.object_type = attributes[:'object_type'] else self.object_type = 'virtualization.VmwareNetwork' end if attributes.key?(:'forged_transmits') self.forged_transmits = attributes[:'forged_transmits'] else self.forged_transmits = 'Reject' end if attributes.key?(:'mac_address_changes') self.mac_address_changes = attributes[:'mac_address_changes'] else self.mac_address_changes = 'Reject' end if attributes.key?(:'nic_teaming_and_failover') self.nic_teaming_and_failover = attributes[:'nic_teaming_and_failover'] end if attributes.key?(:'promiscuous_mode') self.promiscuous_mode = attributes[:'promiscuous_mode'] else self.promiscuous_mode = 'Reject' end if attributes.key?(:'vlan_id') self.vlan_id = attributes[:'vlan_id'] end if attributes.key?(:'host') self.host = attributes[:'host'] end if attributes.key?(:'virtual_switch') self.virtual_switch = attributes[:'virtual_switch'] end end |
Instance Attribute Details
#class_id ⇒ Object
The fully-qualified name of the instantiated, concrete type. This property is used as a discriminator to identify the type of the payload when marshaling and unmarshaling data.
20 21 22 |
# File 'lib/intersight_client/models/virtualization_vmware_network_all_of.rb', line 20 def class_id @class_id end |
#forged_transmits ⇒ Object
If forgedTransmits property value is set to reject, outbound frames with source MAC address different from the one set on the adapter are dropped. If property value is set to accept, no filtering is performed and all outbound frames are passed. * Reject - Indicates that the security policy is rejected. * Accept - Indicates that the security policy is accepted.
26 27 28 |
# File 'lib/intersight_client/models/virtualization_vmware_network_all_of.rb', line 26 def forged_transmits @forged_transmits end |
#host ⇒ Object
Returns the value of attribute host.
39 40 41 |
# File 'lib/intersight_client/models/virtualization_vmware_network_all_of.rb', line 39 def host @host end |
#mac_address_changes ⇒ Object
If macAddressChanges property value is set to reject and the MAC address of the adapter is changed to a value other than the one specified in .vmx configuration file, all inbound frames are dropped. If property value is set to accept and the MAC address is changed, inbound frames to the new MAC address are received. * Reject - Indicates that the security policy is rejected. * Accept - Indicates that the security policy is accepted.
29 30 31 |
# File 'lib/intersight_client/models/virtualization_vmware_network_all_of.rb', line 29 def mac_address_changes @mac_address_changes end |
#nic_teaming_and_failover ⇒ Object
Returns the value of attribute nic_teaming_and_failover.
31 32 33 |
# File 'lib/intersight_client/models/virtualization_vmware_network_all_of.rb', line 31 def nic_teaming_and_failover @nic_teaming_and_failover end |
#object_type ⇒ Object
The fully-qualified name of the instantiated, concrete type. The value should be the same as the ‘ClassId’ property.
23 24 25 |
# File 'lib/intersight_client/models/virtualization_vmware_network_all_of.rb', line 23 def object_type @object_type end |
#promiscuous_mode ⇒ Object
If promiscuousMode property value is set to reject, incoming traffic only targeted to that network will be visible. If property value is set to accept, objects defined within the network can see all incoming traffic on the virtual switch based on the VLAN policy. * Reject - Indicates that the security policy is rejected. * Accept - Indicates that the security policy is accepted.
34 35 36 |
# File 'lib/intersight_client/models/virtualization_vmware_network_all_of.rb', line 34 def promiscuous_mode @promiscuous_mode end |
#virtual_switch ⇒ Object
Returns the value of attribute virtual_switch.
41 42 43 |
# File 'lib/intersight_client/models/virtualization_vmware_network_all_of.rb', line 41 def virtual_switch @virtual_switch end |
#vlan_id ⇒ Object
VLAN id with which the network is associated. A value of 0 specifies that port is not associated with a VLAN.
37 38 39 |
# File 'lib/intersight_client/models/virtualization_vmware_network_all_of.rb', line 37 def vlan_id @vlan_id end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns the key-value map of all the JSON attributes this model knows about
86 87 88 |
# File 'lib/intersight_client/models/virtualization_vmware_network_all_of.rb', line 86 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
81 82 83 |
# File 'lib/intersight_client/models/virtualization_vmware_network_all_of.rb', line 81 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
66 67 68 69 70 71 72 73 74 75 76 77 78 |
# File 'lib/intersight_client/models/virtualization_vmware_network_all_of.rb', line 66 def self.attribute_map { :'class_id' => :'ClassId', :'object_type' => :'ObjectType', :'forged_transmits' => :'ForgedTransmits', :'mac_address_changes' => :'MacAddressChanges', :'nic_teaming_and_failover' => :'NicTeamingAndFailover', :'promiscuous_mode' => :'PromiscuousMode', :'vlan_id' => :'VlanId', :'host' => :'Host', :'virtual_switch' => :'VirtualSwitch' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
288 289 290 |
# File 'lib/intersight_client/models/virtualization_vmware_network_all_of.rb', line 288 def self.build_from_hash(attributes) new.build_from_hash(attributes) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
106 107 108 109 110 |
# File 'lib/intersight_client/models/virtualization_vmware_network_all_of.rb', line 106 def self.openapi_nullable Set.new([ :'nic_teaming_and_failover', ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
91 92 93 94 95 96 97 98 99 100 101 102 103 |
# File 'lib/intersight_client/models/virtualization_vmware_network_all_of.rb', line 91 def self.openapi_types { :'class_id' => :'String', :'object_type' => :'String', :'forged_transmits' => :'String', :'mac_address_changes' => :'String', :'nic_teaming_and_failover' => :'VirtualizationVmwareTeamingAndFailover', :'promiscuous_mode' => :'String', :'vlan_id' => :'Integer', :'host' => :'VirtualizationVmwareHostRelationship', :'virtual_switch' => :'VirtualizationVmwareVirtualSwitchRelationship' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
259 260 261 262 263 264 265 266 267 268 269 270 271 |
# File 'lib/intersight_client/models/virtualization_vmware_network_all_of.rb', line 259 def ==(o) return true if self.equal?(o) self.class == o.class && class_id == o.class_id && object_type == o.object_type && forged_transmits == o.forged_transmits && mac_address_changes == o.mac_address_changes && nic_teaming_and_failover == o.nic_teaming_and_failover && promiscuous_mode == o.promiscuous_mode && vlan_id == o.vlan_id && host == o.host && virtual_switch == o.virtual_switch end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 |
# File 'lib/intersight_client/models/virtualization_vmware_network_all_of.rb', line 318 def _deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = IntersightClient.const_get(type) klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
389 390 391 392 393 394 395 396 397 398 399 400 401 |
# File 'lib/intersight_client/models/virtualization_vmware_network_all_of.rb', line 389 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 |
# File 'lib/intersight_client/models/virtualization_vmware_network_all_of.rb', line 295 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) VirtualizationVmwareNetworkAllOf.openapi_types.each_pair do |key, type| if attributes[VirtualizationVmwareNetworkAllOf.attribute_map[key]].nil? && VirtualizationVmwareNetworkAllOf.openapi_nullable.include?(key) self.send("#{key}=", nil) elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[VirtualizationVmwareNetworkAllOf.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[VirtualizationVmwareNetworkAllOf.attribute_map[key]].map { |v| _deserialize($1, v) }) end elsif !attributes[VirtualizationVmwareNetworkAllOf.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[VirtualizationVmwareNetworkAllOf.attribute_map[key]])) end end self end |
#eql?(o) ⇒ Boolean
275 276 277 |
# File 'lib/intersight_client/models/virtualization_vmware_network_all_of.rb', line 275 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
281 282 283 |
# File 'lib/intersight_client/models/virtualization_vmware_network_all_of.rb', line 281 def hash [class_id, object_type, forged_transmits, mac_address_changes, nic_teaming_and_failover, promiscuous_mode, vlan_id, host, virtual_switch].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
176 177 178 179 180 181 182 183 184 185 186 187 |
# File 'lib/intersight_client/models/virtualization_vmware_network_all_of.rb', line 176 def list_invalid_properties invalid_properties = Array.new if @class_id.nil? invalid_properties.push('invalid value for "class_id", class_id cannot be nil.') end if @object_type.nil? invalid_properties.push('invalid value for "object_type", object_type cannot be nil.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
365 366 367 |
# File 'lib/intersight_client/models/virtualization_vmware_network_all_of.rb', line 365 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
371 372 373 374 375 376 377 378 379 380 381 382 383 |
# File 'lib/intersight_client/models/virtualization_vmware_network_all_of.rb', line 371 def to_hash hash = {} VirtualizationVmwareNetworkAllOf.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = VirtualizationVmwareNetworkAllOf.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
359 360 361 |
# File 'lib/intersight_client/models/virtualization_vmware_network_all_of.rb', line 359 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 |
# File 'lib/intersight_client/models/virtualization_vmware_network_all_of.rb', line 191 def valid? return false if @class_id.nil? class_id_validator = EnumAttributeValidator.new('String', ["virtualization.VmwareNetwork"]) return false unless class_id_validator.valid?(@class_id) return false if @object_type.nil? object_type_validator = EnumAttributeValidator.new('String', ["virtualization.VmwareNetwork"]) return false unless object_type_validator.valid?(@object_type) forged_transmits_validator = EnumAttributeValidator.new('String', ["Reject", "Accept"]) return false unless forged_transmits_validator.valid?(@forged_transmits) mac_address_changes_validator = EnumAttributeValidator.new('String', ["Reject", "Accept"]) return false unless mac_address_changes_validator.valid?(@mac_address_changes) promiscuous_mode_validator = EnumAttributeValidator.new('String', ["Reject", "Accept"]) return false unless promiscuous_mode_validator.valid?(@promiscuous_mode) true end |