Class: IntersightClient::VirtualizationVmwarePhysicalNetworkInterface
- Inherits:
-
VirtualizationBasePhysicalNetworkInterface
- Object
- MoBaseMo
- VirtualizationBaseSourceDevice
- VirtualizationBasePhysicalNetworkInterface
- IntersightClient::VirtualizationVmwarePhysicalNetworkInterface
- Defined in:
- lib/intersight_client/models/virtualization_vmware_physical_network_interface.rb
Overview
Details of VMware physical network interface.
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#class_id ⇒ Object
The fully-qualified name of the instantiated, concrete type.
-
#driver ⇒ Object
Driver type associated with physical network interface.
-
#host ⇒ Object
Returns the value of attribute host.
-
#link_speed ⇒ Object
Link speed of the physical network interface.
-
#mac_address ⇒ Object
Standard MAC address assigned to physical network interface.
-
#object_type ⇒ Object
The fully-qualified name of the instantiated, concrete type.
-
#pci ⇒ Object
PCI info for physical network interface.
-
#switch_name ⇒ Object
Switch associated with the physical network interface.
Attributes inherited from VirtualizationBasePhysicalNetworkInterface
Attributes inherited from VirtualizationBaseSourceDevice
Attributes inherited from MoBaseMo
#account_moid, #ancestors, #create_time, #display_names, #domain_group_moid, #mod_time, #moid, #owners, #parent, #permission_resources, #shared_scope, #tags, #version_context
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns the key-value map of all the JSON attributes this model knows about, including the ones defined in its parent(s).
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about, including the ones defined in its parent(s).
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_all_of ⇒ Object
List of class defined in allOf (OpenAPI v3).
-
.openapi_discriminator_name ⇒ Object
discriminator’s property name in OpenAPI v3.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ VirtualizationVmwarePhysicalNetworkInterface
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ VirtualizationVmwarePhysicalNetworkInterface
Initializes the object
123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 |
# File 'lib/intersight_client/models/virtualization_vmware_physical_network_interface.rb', line 123 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `IntersightClient::VirtualizationVmwarePhysicalNetworkInterface` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `#{self.class.name}`. Please check the name to make sure it's valid. List of attributes: " + self.class.acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } # call parent's initialize super(attributes) if attributes.key?(:'class_id') self.class_id = attributes[:'class_id'] else self.class_id = 'virtualization.VmwarePhysicalNetworkInterface' end if attributes.key?(:'object_type') self.object_type = attributes[:'object_type'] else self.object_type = 'virtualization.VmwarePhysicalNetworkInterface' end if attributes.key?(:'driver') self.driver = attributes[:'driver'] end if attributes.key?(:'link_speed') self.link_speed = attributes[:'link_speed'] end if attributes.key?(:'mac_address') self.mac_address = attributes[:'mac_address'] end if attributes.key?(:'pci') self.pci = attributes[:'pci'] end if attributes.key?(:'switch_name') self.switch_name = attributes[:'switch_name'] end if attributes.key?(:'host') self.host = attributes[:'host'] end end |
Instance Attribute Details
#class_id ⇒ Object
The fully-qualified name of the instantiated, concrete type. This property is used as a discriminator to identify the type of the payload when marshaling and unmarshaling data.
20 21 22 |
# File 'lib/intersight_client/models/virtualization_vmware_physical_network_interface.rb', line 20 def class_id @class_id end |
#driver ⇒ Object
Driver type associated with physical network interface.
26 27 28 |
# File 'lib/intersight_client/models/virtualization_vmware_physical_network_interface.rb', line 26 def driver @driver end |
#host ⇒ Object
Returns the value of attribute host.
40 41 42 |
# File 'lib/intersight_client/models/virtualization_vmware_physical_network_interface.rb', line 40 def host @host end |
#link_speed ⇒ Object
Link speed of the physical network interface.
29 30 31 |
# File 'lib/intersight_client/models/virtualization_vmware_physical_network_interface.rb', line 29 def link_speed @link_speed end |
#mac_address ⇒ Object
Standard MAC address assigned to physical network interface.
32 33 34 |
# File 'lib/intersight_client/models/virtualization_vmware_physical_network_interface.rb', line 32 def mac_address @mac_address end |
#object_type ⇒ Object
The fully-qualified name of the instantiated, concrete type. The value should be the same as the ‘ClassId’ property.
23 24 25 |
# File 'lib/intersight_client/models/virtualization_vmware_physical_network_interface.rb', line 23 def object_type @object_type end |
#pci ⇒ Object
PCI info for physical network interface.
35 36 37 |
# File 'lib/intersight_client/models/virtualization_vmware_physical_network_interface.rb', line 35 def pci @pci end |
#switch_name ⇒ Object
Switch associated with the physical network interface.
38 39 40 |
# File 'lib/intersight_client/models/virtualization_vmware_physical_network_interface.rb', line 38 def switch_name @switch_name end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns the key-value map of all the JSON attributes this model knows about, including the ones defined in its parent(s)
84 85 86 |
# File 'lib/intersight_client/models/virtualization_vmware_physical_network_interface.rb', line 84 def self.acceptable_attribute_map attribute_map.merge(superclass.acceptable_attribute_map) end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about, including the ones defined in its parent(s)
79 80 81 |
# File 'lib/intersight_client/models/virtualization_vmware_physical_network_interface.rb', line 79 def self.acceptable_attributes attribute_map.values.concat(superclass.acceptable_attributes) end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
65 66 67 68 69 70 71 72 73 74 75 76 |
# File 'lib/intersight_client/models/virtualization_vmware_physical_network_interface.rb', line 65 def self.attribute_map { :'class_id' => :'ClassId', :'object_type' => :'ObjectType', :'driver' => :'Driver', :'link_speed' => :'LinkSpeed', :'mac_address' => :'MacAddress', :'pci' => :'Pci', :'switch_name' => :'SwitchName', :'host' => :'Host' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
270 271 272 |
# File 'lib/intersight_client/models/virtualization_vmware_physical_network_interface.rb', line 270 def self.build_from_hash(attributes) new.build_from_hash(attributes) end |
.openapi_all_of ⇒ Object
List of class defined in allOf (OpenAPI v3)
109 110 111 112 113 114 |
# File 'lib/intersight_client/models/virtualization_vmware_physical_network_interface.rb', line 109 def self.openapi_all_of [ :'VirtualizationBasePhysicalNetworkInterface', :'VirtualizationVmwarePhysicalNetworkInterfaceAllOf' ] end |
.openapi_discriminator_name ⇒ Object
discriminator’s property name in OpenAPI v3
117 118 119 |
# File 'lib/intersight_client/models/virtualization_vmware_physical_network_interface.rb', line 117 def self.openapi_discriminator_name :'ClassId' end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
103 104 105 106 |
# File 'lib/intersight_client/models/virtualization_vmware_physical_network_interface.rb', line 103 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
89 90 91 92 93 94 95 96 97 98 99 100 |
# File 'lib/intersight_client/models/virtualization_vmware_physical_network_interface.rb', line 89 def self.openapi_types { :'class_id' => :'String', :'object_type' => :'String', :'driver' => :'String', :'link_speed' => :'Integer', :'mac_address' => :'String', :'pci' => :'String', :'switch_name' => :'String', :'host' => :'VirtualizationVmwareHostRelationship' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
242 243 244 245 246 247 248 249 250 251 252 253 |
# File 'lib/intersight_client/models/virtualization_vmware_physical_network_interface.rb', line 242 def ==(o) return true if self.equal?(o) self.class == o.class && class_id == o.class_id && object_type == o.object_type && driver == o.driver && link_speed == o.link_speed && mac_address == o.mac_address && pci == o.pci && switch_name == o.switch_name && host == o.host && super(o) end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 |
# File 'lib/intersight_client/models/virtualization_vmware_physical_network_interface.rb', line 301 def _deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = IntersightClient.const_get(type) klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
372 373 374 375 376 377 378 379 380 381 382 383 384 |
# File 'lib/intersight_client/models/virtualization_vmware_physical_network_interface.rb', line 372 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 |
# File 'lib/intersight_client/models/virtualization_vmware_physical_network_interface.rb', line 277 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) super(attributes) VirtualizationVmwarePhysicalNetworkInterface.openapi_types.each_pair do |key, type| if attributes[VirtualizationVmwarePhysicalNetworkInterface.attribute_map[key]].nil? && VirtualizationVmwarePhysicalNetworkInterface.openapi_nullable.include?(key) self.send("#{key}=", nil) elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[VirtualizationVmwarePhysicalNetworkInterface.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[VirtualizationVmwarePhysicalNetworkInterface.attribute_map[key]].map { |v| _deserialize($1, v) }) end elsif !attributes[VirtualizationVmwarePhysicalNetworkInterface.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[VirtualizationVmwarePhysicalNetworkInterface.attribute_map[key]])) end end self end |
#eql?(o) ⇒ Boolean
257 258 259 |
# File 'lib/intersight_client/models/virtualization_vmware_physical_network_interface.rb', line 257 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
263 264 265 |
# File 'lib/intersight_client/models/virtualization_vmware_physical_network_interface.rb', line 263 def hash [class_id, object_type, driver, link_speed, mac_address, pci, switch_name, host].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 |
# File 'lib/intersight_client/models/virtualization_vmware_physical_network_interface.rb', line 178 def list_invalid_properties invalid_properties = super if @class_id.nil? invalid_properties.push('invalid value for "class_id", class_id cannot be nil.') end if @object_type.nil? invalid_properties.push('invalid value for "object_type", object_type cannot be nil.') end pattern = Regexp.new(/^$|^([0-9A-Fa-f]{2}[:-]){5}([0-9A-Fa-f]{2})$/) if !@mac_address.nil? && @mac_address !~ pattern invalid_properties.push("invalid value for \"mac_address\", must conform to the pattern #{pattern}.") end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
348 349 350 |
# File 'lib/intersight_client/models/virtualization_vmware_physical_network_interface.rb', line 348 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
354 355 356 357 358 359 360 361 362 363 364 365 366 |
# File 'lib/intersight_client/models/virtualization_vmware_physical_network_interface.rb', line 354 def to_hash hash = super VirtualizationVmwarePhysicalNetworkInterface.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = VirtualizationVmwarePhysicalNetworkInterface.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
342 343 344 |
# File 'lib/intersight_client/models/virtualization_vmware_physical_network_interface.rb', line 342 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
198 199 200 201 202 203 204 205 206 207 |
# File 'lib/intersight_client/models/virtualization_vmware_physical_network_interface.rb', line 198 def valid? return false if @class_id.nil? class_id_validator = EnumAttributeValidator.new('String', ["virtualization.VmwarePhysicalNetworkInterface"]) return false unless class_id_validator.valid?(@class_id) return false if @object_type.nil? object_type_validator = EnumAttributeValidator.new('String', ["virtualization.VmwarePhysicalNetworkInterface"]) return false unless object_type_validator.valid?(@object_type) return false if !@mac_address.nil? && @mac_address !~ Regexp.new(/^$|^([0-9A-Fa-f]{2}[:-]){5}([0-9A-Fa-f]{2})$/) true && super end |