Class: IntersightClient::VnicEthQosPolicy
- Inherits:
-
PolicyAbstractPolicy
- Object
- MoBaseMo
- PolicyAbstractPolicy
- IntersightClient::VnicEthQosPolicy
- Defined in:
- lib/intersight_client/models/vnic_eth_qos_policy.rb
Overview
An Ethernet Quality of Service (QoS) policy assigns a system class to the outgoing traffic for a vNIC. This system class determines the quality of service for the outgoing traffic. For certain adapters additional controls can be specified like burst and rate on the outgoing traffic.
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#burst ⇒ Object
The burst traffic, in bytes, allowed on the vNIC.
-
#class_id ⇒ Object
The fully-qualified name of the instantiated, concrete type.
-
#cos ⇒ Object
Class of Service to be associated to the traffic on the virtual interface.
-
#mtu ⇒ Object
The Maximum Transmission Unit (MTU) or packet size that the virtual interface accepts.
-
#object_type ⇒ Object
The fully-qualified name of the instantiated, concrete type.
-
#organization ⇒ Object
Returns the value of attribute organization.
-
#priority ⇒ Object
The priortity matching the System QoS specified in the fabric profile.
-
#rate_limit ⇒ Object
The value in Mbps (0-10G/40G/100G depending on Adapter Model) to use for limiting the data rate on the virtual interface.
-
#trust_host_cos ⇒ Object
Enables usage of the Class of Service provided by the operating system.
Attributes inherited from PolicyAbstractPolicy
Attributes inherited from MoBaseMo
#account_moid, #ancestors, #create_time, #display_names, #domain_group_moid, #mod_time, #moid, #owners, #parent, #permission_resources, #shared_scope, #tags, #version_context
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns the key-value map of all the JSON attributes this model knows about, including the ones defined in its parent(s).
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about, including the ones defined in its parent(s).
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_all_of ⇒ Object
List of class defined in allOf (OpenAPI v3).
-
.openapi_discriminator_name ⇒ Object
discriminator's property name in OpenAPI v3.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ VnicEthQosPolicy
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ VnicEthQosPolicy
Initializes the object
128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 |
# File 'lib/intersight_client/models/vnic_eth_qos_policy.rb', line 128 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `IntersightClient::VnicEthQosPolicy` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `#{self.class.name}`. Please check the name to make sure it's valid. List of attributes: " + self.class.acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } # call parent's initialize super(attributes) if attributes.key?(:'class_id') self.class_id = attributes[:'class_id'] else self.class_id = 'vnic.EthQosPolicy' end if attributes.key?(:'object_type') self.object_type = attributes[:'object_type'] else self.object_type = 'vnic.EthQosPolicy' end if attributes.key?(:'burst') self.burst = attributes[:'burst'] else self.burst = 10240 end if attributes.key?(:'cos') self.cos = attributes[:'cos'] else self.cos = 0 end if attributes.key?(:'mtu') self.mtu = attributes[:'mtu'] else self.mtu = 1500 end if attributes.key?(:'priority') self.priority = attributes[:'priority'] else self.priority = 'Best Effort' end if attributes.key?(:'rate_limit') self.rate_limit = attributes[:'rate_limit'] else self.rate_limit = 0 end if attributes.key?(:'trust_host_cos') self.trust_host_cos = attributes[:'trust_host_cos'] else self.trust_host_cos = false end if attributes.key?(:'organization') self.organization = attributes[:'organization'] end end |
Instance Attribute Details
#burst ⇒ Object
The burst traffic, in bytes, allowed on the vNIC.
26 27 28 |
# File 'lib/intersight_client/models/vnic_eth_qos_policy.rb', line 26 def burst @burst end |
#class_id ⇒ Object
The fully-qualified name of the instantiated, concrete type. This property is used as a discriminator to identify the type of the payload when marshaling and unmarshaling data.
20 21 22 |
# File 'lib/intersight_client/models/vnic_eth_qos_policy.rb', line 20 def class_id @class_id end |
#cos ⇒ Object
Class of Service to be associated to the traffic on the virtual interface.
29 30 31 |
# File 'lib/intersight_client/models/vnic_eth_qos_policy.rb', line 29 def cos @cos end |
#mtu ⇒ Object
The Maximum Transmission Unit (MTU) or packet size that the virtual interface accepts.
32 33 34 |
# File 'lib/intersight_client/models/vnic_eth_qos_policy.rb', line 32 def mtu @mtu end |
#object_type ⇒ Object
The fully-qualified name of the instantiated, concrete type. The value should be the same as the 'ClassId' property.
23 24 25 |
# File 'lib/intersight_client/models/vnic_eth_qos_policy.rb', line 23 def object_type @object_type end |
#organization ⇒ Object
Returns the value of attribute organization.
43 44 45 |
# File 'lib/intersight_client/models/vnic_eth_qos_policy.rb', line 43 def organization @organization end |
#priority ⇒ Object
The priortity matching the System QoS specified in the fabric profile. * Best Effort - QoS Priority for Best-effort traffic. * FC - QoS Priority for FC traffic. * Platinum - QoS Priority for Platinum traffic. * Gold - QoS Priority for Gold traffic. * Silver - QoS Priority for Silver traffic. * Bronze - QoS Priority for Bronze traffic.
35 36 37 |
# File 'lib/intersight_client/models/vnic_eth_qos_policy.rb', line 35 def priority @priority end |
#rate_limit ⇒ Object
The value in Mbps (0-10G/40G/100G depending on Adapter Model) to use for limiting the data rate on the virtual interface. Setting this to zero will turn rate limiting off.
38 39 40 |
# File 'lib/intersight_client/models/vnic_eth_qos_policy.rb', line 38 def rate_limit @rate_limit end |
#trust_host_cos ⇒ Object
Enables usage of the Class of Service provided by the operating system.
41 42 43 |
# File 'lib/intersight_client/models/vnic_eth_qos_policy.rb', line 41 def trust_host_cos @trust_host_cos end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns the key-value map of all the JSON attributes this model knows about, including the ones defined in its parent(s)
88 89 90 |
# File 'lib/intersight_client/models/vnic_eth_qos_policy.rb', line 88 def self.acceptable_attribute_map attribute_map.merge(superclass.acceptable_attribute_map) end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about, including the ones defined in its parent(s)
83 84 85 |
# File 'lib/intersight_client/models/vnic_eth_qos_policy.rb', line 83 def self.acceptable_attributes attribute_map.values.concat(superclass.acceptable_attributes) end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
68 69 70 71 72 73 74 75 76 77 78 79 80 |
# File 'lib/intersight_client/models/vnic_eth_qos_policy.rb', line 68 def self.attribute_map { :'class_id' => :'ClassId', :'object_type' => :'ObjectType', :'burst' => :'Burst', :'cos' => :'Cos', :'mtu' => :'Mtu', :'priority' => :'Priority', :'rate_limit' => :'RateLimit', :'trust_host_cos' => :'TrustHostCos', :'organization' => :'Organization' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
383 384 385 |
# File 'lib/intersight_client/models/vnic_eth_qos_policy.rb', line 383 def self.build_from_hash(attributes) new.build_from_hash(attributes) end |
.openapi_all_of ⇒ Object
List of class defined in allOf (OpenAPI v3)
114 115 116 117 118 119 |
# File 'lib/intersight_client/models/vnic_eth_qos_policy.rb', line 114 def self.openapi_all_of [ :'PolicyAbstractPolicy', :'VnicEthQosPolicyAllOf' ] end |
.openapi_discriminator_name ⇒ Object
discriminator's property name in OpenAPI v3
122 123 124 |
# File 'lib/intersight_client/models/vnic_eth_qos_policy.rb', line 122 def self.openapi_discriminator_name :'ClassId' end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
108 109 110 111 |
# File 'lib/intersight_client/models/vnic_eth_qos_policy.rb', line 108 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
93 94 95 96 97 98 99 100 101 102 103 104 105 |
# File 'lib/intersight_client/models/vnic_eth_qos_policy.rb', line 93 def self.openapi_types { :'class_id' => :'String', :'object_type' => :'String', :'burst' => :'Integer', :'cos' => :'Integer', :'mtu' => :'Integer', :'priority' => :'String', :'rate_limit' => :'Integer', :'trust_host_cos' => :'Boolean', :'organization' => :'OrganizationOrganizationRelationship' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
354 355 356 357 358 359 360 361 362 363 364 365 366 |
# File 'lib/intersight_client/models/vnic_eth_qos_policy.rb', line 354 def ==(o) return true if self.equal?(o) self.class == o.class && class_id == o.class_id && object_type == o.object_type && burst == o.burst && cos == o.cos && mtu == o.mtu && priority == o.priority && rate_limit == o.rate_limit && trust_host_cos == o.trust_host_cos && organization == o.organization && super(o) end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 450 451 |
# File 'lib/intersight_client/models/vnic_eth_qos_policy.rb', line 414 def _deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = IntersightClient.const_get(type) klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
485 486 487 488 489 490 491 492 493 494 495 496 497 |
# File 'lib/intersight_client/models/vnic_eth_qos_policy.rb', line 485 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 |
# File 'lib/intersight_client/models/vnic_eth_qos_policy.rb', line 390 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) super(attributes) VnicEthQosPolicy.openapi_types.each_pair do |key, type| if attributes[VnicEthQosPolicy.attribute_map[key]].nil? && VnicEthQosPolicy.openapi_nullable.include?(key) self.send("#{key}=", nil) elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[VnicEthQosPolicy.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[VnicEthQosPolicy.attribute_map[key]].map { |v| _deserialize($1, v) }) end elsif !attributes[VnicEthQosPolicy.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[VnicEthQosPolicy.attribute_map[key]])) end end self end |
#eql?(o) ⇒ Boolean
370 371 372 |
# File 'lib/intersight_client/models/vnic_eth_qos_policy.rb', line 370 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
376 377 378 |
# File 'lib/intersight_client/models/vnic_eth_qos_policy.rb', line 376 def hash [class_id, object_type, burst, cos, mtu, priority, rate_limit, trust_host_cos, organization].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 |
# File 'lib/intersight_client/models/vnic_eth_qos_policy.rb', line 199 def list_invalid_properties invalid_properties = super if @class_id.nil? invalid_properties.push('invalid value for "class_id", class_id cannot be nil.') end if @object_type.nil? invalid_properties.push('invalid value for "object_type", object_type cannot be nil.') end if !@burst.nil? && @burst > 1000000 invalid_properties.push('invalid value for "burst", must be smaller than or equal to 1000000.') end if !@burst.nil? && @burst < 1 invalid_properties.push('invalid value for "burst", must be greater than or equal to 1.') end if !@cos.nil? && @cos > 6 invalid_properties.push('invalid value for "cos", must be smaller than or equal to 6.') end if !@cos.nil? && @cos < 0 invalid_properties.push('invalid value for "cos", must be greater than or equal to 0.') end if !@mtu.nil? && @mtu > 9000 invalid_properties.push('invalid value for "mtu", must be smaller than or equal to 9000.') end if !@mtu.nil? && @mtu < 1500 invalid_properties.push('invalid value for "mtu", must be greater than or equal to 1500.') end if !@rate_limit.nil? && @rate_limit > 100000 invalid_properties.push('invalid value for "rate_limit", must be smaller than or equal to 100000.') end if !@rate_limit.nil? && @rate_limit < 0 invalid_properties.push('invalid value for "rate_limit", must be greater than or equal to 0.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
461 462 463 |
# File 'lib/intersight_client/models/vnic_eth_qos_policy.rb', line 461 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
467 468 469 470 471 472 473 474 475 476 477 478 479 |
# File 'lib/intersight_client/models/vnic_eth_qos_policy.rb', line 467 def to_hash hash = super VnicEthQosPolicy.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = VnicEthQosPolicy.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
455 456 457 |
# File 'lib/intersight_client/models/vnic_eth_qos_policy.rb', line 455 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 |
# File 'lib/intersight_client/models/vnic_eth_qos_policy.rb', line 246 def valid? return false if @class_id.nil? class_id_validator = EnumAttributeValidator.new('String', ["vnic.EthQosPolicy"]) return false unless class_id_validator.valid?(@class_id) return false if @object_type.nil? object_type_validator = EnumAttributeValidator.new('String', ["vnic.EthQosPolicy"]) return false unless object_type_validator.valid?(@object_type) return false if !@burst.nil? && @burst > 1000000 return false if !@burst.nil? && @burst < 1 return false if !@cos.nil? && @cos > 6 return false if !@cos.nil? && @cos < 0 return false if !@mtu.nil? && @mtu > 9000 return false if !@mtu.nil? && @mtu < 1500 priority_validator = EnumAttributeValidator.new('String', ["Best Effort", "FC", "Platinum", "Gold", "Silver", "Bronze"]) return false unless priority_validator.valid?(@priority) return false if !@rate_limit.nil? && @rate_limit > 100000 return false if !@rate_limit.nil? && @rate_limit < 0 true && super end |