Class: IntersightClient::VnicLanConnectivityPolicyAllOf

Inherits:
Object
  • Object
show all
Defined in:
lib/intersight_client/models/vnic_lan_connectivity_policy_all_of.rb

Overview

Definition of the list of properties defined in 'vnic.LanConnectivityPolicy', excluding properties defined in parent classes.

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ VnicLanConnectivityPolicyAllOf

Initializes the object

Parameters:

  • (defaults to: {})

    Model attributes in the form of hash



126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
# File 'lib/intersight_client/models/vnic_lan_connectivity_policy_all_of.rb', line 126

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `IntersightClient::VnicLanConnectivityPolicyAllOf` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `#{self.class.name}`. Please check the name to make sure it's valid. List of attributes: " + self.class.acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'class_id')
    self.class_id = attributes[:'class_id']
  else
    self.class_id = 'vnic.LanConnectivityPolicy'
  end

  if attributes.key?(:'object_type')
    self.object_type = attributes[:'object_type']
  else
    self.object_type = 'vnic.LanConnectivityPolicy'
  end

  if attributes.key?(:'azure_qos_enabled')
    self.azure_qos_enabled = attributes[:'azure_qos_enabled']
  else
    self.azure_qos_enabled = false
  end

  if attributes.key?(:'iqn_allocation_type')
    self.iqn_allocation_type = attributes[:'iqn_allocation_type']
  else
    self.iqn_allocation_type = 'None'
  end

  if attributes.key?(:'placement_mode')
    self.placement_mode = attributes[:'placement_mode']
  else
    self.placement_mode = 'custom'
  end

  if attributes.key?(:'static_iqn_name')
    self.static_iqn_name = attributes[:'static_iqn_name']
  end

  if attributes.key?(:'target_platform')
    self.target_platform = attributes[:'target_platform']
  else
    self.target_platform = 'Standalone'
  end

  if attributes.key?(:'eth_ifs')
    if (value = attributes[:'eth_ifs']).is_a?(Array)
      self.eth_ifs = value
    end
  end

  if attributes.key?(:'iqn_pool')
    self.iqn_pool = attributes[:'iqn_pool']
  end

  if attributes.key?(:'organization')
    self.organization = attributes[:'organization']
  end

  if attributes.key?(:'profiles')
    if (value = attributes[:'profiles']).is_a?(Array)
      self.profiles = value
    end
  end
end

Instance Attribute Details

#azure_qos_enabledObject

Enabling AzureStack-Host QoS on an adapter allows the user to carve out traffic classes for RDMA traffic which ensures that a desired portion of the bandwidth is allocated to it.



26
27
28
# File 'lib/intersight_client/models/vnic_lan_connectivity_policy_all_of.rb', line 26

def azure_qos_enabled
  @azure_qos_enabled
end

#class_idObject

The fully-qualified name of the instantiated, concrete type. This property is used as a discriminator to identify the type of the payload when marshaling and unmarshaling data.



20
21
22
# File 'lib/intersight_client/models/vnic_lan_connectivity_policy_all_of.rb', line 20

def class_id
  @class_id
end

#eth_ifsObject

An array of relationships to vnicEthIf resources.



41
42
43
# File 'lib/intersight_client/models/vnic_lan_connectivity_policy_all_of.rb', line 41

def eth_ifs
  @eth_ifs
end

#iqn_allocation_typeObject

Allocation Type of iSCSI Qualified Name - Static/Pool/None. * None - Type indicates that there is no IQN associated to an interface. * Static - Type represents that static IQN is associated to an interface. * Pool - Type indicates that IQN value is sourced from an associated pool.



29
30
31
# File 'lib/intersight_client/models/vnic_lan_connectivity_policy_all_of.rb', line 29

def iqn_allocation_type
  @iqn_allocation_type
end

#iqn_poolObject

Returns the value of attribute iqn_pool.



43
44
45
# File 'lib/intersight_client/models/vnic_lan_connectivity_policy_all_of.rb', line 43

def iqn_pool
  @iqn_pool
end

#object_typeObject

The fully-qualified name of the instantiated, concrete type. The value should be the same as the 'ClassId' property.



23
24
25
# File 'lib/intersight_client/models/vnic_lan_connectivity_policy_all_of.rb', line 23

def object_type
  @object_type
end

#organizationObject

Returns the value of attribute organization.



45
46
47
# File 'lib/intersight_client/models/vnic_lan_connectivity_policy_all_of.rb', line 45

def organization
  @organization
end

#placement_modeObject

The mode used for placement of vNICs on network adapters. It can either be Auto or Custom. * custom - The placement of the vNICs / vHBAs on network adapters is manually chosen by the user. * auto - The placement of the vNICs / vHBAs on network adapters is automatically determined by the system.



32
33
34
# File 'lib/intersight_client/models/vnic_lan_connectivity_policy_all_of.rb', line 32

def placement_mode
  @placement_mode
end

#profilesObject

An array of relationships to policyAbstractConfigProfile resources.



48
49
50
# File 'lib/intersight_client/models/vnic_lan_connectivity_policy_all_of.rb', line 48

def profiles
  @profiles
end

#static_iqn_nameObject

User provided static iSCSI Qualified Name (IQN) for use as initiator identifiers by iSCSI vNICs in a Fabric Interconnect domain.



35
36
37
# File 'lib/intersight_client/models/vnic_lan_connectivity_policy_all_of.rb', line 35

def static_iqn_name
  @static_iqn_name
end

#target_platformObject

The platform for which the server profile is applicable. It can either be a server that is operating in standalone mode or which is attached to a Fabric Interconnect managed by Intersight. * Standalone - Servers which are operating in standalone mode i.e. not connected to a Fabric Interconnected. * FIAttached - Servers which are connected to a Fabric Interconnect that is managed by Intersight.



38
39
40
# File 'lib/intersight_client/models/vnic_lan_connectivity_policy_all_of.rb', line 38

def target_platform
  @target_platform
end

Class Method Details

.acceptable_attribute_mapObject

Returns the key-value map of all the JSON attributes this model knows about



95
96
97
# File 'lib/intersight_client/models/vnic_lan_connectivity_policy_all_of.rb', line 95

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



90
91
92
# File 'lib/intersight_client/models/vnic_lan_connectivity_policy_all_of.rb', line 90

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
# File 'lib/intersight_client/models/vnic_lan_connectivity_policy_all_of.rb', line 73

def self.attribute_map
  {
    :'class_id' => :'ClassId',
    :'object_type' => :'ObjectType',
    :'azure_qos_enabled' => :'AzureQosEnabled',
    :'iqn_allocation_type' => :'IqnAllocationType',
    :'placement_mode' => :'PlacementMode',
    :'static_iqn_name' => :'StaticIqnName',
    :'target_platform' => :'TargetPlatform',
    :'eth_ifs' => :'EthIfs',
    :'iqn_pool' => :'IqnPool',
    :'organization' => :'Organization',
    :'profiles' => :'Profiles'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • Model attributes in the form of hash

Returns:

  • Returns the model itself



333
334
335
# File 'lib/intersight_client/models/vnic_lan_connectivity_policy_all_of.rb', line 333

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_nullableObject

List of attributes with nullable: true



117
118
119
120
121
122
# File 'lib/intersight_client/models/vnic_lan_connectivity_policy_all_of.rb', line 117

def self.openapi_nullable
  Set.new([
    :'eth_ifs',
    :'profiles'
  ])
end

.openapi_typesObject

Attribute type mapping.



100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
# File 'lib/intersight_client/models/vnic_lan_connectivity_policy_all_of.rb', line 100

def self.openapi_types
  {
    :'class_id' => :'String',
    :'object_type' => :'String',
    :'azure_qos_enabled' => :'Boolean',
    :'iqn_allocation_type' => :'String',
    :'placement_mode' => :'String',
    :'static_iqn_name' => :'String',
    :'target_platform' => :'String',
    :'eth_ifs' => :'Array<VnicEthIfRelationship>',
    :'iqn_pool' => :'IqnpoolPoolRelationship',
    :'organization' => :'OrganizationOrganizationRelationship',
    :'profiles' => :'Array<PolicyAbstractConfigProfileRelationship>'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • to be compared



302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
# File 'lib/intersight_client/models/vnic_lan_connectivity_policy_all_of.rb', line 302

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      class_id == o.class_id &&
      object_type == o.object_type &&
      azure_qos_enabled == o.azure_qos_enabled &&
      iqn_allocation_type == o.iqn_allocation_type &&
      placement_mode == o.placement_mode &&
      static_iqn_name == o.static_iqn_name &&
      target_platform == o.target_platform &&
      eth_ifs == o.eth_ifs &&
      iqn_pool == o.iqn_pool &&
      organization == o.organization &&
      profiles == o.profiles
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • type Data type

  • value Value to be deserialized

Returns:

  • Deserialized data



363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
# File 'lib/intersight_client/models/vnic_lan_connectivity_policy_all_of.rb', line 363

def _deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = IntersightClient.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • Any valid value

Returns:

  • Returns the value in the form of hash



434
435
436
437
438
439
440
441
442
443
444
445
446
# File 'lib/intersight_client/models/vnic_lan_connectivity_policy_all_of.rb', line 434

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • Model attributes in the form of hash

Returns:

  • Returns the model itself



340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
# File 'lib/intersight_client/models/vnic_lan_connectivity_policy_all_of.rb', line 340

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  VnicLanConnectivityPolicyAllOf.openapi_types.each_pair do |key, type|
    if attributes[VnicLanConnectivityPolicyAllOf.attribute_map[key]].nil? && VnicLanConnectivityPolicyAllOf.openapi_nullable.include?(key)
      self.send("#{key}=", nil)
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[VnicLanConnectivityPolicyAllOf.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[VnicLanConnectivityPolicyAllOf.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[VnicLanConnectivityPolicyAllOf.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[VnicLanConnectivityPolicyAllOf.attribute_map[key]]))
    end
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • to be compared

Returns:

See Also:

  • `==` method


320
321
322
# File 'lib/intersight_client/models/vnic_lan_connectivity_policy_all_of.rb', line 320

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • Hash code



326
327
328
# File 'lib/intersight_client/models/vnic_lan_connectivity_policy_all_of.rb', line 326

def hash
  [class_id, object_type, azure_qos_enabled, iqn_allocation_type, placement_mode, static_iqn_name, target_platform, eth_ifs, iqn_pool, organization, profiles].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
# File 'lib/intersight_client/models/vnic_lan_connectivity_policy_all_of.rb', line 202

def list_invalid_properties
  invalid_properties = Array.new
  if @class_id.nil?
    invalid_properties.push('invalid value for "class_id", class_id cannot be nil.')
  end

  if @object_type.nil?
    invalid_properties.push('invalid value for "object_type", object_type cannot be nil.')
  end

  pattern = Regexp.new(/^$|^(?:iqn\.[0-9]{4}-[0-9]{2}(?:\.[A-Za-z](?:[A-Za-z0-9\-]*[A-Za-z0-9])?)+(?::.*)?|eui\.[0-9A-Fa-f]{16})/)
  if !@static_iqn_name.nil? && @static_iqn_name !~ pattern
    invalid_properties.push("invalid value for \"static_iqn_name\", must conform to the pattern #{pattern}.")
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • Returns the object in the form of hash



410
411
412
# File 'lib/intersight_client/models/vnic_lan_connectivity_policy_all_of.rb', line 410

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • Returns the object in the form of hash



416
417
418
419
420
421
422
423
424
425
426
427
428
# File 'lib/intersight_client/models/vnic_lan_connectivity_policy_all_of.rb', line 416

def to_hash
  hash = {}
  VnicLanConnectivityPolicyAllOf.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = VnicLanConnectivityPolicyAllOf.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • String presentation of the object



404
405
406
# File 'lib/intersight_client/models/vnic_lan_connectivity_policy_all_of.rb', line 404

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • true if the model is valid



222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
# File 'lib/intersight_client/models/vnic_lan_connectivity_policy_all_of.rb', line 222

def valid?
  return false if @class_id.nil?
  class_id_validator = EnumAttributeValidator.new('String', ["vnic.LanConnectivityPolicy"])
  return false unless class_id_validator.valid?(@class_id)
  return false if @object_type.nil?
  object_type_validator = EnumAttributeValidator.new('String', ["vnic.LanConnectivityPolicy"])
  return false unless object_type_validator.valid?(@object_type)
  iqn_allocation_type_validator = EnumAttributeValidator.new('String', ["None", "Static", "Pool"])
  return false unless iqn_allocation_type_validator.valid?(@iqn_allocation_type)
  placement_mode_validator = EnumAttributeValidator.new('String', ["custom", "auto"])
  return false unless placement_mode_validator.valid?(@placement_mode)
  return false if !@static_iqn_name.nil? && @static_iqn_name !~ Regexp.new(/^$|^(?:iqn\.[0-9]{4}-[0-9]{2}(?:\.[A-Za-z](?:[A-Za-z0-9\-]*[A-Za-z0-9])?)+(?::.*)?|eui\.[0-9A-Fa-f]{16})/)
  target_platform_validator = EnumAttributeValidator.new('String', ["Standalone", "FIAttached"])
  return false unless target_platform_validator.valid?(@target_platform)
  true
end