Class: IntersightClient::VnicVlanSettingsAllOf

Inherits:
Object
  • Object
show all
Defined in:
lib/intersight_client/models/vnic_vlan_settings_all_of.rb

Overview

Definition of the list of properties defined in 'vnic.VlanSettings', excluding properties defined in parent classes.

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ VnicVlanSettingsAllOf

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
# File 'lib/intersight_client/models/vnic_vlan_settings_all_of.rb', line 96

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `IntersightClient::VnicVlanSettingsAllOf` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `#{self.class.name}`. Please check the name to make sure it's valid. List of attributes: " + self.class.acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'class_id')
    self.class_id = attributes[:'class_id']
  else
    self.class_id = 'vnic.VlanSettings'
  end

  if attributes.key?(:'object_type')
    self.object_type = attributes[:'object_type']
  else
    self.object_type = 'vnic.VlanSettings'
  end

  if attributes.key?(:'allowed_vlans')
    self.allowed_vlans = attributes[:'allowed_vlans']
  end

  if attributes.key?(:'default_vlan')
    self.default_vlan = attributes[:'default_vlan']
  else
    self.default_vlan = 0
  end

  if attributes.key?(:'mode')
    self.mode = attributes[:'mode']
  else
    self.mode = 'ACCESS'
  end
end

Instance Attribute Details

#allowed_vlansObject

Allowed VLAN IDs of the virtual interface.



26
27
28
# File 'lib/intersight_client/models/vnic_vlan_settings_all_of.rb', line 26

def allowed_vlans
  @allowed_vlans
end

#class_idObject

The fully-qualified name of the instantiated, concrete type. This property is used as a discriminator to identify the type of the payload when marshaling and unmarshaling data.



20
21
22
# File 'lib/intersight_client/models/vnic_vlan_settings_all_of.rb', line 20

def class_id
  @class_id
end

#default_vlanObject

Native VLAN ID of the virtual interface or the corresponding vethernet on the peer Fabric Interconnect to which the virtual interface is connected. Setting the ID to 0 will not associate any native VLAN to the traffic on the virtual interface.



29
30
31
# File 'lib/intersight_client/models/vnic_vlan_settings_all_of.rb', line 29

def default_vlan
  @default_vlan
end

#modeObject

Option to determine if the port can carry single VLAN (Access) or multiple VLANs (Trunk) traffic. * ACCESS - An access port carries traffic only for a single VLAN on the interface. * TRUNK - A trunk port can have two or more VLANs configured on the interface. It can carry traffic for several VLANs simultaneously.



32
33
34
# File 'lib/intersight_client/models/vnic_vlan_settings_all_of.rb', line 32

def mode
  @mode
end

#object_typeObject

The fully-qualified name of the instantiated, concrete type. The value should be the same as the 'ClassId' property.



23
24
25
# File 'lib/intersight_client/models/vnic_vlan_settings_all_of.rb', line 23

def object_type
  @object_type
end

Class Method Details

.acceptable_attribute_mapObject

Returns the key-value map of all the JSON attributes this model knows about



73
74
75
# File 'lib/intersight_client/models/vnic_vlan_settings_all_of.rb', line 73

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



68
69
70
# File 'lib/intersight_client/models/vnic_vlan_settings_all_of.rb', line 68

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



57
58
59
60
61
62
63
64
65
# File 'lib/intersight_client/models/vnic_vlan_settings_all_of.rb', line 57

def self.attribute_map
  {
    :'class_id' => :'ClassId',
    :'object_type' => :'ObjectType',
    :'allowed_vlans' => :'AllowedVlans',
    :'default_vlan' => :'DefaultVlan',
    :'mode' => :'Mode'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



265
266
267
# File 'lib/intersight_client/models/vnic_vlan_settings_all_of.rb', line 265

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_nullableObject

List of attributes with nullable: true



89
90
91
92
# File 'lib/intersight_client/models/vnic_vlan_settings_all_of.rb', line 89

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



78
79
80
81
82
83
84
85
86
# File 'lib/intersight_client/models/vnic_vlan_settings_all_of.rb', line 78

def self.openapi_types
  {
    :'class_id' => :'String',
    :'object_type' => :'String',
    :'allowed_vlans' => :'String',
    :'default_vlan' => :'Integer',
    :'mode' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



240
241
242
243
244
245
246
247
248
# File 'lib/intersight_client/models/vnic_vlan_settings_all_of.rb', line 240

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      class_id == o.class_id &&
      object_type == o.object_type &&
      allowed_vlans == o.allowed_vlans &&
      default_vlan == o.default_vlan &&
      mode == o.mode
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
# File 'lib/intersight_client/models/vnic_vlan_settings_all_of.rb', line 295

def _deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = IntersightClient.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



366
367
368
369
370
371
372
373
374
375
376
377
378
# File 'lib/intersight_client/models/vnic_vlan_settings_all_of.rb', line 366

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
# File 'lib/intersight_client/models/vnic_vlan_settings_all_of.rb', line 272

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  VnicVlanSettingsAllOf.openapi_types.each_pair do |key, type|
    if attributes[VnicVlanSettingsAllOf.attribute_map[key]].nil? && VnicVlanSettingsAllOf.openapi_nullable.include?(key)
      self.send("#{key}=", nil)
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[VnicVlanSettingsAllOf.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[VnicVlanSettingsAllOf.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[VnicVlanSettingsAllOf.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[VnicVlanSettingsAllOf.attribute_map[key]]))
    end
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


252
253
254
# File 'lib/intersight_client/models/vnic_vlan_settings_all_of.rb', line 252

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



258
259
260
# File 'lib/intersight_client/models/vnic_vlan_settings_all_of.rb', line 258

def hash
  [class_id, object_type, allowed_vlans, default_vlan, mode].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
# File 'lib/intersight_client/models/vnic_vlan_settings_all_of.rb', line 140

def list_invalid_properties
  invalid_properties = Array.new
  if @class_id.nil?
    invalid_properties.push('invalid value for "class_id", class_id cannot be nil.')
  end

  if @object_type.nil?
    invalid_properties.push('invalid value for "object_type", object_type cannot be nil.')
  end

  pattern = Regexp.new(/^$|^((\d+\-\d+)|(\d+))(,((\d+\-\d+)|(\d+)))*$/)
  if !@allowed_vlans.nil? && @allowed_vlans !~ pattern
    invalid_properties.push("invalid value for \"allowed_vlans\", must conform to the pattern #{pattern}.")
  end

  if !@default_vlan.nil? && @default_vlan > 4094
    invalid_properties.push('invalid value for "default_vlan", must be smaller than or equal to 4094.')
  end

  if !@default_vlan.nil? && @default_vlan < 0
    invalid_properties.push('invalid value for "default_vlan", must be greater than or equal to 0.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



342
343
344
# File 'lib/intersight_client/models/vnic_vlan_settings_all_of.rb', line 342

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



348
349
350
351
352
353
354
355
356
357
358
359
360
# File 'lib/intersight_client/models/vnic_vlan_settings_all_of.rb', line 348

def to_hash
  hash = {}
  VnicVlanSettingsAllOf.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = VnicVlanSettingsAllOf.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



336
337
338
# File 'lib/intersight_client/models/vnic_vlan_settings_all_of.rb', line 336

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



168
169
170
171
172
173
174
175
176
177
178
179
180
181
# File 'lib/intersight_client/models/vnic_vlan_settings_all_of.rb', line 168

def valid?
  return false if @class_id.nil?
  class_id_validator = EnumAttributeValidator.new('String', ["vnic.VlanSettings"])
  return false unless class_id_validator.valid?(@class_id)
  return false if @object_type.nil?
  object_type_validator = EnumAttributeValidator.new('String', ["vnic.VlanSettings"])
  return false unless object_type_validator.valid?(@object_type)
  return false if !@allowed_vlans.nil? && @allowed_vlans !~ Regexp.new(/^$|^((\d+\-\d+)|(\d+))(,((\d+\-\d+)|(\d+)))*$/)
  return false if !@default_vlan.nil? && @default_vlan > 4094
  return false if !@default_vlan.nil? && @default_vlan < 0
  mode_validator = EnumAttributeValidator.new('String', ["ACCESS", "TRUNK"])
  return false unless mode_validator.valid?(@mode)
  true
end