Class: IntersightClient::VnicVmqSettingsAllOf

Inherits:
Object
  • Object
show all
Defined in:
lib/intersight_client/models/vnic_vmq_settings_all_of.rb

Overview

Definition of the list of properties defined in 'vnic.VmqSettings', excluding properties defined in parent classes.

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ VnicVmqSettingsAllOf

Initializes the object



111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
# File 'lib/intersight_client/models/vnic_vmq_settings_all_of.rb', line 111

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `IntersightClient::VnicVmqSettingsAllOf` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `#{self.class.name}`. Please check the name to make sure it's valid. List of attributes: " + self.class.acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'class_id')
    self.class_id = attributes[:'class_id']
  else
    self.class_id = 'vnic.VmqSettings'
  end

  if attributes.key?(:'object_type')
    self.object_type = attributes[:'object_type']
  else
    self.object_type = 'vnic.VmqSettings'
  end

  if attributes.key?(:'enabled')
    self.enabled = attributes[:'enabled']
  else
    self.enabled = false
  end

  if attributes.key?(:'multi_queue_support')
    self.multi_queue_support = attributes[:'multi_queue_support']
  else
    self.multi_queue_support = false
  end

  if attributes.key?(:'num_interrupts')
    self.num_interrupts = attributes[:'num_interrupts']
  else
    self.num_interrupts = 16
  end

  if attributes.key?(:'num_sub_vnics')
    self.num_sub_vnics = attributes[:'num_sub_vnics']
  else
    self.num_sub_vnics = 64
  end

  if attributes.key?(:'num_vmqs')
    self.num_vmqs = attributes[:'num_vmqs']
  else
    self.num_vmqs = 4
  end

  if attributes.key?(:'vmmq_adapter_policy')
    self.vmmq_adapter_policy = attributes[:'vmmq_adapter_policy']
  end
end

Instance Attribute Details

#class_idObject

The fully-qualified name of the instantiated, concrete type. This property is used as a discriminator to identify the type of the payload when marshaling and unmarshaling data.



20
21
22
# File 'lib/intersight_client/models/vnic_vmq_settings_all_of.rb', line 20

def class_id
  @class_id
end

#enabledObject

Enables VMQ feature on the virtual interface.



26
27
28
# File 'lib/intersight_client/models/vnic_vmq_settings_all_of.rb', line 26

def enabled
  @enabled
end

#multi_queue_supportObject

Enables Virtual Machine Multi-Queue feature on the virtual interface. VMMQ allows configuration of multiple I/O queues for a single VM and thus distributes traffic across multiple CPU cores in a VM.



29
30
31
# File 'lib/intersight_client/models/vnic_vmq_settings_all_of.rb', line 29

def multi_queue_support
  @multi_queue_support
end

#num_interruptsObject

The number of interrupt resources to be allocated. Recommended value is the number of CPU threads or logical processors available in the server.



32
33
34
# File 'lib/intersight_client/models/vnic_vmq_settings_all_of.rb', line 32

def num_interrupts
  @num_interrupts
end

#num_sub_vnicsObject

The number of sub vNICs to be created.



35
36
37
# File 'lib/intersight_client/models/vnic_vmq_settings_all_of.rb', line 35

def num_sub_vnics
  @num_sub_vnics
end

#num_vmqsObject

The number of hardware Virtual Machine Queues to be allocated. The number of VMQs per adapter must be one more than the maximum number of VM NICs.



38
39
40
# File 'lib/intersight_client/models/vnic_vmq_settings_all_of.rb', line 38

def num_vmqs
  @num_vmqs
end

#object_typeObject

The fully-qualified name of the instantiated, concrete type. The value should be the same as the 'ClassId' property.



23
24
25
# File 'lib/intersight_client/models/vnic_vmq_settings_all_of.rb', line 23

def object_type
  @object_type
end

#vmmq_adapter_policyObject

Ethernet Adapter policy to be associated with the Sub vNICs. The Transmit Queue and Receive Queue resource value of VMMQ adapter policy should be greater than or equal to the configured number of sub vNICs.



41
42
43
# File 'lib/intersight_client/models/vnic_vmq_settings_all_of.rb', line 41

def vmmq_adapter_policy
  @vmmq_adapter_policy
end

Class Method Details

.acceptable_attribute_mapObject

Returns the key-value map of all the JSON attributes this model knows about



85
86
87
# File 'lib/intersight_client/models/vnic_vmq_settings_all_of.rb', line 85

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



80
81
82
# File 'lib/intersight_client/models/vnic_vmq_settings_all_of.rb', line 80

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



66
67
68
69
70
71
72
73
74
75
76
77
# File 'lib/intersight_client/models/vnic_vmq_settings_all_of.rb', line 66

def self.attribute_map
  {
    :'class_id' => :'ClassId',
    :'object_type' => :'ObjectType',
    :'enabled' => :'Enabled',
    :'multi_queue_support' => :'MultiQueueSupport',
    :'num_interrupts' => :'NumInterrupts',
    :'num_sub_vnics' => :'NumSubVnics',
    :'num_vmqs' => :'NumVmqs',
    :'vmmq_adapter_policy' => :'VmmqAdapterPolicy'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash



320
321
322
# File 'lib/intersight_client/models/vnic_vmq_settings_all_of.rb', line 320

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_nullableObject

List of attributes with nullable: true



104
105
106
107
# File 'lib/intersight_client/models/vnic_vmq_settings_all_of.rb', line 104

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



90
91
92
93
94
95
96
97
98
99
100
101
# File 'lib/intersight_client/models/vnic_vmq_settings_all_of.rb', line 90

def self.openapi_types
  {
    :'class_id' => :'String',
    :'object_type' => :'String',
    :'enabled' => :'Boolean',
    :'multi_queue_support' => :'Boolean',
    :'num_interrupts' => :'Integer',
    :'num_sub_vnics' => :'Integer',
    :'num_vmqs' => :'Integer',
    :'vmmq_adapter_policy' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.



292
293
294
295
296
297
298
299
300
301
302
303
# File 'lib/intersight_client/models/vnic_vmq_settings_all_of.rb', line 292

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      class_id == o.class_id &&
      object_type == o.object_type &&
      enabled == o.enabled &&
      multi_queue_support == o.multi_queue_support &&
      num_interrupts == o.num_interrupts &&
      num_sub_vnics == o.num_sub_vnics &&
      num_vmqs == o.num_vmqs &&
      vmmq_adapter_policy == o.vmmq_adapter_policy
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type



350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
# File 'lib/intersight_client/models/vnic_vmq_settings_all_of.rb', line 350

def _deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = IntersightClient.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value



421
422
423
424
425
426
427
428
429
430
431
432
433
# File 'lib/intersight_client/models/vnic_vmq_settings_all_of.rb', line 421

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash



327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
# File 'lib/intersight_client/models/vnic_vmq_settings_all_of.rb', line 327

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  VnicVmqSettingsAllOf.openapi_types.each_pair do |key, type|
    if attributes[VnicVmqSettingsAllOf.attribute_map[key]].nil? && VnicVmqSettingsAllOf.openapi_nullable.include?(key)
      self.send("#{key}=", nil)
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[VnicVmqSettingsAllOf.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[VnicVmqSettingsAllOf.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[VnicVmqSettingsAllOf.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[VnicVmqSettingsAllOf.attribute_map[key]]))
    end
  end

  self
end

#eql?(o) ⇒ Boolean

See Also:

  • `==` method


307
308
309
# File 'lib/intersight_client/models/vnic_vmq_settings_all_of.rb', line 307

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.



313
314
315
# File 'lib/intersight_client/models/vnic_vmq_settings_all_of.rb', line 313

def hash
  [class_id, object_type, enabled, multi_queue_support, num_interrupts, num_sub_vnics, num_vmqs, vmmq_adapter_policy].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?



173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
# File 'lib/intersight_client/models/vnic_vmq_settings_all_of.rb', line 173

def list_invalid_properties
  invalid_properties = Array.new
  if @class_id.nil?
    invalid_properties.push('invalid value for "class_id", class_id cannot be nil.')
  end

  if @object_type.nil?
    invalid_properties.push('invalid value for "object_type", object_type cannot be nil.')
  end

  if !@num_interrupts.nil? && @num_interrupts > 514
    invalid_properties.push('invalid value for "num_interrupts", must be smaller than or equal to 514.')
  end

  if !@num_interrupts.nil? && @num_interrupts < 1
    invalid_properties.push('invalid value for "num_interrupts", must be greater than or equal to 1.')
  end

  if !@num_sub_vnics.nil? && @num_sub_vnics > 64
    invalid_properties.push('invalid value for "num_sub_vnics", must be smaller than or equal to 64.')
  end

  if !@num_sub_vnics.nil? && @num_sub_vnics < 0
    invalid_properties.push('invalid value for "num_sub_vnics", must be greater than or equal to 0.')
  end

  if !@num_vmqs.nil? && @num_vmqs > 128
    invalid_properties.push('invalid value for "num_vmqs", must be smaller than or equal to 128.')
  end

  if !@num_vmqs.nil? && @num_vmqs < 1
    invalid_properties.push('invalid value for "num_vmqs", must be greater than or equal to 1.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)



397
398
399
# File 'lib/intersight_client/models/vnic_vmq_settings_all_of.rb', line 397

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash



403
404
405
406
407
408
409
410
411
412
413
414
415
# File 'lib/intersight_client/models/vnic_vmq_settings_all_of.rb', line 403

def to_hash
  hash = {}
  VnicVmqSettingsAllOf.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = VnicVmqSettingsAllOf.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object



391
392
393
# File 'lib/intersight_client/models/vnic_vmq_settings_all_of.rb', line 391

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid



212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
# File 'lib/intersight_client/models/vnic_vmq_settings_all_of.rb', line 212

def valid?
  return false if @class_id.nil?
  class_id_validator = EnumAttributeValidator.new('String', ["vnic.VmqSettings"])
  return false unless class_id_validator.valid?(@class_id)
  return false if @object_type.nil?
  object_type_validator = EnumAttributeValidator.new('String', ["vnic.VmqSettings"])
  return false unless object_type_validator.valid?(@object_type)
  return false if !@num_interrupts.nil? && @num_interrupts > 514
  return false if !@num_interrupts.nil? && @num_interrupts < 1
  return false if !@num_sub_vnics.nil? && @num_sub_vnics > 64
  return false if !@num_sub_vnics.nil? && @num_sub_vnics < 0
  return false if !@num_vmqs.nil? && @num_vmqs > 128
  return false if !@num_vmqs.nil? && @num_vmqs < 1
  true
end