Class: IntersightClient::WorkflowAbstractWorkerTask
- Inherits:
-
WorkflowWorkflowTask
- Object
- MoBaseComplexType
- WorkflowWorkflowTask
- IntersightClient::WorkflowAbstractWorkerTask
- Defined in:
- lib/intersight_client/models/workflow_abstract_worker_task.rb
Overview
An AbstractWorkerTask is used to model a task that does some end-user work. This can be another task or it can be another workflow.
Direct Known Subclasses
WorkflowSubWorkflowTask, WorkflowWaitTask, WorkflowWorkerTask
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#class_id ⇒ Object
The fully-qualified name of the instantiated, concrete type.
-
#input_parameters ⇒ Object
JSON formatted map that defines the input given to the task.
-
#object_type ⇒ Object
The fully-qualified name of the instantiated, concrete type.
-
#on_failure ⇒ Object
This specifies the name of the next task to run if Task fails.
-
#on_success ⇒ Object
This specifies the name of the next task to run if Task succeeds.
-
#rollback_disabled ⇒ Object
The task is disabled/enabled for rollback operation in this workflow if the task has rollback support.
-
#use_default ⇒ Object
UseDefault when set to true, means the default version of the task or workflow will be used at the time of execution.
Attributes inherited from WorkflowWorkflowTask
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns the key-value map of all the JSON attributes this model knows about, including the ones defined in its parent(s).
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about, including the ones defined in its parent(s).
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_all_of ⇒ Object
List of class defined in allOf (OpenAPI v3).
-
.openapi_discriminator_name ⇒ Object
discriminator’s property name in OpenAPI v3.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ WorkflowAbstractWorkerTask
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ WorkflowAbstractWorkerTask
Initializes the object
120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 |
# File 'lib/intersight_client/models/workflow_abstract_worker_task.rb', line 120 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `IntersightClient::WorkflowAbstractWorkerTask` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `#{self.class.name}`. Please check the name to make sure it's valid. List of attributes: " + self.class.acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } # call parent's initialize super(attributes) if attributes.key?(:'class_id') self.class_id = attributes[:'class_id'] end if attributes.key?(:'object_type') self.object_type = attributes[:'object_type'] end if attributes.key?(:'input_parameters') self.input_parameters = attributes[:'input_parameters'] end if attributes.key?(:'on_failure') self.on_failure = attributes[:'on_failure'] end if attributes.key?(:'on_success') self.on_success = attributes[:'on_success'] end if attributes.key?(:'rollback_disabled') self.rollback_disabled = attributes[:'rollback_disabled'] else self.rollback_disabled = false end if attributes.key?(:'use_default') self.use_default = attributes[:'use_default'] else self.use_default = false end end |
Instance Attribute Details
#class_id ⇒ Object
The fully-qualified name of the instantiated, concrete type. This property is used as a discriminator to identify the type of the payload when marshaling and unmarshaling data. The enum values provides the list of concrete types that can be instantiated from this abstract type.
20 21 22 |
# File 'lib/intersight_client/models/workflow_abstract_worker_task.rb', line 20 def class_id @class_id end |
#input_parameters ⇒ Object
JSON formatted map that defines the input given to the task. JSONPath is used for chaining output from previous tasks as inputs into the current task. The format to specify the mapping is ‘$Source.input/output.JsonPath’. ‘Source’ can be either workflow or the name of the task within the workflow. You can map the task input to either a workflow input or a task output. Following this is JSON path expression to extract JSON fragment from source’s input/output.
26 27 28 |
# File 'lib/intersight_client/models/workflow_abstract_worker_task.rb', line 26 def input_parameters @input_parameters end |
#object_type ⇒ Object
The fully-qualified name of the instantiated, concrete type. The value should be the same as the ‘ClassId’ property. The enum values provides the list of concrete types that can be instantiated from this abstract type.
23 24 25 |
# File 'lib/intersight_client/models/workflow_abstract_worker_task.rb', line 23 def object_type @object_type end |
#on_failure ⇒ Object
This specifies the name of the next task to run if Task fails. This is the unique name given to the task instance within the workflow. In a graph model, denotes an edge to another Task Node.
29 30 31 |
# File 'lib/intersight_client/models/workflow_abstract_worker_task.rb', line 29 def on_failure @on_failure end |
#on_success ⇒ Object
This specifies the name of the next task to run if Task succeeds. This is the unique name given to the task instance within the workflow. In a graph model, denotes an edge to another Task Node.
32 33 34 |
# File 'lib/intersight_client/models/workflow_abstract_worker_task.rb', line 32 def on_success @on_success end |
#rollback_disabled ⇒ Object
The task is disabled/enabled for rollback operation in this workflow if the task has rollback support.
35 36 37 |
# File 'lib/intersight_client/models/workflow_abstract_worker_task.rb', line 35 def rollback_disabled @rollback_disabled end |
#use_default ⇒ Object
UseDefault when set to true, means the default version of the task or workflow will be used at the time of execution. When this property is set then version for task or subworkflow cannot be set. When workflow is created or updated the default version of task or subworkflow will be used for validation, but when the workflow is executed the default version that that time will be used for validation and subsequent execution.
38 39 40 |
# File 'lib/intersight_client/models/workflow_abstract_worker_task.rb', line 38 def use_default @use_default end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns the key-value map of all the JSON attributes this model knows about, including the ones defined in its parent(s)
81 82 83 |
# File 'lib/intersight_client/models/workflow_abstract_worker_task.rb', line 81 def self.acceptable_attribute_map attribute_map.merge(superclass.acceptable_attribute_map) end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about, including the ones defined in its parent(s)
76 77 78 |
# File 'lib/intersight_client/models/workflow_abstract_worker_task.rb', line 76 def self.acceptable_attributes attribute_map.values.concat(superclass.acceptable_attributes) end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
63 64 65 66 67 68 69 70 71 72 73 |
# File 'lib/intersight_client/models/workflow_abstract_worker_task.rb', line 63 def self.attribute_map { :'class_id' => :'ClassId', :'object_type' => :'ObjectType', :'input_parameters' => :'InputParameters', :'on_failure' => :'OnFailure', :'on_success' => :'OnSuccess', :'rollback_disabled' => :'RollbackDisabled', :'use_default' => :'UseDefault' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
245 246 247 |
# File 'lib/intersight_client/models/workflow_abstract_worker_task.rb', line 245 def self.build_from_hash(attributes) new.build_from_hash(attributes) end |
.openapi_all_of ⇒ Object
List of class defined in allOf (OpenAPI v3)
106 107 108 109 110 111 |
# File 'lib/intersight_client/models/workflow_abstract_worker_task.rb', line 106 def self.openapi_all_of [ :'WorkflowAbstractWorkerTaskAllOf', :'WorkflowWorkflowTask' ] end |
.openapi_discriminator_name ⇒ Object
discriminator’s property name in OpenAPI v3
114 115 116 |
# File 'lib/intersight_client/models/workflow_abstract_worker_task.rb', line 114 def self.openapi_discriminator_name :'ClassId' end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
99 100 101 102 103 |
# File 'lib/intersight_client/models/workflow_abstract_worker_task.rb', line 99 def self.openapi_nullable Set.new([ :'input_parameters', ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
86 87 88 89 90 91 92 93 94 95 96 |
# File 'lib/intersight_client/models/workflow_abstract_worker_task.rb', line 86 def self.openapi_types { :'class_id' => :'String', :'object_type' => :'String', :'input_parameters' => :'Object', :'on_failure' => :'String', :'on_success' => :'String', :'rollback_disabled' => :'Boolean', :'use_default' => :'Boolean' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
218 219 220 221 222 223 224 225 226 227 228 |
# File 'lib/intersight_client/models/workflow_abstract_worker_task.rb', line 218 def ==(o) return true if self.equal?(o) self.class == o.class && class_id == o.class_id && object_type == o.object_type && input_parameters == o.input_parameters && on_failure == o.on_failure && on_success == o.on_success && rollback_disabled == o.rollback_disabled && use_default == o.use_default && super(o) end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 |
# File 'lib/intersight_client/models/workflow_abstract_worker_task.rb', line 276 def _deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = IntersightClient.const_get(type) klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
347 348 349 350 351 352 353 354 355 356 357 358 359 |
# File 'lib/intersight_client/models/workflow_abstract_worker_task.rb', line 347 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 |
# File 'lib/intersight_client/models/workflow_abstract_worker_task.rb', line 252 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) super(attributes) WorkflowAbstractWorkerTask.openapi_types.each_pair do |key, type| if attributes[WorkflowAbstractWorkerTask.attribute_map[key]].nil? && WorkflowAbstractWorkerTask.openapi_nullable.include?(key) self.send("#{key}=", nil) elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[WorkflowAbstractWorkerTask.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[WorkflowAbstractWorkerTask.attribute_map[key]].map { |v| _deserialize($1, v) }) end elsif !attributes[WorkflowAbstractWorkerTask.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[WorkflowAbstractWorkerTask.attribute_map[key]])) end end self end |
#eql?(o) ⇒ Boolean
232 233 234 |
# File 'lib/intersight_client/models/workflow_abstract_worker_task.rb', line 232 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
238 239 240 |
# File 'lib/intersight_client/models/workflow_abstract_worker_task.rb', line 238 def hash [class_id, object_type, input_parameters, on_failure, on_success, rollback_disabled, use_default].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
171 172 173 174 175 176 177 178 179 180 181 182 |
# File 'lib/intersight_client/models/workflow_abstract_worker_task.rb', line 171 def list_invalid_properties invalid_properties = super if @class_id.nil? invalid_properties.push('invalid value for "class_id", class_id cannot be nil.') end if @object_type.nil? invalid_properties.push('invalid value for "object_type", object_type cannot be nil.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
323 324 325 |
# File 'lib/intersight_client/models/workflow_abstract_worker_task.rb', line 323 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
329 330 331 332 333 334 335 336 337 338 339 340 341 |
# File 'lib/intersight_client/models/workflow_abstract_worker_task.rb', line 329 def to_hash hash = super WorkflowAbstractWorkerTask.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = WorkflowAbstractWorkerTask.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
317 318 319 |
# File 'lib/intersight_client/models/workflow_abstract_worker_task.rb', line 317 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
186 187 188 189 190 191 192 193 194 |
# File 'lib/intersight_client/models/workflow_abstract_worker_task.rb', line 186 def valid? return false if @class_id.nil? class_id_validator = EnumAttributeValidator.new('String', ["workflow.SubWorkflowTask", "workflow.WaitTask", "workflow.WorkerTask"]) return false unless class_id_validator.valid?(@class_id) return false if @object_type.nil? object_type_validator = EnumAttributeValidator.new('String', ["workflow.SubWorkflowTask", "workflow.WaitTask", "workflow.WorkerTask"]) return false unless object_type_validator.valid?(@object_type) true && super end |