Class: IntersightClient::WorkflowBaseDataTypeAllOf

Inherits:
Object
  • Object
show all
Defined in:
lib/intersight_client/models/workflow_base_data_type_all_of.rb

Overview

Definition of the list of properties defined in ‘workflow.BaseDataType’, excluding properties defined in parent classes.

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ WorkflowBaseDataTypeAllOf

Initializes the object

Parameters:

  • (defaults to: {})

    Model attributes in the form of hash



117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
# File 'lib/intersight_client/models/workflow_base_data_type_all_of.rb', line 117

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `IntersightClient::WorkflowBaseDataTypeAllOf` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `#{self.class.name}`. Please check the name to make sure it's valid. List of attributes: " + self.class.acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'class_id')
    self.class_id = attributes[:'class_id']
  end

  if attributes.key?(:'object_type')
    self.object_type = attributes[:'object_type']
  end

  if attributes.key?(:'default')
    self.default = attributes[:'default']
  end

  if attributes.key?(:'description')
    self.description = attributes[:'description']
  end

  if attributes.key?(:'display_meta')
    self.display_meta = attributes[:'display_meta']
  end

  if attributes.key?(:'input_parameters')
    self.input_parameters = attributes[:'input_parameters']
  end

  if attributes.key?(:'label')
    self.label = attributes[:'label']
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  end

  if attributes.key?(:'required')
    self.required = attributes[:'required']
  end
end

Instance Attribute Details

#class_idObject

The fully-qualified name of the instantiated, concrete type. This property is used as a discriminator to identify the type of the payload when marshaling and unmarshaling data. The enum values provides the list of concrete types that can be instantiated from this abstract type.



20
21
22
# File 'lib/intersight_client/models/workflow_base_data_type_all_of.rb', line 20

def class_id
  @class_id
end

#defaultObject

Returns the value of attribute default.



25
26
27
# File 'lib/intersight_client/models/workflow_base_data_type_all_of.rb', line 25

def default
  @default
end

#descriptionObject

Provide a detailed description of the data type.



28
29
30
# File 'lib/intersight_client/models/workflow_base_data_type_all_of.rb', line 28

def description
  @description
end

#display_metaObject

Returns the value of attribute display_meta.



30
31
32
# File 'lib/intersight_client/models/workflow_base_data_type_all_of.rb', line 30

def display_meta
  @display_meta
end

#input_parametersObject

JSON formatted mapping from other property of the definition to the current property. Input parameter mapping is supported only for custom data type property in workflow definition and custom data type definition. The format to specify mapping ina workflow definition when source property is of scalar types is ‘$IntersightClient::WorkflowBaseDataTypeAllOf.workflowworkflow.inputworkflow.input.property’. The format to specify mapping when the source property is of object reference and mapping needs to be made to the property of the object is ‘$IntersightClient::WorkflowBaseDataTypeAllOf.workflowworkflow.inputworkflow.input.propertyworkflow.input.property.subproperty’. The format to specify mapping in a custom data type definition is ‘$IntersightClient::WorkflowBaseDataTypeAllOf.datatypedatatype.typedatatype.type.property’. When the current property is of non-scalar type like composite custom data type, then mapping can be provided to the individual property of the custom data type like ‘cdt_property:$IntersightClient::WorkflowBaseDataTypeAllOf.workflowworkflow.inputworkflow.input.property’.



33
34
35
# File 'lib/intersight_client/models/workflow_base_data_type_all_of.rb', line 33

def input_parameters
  @input_parameters
end

#labelObject

Descriptive label for the data type. Label can only contain letters (a-z, A-Z), numbers (0-9), hyphen (-), space ( ) or an underscore (_). The first and last character in label must be an alphanumeric character.



36
37
38
# File 'lib/intersight_client/models/workflow_base_data_type_all_of.rb', line 36

def label
  @label
end

#nameObject

Descriptive name for the data type. Name can only contain letters (a-z, A-Z), numbers (0-9), hyphen (-) or an underscore (_). The first and last character in name must be an alphanumeric character.



39
40
41
# File 'lib/intersight_client/models/workflow_base_data_type_all_of.rb', line 39

def name
  @name
end

#object_typeObject

The fully-qualified name of the instantiated, concrete type. The value should be the same as the ‘ClassId’ property. The enum values provides the list of concrete types that can be instantiated from this abstract type.



23
24
25
# File 'lib/intersight_client/models/workflow_base_data_type_all_of.rb', line 23

def object_type
  @object_type
end

#requiredObject

Specifies whether this parameter is required. The field is applicable for task and workflow.



42
43
44
# File 'lib/intersight_client/models/workflow_base_data_type_all_of.rb', line 42

def required
  @required
end

Class Method Details

.acceptable_attribute_mapObject

Returns the key-value map of all the JSON attributes this model knows about



87
88
89
# File 'lib/intersight_client/models/workflow_base_data_type_all_of.rb', line 87

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



82
83
84
# File 'lib/intersight_client/models/workflow_base_data_type_all_of.rb', line 82

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



67
68
69
70
71
72
73
74
75
76
77
78
79
# File 'lib/intersight_client/models/workflow_base_data_type_all_of.rb', line 67

def self.attribute_map
  {
    :'class_id' => :'ClassId',
    :'object_type' => :'ObjectType',
    :'default' => :'Default',
    :'description' => :'Description',
    :'display_meta' => :'DisplayMeta',
    :'input_parameters' => :'InputParameters',
    :'label' => :'Label',
    :'name' => :'Name',
    :'required' => :'Required'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • Model attributes in the form of hash

Returns:

  • Returns the model itself



315
316
317
# File 'lib/intersight_client/models/workflow_base_data_type_all_of.rb', line 315

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_nullableObject

List of attributes with nullable: true



107
108
109
110
111
112
113
# File 'lib/intersight_client/models/workflow_base_data_type_all_of.rb', line 107

def self.openapi_nullable
  Set.new([
    :'default',
    :'display_meta',
    :'input_parameters',
  ])
end

.openapi_typesObject

Attribute type mapping.



92
93
94
95
96
97
98
99
100
101
102
103
104
# File 'lib/intersight_client/models/workflow_base_data_type_all_of.rb', line 92

def self.openapi_types
  {
    :'class_id' => :'String',
    :'object_type' => :'String',
    :'default' => :'WorkflowDefaultValue',
    :'description' => :'String',
    :'display_meta' => :'WorkflowDisplayMeta',
    :'input_parameters' => :'Object',
    :'label' => :'String',
    :'name' => :'String',
    :'required' => :'Boolean'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • to be compared



286
287
288
289
290
291
292
293
294
295
296
297
298
# File 'lib/intersight_client/models/workflow_base_data_type_all_of.rb', line 286

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      class_id == o.class_id &&
      object_type == o.object_type &&
      default == o.default &&
      description == o.description &&
      display_meta == o.display_meta &&
      input_parameters == o.input_parameters &&
      label == o.label &&
      name == o.name &&
      required == o.required
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • type Data type

  • value Value to be deserialized

Returns:

  • Deserialized data



345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
# File 'lib/intersight_client/models/workflow_base_data_type_all_of.rb', line 345

def _deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = IntersightClient.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • Any valid value

Returns:

  • Returns the value in the form of hash



416
417
418
419
420
421
422
423
424
425
426
427
428
# File 'lib/intersight_client/models/workflow_base_data_type_all_of.rb', line 416

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • Model attributes in the form of hash

Returns:

  • Returns the model itself



322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
# File 'lib/intersight_client/models/workflow_base_data_type_all_of.rb', line 322

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  WorkflowBaseDataTypeAllOf.openapi_types.each_pair do |key, type|
    if attributes[WorkflowBaseDataTypeAllOf.attribute_map[key]].nil? && WorkflowBaseDataTypeAllOf.openapi_nullable.include?(key)
      self.send("#{key}=", nil)
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[WorkflowBaseDataTypeAllOf.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[WorkflowBaseDataTypeAllOf.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[WorkflowBaseDataTypeAllOf.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[WorkflowBaseDataTypeAllOf.attribute_map[key]]))
    end
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • to be compared

Returns:

See Also:

  • `==` method


302
303
304
# File 'lib/intersight_client/models/workflow_base_data_type_all_of.rb', line 302

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • Hash code



308
309
310
# File 'lib/intersight_client/models/workflow_base_data_type_all_of.rb', line 308

def hash
  [class_id, object_type, default, description, display_meta, input_parameters, label, name, required].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
# File 'lib/intersight_client/models/workflow_base_data_type_all_of.rb', line 169

def list_invalid_properties
  invalid_properties = Array.new
  if @class_id.nil?
    invalid_properties.push('invalid value for "class_id", class_id cannot be nil.')
  end

  if @object_type.nil?
    invalid_properties.push('invalid value for "object_type", object_type cannot be nil.')
  end

  if !@label.nil? && @label.to_s.length > 92
    invalid_properties.push('invalid value for "label", the character length must be smaller than or equal to 92.')
  end

  if !@label.nil? && @label.to_s.length < 1
    invalid_properties.push('invalid value for "label", the character length must be great than or equal to 1.')
  end

  pattern = Regexp.new(/^[a-zA-Z0-9]+[\sa-zA-Z0-9_'.:-]{1,92}$/)
  if !@label.nil? && @label !~ pattern
    invalid_properties.push("invalid value for \"label\", must conform to the pattern #{pattern}.")
  end

  if !@name.nil? && @name.to_s.length > 92
    invalid_properties.push('invalid value for "name", the character length must be smaller than or equal to 92.')
  end

  if !@name.nil? && @name.to_s.length < 1
    invalid_properties.push('invalid value for "name", the character length must be great than or equal to 1.')
  end

  pattern = Regexp.new(/^[a-zA-Z0-9]+([a-zA-Z0-9\-_]*[a-zA-Z0-9])*$/)
  if !@name.nil? && @name !~ pattern
    invalid_properties.push("invalid value for \"name\", must conform to the pattern #{pattern}.")
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • Returns the object in the form of hash



392
393
394
# File 'lib/intersight_client/models/workflow_base_data_type_all_of.rb', line 392

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • Returns the object in the form of hash



398
399
400
401
402
403
404
405
406
407
408
409
410
# File 'lib/intersight_client/models/workflow_base_data_type_all_of.rb', line 398

def to_hash
  hash = {}
  WorkflowBaseDataTypeAllOf.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = WorkflowBaseDataTypeAllOf.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • String presentation of the object



386
387
388
# File 'lib/intersight_client/models/workflow_base_data_type_all_of.rb', line 386

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • true if the model is valid



210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
# File 'lib/intersight_client/models/workflow_base_data_type_all_of.rb', line 210

def valid?
  return false if @class_id.nil?
  class_id_validator = EnumAttributeValidator.new('String', ["workflow.ArrayDataType", "workflow.CustomDataType", "workflow.MoReferenceDataType", "workflow.PrimitiveDataType", "workflow.TargetDataType"])
  return false unless class_id_validator.valid?(@class_id)
  return false if @object_type.nil?
  object_type_validator = EnumAttributeValidator.new('String', ["workflow.ArrayDataType", "workflow.CustomDataType", "workflow.MoReferenceDataType", "workflow.PrimitiveDataType", "workflow.TargetDataType"])
  return false unless object_type_validator.valid?(@object_type)
  return false if !@label.nil? && @label.to_s.length > 92
  return false if !@label.nil? && @label.to_s.length < 1
  return false if !@label.nil? && @label !~ Regexp.new(/^[a-zA-Z0-9]+[\sa-zA-Z0-9_'.:-]{1,92}$/)
  return false if !@name.nil? && @name.to_s.length > 92
  return false if !@name.nil? && @name.to_s.length < 1
  return false if !@name.nil? && @name !~ Regexp.new(/^[a-zA-Z0-9]+([a-zA-Z0-9\-_]*[a-zA-Z0-9])*$/)
  true
end