Class: IntersightClient::WorkflowLoopTask
- Inherits:
-
WorkflowControlTask
- Object
- MoBaseComplexType
- WorkflowWorkflowTask
- WorkflowControlTask
- IntersightClient::WorkflowLoopTask
- Defined in:
- lib/intersight_client/models/workflow_loop_task.rb
Overview
A LoopTask is a control task that runs one or more task multiple times based on a counter. The tasks can be run in serial or parallel.
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#class_id ⇒ Object
The fully-qualified name of the instantiated, concrete type.
-
#count ⇒ Object
Count value for the loop, this can be a constant or an expression which will evaluate to an integer value.
-
#loop_start_task ⇒ Object
Start task where the list of tasks will be executed multiple times based on the count value.
-
#number_of_batches ⇒ Object
When tasks are run in parallel and the count is large, the actual number of task run in parallel can be controlled by this property.
-
#object_type ⇒ Object
The fully-qualified name of the instantiated, concrete type.
-
#on_success ⇒ Object
This specifies the name of the next task to run if all iterations of the loop task succeeds.
-
#parallel ⇒ Object
When set to true the loop will run in parallel else it will run in a serial fashion.
Attributes inherited from WorkflowWorkflowTask
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns the key-value map of all the JSON attributes this model knows about, including the ones defined in its parent(s).
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about, including the ones defined in its parent(s).
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_all_of ⇒ Object
List of class defined in allOf (OpenAPI v3).
-
.openapi_discriminator_name ⇒ Object
discriminator’s property name in OpenAPI v3.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ WorkflowLoopTask
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ WorkflowLoopTask
Initializes the object
119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 |
# File 'lib/intersight_client/models/workflow_loop_task.rb', line 119 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `IntersightClient::WorkflowLoopTask` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `#{self.class.name}`. Please check the name to make sure it's valid. List of attributes: " + self.class.acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } # call parent's initialize super(attributes) if attributes.key?(:'class_id') self.class_id = attributes[:'class_id'] else self.class_id = 'workflow.LoopTask' end if attributes.key?(:'object_type') self.object_type = attributes[:'object_type'] else self.object_type = 'workflow.LoopTask' end if attributes.key?(:'count') self.count = attributes[:'count'] end if attributes.key?(:'loop_start_task') self.loop_start_task = attributes[:'loop_start_task'] end if attributes.key?(:'number_of_batches') self.number_of_batches = attributes[:'number_of_batches'] else self.number_of_batches = 1 end if attributes.key?(:'on_success') self.on_success = attributes[:'on_success'] end if attributes.key?(:'parallel') self.parallel = attributes[:'parallel'] else self.parallel = true end end |
Instance Attribute Details
#class_id ⇒ Object
The fully-qualified name of the instantiated, concrete type. This property is used as a discriminator to identify the type of the payload when marshaling and unmarshaling data.
20 21 22 |
# File 'lib/intersight_client/models/workflow_loop_task.rb', line 20 def class_id @class_id end |
#count ⇒ Object
Count value for the loop, this can be a constant or an expression which will evaluate to an integer value. Example, Use the length of the input A which is an array. Count must be less than or equal to 500.
26 27 28 |
# File 'lib/intersight_client/models/workflow_loop_task.rb', line 26 def count @count end |
#loop_start_task ⇒ Object
Start task where the list of tasks will be executed multiple times based on the count value.
29 30 31 |
# File 'lib/intersight_client/models/workflow_loop_task.rb', line 29 def loop_start_task @loop_start_task end |
#number_of_batches ⇒ Object
When tasks are run in parallel and the count is large, the actual number of task run in parallel can be controlled by this property. If count is 100 and numberOfBatches is 5 then 20 tasks are run in parallel 5 times. Parallel batch size must be less than the count. In cases where count is dynamic and depends on input given during workflow execution, if that count is less than batch then empty batches might get created which do not have any tasks under them.
32 33 34 |
# File 'lib/intersight_client/models/workflow_loop_task.rb', line 32 def number_of_batches @number_of_batches end |
#object_type ⇒ Object
The fully-qualified name of the instantiated, concrete type. The value should be the same as the ‘ClassId’ property.
23 24 25 |
# File 'lib/intersight_client/models/workflow_loop_task.rb', line 23 def object_type @object_type end |
#on_success ⇒ Object
This specifies the name of the next task to run if all iterations of the loop task succeeds. The unique name given to the task instance within the workflow must be provided here. In a graph model, denotes an edge to another Task Node.
35 36 37 |
# File 'lib/intersight_client/models/workflow_loop_task.rb', line 35 def on_success @on_success end |
#parallel ⇒ Object
When set to true the loop will run in parallel else it will run in a serial fashion. Only one task is supported inside the loop task when the loop is run in parallel. Subworkflow can be used inside the single loop task to build complex conditions.
38 39 40 |
# File 'lib/intersight_client/models/workflow_loop_task.rb', line 38 def parallel @parallel end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns the key-value map of all the JSON attributes this model knows about, including the ones defined in its parent(s)
81 82 83 |
# File 'lib/intersight_client/models/workflow_loop_task.rb', line 81 def self.acceptable_attribute_map attribute_map.merge(superclass.acceptable_attribute_map) end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about, including the ones defined in its parent(s)
76 77 78 |
# File 'lib/intersight_client/models/workflow_loop_task.rb', line 76 def self.acceptable_attributes attribute_map.values.concat(superclass.acceptable_attributes) end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
63 64 65 66 67 68 69 70 71 72 73 |
# File 'lib/intersight_client/models/workflow_loop_task.rb', line 63 def self.attribute_map { :'class_id' => :'ClassId', :'object_type' => :'ObjectType', :'count' => :'Count', :'loop_start_task' => :'LoopStartTask', :'number_of_batches' => :'NumberOfBatches', :'on_success' => :'OnSuccess', :'parallel' => :'Parallel' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
263 264 265 |
# File 'lib/intersight_client/models/workflow_loop_task.rb', line 263 def self.build_from_hash(attributes) new.build_from_hash(attributes) end |
.openapi_all_of ⇒ Object
List of class defined in allOf (OpenAPI v3)
105 106 107 108 109 110 |
# File 'lib/intersight_client/models/workflow_loop_task.rb', line 105 def self.openapi_all_of [ :'WorkflowControlTask', :'WorkflowLoopTaskAllOf' ] end |
.openapi_discriminator_name ⇒ Object
discriminator’s property name in OpenAPI v3
113 114 115 |
# File 'lib/intersight_client/models/workflow_loop_task.rb', line 113 def self.openapi_discriminator_name :'ClassId' end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
99 100 101 102 |
# File 'lib/intersight_client/models/workflow_loop_task.rb', line 99 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
86 87 88 89 90 91 92 93 94 95 96 |
# File 'lib/intersight_client/models/workflow_loop_task.rb', line 86 def self.openapi_types { :'class_id' => :'String', :'object_type' => :'String', :'count' => :'String', :'loop_start_task' => :'String', :'number_of_batches' => :'Integer', :'on_success' => :'String', :'parallel' => :'Boolean' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
236 237 238 239 240 241 242 243 244 245 246 |
# File 'lib/intersight_client/models/workflow_loop_task.rb', line 236 def ==(o) return true if self.equal?(o) self.class == o.class && class_id == o.class_id && object_type == o.object_type && count == o.count && loop_start_task == o.loop_start_task && number_of_batches == o.number_of_batches && on_success == o.on_success && parallel == o.parallel && super(o) end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 |
# File 'lib/intersight_client/models/workflow_loop_task.rb', line 294 def _deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = IntersightClient.const_get(type) klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
365 366 367 368 369 370 371 372 373 374 375 376 377 |
# File 'lib/intersight_client/models/workflow_loop_task.rb', line 365 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 |
# File 'lib/intersight_client/models/workflow_loop_task.rb', line 270 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) super(attributes) WorkflowLoopTask.openapi_types.each_pair do |key, type| if attributes[WorkflowLoopTask.attribute_map[key]].nil? && WorkflowLoopTask.openapi_nullable.include?(key) self.send("#{key}=", nil) elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[WorkflowLoopTask.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[WorkflowLoopTask.attribute_map[key]].map { |v| _deserialize($1, v) }) end elsif !attributes[WorkflowLoopTask.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[WorkflowLoopTask.attribute_map[key]])) end end self end |
#eql?(o) ⇒ Boolean
250 251 252 |
# File 'lib/intersight_client/models/workflow_loop_task.rb', line 250 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
256 257 258 |
# File 'lib/intersight_client/models/workflow_loop_task.rb', line 256 def hash [class_id, object_type, count, loop_start_task, number_of_batches, on_success, parallel].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 |
# File 'lib/intersight_client/models/workflow_loop_task.rb', line 174 def list_invalid_properties invalid_properties = super if @class_id.nil? invalid_properties.push('invalid value for "class_id", class_id cannot be nil.') end if @object_type.nil? invalid_properties.push('invalid value for "object_type", object_type cannot be nil.') end if !@number_of_batches.nil? && @number_of_batches < 1 invalid_properties.push('invalid value for "number_of_batches", must be greater than or equal to 1.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
341 342 343 |
# File 'lib/intersight_client/models/workflow_loop_task.rb', line 341 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
347 348 349 350 351 352 353 354 355 356 357 358 359 |
# File 'lib/intersight_client/models/workflow_loop_task.rb', line 347 def to_hash hash = super WorkflowLoopTask.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = WorkflowLoopTask.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
335 336 337 |
# File 'lib/intersight_client/models/workflow_loop_task.rb', line 335 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
193 194 195 196 197 198 199 200 201 202 |
# File 'lib/intersight_client/models/workflow_loop_task.rb', line 193 def valid? return false if @class_id.nil? class_id_validator = EnumAttributeValidator.new('String', ["workflow.LoopTask"]) return false unless class_id_validator.valid?(@class_id) return false if @object_type.nil? object_type_validator = EnumAttributeValidator.new('String', ["workflow.LoopTask"]) return false unless object_type_validator.valid?(@object_type) return false if !@number_of_batches.nil? && @number_of_batches < 1 true && super end |