Class: IntersightClient::WorkflowPrimitiveDataPropertyAllOf

Inherits:
Object
  • Object
show all
Defined in:
lib/intersight_client/models/workflow_primitive_data_property_all_of.rb

Overview

Definition of the list of properties defined in 'workflow.PrimitiveDataProperty', excluding properties defined in parent classes.

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ WorkflowPrimitiveDataPropertyAllOf

Initializes the object



101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
# File 'lib/intersight_client/models/workflow_primitive_data_property_all_of.rb', line 101

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `IntersightClient::WorkflowPrimitiveDataPropertyAllOf` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `#{self.class.name}`. Please check the name to make sure it's valid. List of attributes: " + self.class.acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'class_id')
    self.class_id = attributes[:'class_id']
  else
    self.class_id = 'workflow.PrimitiveDataProperty'
  end

  if attributes.key?(:'object_type')
    self.object_type = attributes[:'object_type']
  else
    self.object_type = 'workflow.PrimitiveDataProperty'
  end

  if attributes.key?(:'constraints')
    self.constraints = attributes[:'constraints']
  end

  if attributes.key?(:'inventory_selector')
    if (value = attributes[:'inventory_selector']).is_a?(Array)
      self.inventory_selector = value
    end
  end

  if attributes.key?(:'secure')
    self.secure = attributes[:'secure']
  end

  if attributes.key?(:'type')
    self.type = attributes[:'type']
  else
    self.type = 'string'
  end
end

Instance Attribute Details

#class_id ⇒ Object

The fully-qualified name of the instantiated, concrete type. This property is used as a discriminator to identify the type of the payload when marshaling and unmarshaling data.



20
21
22
# File 'lib/intersight_client/models/workflow_primitive_data_property_all_of.rb', line 20

def class_id
  @class_id
end

#constraints ⇒ Object

Returns the value of attribute constraints.



25
26
27
# File 'lib/intersight_client/models/workflow_primitive_data_property_all_of.rb', line 25

def constraints
  @constraints
end

#inventory_selector ⇒ Object

Returns the value of attribute inventory_selector.



27
28
29
# File 'lib/intersight_client/models/workflow_primitive_data_property_all_of.rb', line 27

def inventory_selector
  @inventory_selector
end

#object_type ⇒ Object

The fully-qualified name of the instantiated, concrete type. The value should be the same as the 'ClassId' property.



23
24
25
# File 'lib/intersight_client/models/workflow_primitive_data_property_all_of.rb', line 23

def object_type
  @object_type
end

#secure ⇒ Object

Intersight supports secure properties as task input/output. The values of these properties are encrypted and stored in Intersight. This flag marks the property to be secure when it is set to true.



30
31
32
# File 'lib/intersight_client/models/workflow_primitive_data_property_all_of.rb', line 30

def secure
  @secure
end

#type ⇒ Object

Specify the enum type for primitive data type. * string - Enum to specify a string data type. * integer - Enum to specify an integer32 data type. * float - Enum to specify a float64 data type. * boolean - Enum to specify a boolean data type. * json - Enum to specify a json data type. * enum - Enum to specify a enum data type which is a list of pre-defined strings.



33
34
35
# File 'lib/intersight_client/models/workflow_primitive_data_property_all_of.rb', line 33

def type
  @type
end

Class Method Details

.acceptable_attribute_map ⇒ Object

Returns the key-value map of all the JSON attributes this model knows about



75
76
77
# File 'lib/intersight_client/models/workflow_primitive_data_property_all_of.rb', line 75

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributes ⇒ Object

Returns all the JSON keys this model knows about



70
71
72
# File 'lib/intersight_client/models/workflow_primitive_data_property_all_of.rb', line 70

def self.acceptable_attributes
  attribute_map.values
end

.attribute_map ⇒ Object

Attribute mapping from ruby-style variable name to JSON key.



58
59
60
61
62
63
64
65
66
67
# File 'lib/intersight_client/models/workflow_primitive_data_property_all_of.rb', line 58

def self.attribute_map
  {
    :'class_id' => :'ClassId',
    :'object_type' => :'ObjectType',
    :'constraints' => :'Constraints',
    :'inventory_selector' => :'InventorySelector',
    :'secure' => :'Secure',
    :'type' => :'Type'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash



234
235
236
# File 'lib/intersight_client/models/workflow_primitive_data_property_all_of.rb', line 234

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_nullable ⇒ Object

List of attributes with nullable: true



92
93
94
95
96
97
# File 'lib/intersight_client/models/workflow_primitive_data_property_all_of.rb', line 92

def self.openapi_nullable
  Set.new([
    :'constraints',
    :'inventory_selector',
  ])
end

.openapi_types ⇒ Object

Attribute type mapping.



80
81
82
83
84
85
86
87
88
89
# File 'lib/intersight_client/models/workflow_primitive_data_property_all_of.rb', line 80

def self.openapi_types
  {
    :'class_id' => :'String',
    :'object_type' => :'String',
    :'constraints' => :'WorkflowConstraints',
    :'inventory_selector' => :'Array<WorkflowMoReferenceProperty>',
    :'secure' => :'Boolean',
    :'type' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.



208
209
210
211
212
213
214
215
216
217
# File 'lib/intersight_client/models/workflow_primitive_data_property_all_of.rb', line 208

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      class_id == o.class_id &&
      object_type == o.object_type &&
      constraints == o.constraints &&
      inventory_selector == o.inventory_selector &&
      secure == o.secure &&
      type == o.type
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type



264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
# File 'lib/intersight_client/models/workflow_primitive_data_property_all_of.rb', line 264

def _deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = IntersightClient.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value



335
336
337
338
339
340
341
342
343
344
345
346
347
# File 'lib/intersight_client/models/workflow_primitive_data_property_all_of.rb', line 335

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash



241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
# File 'lib/intersight_client/models/workflow_primitive_data_property_all_of.rb', line 241

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  WorkflowPrimitiveDataPropertyAllOf.openapi_types.each_pair do |key, type|
    if attributes[WorkflowPrimitiveDataPropertyAllOf.attribute_map[key]].nil? && WorkflowPrimitiveDataPropertyAllOf.openapi_nullable.include?(key)
      self.send("#{key}=", nil)
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[WorkflowPrimitiveDataPropertyAllOf.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[WorkflowPrimitiveDataPropertyAllOf.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[WorkflowPrimitiveDataPropertyAllOf.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[WorkflowPrimitiveDataPropertyAllOf.attribute_map[key]]))
    end
  end

  self
end

#eql?(o) ⇒ Boolean

See Also:

  • `==` method


221
222
223
# File 'lib/intersight_client/models/workflow_primitive_data_property_all_of.rb', line 221

def eql?(o)
  self == o
end

#hash ⇒ Integer

Calculates hash code according to all attributes.



227
228
229
# File 'lib/intersight_client/models/workflow_primitive_data_property_all_of.rb', line 227

def hash
  [class_id, object_type, constraints, inventory_selector, secure, type].hash
end

#list_invalid_properties ⇒ Object

Show invalid properties with the reasons. Usually used together with valid?



149
150
151
152
153
154
155
156
157
158
159
160
# File 'lib/intersight_client/models/workflow_primitive_data_property_all_of.rb', line 149

def list_invalid_properties
  invalid_properties = Array.new
  if @class_id.nil?
    invalid_properties.push('invalid value for "class_id", class_id cannot be nil.')
  end

  if @object_type.nil?
    invalid_properties.push('invalid value for "object_type", object_type cannot be nil.')
  end

  invalid_properties
end

#to_body ⇒ Hash

to_body is an alias to to_hash (backward compatibility)



311
312
313
# File 'lib/intersight_client/models/workflow_primitive_data_property_all_of.rb', line 311

def to_body
  to_hash
end

#to_hash ⇒ Hash

Returns the object in the form of hash



317
318
319
320
321
322
323
324
325
326
327
328
329
# File 'lib/intersight_client/models/workflow_primitive_data_property_all_of.rb', line 317

def to_hash
  hash = {}
  WorkflowPrimitiveDataPropertyAllOf.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = WorkflowPrimitiveDataPropertyAllOf.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_s ⇒ String

Returns the string representation of the object



305
306
307
# File 'lib/intersight_client/models/workflow_primitive_data_property_all_of.rb', line 305

def to_s
  to_hash.to_s
end

#valid? ⇒ Boolean

Check to see if the all the properties in the model are valid



164
165
166
167
168
169
170
171
172
173
174
# File 'lib/intersight_client/models/workflow_primitive_data_property_all_of.rb', line 164

def valid?
  return false if @class_id.nil?
  class_id_validator = EnumAttributeValidator.new('String', ["workflow.PrimitiveDataProperty"])
  return false unless class_id_validator.valid?(@class_id)
  return false if @object_type.nil?
  object_type_validator = EnumAttributeValidator.new('String', ["workflow.PrimitiveDataProperty"])
  return false unless object_type_validator.valid?(@object_type)
  type_validator = EnumAttributeValidator.new('String', ["string", "integer", "float", "boolean", "json", "enum"])
  return false unless type_validator.valid?(@type)
  true
end