Class: IntersightClient::WorkflowSolutionInstance

Inherits:
MoBaseMo
  • Object
show all
Defined in:
lib/intersight_client/models/workflow_solution_instance.rb

Overview

Solution instance is one instance of a solution based on a solution definition.

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Attributes inherited from MoBaseMo

#account_moid, #ancestors, #create_time, #display_names, #domain_group_moid, #mod_time, #moid, #owners, #parent, #permission_resources, #shared_scope, #tags, #version_context

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ WorkflowSolutionInstance

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
# File 'lib/intersight_client/models/workflow_solution_instance.rb', line 127

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `IntersightClient::WorkflowSolutionInstance` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `#{self.class.name}`. Please check the name to make sure it's valid. List of attributes: " + self.class.acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  # call parent's initialize
  super(attributes)

  if attributes.key?(:'class_id')
    self.class_id = attributes[:'class_id']
  else
    self.class_id = 'workflow.SolutionInstance'
  end

  if attributes.key?(:'object_type')
    self.object_type = attributes[:'object_type']
  else
    self.object_type = 'workflow.SolutionInstance'
  end

  if attributes.key?(:'description')
    self.description = attributes[:'description']
  end

  if attributes.key?(:'last_status')
    self.last_status = attributes[:'last_status']
  else
    self.last_status = 'NotCreated'
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  end

  if attributes.key?(:'status')
    self.status = attributes[:'status']
  else
    self.status = 'NotCreated'
  end

  if attributes.key?(:'user_id')
    self.user_id = attributes[:'user_id']
  end

  if attributes.key?(:'organization')
    self.organization = attributes[:'organization']
  end

  if attributes.key?(:'solution_definition')
    self.solution_definition = attributes[:'solution_definition']
  end
end

Instance Attribute Details

#class_idObject

The fully-qualified name of the instantiated, concrete type. This property is used as a discriminator to identify the type of the payload when marshaling and unmarshaling data.



20
21
22
# File 'lib/intersight_client/models/workflow_solution_instance.rb', line 20

def class_id
  @class_id
end

#descriptionObject

The description for this solution instance.



26
27
28
# File 'lib/intersight_client/models/workflow_solution_instance.rb', line 26

def description
  @description
end

#last_statusObject

Last status of the solution instance which will be reverted when an ongoing solution action instance is aborted. * NotCreated - Solution is not yet created and it is in a draft mode. A solution instance can be deleted in this state. * InProgress - An action is in progress and until that action has reached a final state, another action cannot be started. * Failed - The last action on the solution failed and corrective measures need to be taken to bring the solution back to valid state. * Okay - The last action on the solution completed and the solution is in Okay state. * Decommissioned - The solution is decommissioned and can be safely deleted. Solution in any other state after it has been created cannot be deleted until it has been decommissioned.



29
30
31
# File 'lib/intersight_client/models/workflow_solution_instance.rb', line 29

def last_status
  @last_status
end

#nameObject

A name of the solution instance. Name of the solution instance must be unique within a type of Solution definition.



32
33
34
# File 'lib/intersight_client/models/workflow_solution_instance.rb', line 32

def name
  @name
end

#object_typeObject

The fully-qualified name of the instantiated, concrete type. The value should be the same as the ‘ClassId’ property.



23
24
25
# File 'lib/intersight_client/models/workflow_solution_instance.rb', line 23

def object_type
  @object_type
end

#organizationObject

Returns the value of attribute organization.



40
41
42
# File 'lib/intersight_client/models/workflow_solution_instance.rb', line 40

def organization
  @organization
end

#solution_definitionObject

Returns the value of attribute solution_definition.



42
43
44
# File 'lib/intersight_client/models/workflow_solution_instance.rb', line 42

def solution_definition
  @solution_definition
end

#statusObject

Status of the solution instance which controls the actions that can be performed on this instance. * NotCreated - Solution is not yet created and it is in a draft mode. A solution instance can be deleted in this state. * InProgress - An action is in progress and until that action has reached a final state, another action cannot be started. * Failed - The last action on the solution failed and corrective measures need to be taken to bring the solution back to valid state. * Okay - The last action on the solution completed and the solution is in Okay state. * Decommissioned - The solution is decommissioned and can be safely deleted. Solution in any other state after it has been created cannot be deleted until it has been decommissioned.



35
36
37
# File 'lib/intersight_client/models/workflow_solution_instance.rb', line 35

def status
  @status
end

#user_idObject

The user identifier which indicates the user that started this workflow.



38
39
40
# File 'lib/intersight_client/models/workflow_solution_instance.rb', line 38

def user_id
  @user_id
end

Class Method Details

.acceptable_attribute_mapObject

Returns the key-value map of all the JSON attributes this model knows about, including the ones defined in its parent(s)



87
88
89
# File 'lib/intersight_client/models/workflow_solution_instance.rb', line 87

def self.acceptable_attribute_map
  attribute_map.merge(superclass.acceptable_attribute_map)
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about, including the ones defined in its parent(s)



82
83
84
# File 'lib/intersight_client/models/workflow_solution_instance.rb', line 82

def self.acceptable_attributes
  attribute_map.values.concat(superclass.acceptable_attributes)
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



67
68
69
70
71
72
73
74
75
76
77
78
79
# File 'lib/intersight_client/models/workflow_solution_instance.rb', line 67

def self.attribute_map
  {
    :'class_id' => :'ClassId',
    :'object_type' => :'ObjectType',
    :'description' => :'Description',
    :'last_status' => :'LastStatus',
    :'name' => :'Name',
    :'status' => :'Status',
    :'user_id' => :'UserId',
    :'organization' => :'Organization',
    :'solution_definition' => :'SolutionDefinition'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



307
308
309
# File 'lib/intersight_client/models/workflow_solution_instance.rb', line 307

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_all_ofObject

List of class defined in allOf (OpenAPI v3)



113
114
115
116
117
118
# File 'lib/intersight_client/models/workflow_solution_instance.rb', line 113

def self.openapi_all_of
  [
  :'MoBaseMo',
  :'WorkflowSolutionInstanceAllOf'
  ]
end

.openapi_discriminator_nameObject

discriminator’s property name in OpenAPI v3



121
122
123
# File 'lib/intersight_client/models/workflow_solution_instance.rb', line 121

def self.openapi_discriminator_name
  :'ClassId'
end

.openapi_nullableObject

List of attributes with nullable: true



107
108
109
110
# File 'lib/intersight_client/models/workflow_solution_instance.rb', line 107

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



92
93
94
95
96
97
98
99
100
101
102
103
104
# File 'lib/intersight_client/models/workflow_solution_instance.rb', line 92

def self.openapi_types
  {
    :'class_id' => :'String',
    :'object_type' => :'String',
    :'description' => :'String',
    :'last_status' => :'String',
    :'name' => :'String',
    :'status' => :'String',
    :'user_id' => :'String',
    :'organization' => :'OrganizationOrganizationRelationship',
    :'solution_definition' => :'WorkflowSolutionDefinitionRelationship'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



278
279
280
281
282
283
284
285
286
287
288
289
290
# File 'lib/intersight_client/models/workflow_solution_instance.rb', line 278

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      class_id == o.class_id &&
      object_type == o.object_type &&
      description == o.description &&
      last_status == o.last_status &&
      name == o.name &&
      status == o.status &&
      user_id == o.user_id &&
      organization == o.organization &&
      solution_definition == o.solution_definition && super(o)
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
# File 'lib/intersight_client/models/workflow_solution_instance.rb', line 338

def _deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = IntersightClient.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



409
410
411
412
413
414
415
416
417
418
419
420
421
# File 'lib/intersight_client/models/workflow_solution_instance.rb', line 409

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
# File 'lib/intersight_client/models/workflow_solution_instance.rb', line 314

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  super(attributes)
  WorkflowSolutionInstance.openapi_types.each_pair do |key, type|
    if attributes[WorkflowSolutionInstance.attribute_map[key]].nil? && WorkflowSolutionInstance.openapi_nullable.include?(key)
      self.send("#{key}=", nil)
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[WorkflowSolutionInstance.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[WorkflowSolutionInstance.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[WorkflowSolutionInstance.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[WorkflowSolutionInstance.attribute_map[key]]))
    end
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


294
295
296
# File 'lib/intersight_client/models/workflow_solution_instance.rb', line 294

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



300
301
302
# File 'lib/intersight_client/models/workflow_solution_instance.rb', line 300

def hash
  [class_id, object_type, description, last_status, name, status, user_id, organization, solution_definition].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
# File 'lib/intersight_client/models/workflow_solution_instance.rb', line 190

def list_invalid_properties
  invalid_properties = super
  if @class_id.nil?
    invalid_properties.push('invalid value for "class_id", class_id cannot be nil.')
  end

  if @object_type.nil?
    invalid_properties.push('invalid value for "object_type", object_type cannot be nil.')
  end

  pattern = Regexp.new(/^[a-zA-Z0-9]+[\sa-zA-Z0-9_.:-]{1,92}$/)
  if !@name.nil? && @name !~ pattern
    invalid_properties.push("invalid value for \"name\", must conform to the pattern #{pattern}.")
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



385
386
387
# File 'lib/intersight_client/models/workflow_solution_instance.rb', line 385

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



391
392
393
394
395
396
397
398
399
400
401
402
403
# File 'lib/intersight_client/models/workflow_solution_instance.rb', line 391

def to_hash
  hash = super
  WorkflowSolutionInstance.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = WorkflowSolutionInstance.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



379
380
381
# File 'lib/intersight_client/models/workflow_solution_instance.rb', line 379

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



210
211
212
213
214
215
216
217
218
219
220
221
222
223
# File 'lib/intersight_client/models/workflow_solution_instance.rb', line 210

def valid?
  return false if @class_id.nil?
  class_id_validator = EnumAttributeValidator.new('String', ["workflow.SolutionInstance"])
  return false unless class_id_validator.valid?(@class_id)
  return false if @object_type.nil?
  object_type_validator = EnumAttributeValidator.new('String', ["workflow.SolutionInstance"])
  return false unless object_type_validator.valid?(@object_type)
  last_status_validator = EnumAttributeValidator.new('String', ["NotCreated", "InProgress", "Failed", "Okay", "Decommissioned"])
  return false unless last_status_validator.valid?(@last_status)
  return false if !@name.nil? && @name !~ Regexp.new(/^[a-zA-Z0-9]+[\sa-zA-Z0-9_.:-]{1,92}$/)
  status_validator = EnumAttributeValidator.new('String', ["NotCreated", "InProgress", "Failed", "Okay", "Decommissioned"])
  return false unless status_validator.valid?(@status)
  true && super
end