Class: IntersightClient::WorkflowTaskInfoAllOf
- Inherits:
-
Object
- Object
- IntersightClient::WorkflowTaskInfoAllOf
- Defined in:
- lib/intersight_client/models/workflow_task_info_all_of.rb
Overview
Definition of the list of properties defined in ‘workflow.TaskInfo’, excluding properties defined in parent classes.
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#class_id ⇒ Object
The fully-qualified name of the instantiated, concrete type.
-
#description ⇒ Object
The task description and this is the description that was added when the task was included into the workflow.
-
#end_time ⇒ Object
The time stamp when the task reached a final state.
-
#failure_reason ⇒ Object
Description of the reason why the task failed.
-
#input ⇒ Object
The input data that was sent to the task at the start of execution.
-
#inst_id ⇒ Object
The instance ID of the task running in the workflow engine.
-
#internal ⇒ Object
Denotes whether or not this is an internal task.
-
#label ⇒ Object
User friendly short label to describe this task instance in the workflow.
-
#message ⇒ Object
Returns the value of attribute message.
-
#name ⇒ Object
Task definition name which specifies the task type.
-
#object_type ⇒ Object
The fully-qualified name of the instantiated, concrete type.
-
#output ⇒ Object
The output data that was generated by this task.
-
#ref_name ⇒ Object
The task reference name to ensure its unique inside a workflow.
-
#retry_count ⇒ Object
A counter for number of retries.
-
#rollback_disabled ⇒ Object
The task is disabled/enabled for rollback operation in this workflow if the task has rollback support.
-
#running_inst_id ⇒ Object
The instance ID of the task that is currently being executed.
-
#start_time ⇒ Object
The time stamp when the task started execution.
-
#status ⇒ Object
The status of the task and this will specify if the task is running or has reached a final state.
-
#sub_workflow_info ⇒ Object
Returns the value of attribute sub_workflow_info.
-
#task_definition ⇒ Object
Returns the value of attribute task_definition.
-
#task_inst_id_list ⇒ Object
Returns the value of attribute task_inst_id_list.
-
#workflow_info ⇒ Object
Returns the value of attribute workflow_info.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns the key-value map of all the JSON attributes this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ WorkflowTaskInfoAllOf
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ WorkflowTaskInfoAllOf
Initializes the object
180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 |
# File 'lib/intersight_client/models/workflow_task_info_all_of.rb', line 180 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `IntersightClient::WorkflowTaskInfoAllOf` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `#{self.class.name}`. Please check the name to make sure it's valid. List of attributes: " + self.class.acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'class_id') self.class_id = attributes[:'class_id'] else self.class_id = 'workflow.TaskInfo' end if attributes.key?(:'object_type') self.object_type = attributes[:'object_type'] else self.object_type = 'workflow.TaskInfo' end if attributes.key?(:'description') self.description = attributes[:'description'] end if attributes.key?(:'end_time') self.end_time = attributes[:'end_time'] end if attributes.key?(:'failure_reason') self.failure_reason = attributes[:'failure_reason'] end if attributes.key?(:'input') self.input = attributes[:'input'] end if attributes.key?(:'inst_id') self.inst_id = attributes[:'inst_id'] end if attributes.key?(:'internal') self.internal = attributes[:'internal'] end if attributes.key?(:'label') self.label = attributes[:'label'] end if attributes.key?(:'message') if (value = attributes[:'message']).is_a?(Array) self. = value end end if attributes.key?(:'name') self.name = attributes[:'name'] end if attributes.key?(:'output') self.output = attributes[:'output'] end if attributes.key?(:'ref_name') self.ref_name = attributes[:'ref_name'] end if attributes.key?(:'retry_count') self.retry_count = attributes[:'retry_count'] end if attributes.key?(:'rollback_disabled') self.rollback_disabled = attributes[:'rollback_disabled'] else self.rollback_disabled = false end if attributes.key?(:'running_inst_id') self.running_inst_id = attributes[:'running_inst_id'] end if attributes.key?(:'start_time') self.start_time = attributes[:'start_time'] end if attributes.key?(:'status') self.status = attributes[:'status'] end if attributes.key?(:'task_inst_id_list') if (value = attributes[:'task_inst_id_list']).is_a?(Array) self.task_inst_id_list = value end end if attributes.key?(:'sub_workflow_info') self.sub_workflow_info = attributes[:'sub_workflow_info'] end if attributes.key?(:'task_definition') self.task_definition = attributes[:'task_definition'] end if attributes.key?(:'workflow_info') self.workflow_info = attributes[:'workflow_info'] end end |
Instance Attribute Details
#class_id ⇒ Object
The fully-qualified name of the instantiated, concrete type. This property is used as a discriminator to identify the type of the payload when marshaling and unmarshaling data.
20 21 22 |
# File 'lib/intersight_client/models/workflow_task_info_all_of.rb', line 20 def class_id @class_id end |
#description ⇒ Object
The task description and this is the description that was added when the task was included into the workflow.
26 27 28 |
# File 'lib/intersight_client/models/workflow_task_info_all_of.rb', line 26 def description @description end |
#end_time ⇒ Object
The time stamp when the task reached a final state.
29 30 31 |
# File 'lib/intersight_client/models/workflow_task_info_all_of.rb', line 29 def end_time @end_time end |
#failure_reason ⇒ Object
Description of the reason why the task failed.
32 33 34 |
# File 'lib/intersight_client/models/workflow_task_info_all_of.rb', line 32 def failure_reason @failure_reason end |
#input ⇒ Object
The input data that was sent to the task at the start of execution.
35 36 37 |
# File 'lib/intersight_client/models/workflow_task_info_all_of.rb', line 35 def input @input end |
#inst_id ⇒ Object
The instance ID of the task running in the workflow engine.
38 39 40 |
# File 'lib/intersight_client/models/workflow_task_info_all_of.rb', line 38 def inst_id @inst_id end |
#internal ⇒ Object
Denotes whether or not this is an internal task. Internal tasks will be hidden from the UI within a workflow.
41 42 43 |
# File 'lib/intersight_client/models/workflow_task_info_all_of.rb', line 41 def internal @internal end |
#label ⇒ Object
User friendly short label to describe this task instance in the workflow.
44 45 46 |
# File 'lib/intersight_client/models/workflow_task_info_all_of.rb', line 44 def label @label end |
#message ⇒ Object
Returns the value of attribute message.
46 47 48 |
# File 'lib/intersight_client/models/workflow_task_info_all_of.rb', line 46 def end |
#name ⇒ Object
Task definition name which specifies the task type.
49 50 51 |
# File 'lib/intersight_client/models/workflow_task_info_all_of.rb', line 49 def name @name end |
#object_type ⇒ Object
The fully-qualified name of the instantiated, concrete type. The value should be the same as the ‘ClassId’ property.
23 24 25 |
# File 'lib/intersight_client/models/workflow_task_info_all_of.rb', line 23 def object_type @object_type end |
#output ⇒ Object
The output data that was generated by this task.
52 53 54 |
# File 'lib/intersight_client/models/workflow_task_info_all_of.rb', line 52 def output @output end |
#ref_name ⇒ Object
The task reference name to ensure its unique inside a workflow.
55 56 57 |
# File 'lib/intersight_client/models/workflow_task_info_all_of.rb', line 55 def ref_name @ref_name end |
#retry_count ⇒ Object
A counter for number of retries.
58 59 60 |
# File 'lib/intersight_client/models/workflow_task_info_all_of.rb', line 58 def retry_count @retry_count end |
#rollback_disabled ⇒ Object
The task is disabled/enabled for rollback operation in this workflow if the task has rollback support.
61 62 63 |
# File 'lib/intersight_client/models/workflow_task_info_all_of.rb', line 61 def rollback_disabled @rollback_disabled end |
#running_inst_id ⇒ Object
The instance ID of the task that is currently being executed. When retrying a workflow with failed tasks, the task in workflow engine will have a new instance ID, but the task may still be in-progress. In this case, the task instId reflects the instance ID in the workflow engine, while runningInstId reflects the instance ID of the instance that is currently being executed.
64 65 66 |
# File 'lib/intersight_client/models/workflow_task_info_all_of.rb', line 64 def running_inst_id @running_inst_id end |
#start_time ⇒ Object
The time stamp when the task started execution.
67 68 69 |
# File 'lib/intersight_client/models/workflow_task_info_all_of.rb', line 67 def start_time @start_time end |
#status ⇒ Object
The status of the task and this will specify if the task is running or has reached a final state.
70 71 72 |
# File 'lib/intersight_client/models/workflow_task_info_all_of.rb', line 70 def status @status end |
#sub_workflow_info ⇒ Object
Returns the value of attribute sub_workflow_info.
74 75 76 |
# File 'lib/intersight_client/models/workflow_task_info_all_of.rb', line 74 def sub_workflow_info @sub_workflow_info end |
#task_definition ⇒ Object
Returns the value of attribute task_definition.
76 77 78 |
# File 'lib/intersight_client/models/workflow_task_info_all_of.rb', line 76 def task_definition @task_definition end |
#task_inst_id_list ⇒ Object
Returns the value of attribute task_inst_id_list.
72 73 74 |
# File 'lib/intersight_client/models/workflow_task_info_all_of.rb', line 72 def task_inst_id_list @task_inst_id_list end |
#workflow_info ⇒ Object
Returns the value of attribute workflow_info.
78 79 80 |
# File 'lib/intersight_client/models/workflow_task_info_all_of.rb', line 78 def workflow_info @workflow_info end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns the key-value map of all the JSON attributes this model knows about
136 137 138 |
# File 'lib/intersight_client/models/workflow_task_info_all_of.rb', line 136 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
131 132 133 |
# File 'lib/intersight_client/models/workflow_task_info_all_of.rb', line 131 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 |
# File 'lib/intersight_client/models/workflow_task_info_all_of.rb', line 103 def self.attribute_map { :'class_id' => :'ClassId', :'object_type' => :'ObjectType', :'description' => :'Description', :'end_time' => :'EndTime', :'failure_reason' => :'FailureReason', :'input' => :'Input', :'inst_id' => :'InstId', :'internal' => :'Internal', :'label' => :'Label', :'message' => :'Message', :'name' => :'Name', :'output' => :'Output', :'ref_name' => :'RefName', :'retry_count' => :'RetryCount', :'rollback_disabled' => :'RollbackDisabled', :'running_inst_id' => :'RunningInstId', :'start_time' => :'StartTime', :'status' => :'Status', :'task_inst_id_list' => :'TaskInstIdList', :'sub_workflow_info' => :'SubWorkflowInfo', :'task_definition' => :'TaskDefinition', :'workflow_info' => :'WorkflowInfo' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
383 384 385 |
# File 'lib/intersight_client/models/workflow_task_info_all_of.rb', line 383 def self.build_from_hash(attributes) new.build_from_hash(attributes) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
169 170 171 172 173 174 175 176 |
# File 'lib/intersight_client/models/workflow_task_info_all_of.rb', line 169 def self.openapi_nullable Set.new([ :'input', :'message', :'output', :'task_inst_id_list', ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 |
# File 'lib/intersight_client/models/workflow_task_info_all_of.rb', line 141 def self.openapi_types { :'class_id' => :'String', :'object_type' => :'String', :'description' => :'String', :'end_time' => :'Time', :'failure_reason' => :'String', :'input' => :'Object', :'inst_id' => :'String', :'internal' => :'Boolean', :'label' => :'String', :'message' => :'Array<WorkflowMessage>', :'name' => :'String', :'output' => :'Object', :'ref_name' => :'String', :'retry_count' => :'Integer', :'rollback_disabled' => :'Boolean', :'running_inst_id' => :'String', :'start_time' => :'Time', :'status' => :'String', :'task_inst_id_list' => :'Array<WorkflowTaskRetryInfo>', :'sub_workflow_info' => :'WorkflowWorkflowInfoRelationship', :'task_definition' => :'WorkflowTaskDefinitionRelationship', :'workflow_info' => :'WorkflowWorkflowInfoRelationship' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 |
# File 'lib/intersight_client/models/workflow_task_info_all_of.rb', line 341 def ==(o) return true if self.equal?(o) self.class == o.class && class_id == o.class_id && object_type == o.object_type && description == o.description && end_time == o.end_time && failure_reason == o.failure_reason && input == o.input && inst_id == o.inst_id && internal == o.internal && label == o.label && == o. && name == o.name && output == o.output && ref_name == o.ref_name && retry_count == o.retry_count && rollback_disabled == o.rollback_disabled && running_inst_id == o.running_inst_id && start_time == o.start_time && status == o.status && task_inst_id_list == o.task_inst_id_list && sub_workflow_info == o.sub_workflow_info && task_definition == o.task_definition && workflow_info == o.workflow_info end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 450 |
# File 'lib/intersight_client/models/workflow_task_info_all_of.rb', line 413 def _deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = IntersightClient.const_get(type) klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
484 485 486 487 488 489 490 491 492 493 494 495 496 |
# File 'lib/intersight_client/models/workflow_task_info_all_of.rb', line 484 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 |
# File 'lib/intersight_client/models/workflow_task_info_all_of.rb', line 390 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) WorkflowTaskInfoAllOf.openapi_types.each_pair do |key, type| if attributes[WorkflowTaskInfoAllOf.attribute_map[key]].nil? && WorkflowTaskInfoAllOf.openapi_nullable.include?(key) self.send("#{key}=", nil) elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[WorkflowTaskInfoAllOf.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[WorkflowTaskInfoAllOf.attribute_map[key]].map { |v| _deserialize($1, v) }) end elsif !attributes[WorkflowTaskInfoAllOf.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[WorkflowTaskInfoAllOf.attribute_map[key]])) end end self end |
#eql?(o) ⇒ Boolean
370 371 372 |
# File 'lib/intersight_client/models/workflow_task_info_all_of.rb', line 370 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
376 377 378 |
# File 'lib/intersight_client/models/workflow_task_info_all_of.rb', line 376 def hash [class_id, object_type, description, end_time, failure_reason, input, inst_id, internal, label, , name, output, ref_name, retry_count, rollback_disabled, running_inst_id, start_time, status, task_inst_id_list, sub_workflow_info, task_definition, workflow_info].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
294 295 296 297 298 299 300 301 302 303 304 305 |
# File 'lib/intersight_client/models/workflow_task_info_all_of.rb', line 294 def list_invalid_properties invalid_properties = Array.new if @class_id.nil? invalid_properties.push('invalid value for "class_id", class_id cannot be nil.') end if @object_type.nil? invalid_properties.push('invalid value for "object_type", object_type cannot be nil.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
460 461 462 |
# File 'lib/intersight_client/models/workflow_task_info_all_of.rb', line 460 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
466 467 468 469 470 471 472 473 474 475 476 477 478 |
# File 'lib/intersight_client/models/workflow_task_info_all_of.rb', line 466 def to_hash hash = {} WorkflowTaskInfoAllOf.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = WorkflowTaskInfoAllOf.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
454 455 456 |
# File 'lib/intersight_client/models/workflow_task_info_all_of.rb', line 454 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
309 310 311 312 313 314 315 316 317 |
# File 'lib/intersight_client/models/workflow_task_info_all_of.rb', line 309 def valid? return false if @class_id.nil? class_id_validator = EnumAttributeValidator.new('String', ["workflow.TaskInfo"]) return false unless class_id_validator.valid?(@class_id) return false if @object_type.nil? object_type_validator = EnumAttributeValidator.new('String', ["workflow.TaskInfo"]) return false unless object_type_validator.valid?(@object_type) true end |