Class: IntersightClient::ComputeBladeIdentityAllOf
- Inherits:
-
Object
- Object
- IntersightClient::ComputeBladeIdentityAllOf
- Defined in:
- lib/intersight_client/models/compute_blade_identity_all_of.rb
Overview
Definition of the list of properties defined in ‘compute.BladeIdentity’, excluding properties defined in parent classes.
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#chassis_id ⇒ Object
Chassis Identifier of a blade server.
-
#class_id ⇒ Object
The fully-qualified name of the instantiated, concrete type.
-
#current_chassis_id ⇒ Object
The id of the chassis that the blade is currently located in.
-
#current_slot_id ⇒ Object
The slot number in the chassis that the blade is currently located in.
-
#firmware_supportability ⇒ Object
Describes whether the running CIMC version supports Intersight managed mode.
-
#object_type ⇒ Object
The fully-qualified name of the instantiated, concrete type.
-
#presence ⇒ Object
The presence state of the blade server.
-
#slot_id ⇒ Object
Chassis slot number of a blade server.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns the key-value map of all the JSON attributes this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ComputeBladeIdentityAllOf
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ ComputeBladeIdentityAllOf
Initializes the object
111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 |
# File 'lib/intersight_client/models/compute_blade_identity_all_of.rb', line 111 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `IntersightClient::ComputeBladeIdentityAllOf` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `#{self.class.name}`. Please check the name to make sure it's valid. List of attributes: " + self.class.acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'class_id') self.class_id = attributes[:'class_id'] else self.class_id = 'compute.BladeIdentity' end if attributes.key?(:'object_type') self.object_type = attributes[:'object_type'] else self.object_type = 'compute.BladeIdentity' end if attributes.key?(:'chassis_id') self.chassis_id = attributes[:'chassis_id'] end if attributes.key?(:'current_chassis_id') self.current_chassis_id = attributes[:'current_chassis_id'] end if attributes.key?(:'current_slot_id') self.current_slot_id = attributes[:'current_slot_id'] end if attributes.key?(:'firmware_supportability') self.firmware_supportability = attributes[:'firmware_supportability'] else self.firmware_supportability = 'Unknown' end if attributes.key?(:'presence') self.presence = attributes[:'presence'] else self.presence = 'Unknown' end if attributes.key?(:'slot_id') self.slot_id = attributes[:'slot_id'] end end |
Instance Attribute Details
#chassis_id ⇒ Object
Chassis Identifier of a blade server.
26 27 28 |
# File 'lib/intersight_client/models/compute_blade_identity_all_of.rb', line 26 def chassis_id @chassis_id end |
#class_id ⇒ Object
The fully-qualified name of the instantiated, concrete type. This property is used as a discriminator to identify the type of the payload when marshaling and unmarshaling data.
20 21 22 |
# File 'lib/intersight_client/models/compute_blade_identity_all_of.rb', line 20 def class_id @class_id end |
#current_chassis_id ⇒ Object
The id of the chassis that the blade is currently located in.
29 30 31 |
# File 'lib/intersight_client/models/compute_blade_identity_all_of.rb', line 29 def current_chassis_id @current_chassis_id end |
#current_slot_id ⇒ Object
The slot number in the chassis that the blade is currently located in.
32 33 34 |
# File 'lib/intersight_client/models/compute_blade_identity_all_of.rb', line 32 def current_slot_id @current_slot_id end |
#firmware_supportability ⇒ Object
Describes whether the running CIMC version supports Intersight managed mode. * Unknown - The running firmware version is unknown. * Supported - The running firmware version is known and supports IMM mode. * NotSupported - The running firmware version is known and does not support IMM mode.
35 36 37 |
# File 'lib/intersight_client/models/compute_blade_identity_all_of.rb', line 35 def firmware_supportability @firmware_supportability end |
#object_type ⇒ Object
The fully-qualified name of the instantiated, concrete type. The value should be the same as the ‘ClassId’ property.
23 24 25 |
# File 'lib/intersight_client/models/compute_blade_identity_all_of.rb', line 23 def object_type @object_type end |
#presence ⇒ Object
The presence state of the blade server. * Unknown - The default presence state. * Equipped - The server is equipped in the slot. * EquippedMismatch - The slot is equipped, but there is another server currently inventoried in the slot. * Missing - The server is not present in the given slot.
38 39 40 |
# File 'lib/intersight_client/models/compute_blade_identity_all_of.rb', line 38 def presence @presence end |
#slot_id ⇒ Object
Chassis slot number of a blade server.
41 42 43 |
# File 'lib/intersight_client/models/compute_blade_identity_all_of.rb', line 41 def slot_id @slot_id end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns the key-value map of all the JSON attributes this model knows about
85 86 87 |
# File 'lib/intersight_client/models/compute_blade_identity_all_of.rb', line 85 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
80 81 82 |
# File 'lib/intersight_client/models/compute_blade_identity_all_of.rb', line 80 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
66 67 68 69 70 71 72 73 74 75 76 77 |
# File 'lib/intersight_client/models/compute_blade_identity_all_of.rb', line 66 def self.attribute_map { :'class_id' => :'ClassId', :'object_type' => :'ObjectType', :'chassis_id' => :'ChassisId', :'current_chassis_id' => :'CurrentChassisId', :'current_slot_id' => :'CurrentSlotId', :'firmware_supportability' => :'FirmwareSupportability', :'presence' => :'Presence', :'slot_id' => :'SlotId' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
266 267 268 |
# File 'lib/intersight_client/models/compute_blade_identity_all_of.rb', line 266 def self.build_from_hash(attributes) new.build_from_hash(attributes) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
104 105 106 107 |
# File 'lib/intersight_client/models/compute_blade_identity_all_of.rb', line 104 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
90 91 92 93 94 95 96 97 98 99 100 101 |
# File 'lib/intersight_client/models/compute_blade_identity_all_of.rb', line 90 def self.openapi_types { :'class_id' => :'String', :'object_type' => :'String', :'chassis_id' => :'Integer', :'current_chassis_id' => :'Integer', :'current_slot_id' => :'Integer', :'firmware_supportability' => :'String', :'presence' => :'String', :'slot_id' => :'Integer' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
238 239 240 241 242 243 244 245 246 247 248 249 |
# File 'lib/intersight_client/models/compute_blade_identity_all_of.rb', line 238 def ==(o) return true if self.equal?(o) self.class == o.class && class_id == o.class_id && object_type == o.object_type && chassis_id == o.chassis_id && current_chassis_id == o.current_chassis_id && current_slot_id == o.current_slot_id && firmware_supportability == o.firmware_supportability && presence == o.presence && slot_id == o.slot_id end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 |
# File 'lib/intersight_client/models/compute_blade_identity_all_of.rb', line 296 def _deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = IntersightClient.const_get(type) klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
367 368 369 370 371 372 373 374 375 376 377 378 379 |
# File 'lib/intersight_client/models/compute_blade_identity_all_of.rb', line 367 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 |
# File 'lib/intersight_client/models/compute_blade_identity_all_of.rb', line 273 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) ComputeBladeIdentityAllOf.openapi_types.each_pair do |key, type| if attributes[ComputeBladeIdentityAllOf.attribute_map[key]].nil? && ComputeBladeIdentityAllOf.openapi_nullable.include?(key) self.send("#{key}=", nil) elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[ComputeBladeIdentityAllOf.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[ComputeBladeIdentityAllOf.attribute_map[key]].map { |v| _deserialize($1, v) }) end elsif !attributes[ComputeBladeIdentityAllOf.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[ComputeBladeIdentityAllOf.attribute_map[key]])) end end self end |
#eql?(o) ⇒ Boolean
253 254 255 |
# File 'lib/intersight_client/models/compute_blade_identity_all_of.rb', line 253 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
259 260 261 |
# File 'lib/intersight_client/models/compute_blade_identity_all_of.rb', line 259 def hash [class_id, object_type, chassis_id, current_chassis_id, current_slot_id, firmware_supportability, presence, slot_id].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
167 168 169 170 171 172 173 174 175 176 177 178 |
# File 'lib/intersight_client/models/compute_blade_identity_all_of.rb', line 167 def list_invalid_properties invalid_properties = Array.new if @class_id.nil? invalid_properties.push('invalid value for "class_id", class_id cannot be nil.') end if @object_type.nil? invalid_properties.push('invalid value for "object_type", object_type cannot be nil.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
343 344 345 |
# File 'lib/intersight_client/models/compute_blade_identity_all_of.rb', line 343 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
349 350 351 352 353 354 355 356 357 358 359 360 361 |
# File 'lib/intersight_client/models/compute_blade_identity_all_of.rb', line 349 def to_hash hash = {} ComputeBladeIdentityAllOf.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = ComputeBladeIdentityAllOf.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
337 338 339 |
# File 'lib/intersight_client/models/compute_blade_identity_all_of.rb', line 337 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
182 183 184 185 186 187 188 189 190 191 192 193 194 |
# File 'lib/intersight_client/models/compute_blade_identity_all_of.rb', line 182 def valid? return false if @class_id.nil? class_id_validator = EnumAttributeValidator.new('String', ["compute.BladeIdentity"]) return false unless class_id_validator.valid?(@class_id) return false if @object_type.nil? object_type_validator = EnumAttributeValidator.new('String', ["compute.BladeIdentity"]) return false unless object_type_validator.valid?(@object_type) firmware_supportability_validator = EnumAttributeValidator.new('String', ["Unknown", "Supported", "NotSupported"]) return false unless firmware_supportability_validator.valid?(@firmware_supportability) presence_validator = EnumAttributeValidator.new('String', ["Unknown", "Equipped", "EquippedMismatch", "Missing"]) return false unless presence_validator.valid?(@presence) true end |