Class: IntersightClient::HclFirmwareAllOf
- Inherits:
-
Object
- Object
- IntersightClient::HclFirmwareAllOf
- Defined in:
- lib/intersight_client/models/hcl_firmware_all_of.rb
Overview
Definition of the list of properties defined in ‘hcl.Firmware’, excluding properties defined in parent classes.
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#class_id ⇒ Object
The fully-qualified name of the instantiated, concrete type.
-
#driver_name ⇒ Object
Protocol for which the driver is provided.
-
#driver_version ⇒ Object
Version of the Driver supported.
-
#error_code ⇒ Object
Error code for the support status.
-
#firmware_version ⇒ Object
Firmware version of the product/adapter supported.
-
#id ⇒ Object
Identifier of the firmware.
-
#latest_driver ⇒ Object
True if the driver is latest recommended driver.
-
#latest_firmware ⇒ Object
True if the firmware is latest recommended firmware.
-
#object_type ⇒ Object
The fully-qualified name of the instantiated, concrete type.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns the key-value map of all the JSON attributes this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ HclFirmwareAllOf
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ HclFirmwareAllOf
Initializes the object
116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 |
# File 'lib/intersight_client/models/hcl_firmware_all_of.rb', line 116 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `IntersightClient::HclFirmwareAllOf` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `#{self.class.name}`. Please check the name to make sure it's valid. List of attributes: " + self.class.acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'class_id') self.class_id = attributes[:'class_id'] else self.class_id = 'hcl.Firmware' end if attributes.key?(:'object_type') self.object_type = attributes[:'object_type'] else self.object_type = 'hcl.Firmware' end if attributes.key?(:'driver_name') self.driver_name = attributes[:'driver_name'] end if attributes.key?(:'driver_version') self.driver_version = attributes[:'driver_version'] end if attributes.key?(:'error_code') self.error_code = attributes[:'error_code'] else self.error_code = 'Success' end if attributes.key?(:'firmware_version') self.firmware_version = attributes[:'firmware_version'] end if attributes.key?(:'id') self.id = attributes[:'id'] end if attributes.key?(:'latest_driver') self.latest_driver = attributes[:'latest_driver'] end if attributes.key?(:'latest_firmware') self.latest_firmware = attributes[:'latest_firmware'] end end |
Instance Attribute Details
#class_id ⇒ Object
The fully-qualified name of the instantiated, concrete type. This property is used as a discriminator to identify the type of the payload when marshaling and unmarshaling data.
20 21 22 |
# File 'lib/intersight_client/models/hcl_firmware_all_of.rb', line 20 def class_id @class_id end |
#driver_name ⇒ Object
Protocol for which the driver is provided. E.g. enic, fnic, lsi_mr3.
26 27 28 |
# File 'lib/intersight_client/models/hcl_firmware_all_of.rb', line 26 def driver_name @driver_name end |
#driver_version ⇒ Object
Version of the Driver supported.
29 30 31 |
# File 'lib/intersight_client/models/hcl_firmware_all_of.rb', line 29 def driver_version @driver_version end |
#error_code ⇒ Object
Error code for the support status. * Success - The input combination is valid. * Unknown - Unknown API request to the service. * UnknownServer - An invalid server model is given API requests or the server model is not present in the HCL database. * InvalidUcsVersion - UCS Version is not in expected format. * ProcessorNotSupported - Processor is not supported with the given Server or the Processor does not exist in the HCL database. * OSNotSupported - OS version is not supported with the given server, processor combination or OS information is not present in the HCL database. * OSUnknown - OS vendor or version is not known as per the HCL database. * UCSVersionNotSupported - UCS Version is not supported with the given server, processor and OS combination or the UCS version is not present in the HCL database. * UcsVersionServerOSCombinationNotSupported - Combination of UCS version, server (model and processor) and os version is not supported. * ProductUnknown - Product is not known as per the HCL database. * ProductNotSupported - Product is not supported in the given UCS version, server (model and processor) and operating system version. * DriverNameNotSupported - Driver protocol or name is not supported for the given product. * FirmwareVersionNotSupported - Firmware version not supported for the component and the server, operating system combination. * DriverVersionNotSupported - Driver version not supported for the component and the server, operating system combination. * FirmwareVersionDriverVersionCombinationNotSupported - Both Firmware and Driver versions are not supported for the component and the server, operating system combination. * FirmwareVersionAndDriverVersionNotSupported - Firmware and Driver version combination not supported for the component and the server, operating system combination. * FirmwareVersionAndDriverNameNotSupported - Firmware Version and Driver name or not supported with the component and the server, operating system combination. * InternalError - API requests to the service have either failed or timed out. * MarshallingError - Error in JSON marshalling. * Exempted - An exempted error code means that the product is part of the exempted Catalog and should be ignored for HCL validation purposes.
32 33 34 |
# File 'lib/intersight_client/models/hcl_firmware_all_of.rb', line 32 def error_code @error_code end |
#firmware_version ⇒ Object
Firmware version of the product/adapter supported.
35 36 37 |
# File 'lib/intersight_client/models/hcl_firmware_all_of.rb', line 35 def firmware_version @firmware_version end |
#id ⇒ Object
Identifier of the firmware.
38 39 40 |
# File 'lib/intersight_client/models/hcl_firmware_all_of.rb', line 38 def id @id end |
#latest_driver ⇒ Object
True if the driver is latest recommended driver.
41 42 43 |
# File 'lib/intersight_client/models/hcl_firmware_all_of.rb', line 41 def latest_driver @latest_driver end |
#latest_firmware ⇒ Object
True if the firmware is latest recommended firmware.
44 45 46 |
# File 'lib/intersight_client/models/hcl_firmware_all_of.rb', line 44 def latest_firmware @latest_firmware end |
#object_type ⇒ Object
The fully-qualified name of the instantiated, concrete type. The value should be the same as the ‘ClassId’ property.
23 24 25 |
# File 'lib/intersight_client/models/hcl_firmware_all_of.rb', line 23 def object_type @object_type end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns the key-value map of all the JSON attributes this model knows about
89 90 91 |
# File 'lib/intersight_client/models/hcl_firmware_all_of.rb', line 89 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
84 85 86 |
# File 'lib/intersight_client/models/hcl_firmware_all_of.rb', line 84 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
69 70 71 72 73 74 75 76 77 78 79 80 81 |
# File 'lib/intersight_client/models/hcl_firmware_all_of.rb', line 69 def self.attribute_map { :'class_id' => :'ClassId', :'object_type' => :'ObjectType', :'driver_name' => :'DriverName', :'driver_version' => :'DriverVersion', :'error_code' => :'ErrorCode', :'firmware_version' => :'FirmwareVersion', :'id' => :'Id', :'latest_driver' => :'LatestDriver', :'latest_firmware' => :'LatestFirmware' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
262 263 264 |
# File 'lib/intersight_client/models/hcl_firmware_all_of.rb', line 262 def self.build_from_hash(attributes) new.build_from_hash(attributes) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
109 110 111 112 |
# File 'lib/intersight_client/models/hcl_firmware_all_of.rb', line 109 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
94 95 96 97 98 99 100 101 102 103 104 105 106 |
# File 'lib/intersight_client/models/hcl_firmware_all_of.rb', line 94 def self.openapi_types { :'class_id' => :'String', :'object_type' => :'String', :'driver_name' => :'String', :'driver_version' => :'String', :'error_code' => :'String', :'firmware_version' => :'String', :'id' => :'String', :'latest_driver' => :'Boolean', :'latest_firmware' => :'Boolean' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
233 234 235 236 237 238 239 240 241 242 243 244 245 |
# File 'lib/intersight_client/models/hcl_firmware_all_of.rb', line 233 def ==(o) return true if self.equal?(o) self.class == o.class && class_id == o.class_id && object_type == o.object_type && driver_name == o.driver_name && driver_version == o.driver_version && error_code == o.error_code && firmware_version == o.firmware_version && id == o.id && latest_driver == o.latest_driver && latest_firmware == o.latest_firmware end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 |
# File 'lib/intersight_client/models/hcl_firmware_all_of.rb', line 292 def _deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = IntersightClient.const_get(type) klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
363 364 365 366 367 368 369 370 371 372 373 374 375 |
# File 'lib/intersight_client/models/hcl_firmware_all_of.rb', line 363 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 |
# File 'lib/intersight_client/models/hcl_firmware_all_of.rb', line 269 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) HclFirmwareAllOf.openapi_types.each_pair do |key, type| if attributes[HclFirmwareAllOf.attribute_map[key]].nil? && HclFirmwareAllOf.openapi_nullable.include?(key) self.send("#{key}=", nil) elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[HclFirmwareAllOf.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[HclFirmwareAllOf.attribute_map[key]].map { |v| _deserialize($1, v) }) end elsif !attributes[HclFirmwareAllOf.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[HclFirmwareAllOf.attribute_map[key]])) end end self end |
#eql?(o) ⇒ Boolean
249 250 251 |
# File 'lib/intersight_client/models/hcl_firmware_all_of.rb', line 249 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
255 256 257 |
# File 'lib/intersight_client/models/hcl_firmware_all_of.rb', line 255 def hash [class_id, object_type, driver_name, driver_version, error_code, firmware_version, id, latest_driver, latest_firmware].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
174 175 176 177 178 179 180 181 182 183 184 185 |
# File 'lib/intersight_client/models/hcl_firmware_all_of.rb', line 174 def list_invalid_properties invalid_properties = Array.new if @class_id.nil? invalid_properties.push('invalid value for "class_id", class_id cannot be nil.') end if @object_type.nil? invalid_properties.push('invalid value for "object_type", object_type cannot be nil.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
339 340 341 |
# File 'lib/intersight_client/models/hcl_firmware_all_of.rb', line 339 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
345 346 347 348 349 350 351 352 353 354 355 356 357 |
# File 'lib/intersight_client/models/hcl_firmware_all_of.rb', line 345 def to_hash hash = {} HclFirmwareAllOf.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = HclFirmwareAllOf.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
333 334 335 |
# File 'lib/intersight_client/models/hcl_firmware_all_of.rb', line 333 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
189 190 191 192 193 194 195 196 197 198 199 |
# File 'lib/intersight_client/models/hcl_firmware_all_of.rb', line 189 def valid? return false if @class_id.nil? class_id_validator = EnumAttributeValidator.new('String', ["hcl.Firmware"]) return false unless class_id_validator.valid?(@class_id) return false if @object_type.nil? object_type_validator = EnumAttributeValidator.new('String', ["hcl.Firmware"]) return false unless object_type_validator.valid?(@object_type) error_code_validator = EnumAttributeValidator.new('String', ["Success", "Unknown", "UnknownServer", "InvalidUcsVersion", "ProcessorNotSupported", "OSNotSupported", "OSUnknown", "UCSVersionNotSupported", "UcsVersionServerOSCombinationNotSupported", "ProductUnknown", "ProductNotSupported", "DriverNameNotSupported", "FirmwareVersionNotSupported", "DriverVersionNotSupported", "FirmwareVersionDriverVersionCombinationNotSupported", "FirmwareVersionAndDriverVersionNotSupported", "FirmwareVersionAndDriverNameNotSupported", "InternalError", "MarshallingError", "Exempted"]) return false unless error_code_validator.valid?(@error_code) true end |