Class: IntersightClient::HyperflexHealthAllOf
- Inherits:
-
Object
- Object
- IntersightClient::HyperflexHealthAllOf
- Defined in:
- lib/intersight_client/models/hyperflex_health_all_of.rb
Overview
Definition of the list of properties defined in ‘hyperflex.Health’, excluding properties defined in parent classes.
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#arbitration_service_state ⇒ Object
The status of the HyperFlex cluster’s connection to the Intersight arbitration service.
-
#class_id ⇒ Object
The fully-qualified name of the instantiated, concrete type.
-
#cluster ⇒ Object
Returns the value of attribute cluster.
-
#data_replication_compliance ⇒ Object
The HyperFlex cluster’s compliance to the configured replication factor.
-
#object_type ⇒ Object
The fully-qualified name of the instantiated, concrete type.
-
#resiliency_details ⇒ Object
Returns the value of attribute resiliency_details.
-
#state ⇒ Object
The operational status of the HyperFlex cluster.
-
#uuid ⇒ Object
The unique identifier for the cluster.
-
#zk_health ⇒ Object
The health status of the HyperFlex cluster’s zookeeper ensemble.
-
#zone_resiliency_list ⇒ Object
Returns the value of attribute zone_resiliency_list.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns the key-value map of all the JSON attributes this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ HyperflexHealthAllOf
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ HyperflexHealthAllOf
Initializes the object
120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 |
# File 'lib/intersight_client/models/hyperflex_health_all_of.rb', line 120 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `IntersightClient::HyperflexHealthAllOf` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `#{self.class.name}`. Please check the name to make sure it's valid. List of attributes: " + self.class.acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'class_id') self.class_id = attributes[:'class_id'] else self.class_id = 'hyperflex.Health' end if attributes.key?(:'object_type') self.object_type = attributes[:'object_type'] else self.object_type = 'hyperflex.Health' end if attributes.key?(:'arbitration_service_state') self.arbitration_service_state = attributes[:'arbitration_service_state'] else self.arbitration_service_state = 'NOT_AVAILABLE' end if attributes.key?(:'data_replication_compliance') self.data_replication_compliance = attributes[:'data_replication_compliance'] else self.data_replication_compliance = 'UNKNOWN' end if attributes.key?(:'resiliency_details') self.resiliency_details = attributes[:'resiliency_details'] end if attributes.key?(:'state') self.state = attributes[:'state'] else self.state = 'UNKNOWN' end if attributes.key?(:'uuid') self.uuid = attributes[:'uuid'] end if attributes.key?(:'zk_health') self.zk_health = attributes[:'zk_health'] else self.zk_health = 'NOT_AVAILABLE' end if attributes.key?(:'zone_resiliency_list') if (value = attributes[:'zone_resiliency_list']).is_a?(Array) self.zone_resiliency_list = value end end if attributes.key?(:'cluster') self.cluster = attributes[:'cluster'] end end |
Instance Attribute Details
#arbitration_service_state ⇒ Object
The status of the HyperFlex cluster’s connection to the Intersight arbitration service. The arbitration service state is only applicable to 2-node edge clusters. * NOT_AVAILABLE - The cluster does not require a connection to the arbitration service. * UNKNOWN - The cluster’s connection state to the arbitration service cannot be determined. * ONLINE - The cluster is connected to the arbitration service. * OFFLINE - The cluster is disconnected from the arbitration service.
26 27 28 |
# File 'lib/intersight_client/models/hyperflex_health_all_of.rb', line 26 def arbitration_service_state @arbitration_service_state end |
#class_id ⇒ Object
The fully-qualified name of the instantiated, concrete type. This property is used as a discriminator to identify the type of the payload when marshaling and unmarshaling data.
20 21 22 |
# File 'lib/intersight_client/models/hyperflex_health_all_of.rb', line 20 def class_id @class_id end |
#cluster ⇒ Object
Returns the value of attribute cluster.
44 45 46 |
# File 'lib/intersight_client/models/hyperflex_health_all_of.rb', line 44 def cluster @cluster end |
#data_replication_compliance ⇒ Object
The HyperFlex cluster’s compliance to the configured replication factor. It indicates that the compliance has degraded if the number of copies of data is reduced. * UNKNOWN - The replication compliance of the HyperFlex cluster is not known. * COMPLIANT - The HyperFlex cluster is compliant with the replication policy. All data on the cluster is replicated according to the configured replication factor. * NON_COMPLIANT - The HyperFlex cluster is not compliant with the replication policy. Some data on the cluster is not replicated in accordance with the configured replication factor.
29 30 31 |
# File 'lib/intersight_client/models/hyperflex_health_all_of.rb', line 29 def data_replication_compliance @data_replication_compliance end |
#object_type ⇒ Object
The fully-qualified name of the instantiated, concrete type. The value should be the same as the ‘ClassId’ property.
23 24 25 |
# File 'lib/intersight_client/models/hyperflex_health_all_of.rb', line 23 def object_type @object_type end |
#resiliency_details ⇒ Object
Returns the value of attribute resiliency_details.
31 32 33 |
# File 'lib/intersight_client/models/hyperflex_health_all_of.rb', line 31 def resiliency_details @resiliency_details end |
#state ⇒ Object
The operational status of the HyperFlex cluster. * UNKNOWN - The operational status of the cluster cannot be determined. * ONLINE - The HyperFlex cluster is online and is performing IO operations. * OFFLINE - The HyperFlex cluster is offline and is not ready to perform IO operations. * ENOSPACE - The HyperFlex cluster is out of available storage capacity and cannot perform write transactions. * READONLY - The HyperFlex cluster is not accepting write transactions, but can still display static cluster information.
34 35 36 |
# File 'lib/intersight_client/models/hyperflex_health_all_of.rb', line 34 def state @state end |
#uuid ⇒ Object
The unique identifier for the cluster.
37 38 39 |
# File 'lib/intersight_client/models/hyperflex_health_all_of.rb', line 37 def uuid @uuid end |
#zk_health ⇒ Object
The health status of the HyperFlex cluster’s zookeeper ensemble. * NOT_AVAILABLE - The operational status of the ZK ensemble is not provided by the HyperFlex cluster. * UNKNOWN - The operational status of the ZK ensemble cannot be determined. * ONLINE - The ZK ensemble is online and operational. * OFFLINE - The ZK ensemble is offline and not operational.
40 41 42 |
# File 'lib/intersight_client/models/hyperflex_health_all_of.rb', line 40 def zk_health @zk_health end |
#zone_resiliency_list ⇒ Object
Returns the value of attribute zone_resiliency_list.
42 43 44 |
# File 'lib/intersight_client/models/hyperflex_health_all_of.rb', line 42 def zone_resiliency_list @zone_resiliency_list end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns the key-value map of all the JSON attributes this model knows about
90 91 92 |
# File 'lib/intersight_client/models/hyperflex_health_all_of.rb', line 90 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
85 86 87 |
# File 'lib/intersight_client/models/hyperflex_health_all_of.rb', line 85 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
69 70 71 72 73 74 75 76 77 78 79 80 81 82 |
# File 'lib/intersight_client/models/hyperflex_health_all_of.rb', line 69 def self.attribute_map { :'class_id' => :'ClassId', :'object_type' => :'ObjectType', :'arbitration_service_state' => :'ArbitrationServiceState', :'data_replication_compliance' => :'DataReplicationCompliance', :'resiliency_details' => :'ResiliencyDetails', :'state' => :'State', :'uuid' => :'Uuid', :'zk_health' => :'ZkHealth', :'zone_resiliency_list' => :'ZoneResiliencyList', :'cluster' => :'Cluster' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
315 316 317 |
# File 'lib/intersight_client/models/hyperflex_health_all_of.rb', line 315 def self.build_from_hash(attributes) new.build_from_hash(attributes) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
111 112 113 114 115 116 |
# File 'lib/intersight_client/models/hyperflex_health_all_of.rb', line 111 def self.openapi_nullable Set.new([ :'resiliency_details', :'zone_resiliency_list', ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
95 96 97 98 99 100 101 102 103 104 105 106 107 108 |
# File 'lib/intersight_client/models/hyperflex_health_all_of.rb', line 95 def self.openapi_types { :'class_id' => :'String', :'object_type' => :'String', :'arbitration_service_state' => :'String', :'data_replication_compliance' => :'String', :'resiliency_details' => :'HyperflexHxResiliencyInfoDt', :'state' => :'String', :'uuid' => :'String', :'zk_health' => :'String', :'zone_resiliency_list' => :'Array<HyperflexHxZoneResiliencyInfoDt>', :'cluster' => :'HyperflexClusterRelationship' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
285 286 287 288 289 290 291 292 293 294 295 296 297 298 |
# File 'lib/intersight_client/models/hyperflex_health_all_of.rb', line 285 def ==(o) return true if self.equal?(o) self.class == o.class && class_id == o.class_id && object_type == o.object_type && arbitration_service_state == o.arbitration_service_state && data_replication_compliance == o.data_replication_compliance && resiliency_details == o.resiliency_details && state == o.state && uuid == o.uuid && zk_health == o.zk_health && zone_resiliency_list == o.zone_resiliency_list && cluster == o.cluster end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 |
# File 'lib/intersight_client/models/hyperflex_health_all_of.rb', line 345 def _deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = IntersightClient.const_get(type) klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
416 417 418 419 420 421 422 423 424 425 426 427 428 |
# File 'lib/intersight_client/models/hyperflex_health_all_of.rb', line 416 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 |
# File 'lib/intersight_client/models/hyperflex_health_all_of.rb', line 322 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) HyperflexHealthAllOf.openapi_types.each_pair do |key, type| if attributes[HyperflexHealthAllOf.attribute_map[key]].nil? && HyperflexHealthAllOf.openapi_nullable.include?(key) self.send("#{key}=", nil) elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[HyperflexHealthAllOf.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[HyperflexHealthAllOf.attribute_map[key]].map { |v| _deserialize($1, v) }) end elsif !attributes[HyperflexHealthAllOf.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[HyperflexHealthAllOf.attribute_map[key]])) end end self end |
#eql?(o) ⇒ Boolean
302 303 304 |
# File 'lib/intersight_client/models/hyperflex_health_all_of.rb', line 302 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
308 309 310 |
# File 'lib/intersight_client/models/hyperflex_health_all_of.rb', line 308 def hash [class_id, object_type, arbitration_service_state, data_replication_compliance, resiliency_details, state, uuid, zk_health, zone_resiliency_list, cluster].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
190 191 192 193 194 195 196 197 198 199 200 201 |
# File 'lib/intersight_client/models/hyperflex_health_all_of.rb', line 190 def list_invalid_properties invalid_properties = Array.new if @class_id.nil? invalid_properties.push('invalid value for "class_id", class_id cannot be nil.') end if @object_type.nil? invalid_properties.push('invalid value for "object_type", object_type cannot be nil.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
392 393 394 |
# File 'lib/intersight_client/models/hyperflex_health_all_of.rb', line 392 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
398 399 400 401 402 403 404 405 406 407 408 409 410 |
# File 'lib/intersight_client/models/hyperflex_health_all_of.rb', line 398 def to_hash hash = {} HyperflexHealthAllOf.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = HyperflexHealthAllOf.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
386 387 388 |
# File 'lib/intersight_client/models/hyperflex_health_all_of.rb', line 386 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 |
# File 'lib/intersight_client/models/hyperflex_health_all_of.rb', line 205 def valid? return false if @class_id.nil? class_id_validator = EnumAttributeValidator.new('String', ["hyperflex.Health"]) return false unless class_id_validator.valid?(@class_id) return false if @object_type.nil? object_type_validator = EnumAttributeValidator.new('String', ["hyperflex.Health"]) return false unless object_type_validator.valid?(@object_type) arbitration_service_state_validator = EnumAttributeValidator.new('String', ["NOT_AVAILABLE", "UNKNOWN", "ONLINE", "OFFLINE"]) return false unless arbitration_service_state_validator.valid?(@arbitration_service_state) data_replication_compliance_validator = EnumAttributeValidator.new('String', ["UNKNOWN", "COMPLIANT", "NON_COMPLIANT"]) return false unless data_replication_compliance_validator.valid?(@data_replication_compliance) state_validator = EnumAttributeValidator.new('String', ["UNKNOWN", "ONLINE", "OFFLINE", "ENOSPACE", "READONLY"]) return false unless state_validator.valid?(@state) zk_health_validator = EnumAttributeValidator.new('String', ["NOT_AVAILABLE", "UNKNOWN", "ONLINE", "OFFLINE"]) return false unless zk_health_validator.valid?(@zk_health) true end |