Class: IntersightClient::IaasDeviceStatus
- Defined in:
- lib/intersight_client/models/iaas_device_status.rb
Overview
List of infra accounts managed by UCSD.
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#account_name ⇒ Object
The UCSD infra account name.
-
#account_type ⇒ Object
The UCSD Infra Account type.
-
#category ⇒ Object
The UCSD Infra Account category.
-
#claim_status ⇒ Object
Describes if the device is claimed in Intersight or not.
-
#class_id ⇒ Object
The fully-qualified name of the instantiated, concrete type.
-
#connection_status ⇒ Object
Describes about the connection status between the UCSD and the actual end device.
-
#device_model ⇒ Object
Describes about the device model.
-
#device_vendor ⇒ Object
Describes about the device vendor/manufacturer of the device.
-
#device_version ⇒ Object
Describes about the current firmware version running on the device.
-
#guid ⇒ Object
Returns the value of attribute guid.
-
#ip_address ⇒ Object
The IPAddress of the device.
-
#object_type ⇒ Object
The fully-qualified name of the instantiated, concrete type.
-
#pod ⇒ Object
Describes about the pod to which this device belongs to in UCSD.
-
#pod_type ⇒ Object
Describes about the podType of Pod to which this device belongs to in UCSD.
Attributes inherited from MoBaseMo
#account_moid, #ancestors, #create_time, #display_names, #domain_group_moid, #mod_time, #moid, #owners, #parent, #permission_resources, #shared_scope, #tags, #version_context
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns the key-value map of all the JSON attributes this model knows about, including the ones defined in its parent(s).
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about, including the ones defined in its parent(s).
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_all_of ⇒ Object
List of class defined in allOf (OpenAPI v3).
-
.openapi_discriminator_name ⇒ Object
discriminator’s property name in OpenAPI v3.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ IaasDeviceStatus
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ IaasDeviceStatus
Initializes the object
153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 |
# File 'lib/intersight_client/models/iaas_device_status.rb', line 153 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `IntersightClient::IaasDeviceStatus` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `#{self.class.name}`. Please check the name to make sure it's valid. List of attributes: " + self.class.acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } # call parent's initialize super(attributes) if attributes.key?(:'class_id') self.class_id = attributes[:'class_id'] else self.class_id = 'iaas.DeviceStatus' end if attributes.key?(:'object_type') self.object_type = attributes[:'object_type'] else self.object_type = 'iaas.DeviceStatus' end if attributes.key?(:'account_name') self.account_name = attributes[:'account_name'] end if attributes.key?(:'account_type') self.account_type = attributes[:'account_type'] end if attributes.key?(:'category') self.category = attributes[:'category'] end if attributes.key?(:'claim_status') self.claim_status = attributes[:'claim_status'] else self.claim_status = 'Unknown' end if attributes.key?(:'connection_status') self.connection_status = attributes[:'connection_status'] end if attributes.key?(:'device_model') self.device_model = attributes[:'device_model'] end if attributes.key?(:'device_vendor') self.device_vendor = attributes[:'device_vendor'] end if attributes.key?(:'device_version') self.device_version = attributes[:'device_version'] end if attributes.key?(:'ip_address') self.ip_address = attributes[:'ip_address'] end if attributes.key?(:'pod') self.pod = attributes[:'pod'] end if attributes.key?(:'pod_type') self.pod_type = attributes[:'pod_type'] end if attributes.key?(:'guid') self.guid = attributes[:'guid'] end end |
Instance Attribute Details
#account_name ⇒ Object
The UCSD infra account name. Account Name is created when UCSD admin adds any new infra account (Physical/Virtual/Compute/Network) to be managed by UCSD.
26 27 28 |
# File 'lib/intersight_client/models/iaas_device_status.rb', line 26 def account_name @account_name end |
#account_type ⇒ Object
The UCSD Infra Account type.
29 30 31 |
# File 'lib/intersight_client/models/iaas_device_status.rb', line 29 def account_type @account_type end |
#category ⇒ Object
The UCSD Infra Account category.
32 33 34 |
# File 'lib/intersight_client/models/iaas_device_status.rb', line 32 def category @category end |
#claim_status ⇒ Object
Describes if the device is claimed in Intersight or not. * Unknown - If UCS Director managed account claim status information is unknown. * Yes - If UCS Director managed account is claimed in Intersight. * No - If UCS Director managed account is not claimed in Intersight. * ‘Not Applicable` - If UCS Director managed account is not capable of providing claim status information.
35 36 37 |
# File 'lib/intersight_client/models/iaas_device_status.rb', line 35 def claim_status @claim_status end |
#class_id ⇒ Object
The fully-qualified name of the instantiated, concrete type. This property is used as a discriminator to identify the type of the payload when marshaling and unmarshaling data.
20 21 22 |
# File 'lib/intersight_client/models/iaas_device_status.rb', line 20 def class_id @class_id end |
#connection_status ⇒ Object
Describes about the connection status between the UCSD and the actual end device.
38 39 40 |
# File 'lib/intersight_client/models/iaas_device_status.rb', line 38 def connection_status @connection_status end |
#device_model ⇒ Object
Describes about the device model.
41 42 43 |
# File 'lib/intersight_client/models/iaas_device_status.rb', line 41 def device_model @device_model end |
#device_vendor ⇒ Object
Describes about the device vendor/manufacturer of the device.
44 45 46 |
# File 'lib/intersight_client/models/iaas_device_status.rb', line 44 def device_vendor @device_vendor end |
#device_version ⇒ Object
Describes about the current firmware version running on the device.
47 48 49 |
# File 'lib/intersight_client/models/iaas_device_status.rb', line 47 def device_version @device_version end |
#guid ⇒ Object
Returns the value of attribute guid.
58 59 60 |
# File 'lib/intersight_client/models/iaas_device_status.rb', line 58 def guid @guid end |
#ip_address ⇒ Object
The IPAddress of the device.
50 51 52 |
# File 'lib/intersight_client/models/iaas_device_status.rb', line 50 def ip_address @ip_address end |
#object_type ⇒ Object
The fully-qualified name of the instantiated, concrete type. The value should be the same as the ‘ClassId’ property.
23 24 25 |
# File 'lib/intersight_client/models/iaas_device_status.rb', line 23 def object_type @object_type end |
#pod ⇒ Object
Describes about the pod to which this device belongs to in UCSD.
53 54 55 |
# File 'lib/intersight_client/models/iaas_device_status.rb', line 53 def pod @pod end |
#pod_type ⇒ Object
Describes about the podType of Pod to which this device belongs to in UCSD.
56 57 58 |
# File 'lib/intersight_client/models/iaas_device_status.rb', line 56 def pod_type @pod_type end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns the key-value map of all the JSON attributes this model knows about, including the ones defined in its parent(s)
108 109 110 |
# File 'lib/intersight_client/models/iaas_device_status.rb', line 108 def self.acceptable_attribute_map attribute_map.merge(superclass.acceptable_attribute_map) end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about, including the ones defined in its parent(s)
103 104 105 |
# File 'lib/intersight_client/models/iaas_device_status.rb', line 103 def self.acceptable_attributes attribute_map.values.concat(superclass.acceptable_attributes) end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 |
# File 'lib/intersight_client/models/iaas_device_status.rb', line 83 def self.attribute_map { :'class_id' => :'ClassId', :'object_type' => :'ObjectType', :'account_name' => :'AccountName', :'account_type' => :'AccountType', :'category' => :'Category', :'claim_status' => :'ClaimStatus', :'connection_status' => :'ConnectionStatus', :'device_model' => :'DeviceModel', :'device_vendor' => :'DeviceVendor', :'device_version' => :'DeviceVersion', :'ip_address' => :'IpAddress', :'pod' => :'Pod', :'pod_type' => :'PodType', :'guid' => :'Guid' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
327 328 329 |
# File 'lib/intersight_client/models/iaas_device_status.rb', line 327 def self.build_from_hash(attributes) new.build_from_hash(attributes) end |
.openapi_all_of ⇒ Object
List of class defined in allOf (OpenAPI v3)
139 140 141 142 143 144 |
# File 'lib/intersight_client/models/iaas_device_status.rb', line 139 def self.openapi_all_of [ :'IaasDeviceStatusAllOf', :'MoBaseMo' ] end |
.openapi_discriminator_name ⇒ Object
discriminator’s property name in OpenAPI v3
147 148 149 |
# File 'lib/intersight_client/models/iaas_device_status.rb', line 147 def self.openapi_discriminator_name :'ClassId' end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
133 134 135 136 |
# File 'lib/intersight_client/models/iaas_device_status.rb', line 133 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 |
# File 'lib/intersight_client/models/iaas_device_status.rb', line 113 def self.openapi_types { :'class_id' => :'String', :'object_type' => :'String', :'account_name' => :'String', :'account_type' => :'String', :'category' => :'String', :'claim_status' => :'String', :'connection_status' => :'String', :'device_model' => :'String', :'device_vendor' => :'String', :'device_version' => :'String', :'ip_address' => :'String', :'pod' => :'String', :'pod_type' => :'String', :'guid' => :'IaasUcsdInfoRelationship' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 |
# File 'lib/intersight_client/models/iaas_device_status.rb', line 293 def ==(o) return true if self.equal?(o) self.class == o.class && class_id == o.class_id && object_type == o.object_type && account_name == o.account_name && account_type == o.account_type && category == o.category && claim_status == o.claim_status && connection_status == o.connection_status && device_model == o.device_model && device_vendor == o.device_vendor && device_version == o.device_version && ip_address == o.ip_address && pod == o.pod && pod_type == o.pod_type && guid == o.guid && super(o) end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 |
# File 'lib/intersight_client/models/iaas_device_status.rb', line 358 def _deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = IntersightClient.const_get(type) klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
429 430 431 432 433 434 435 436 437 438 439 440 441 |
# File 'lib/intersight_client/models/iaas_device_status.rb', line 429 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 |
# File 'lib/intersight_client/models/iaas_device_status.rb', line 334 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) super(attributes) IaasDeviceStatus.openapi_types.each_pair do |key, type| if attributes[IaasDeviceStatus.attribute_map[key]].nil? && IaasDeviceStatus.openapi_nullable.include?(key) self.send("#{key}=", nil) elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[IaasDeviceStatus.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[IaasDeviceStatus.attribute_map[key]].map { |v| _deserialize($1, v) }) end elsif !attributes[IaasDeviceStatus.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[IaasDeviceStatus.attribute_map[key]])) end end self end |
#eql?(o) ⇒ Boolean
314 315 316 |
# File 'lib/intersight_client/models/iaas_device_status.rb', line 314 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
320 321 322 |
# File 'lib/intersight_client/models/iaas_device_status.rb', line 320 def hash [class_id, object_type, account_name, account_type, category, claim_status, connection_status, device_model, device_vendor, device_version, ip_address, pod, pod_type, guid].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
234 235 236 237 238 239 240 241 242 243 244 245 |
# File 'lib/intersight_client/models/iaas_device_status.rb', line 234 def list_invalid_properties invalid_properties = super if @class_id.nil? invalid_properties.push('invalid value for "class_id", class_id cannot be nil.') end if @object_type.nil? invalid_properties.push('invalid value for "object_type", object_type cannot be nil.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
405 406 407 |
# File 'lib/intersight_client/models/iaas_device_status.rb', line 405 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
411 412 413 414 415 416 417 418 419 420 421 422 423 |
# File 'lib/intersight_client/models/iaas_device_status.rb', line 411 def to_hash hash = super IaasDeviceStatus.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = IaasDeviceStatus.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
399 400 401 |
# File 'lib/intersight_client/models/iaas_device_status.rb', line 399 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
249 250 251 252 253 254 255 256 257 258 259 |
# File 'lib/intersight_client/models/iaas_device_status.rb', line 249 def valid? return false if @class_id.nil? class_id_validator = EnumAttributeValidator.new('String', ["iaas.DeviceStatus"]) return false unless class_id_validator.valid?(@class_id) return false if @object_type.nil? object_type_validator = EnumAttributeValidator.new('String', ["iaas.DeviceStatus"]) return false unless object_type_validator.valid?(@object_type) claim_status_validator = EnumAttributeValidator.new('String', ["Unknown", "Yes", "No", "Not Applicable"]) return false unless claim_status_validator.valid?(@claim_status) true && super end |