Class: IntersightClient::IamEndPointPasswordPropertiesAllOf
- Inherits:
-
Object
- Object
- IntersightClient::IamEndPointPasswordPropertiesAllOf
- Defined in:
- lib/intersight_client/models/iam_end_point_password_properties_all_of.rb
Overview
Definition of the list of properties defined in ‘iam.EndPointPasswordProperties’, excluding properties defined in parent classes.
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#class_id ⇒ Object
The fully-qualified name of the instantiated, concrete type.
-
#enable_password_expiry ⇒ Object
Enables password expiry on the endpoint.
-
#enforce_strong_password ⇒ Object
Enables a strong password policy.
-
#force_send_password ⇒ Object
User password will always be sent to endpoint device.
-
#grace_period ⇒ Object
Time period until when you can use the existing password, after it expires.
-
#notification_period ⇒ Object
The duration after which the password will expire.
-
#object_type ⇒ Object
The fully-qualified name of the instantiated, concrete type.
-
#password_expiry_duration ⇒ Object
Set time period for password expiration.
-
#password_history ⇒ Object
Tracks password change history.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns the key-value map of all the JSON attributes this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ IamEndPointPasswordPropertiesAllOf
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ IamEndPointPasswordPropertiesAllOf
Initializes the object
116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 |
# File 'lib/intersight_client/models/iam_end_point_password_properties_all_of.rb', line 116 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `IntersightClient::IamEndPointPasswordPropertiesAllOf` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `#{self.class.name}`. Please check the name to make sure it's valid. List of attributes: " + self.class.acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'class_id') self.class_id = attributes[:'class_id'] else self.class_id = 'iam.EndPointPasswordProperties' end if attributes.key?(:'object_type') self.object_type = attributes[:'object_type'] else self.object_type = 'iam.EndPointPasswordProperties' end if attributes.key?(:'enable_password_expiry') self.enable_password_expiry = attributes[:'enable_password_expiry'] else self.enable_password_expiry = false end if attributes.key?(:'enforce_strong_password') self.enforce_strong_password = attributes[:'enforce_strong_password'] else self.enforce_strong_password = true end if attributes.key?(:'force_send_password') self.force_send_password = attributes[:'force_send_password'] else self.force_send_password = false end if attributes.key?(:'grace_period') self.grace_period = attributes[:'grace_period'] else self.grace_period = 0 end if attributes.key?(:'notification_period') self.notification_period = attributes[:'notification_period'] else self.notification_period = 15 end if attributes.key?(:'password_expiry_duration') self.password_expiry_duration = attributes[:'password_expiry_duration'] else self.password_expiry_duration = 90 end if attributes.key?(:'password_history') self.password_history = attributes[:'password_history'] else self.password_history = 5 end end |
Instance Attribute Details
#class_id ⇒ Object
The fully-qualified name of the instantiated, concrete type. This property is used as a discriminator to identify the type of the payload when marshaling and unmarshaling data.
20 21 22 |
# File 'lib/intersight_client/models/iam_end_point_password_properties_all_of.rb', line 20 def class_id @class_id end |
#enable_password_expiry ⇒ Object
Enables password expiry on the endpoint.
26 27 28 |
# File 'lib/intersight_client/models/iam_end_point_password_properties_all_of.rb', line 26 def enable_password_expiry @enable_password_expiry end |
#enforce_strong_password ⇒ Object
Enables a strong password policy. Strong password requirements: A. The password must have a minimum of 8 and a maximum of 20 characters. B. The password must not contain the User’s Name. C. The password must contain characters from three of the following four categories. 1) English uppercase characters (A through Z). 2) English lowercase characters (a through z). 3) Base 10 digits (0 through 9). 4) Non-alphabetic characters (! , @, #, $, %, ^, &, *, -, _, +, =).
29 30 31 |
# File 'lib/intersight_client/models/iam_end_point_password_properties_all_of.rb', line 29 def enforce_strong_password @enforce_strong_password end |
#force_send_password ⇒ Object
User password will always be sent to endpoint device. If the option is not selected, then user password will be sent to endpoint device for new users and if user password is changed for existing users.
32 33 34 |
# File 'lib/intersight_client/models/iam_end_point_password_properties_all_of.rb', line 32 def force_send_password @force_send_password end |
#grace_period ⇒ Object
Time period until when you can use the existing password, after it expires.
35 36 37 |
# File 'lib/intersight_client/models/iam_end_point_password_properties_all_of.rb', line 35 def grace_period @grace_period end |
#notification_period ⇒ Object
The duration after which the password will expire.
38 39 40 |
# File 'lib/intersight_client/models/iam_end_point_password_properties_all_of.rb', line 38 def notification_period @notification_period end |
#object_type ⇒ Object
The fully-qualified name of the instantiated, concrete type. The value should be the same as the ‘ClassId’ property.
23 24 25 |
# File 'lib/intersight_client/models/iam_end_point_password_properties_all_of.rb', line 23 def object_type @object_type end |
#password_expiry_duration ⇒ Object
Set time period for password expiration. Value should be greater than notification period and grace period.
41 42 43 |
# File 'lib/intersight_client/models/iam_end_point_password_properties_all_of.rb', line 41 def password_expiry_duration @password_expiry_duration end |
#password_history ⇒ Object
Tracks password change history. Specifies in number of instances, that the new password was already used.
44 45 46 |
# File 'lib/intersight_client/models/iam_end_point_password_properties_all_of.rb', line 44 def password_history @password_history end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns the key-value map of all the JSON attributes this model knows about
89 90 91 |
# File 'lib/intersight_client/models/iam_end_point_password_properties_all_of.rb', line 89 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
84 85 86 |
# File 'lib/intersight_client/models/iam_end_point_password_properties_all_of.rb', line 84 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
69 70 71 72 73 74 75 76 77 78 79 80 81 |
# File 'lib/intersight_client/models/iam_end_point_password_properties_all_of.rb', line 69 def self.attribute_map { :'class_id' => :'ClassId', :'object_type' => :'ObjectType', :'enable_password_expiry' => :'EnablePasswordExpiry', :'enforce_strong_password' => :'EnforceStrongPassword', :'force_send_password' => :'ForceSendPassword', :'grace_period' => :'GracePeriod', :'notification_period' => :'NotificationPeriod', :'password_expiry_duration' => :'PasswordExpiryDuration', :'password_history' => :'PasswordHistory' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
358 359 360 |
# File 'lib/intersight_client/models/iam_end_point_password_properties_all_of.rb', line 358 def self.build_from_hash(attributes) new.build_from_hash(attributes) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
109 110 111 112 |
# File 'lib/intersight_client/models/iam_end_point_password_properties_all_of.rb', line 109 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
94 95 96 97 98 99 100 101 102 103 104 105 106 |
# File 'lib/intersight_client/models/iam_end_point_password_properties_all_of.rb', line 94 def self.openapi_types { :'class_id' => :'String', :'object_type' => :'String', :'enable_password_expiry' => :'Boolean', :'enforce_strong_password' => :'Boolean', :'force_send_password' => :'Boolean', :'grace_period' => :'Integer', :'notification_period' => :'Integer', :'password_expiry_duration' => :'Integer', :'password_history' => :'Integer' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
329 330 331 332 333 334 335 336 337 338 339 340 341 |
# File 'lib/intersight_client/models/iam_end_point_password_properties_all_of.rb', line 329 def ==(o) return true if self.equal?(o) self.class == o.class && class_id == o.class_id && object_type == o.object_type && enable_password_expiry == o.enable_password_expiry && enforce_strong_password == o.enforce_strong_password && force_send_password == o.force_send_password && grace_period == o.grace_period && notification_period == o.notification_period && password_expiry_duration == o.password_expiry_duration && password_history == o.password_history end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 |
# File 'lib/intersight_client/models/iam_end_point_password_properties_all_of.rb', line 388 def _deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = IntersightClient.const_get(type) klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
459 460 461 462 463 464 465 466 467 468 469 470 471 |
# File 'lib/intersight_client/models/iam_end_point_password_properties_all_of.rb', line 459 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 |
# File 'lib/intersight_client/models/iam_end_point_password_properties_all_of.rb', line 365 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) IamEndPointPasswordPropertiesAllOf.openapi_types.each_pair do |key, type| if attributes[IamEndPointPasswordPropertiesAllOf.attribute_map[key]].nil? && IamEndPointPasswordPropertiesAllOf.openapi_nullable.include?(key) self.send("#{key}=", nil) elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[IamEndPointPasswordPropertiesAllOf.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[IamEndPointPasswordPropertiesAllOf.attribute_map[key]].map { |v| _deserialize($1, v) }) end elsif !attributes[IamEndPointPasswordPropertiesAllOf.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[IamEndPointPasswordPropertiesAllOf.attribute_map[key]])) end end self end |
#eql?(o) ⇒ Boolean
345 346 347 |
# File 'lib/intersight_client/models/iam_end_point_password_properties_all_of.rb', line 345 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
351 352 353 |
# File 'lib/intersight_client/models/iam_end_point_password_properties_all_of.rb', line 351 def hash [class_id, object_type, enable_password_expiry, enforce_strong_password, force_send_password, grace_period, notification_period, password_expiry_duration, password_history].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 |
# File 'lib/intersight_client/models/iam_end_point_password_properties_all_of.rb', line 186 def list_invalid_properties invalid_properties = Array.new if @class_id.nil? invalid_properties.push('invalid value for "class_id", class_id cannot be nil.') end if @object_type.nil? invalid_properties.push('invalid value for "object_type", object_type cannot be nil.') end if !@grace_period.nil? && @grace_period > 5 invalid_properties.push('invalid value for "grace_period", must be smaller than or equal to 5.') end if !@grace_period.nil? && @grace_period < 0 invalid_properties.push('invalid value for "grace_period", must be greater than or equal to 0.') end if !@notification_period.nil? && @notification_period > 15 invalid_properties.push('invalid value for "notification_period", must be smaller than or equal to 15.') end if !@notification_period.nil? && @notification_period < 0 invalid_properties.push('invalid value for "notification_period", must be greater than or equal to 0.') end if !@password_expiry_duration.nil? && @password_expiry_duration > 3650 invalid_properties.push('invalid value for "password_expiry_duration", must be smaller than or equal to 3650.') end if !@password_expiry_duration.nil? && @password_expiry_duration < 1 invalid_properties.push('invalid value for "password_expiry_duration", must be greater than or equal to 1.') end if !@password_history.nil? && @password_history > 5 invalid_properties.push('invalid value for "password_history", must be smaller than or equal to 5.') end if !@password_history.nil? && @password_history < 0 invalid_properties.push('invalid value for "password_history", must be greater than or equal to 0.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
435 436 437 |
# File 'lib/intersight_client/models/iam_end_point_password_properties_all_of.rb', line 435 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
441 442 443 444 445 446 447 448 449 450 451 452 453 |
# File 'lib/intersight_client/models/iam_end_point_password_properties_all_of.rb', line 441 def to_hash hash = {} IamEndPointPasswordPropertiesAllOf.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = IamEndPointPasswordPropertiesAllOf.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
429 430 431 |
# File 'lib/intersight_client/models/iam_end_point_password_properties_all_of.rb', line 429 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 |
# File 'lib/intersight_client/models/iam_end_point_password_properties_all_of.rb', line 233 def valid? return false if @class_id.nil? class_id_validator = EnumAttributeValidator.new('String', ["iam.EndPointPasswordProperties"]) return false unless class_id_validator.valid?(@class_id) return false if @object_type.nil? object_type_validator = EnumAttributeValidator.new('String', ["iam.EndPointPasswordProperties"]) return false unless object_type_validator.valid?(@object_type) return false if !@grace_period.nil? && @grace_period > 5 return false if !@grace_period.nil? && @grace_period < 0 return false if !@notification_period.nil? && @notification_period > 15 return false if !@notification_period.nil? && @notification_period < 0 return false if !@password_expiry_duration.nil? && @password_expiry_duration > 3650 return false if !@password_expiry_duration.nil? && @password_expiry_duration < 1 return false if !@password_history.nil? && @password_history > 5 return false if !@password_history.nil? && @password_history < 0 true end |