Class: IntersightClient::KubernetesAciCniProfile
- Inherits:
-
PolicyAbstractProfile
- Object
- MoBaseMo
- PolicyAbstractProfile
- IntersightClient::KubernetesAciCniProfile
- Defined in:
- lib/intersight_client/models/kubernetes_aci_cni_profile.rb
Overview
Configuration for an ACI CNI profile.
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#aaep_name ⇒ Object
Name of ACI AAEP (Attachable Access Entity Profile) to be used for all Kubernetes clusters using this policy.
-
#class_id ⇒ Object
The fully-qualified name of the instantiated, concrete type.
-
#cluster_aci_allocations ⇒ Object
An array of relationships to kubernetesAciCniTenantClusterAllocation resources.
-
#cluster_profiles ⇒ Object
An array of relationships to kubernetesClusterProfile resources.
-
#ext_svc_dyn_subnet_start ⇒ Object
Start of range of IP subnets for external services with dynamic IP allocation for use by Kubernetes clusters using this ACI CNI policy.
-
#ext_svc_static_subnet_start ⇒ Object
Start of range of IP subnets for external services with static IP allocation for use by Kubernetes clusters using this ACI CNI policy.
-
#infra_vlan_id ⇒ Object
Value of ACI infrastructuere VLAN ID for the ACI fabric.
-
#l3_out_network_name ⇒ Object
Name of ACI L3Out network to be used for all Kubernetes clusters using this policy.
-
#l3_out_policy_name ⇒ Object
Name of ACI L3Out policy to be used for all Kubernetes clusters using this policy.
-
#l3_out_tenant ⇒ Object
Tenant in ACI used by this L3Out and Common VRF.
-
#nested_vmm_domain ⇒ Object
VMM domain within which Kubernetes clusters using this policy are nested.
-
#node_svc_subnet_start ⇒ Object
Start of range of ACI Node Service IP subnets to use by Kubernetes clusters using this ACI CNI policy This is used for the service graph which is used for ACI PBR based load balancing.
-
#node_vlan_range_end ⇒ Object
Ending value of VLAN range used to assign Node VLAN Ids for each Kubernetes cluster using this policy.
-
#node_vlan_range_start ⇒ Object
Starting value of VLAN range used to assign Node VLAN Ids for each Kubernetes cluster using this policy.
-
#number_of_kubernetes_clusters ⇒ Object
Number of k8s clusters currently using this ACI CNI profile.
-
#object_type ⇒ Object
The fully-qualified name of the instantiated, concrete type.
-
#opflex_multicast_address_range ⇒ Object
Range of IP Multicast addresses to be used by the Opflex protocol for Kubernetes clusters using this policy.
-
#organization ⇒ Object
Returns the value of attribute organization.
-
#pod_subnet_start ⇒ Object
Start of range of Kubernetes pod IP subnets to use by Kubernetes clusters using this ACI CNI policy This should be a /8 IP subnet so that multiple /16 subnets can be assigned for pod subnets of Kubernetes clusters using this profile.
-
#registered_device ⇒ Object
Returns the value of attribute registered_device.
-
#svc_subnet_start ⇒ Object
Start of range of Kubernetes Service IP subnets to use by Kubernetes clusters using this ACI CNI policy Currently this is fixed internally and read-only.
-
#vrf ⇒ Object
VRF (Virtual Routing and Forwarding) domain to be used within ACI fabric by all k8s clusters using this policy.
Attributes inherited from PolicyAbstractProfile
#description, #name, #src_template, #type
Attributes inherited from MoBaseMo
#account_moid, #ancestors, #create_time, #display_names, #domain_group_moid, #mod_time, #moid, #owners, #parent, #permission_resources, #shared_scope, #tags, #version_context
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns the key-value map of all the JSON attributes this model knows about, including the ones defined in its parent(s).
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about, including the ones defined in its parent(s).
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_all_of ⇒ Object
List of class defined in allOf (OpenAPI v3).
-
.openapi_discriminator_name ⇒ Object
discriminator's property name in OpenAPI v3.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ KubernetesAciCniProfile
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ KubernetesAciCniProfile
Initializes the object
194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 |
# File 'lib/intersight_client/models/kubernetes_aci_cni_profile.rb', line 194 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `IntersightClient::KubernetesAciCniProfile` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `#{self.class.name}`. Please check the name to make sure it's valid. List of attributes: " + self.class.acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } # call parent's initialize super(attributes) if attributes.key?(:'class_id') self.class_id = attributes[:'class_id'] else self.class_id = 'kubernetes.AciCniProfile' end if attributes.key?(:'object_type') self.object_type = attributes[:'object_type'] else self.object_type = 'kubernetes.AciCniProfile' end if attributes.key?(:'aaep_name') self.aaep_name = attributes[:'aaep_name'] end if attributes.key?(:'ext_svc_dyn_subnet_start') self.ext_svc_dyn_subnet_start = attributes[:'ext_svc_dyn_subnet_start'] end if attributes.key?(:'ext_svc_static_subnet_start') self.ext_svc_static_subnet_start = attributes[:'ext_svc_static_subnet_start'] end if attributes.key?(:'infra_vlan_id') self.infra_vlan_id = attributes[:'infra_vlan_id'] end if attributes.key?(:'l3_out_network_name') self.l3_out_network_name = attributes[:'l3_out_network_name'] end if attributes.key?(:'l3_out_policy_name') self.l3_out_policy_name = attributes[:'l3_out_policy_name'] end if attributes.key?(:'l3_out_tenant') self.l3_out_tenant = attributes[:'l3_out_tenant'] end if attributes.key?(:'nested_vmm_domain') self.nested_vmm_domain = attributes[:'nested_vmm_domain'] end if attributes.key?(:'node_svc_subnet_start') self.node_svc_subnet_start = attributes[:'node_svc_subnet_start'] end if attributes.key?(:'node_vlan_range_end') self.node_vlan_range_end = attributes[:'node_vlan_range_end'] end if attributes.key?(:'node_vlan_range_start') self.node_vlan_range_start = attributes[:'node_vlan_range_start'] end if attributes.key?(:'number_of_kubernetes_clusters') self.number_of_kubernetes_clusters = attributes[:'number_of_kubernetes_clusters'] end if attributes.key?(:'opflex_multicast_address_range') self.opflex_multicast_address_range = attributes[:'opflex_multicast_address_range'] end if attributes.key?(:'pod_subnet_start') self.pod_subnet_start = attributes[:'pod_subnet_start'] end if attributes.key?(:'svc_subnet_start') self.svc_subnet_start = attributes[:'svc_subnet_start'] end if attributes.key?(:'vrf') self.vrf = attributes[:'vrf'] end if attributes.key?(:'cluster_aci_allocations') if (value = attributes[:'cluster_aci_allocations']).is_a?(Array) self.cluster_aci_allocations = value end end if attributes.key?(:'cluster_profiles') if (value = attributes[:'cluster_profiles']).is_a?(Array) self.cluster_profiles = value end end if attributes.key?(:'organization') self.organization = attributes[:'organization'] end if attributes.key?(:'registered_device') self.registered_device = attributes[:'registered_device'] end end |
Instance Attribute Details
#aaep_name ⇒ Object
Name of ACI AAEP (Attachable Access Entity Profile) to be used for all Kubernetes clusters using this policy.
26 27 28 |
# File 'lib/intersight_client/models/kubernetes_aci_cni_profile.rb', line 26 def aaep_name @aaep_name end |
#class_id ⇒ Object
The fully-qualified name of the instantiated, concrete type. This property is used as a discriminator to identify the type of the payload when marshaling and unmarshaling data.
20 21 22 |
# File 'lib/intersight_client/models/kubernetes_aci_cni_profile.rb', line 20 def class_id @class_id end |
#cluster_aci_allocations ⇒ Object
An array of relationships to kubernetesAciCniTenantClusterAllocation resources.
74 75 76 |
# File 'lib/intersight_client/models/kubernetes_aci_cni_profile.rb', line 74 def cluster_aci_allocations @cluster_aci_allocations end |
#cluster_profiles ⇒ Object
An array of relationships to kubernetesClusterProfile resources.
77 78 79 |
# File 'lib/intersight_client/models/kubernetes_aci_cni_profile.rb', line 77 def cluster_profiles @cluster_profiles end |
#ext_svc_dyn_subnet_start ⇒ Object
Start of range of IP subnets for external services with dynamic IP allocation for use by Kubernetes clusters using this ACI CNI policy.
29 30 31 |
# File 'lib/intersight_client/models/kubernetes_aci_cni_profile.rb', line 29 def ext_svc_dyn_subnet_start @ext_svc_dyn_subnet_start end |
#ext_svc_static_subnet_start ⇒ Object
Start of range of IP subnets for external services with static IP allocation for use by Kubernetes clusters using this ACI CNI policy.
32 33 34 |
# File 'lib/intersight_client/models/kubernetes_aci_cni_profile.rb', line 32 def ext_svc_static_subnet_start @ext_svc_static_subnet_start end |
#infra_vlan_id ⇒ Object
Value of ACI infrastructuere VLAN ID for the ACI fabric.
35 36 37 |
# File 'lib/intersight_client/models/kubernetes_aci_cni_profile.rb', line 35 def infra_vlan_id @infra_vlan_id end |
#l3_out_network_name ⇒ Object
Name of ACI L3Out network to be used for all Kubernetes clusters using this policy.
38 39 40 |
# File 'lib/intersight_client/models/kubernetes_aci_cni_profile.rb', line 38 def l3_out_network_name @l3_out_network_name end |
#l3_out_policy_name ⇒ Object
Name of ACI L3Out policy to be used for all Kubernetes clusters using this policy.
41 42 43 |
# File 'lib/intersight_client/models/kubernetes_aci_cni_profile.rb', line 41 def l3_out_policy_name @l3_out_policy_name end |
#l3_out_tenant ⇒ Object
Tenant in ACI used by this L3Out and Common VRF.
44 45 46 |
# File 'lib/intersight_client/models/kubernetes_aci_cni_profile.rb', line 44 def l3_out_tenant @l3_out_tenant end |
#nested_vmm_domain ⇒ Object
VMM domain within which Kubernetes clusters using this policy are nested.
47 48 49 |
# File 'lib/intersight_client/models/kubernetes_aci_cni_profile.rb', line 47 def nested_vmm_domain @nested_vmm_domain end |
#node_svc_subnet_start ⇒ Object
Start of range of ACI Node Service IP subnets to use by Kubernetes clusters using this ACI CNI policy This is used for the service graph which is used for ACI PBR based load balancing.
50 51 52 |
# File 'lib/intersight_client/models/kubernetes_aci_cni_profile.rb', line 50 def node_svc_subnet_start @node_svc_subnet_start end |
#node_vlan_range_end ⇒ Object
Ending value of VLAN range used to assign Node VLAN Ids for each Kubernetes cluster using this policy.
53 54 55 |
# File 'lib/intersight_client/models/kubernetes_aci_cni_profile.rb', line 53 def node_vlan_range_end @node_vlan_range_end end |
#node_vlan_range_start ⇒ Object
Starting value of VLAN range used to assign Node VLAN Ids for each Kubernetes cluster using this policy.
56 57 58 |
# File 'lib/intersight_client/models/kubernetes_aci_cni_profile.rb', line 56 def node_vlan_range_start @node_vlan_range_start end |
#number_of_kubernetes_clusters ⇒ Object
Number of k8s clusters currently using this ACI CNI profile.
59 60 61 |
# File 'lib/intersight_client/models/kubernetes_aci_cni_profile.rb', line 59 def number_of_kubernetes_clusters @number_of_kubernetes_clusters end |
#object_type ⇒ Object
The fully-qualified name of the instantiated, concrete type. The value should be the same as the 'ClassId' property.
23 24 25 |
# File 'lib/intersight_client/models/kubernetes_aci_cni_profile.rb', line 23 def object_type @object_type end |
#opflex_multicast_address_range ⇒ Object
Range of IP Multicast addresses to be used by the Opflex protocol for Kubernetes clusters using this policy.
62 63 64 |
# File 'lib/intersight_client/models/kubernetes_aci_cni_profile.rb', line 62 def opflex_multicast_address_range @opflex_multicast_address_range end |
#organization ⇒ Object
Returns the value of attribute organization.
79 80 81 |
# File 'lib/intersight_client/models/kubernetes_aci_cni_profile.rb', line 79 def organization @organization end |
#pod_subnet_start ⇒ Object
Start of range of Kubernetes pod IP subnets to use by Kubernetes clusters using this ACI CNI policy This should be a /8 IP subnet so that multiple /16 subnets can be assigned for pod subnets of Kubernetes clusters using this profile.
65 66 67 |
# File 'lib/intersight_client/models/kubernetes_aci_cni_profile.rb', line 65 def pod_subnet_start @pod_subnet_start end |
#registered_device ⇒ Object
Returns the value of attribute registered_device.
81 82 83 |
# File 'lib/intersight_client/models/kubernetes_aci_cni_profile.rb', line 81 def registered_device @registered_device end |
#svc_subnet_start ⇒ Object
Start of range of Kubernetes Service IP subnets to use by Kubernetes clusters using this ACI CNI policy Currently this is fixed internally and read-only.
68 69 70 |
# File 'lib/intersight_client/models/kubernetes_aci_cni_profile.rb', line 68 def svc_subnet_start @svc_subnet_start end |
#vrf ⇒ Object
VRF (Virtual Routing and Forwarding) domain to be used within ACI fabric by all k8s clusters using this policy.
71 72 73 |
# File 'lib/intersight_client/models/kubernetes_aci_cni_profile.rb', line 71 def vrf @vrf end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns the key-value map of all the JSON attributes this model knows about, including the ones defined in its parent(s)
139 140 141 |
# File 'lib/intersight_client/models/kubernetes_aci_cni_profile.rb', line 139 def self.acceptable_attribute_map attribute_map.merge(superclass.acceptable_attribute_map) end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about, including the ones defined in its parent(s)
134 135 136 |
# File 'lib/intersight_client/models/kubernetes_aci_cni_profile.rb', line 134 def self.acceptable_attributes attribute_map.values.concat(superclass.acceptable_attributes) end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 |
# File 'lib/intersight_client/models/kubernetes_aci_cni_profile.rb', line 106 def self.attribute_map { :'class_id' => :'ClassId', :'object_type' => :'ObjectType', :'aaep_name' => :'AaepName', :'ext_svc_dyn_subnet_start' => :'ExtSvcDynSubnetStart', :'ext_svc_static_subnet_start' => :'ExtSvcStaticSubnetStart', :'infra_vlan_id' => :'InfraVlanId', :'l3_out_network_name' => :'L3OutNetworkName', :'l3_out_policy_name' => :'L3OutPolicyName', :'l3_out_tenant' => :'L3OutTenant', :'nested_vmm_domain' => :'NestedVmmDomain', :'node_svc_subnet_start' => :'NodeSvcSubnetStart', :'node_vlan_range_end' => :'NodeVlanRangeEnd', :'node_vlan_range_start' => :'NodeVlanRangeStart', :'number_of_kubernetes_clusters' => :'NumberOfKubernetesClusters', :'opflex_multicast_address_range' => :'OpflexMulticastAddressRange', :'pod_subnet_start' => :'PodSubnetStart', :'svc_subnet_start' => :'SvcSubnetStart', :'vrf' => :'Vrf', :'cluster_aci_allocations' => :'ClusterAciAllocations', :'cluster_profiles' => :'ClusterProfiles', :'organization' => :'Organization', :'registered_device' => :'RegisteredDevice' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
602 603 604 |
# File 'lib/intersight_client/models/kubernetes_aci_cni_profile.rb', line 602 def self.build_from_hash(attributes) new.build_from_hash(attributes) end |
.openapi_all_of ⇒ Object
List of class defined in allOf (OpenAPI v3)
180 181 182 183 184 185 |
# File 'lib/intersight_client/models/kubernetes_aci_cni_profile.rb', line 180 def self.openapi_all_of [ :'KubernetesAciCniProfileAllOf', :'PolicyAbstractProfile' ] end |
.openapi_discriminator_name ⇒ Object
discriminator's property name in OpenAPI v3
188 189 190 |
# File 'lib/intersight_client/models/kubernetes_aci_cni_profile.rb', line 188 def self.openapi_discriminator_name :'ClassId' end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
172 173 174 175 176 177 |
# File 'lib/intersight_client/models/kubernetes_aci_cni_profile.rb', line 172 def self.openapi_nullable Set.new([ :'cluster_aci_allocations', :'cluster_profiles', ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 |
# File 'lib/intersight_client/models/kubernetes_aci_cni_profile.rb', line 144 def self.openapi_types { :'class_id' => :'String', :'object_type' => :'String', :'aaep_name' => :'String', :'ext_svc_dyn_subnet_start' => :'String', :'ext_svc_static_subnet_start' => :'String', :'infra_vlan_id' => :'Integer', :'l3_out_network_name' => :'String', :'l3_out_policy_name' => :'String', :'l3_out_tenant' => :'String', :'nested_vmm_domain' => :'String', :'node_svc_subnet_start' => :'String', :'node_vlan_range_end' => :'Integer', :'node_vlan_range_start' => :'Integer', :'number_of_kubernetes_clusters' => :'Integer', :'opflex_multicast_address_range' => :'String', :'pod_subnet_start' => :'String', :'svc_subnet_start' => :'String', :'vrf' => :'String', :'cluster_aci_allocations' => :'Array<KubernetesAciCniTenantClusterAllocationRelationship>', :'cluster_profiles' => :'Array<KubernetesClusterProfileRelationship>', :'organization' => :'OrganizationOrganizationRelationship', :'registered_device' => :'AssetDeviceRegistrationRelationship' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
560 561 562 563 564 565 566 567 568 569 570 571 572 573 574 575 576 577 578 579 580 581 582 583 584 585 |
# File 'lib/intersight_client/models/kubernetes_aci_cni_profile.rb', line 560 def ==(o) return true if self.equal?(o) self.class == o.class && class_id == o.class_id && object_type == o.object_type && aaep_name == o.aaep_name && ext_svc_dyn_subnet_start == o.ext_svc_dyn_subnet_start && ext_svc_static_subnet_start == o.ext_svc_static_subnet_start && infra_vlan_id == o.infra_vlan_id && l3_out_network_name == o.l3_out_network_name && l3_out_policy_name == o.l3_out_policy_name && l3_out_tenant == o.l3_out_tenant && nested_vmm_domain == o.nested_vmm_domain && node_svc_subnet_start == o.node_svc_subnet_start && node_vlan_range_end == o.node_vlan_range_end && node_vlan_range_start == o.node_vlan_range_start && number_of_kubernetes_clusters == o.number_of_kubernetes_clusters && opflex_multicast_address_range == o.opflex_multicast_address_range && pod_subnet_start == o.pod_subnet_start && svc_subnet_start == o.svc_subnet_start && vrf == o.vrf && cluster_aci_allocations == o.cluster_aci_allocations && cluster_profiles == o.cluster_profiles && organization == o.organization && registered_device == o.registered_device && super(o) end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
633 634 635 636 637 638 639 640 641 642 643 644 645 646 647 648 649 650 651 652 653 654 655 656 657 658 659 660 661 662 663 664 665 666 667 668 669 670 |
# File 'lib/intersight_client/models/kubernetes_aci_cni_profile.rb', line 633 def _deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = IntersightClient.const_get(type) klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
704 705 706 707 708 709 710 711 712 713 714 715 716 |
# File 'lib/intersight_client/models/kubernetes_aci_cni_profile.rb', line 704 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
609 610 611 612 613 614 615 616 617 618 619 620 621 622 623 624 625 626 627 |
# File 'lib/intersight_client/models/kubernetes_aci_cni_profile.rb', line 609 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) super(attributes) KubernetesAciCniProfile.openapi_types.each_pair do |key, type| if attributes[KubernetesAciCniProfile.attribute_map[key]].nil? && KubernetesAciCniProfile.openapi_nullable.include?(key) self.send("#{key}=", nil) elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[KubernetesAciCniProfile.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[KubernetesAciCniProfile.attribute_map[key]].map { |v| _deserialize($1, v) }) end elsif !attributes[KubernetesAciCniProfile.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[KubernetesAciCniProfile.attribute_map[key]])) end end self end |
#eql?(o) ⇒ Boolean
589 590 591 |
# File 'lib/intersight_client/models/kubernetes_aci_cni_profile.rb', line 589 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
595 596 597 |
# File 'lib/intersight_client/models/kubernetes_aci_cni_profile.rb', line 595 def hash [class_id, object_type, aaep_name, ext_svc_dyn_subnet_start, ext_svc_static_subnet_start, infra_vlan_id, l3_out_network_name, l3_out_policy_name, l3_out_tenant, nested_vmm_domain, node_svc_subnet_start, node_vlan_range_end, node_vlan_range_start, number_of_kubernetes_clusters, opflex_multicast_address_range, pod_subnet_start, svc_subnet_start, vrf, cluster_aci_allocations, cluster_profiles, organization, registered_device].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 |
# File 'lib/intersight_client/models/kubernetes_aci_cni_profile.rb', line 309 def list_invalid_properties invalid_properties = super if @class_id.nil? invalid_properties.push('invalid value for "class_id", class_id cannot be nil.') end if @object_type.nil? invalid_properties.push('invalid value for "object_type", object_type cannot be nil.') end pattern = Regexp.new(/^$|^[a-zA-Z0-9][a-zA-Z0-9\-_]*[a-zA-Z0-9]$/) if !@aaep_name.nil? && @aaep_name !~ pattern invalid_properties.push("invalid value for \"aaep_name\", must conform to the pattern #{pattern}.") end pattern = Regexp.new(/^$|^([1-9]|[1-9][0-9]|1[0-9][0-9]|2[0-4][0-9]|25[0-5]).([0-9]|[1-9][0-9]|1[0-9][0-9]|2[0-4][0-9]|25[0-5]).([0-9]|[1-9][0-9]|1[0-9][0-9]|2[0-4][0-9]|25[0-5]).([0-9]|[1-9][0-9]|1[0-9][0-9]|2[0-4][0-9]|25[0-5])\/([0-9]|[1-2][0-9]|3[0-2])$/) if !@ext_svc_dyn_subnet_start.nil? && @ext_svc_dyn_subnet_start !~ pattern invalid_properties.push("invalid value for \"ext_svc_dyn_subnet_start\", must conform to the pattern #{pattern}.") end pattern = Regexp.new(/^$|^([1-9]|[1-9][0-9]|1[0-9][0-9]|2[0-4][0-9]|25[0-5]).([0-9]|[1-9][0-9]|1[0-9][0-9]|2[0-4][0-9]|25[0-5]).([0-9]|[1-9][0-9]|1[0-9][0-9]|2[0-4][0-9]|25[0-5]).([0-9]|[1-9][0-9]|1[0-9][0-9]|2[0-4][0-9]|25[0-5])\/([0-9]|[1-2][0-9]|3[0-2])$/) if !@ext_svc_static_subnet_start.nil? && @ext_svc_static_subnet_start !~ pattern invalid_properties.push("invalid value for \"ext_svc_static_subnet_start\", must conform to the pattern #{pattern}.") end pattern = Regexp.new(/^$|^[a-zA-Z0-9][a-zA-Z0-9\-_]*[a-zA-Z0-9]$/) if !@l3_out_network_name.nil? && @l3_out_network_name !~ pattern invalid_properties.push("invalid value for \"l3_out_network_name\", must conform to the pattern #{pattern}.") end pattern = Regexp.new(/^$|^[a-zA-Z0-9][a-zA-Z0-9\-_]*[a-zA-Z0-9]$/) if !@l3_out_policy_name.nil? && @l3_out_policy_name !~ pattern invalid_properties.push("invalid value for \"l3_out_policy_name\", must conform to the pattern #{pattern}.") end pattern = Regexp.new(/^$|^[a-zA-Z0-9][a-zA-Z0-9\-_]*[a-zA-Z0-9]$/) if !@l3_out_tenant.nil? && @l3_out_tenant !~ pattern invalid_properties.push("invalid value for \"l3_out_tenant\", must conform to the pattern #{pattern}.") end pattern = Regexp.new(/^$|^[a-zA-Z0-9][a-zA-Z0-9\-_]*[a-zA-Z0-9]$/) if !@nested_vmm_domain.nil? && @nested_vmm_domain !~ pattern invalid_properties.push("invalid value for \"nested_vmm_domain\", must conform to the pattern #{pattern}.") end pattern = Regexp.new(/^$|^([1-9]|[1-9][0-9]|1[0-9][0-9]|2[0-4][0-9]|25[0-5]).([0-9]|[1-9][0-9]|1[0-9][0-9]|2[0-4][0-9]|25[0-5]).([0-9]|[1-9][0-9]|1[0-9][0-9]|2[0-4][0-9]|25[0-5]).([0-9]|[1-9][0-9]|1[0-9][0-9]|2[0-4][0-9]|25[0-5])\/([0-9]|[1-2][0-9]|3[0-2])$/) if !@node_svc_subnet_start.nil? && @node_svc_subnet_start !~ pattern invalid_properties.push("invalid value for \"node_svc_subnet_start\", must conform to the pattern #{pattern}.") end pattern = Regexp.new(/^$|^([1-9]|[1-9][0-9]|1[0-9][0-9]|2[0-4][0-9]|25[0-5]).([0-9]|[1-9][0-9]|1[0-9][0-9]|2[0-4][0-9]|25[0-5]).([0-9]|[1-9][0-9]|1[0-9][0-9]|2[0-4][0-9]|25[0-5]).([0-9]|[1-9][0-9]|1[0-9][0-9]|2[0-4][0-9]|25[0-5])\/([0-9]|[1-2][0-9]|3[0-2])$/) if !@opflex_multicast_address_range.nil? && @opflex_multicast_address_range !~ pattern invalid_properties.push("invalid value for \"opflex_multicast_address_range\", must conform to the pattern #{pattern}.") end pattern = Regexp.new(/^$|^([1-9]|[1-9][0-9]|1[0-9][0-9]|2[0-4][0-9]|25[0-5]).([0-9]|[1-9][0-9]|1[0-9][0-9]|2[0-4][0-9]|25[0-5]).([0-9]|[1-9][0-9]|1[0-9][0-9]|2[0-4][0-9]|25[0-5]).([0-9]|[1-9][0-9]|1[0-9][0-9]|2[0-4][0-9]|25[0-5])\/([0-9]|[1-2][0-9]|3[0-2])$/) if !@pod_subnet_start.nil? && @pod_subnet_start !~ pattern invalid_properties.push("invalid value for \"pod_subnet_start\", must conform to the pattern #{pattern}.") end pattern = Regexp.new(/^$|^([1-9]|[1-9][0-9]|1[0-9][0-9]|2[0-4][0-9]|25[0-5]).([0-9]|[1-9][0-9]|1[0-9][0-9]|2[0-4][0-9]|25[0-5]).([0-9]|[1-9][0-9]|1[0-9][0-9]|2[0-4][0-9]|25[0-5]).([0-9]|[1-9][0-9]|1[0-9][0-9]|2[0-4][0-9]|25[0-5])\/([0-9]|[1-2][0-9]|3[0-2])$/) if !@svc_subnet_start.nil? && @svc_subnet_start !~ pattern invalid_properties.push("invalid value for \"svc_subnet_start\", must conform to the pattern #{pattern}.") end pattern = Regexp.new(/^$|^[a-zA-Z0-9][a-zA-Z0-9\-_]*[a-zA-Z0-9]$/) if !@vrf.nil? && @vrf !~ pattern invalid_properties.push("invalid value for \"vrf\", must conform to the pattern #{pattern}.") end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
680 681 682 |
# File 'lib/intersight_client/models/kubernetes_aci_cni_profile.rb', line 680 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
686 687 688 689 690 691 692 693 694 695 696 697 698 |
# File 'lib/intersight_client/models/kubernetes_aci_cni_profile.rb', line 686 def to_hash hash = super KubernetesAciCniProfile.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = KubernetesAciCniProfile.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
674 675 676 |
# File 'lib/intersight_client/models/kubernetes_aci_cni_profile.rb', line 674 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 |
# File 'lib/intersight_client/models/kubernetes_aci_cni_profile.rb', line 384 def valid? return false if @class_id.nil? class_id_validator = EnumAttributeValidator.new('String', ["kubernetes.AciCniProfile"]) return false unless class_id_validator.valid?(@class_id) return false if @object_type.nil? object_type_validator = EnumAttributeValidator.new('String', ["kubernetes.AciCniProfile"]) return false unless object_type_validator.valid?(@object_type) return false if !@aaep_name.nil? && @aaep_name !~ Regexp.new(/^$|^[a-zA-Z0-9][a-zA-Z0-9\-_]*[a-zA-Z0-9]$/) return false if !@ext_svc_dyn_subnet_start.nil? && @ext_svc_dyn_subnet_start !~ Regexp.new(/^$|^([1-9]|[1-9][0-9]|1[0-9][0-9]|2[0-4][0-9]|25[0-5]).([0-9]|[1-9][0-9]|1[0-9][0-9]|2[0-4][0-9]|25[0-5]).([0-9]|[1-9][0-9]|1[0-9][0-9]|2[0-4][0-9]|25[0-5]).([0-9]|[1-9][0-9]|1[0-9][0-9]|2[0-4][0-9]|25[0-5])\/([0-9]|[1-2][0-9]|3[0-2])$/) return false if !@ext_svc_static_subnet_start.nil? && @ext_svc_static_subnet_start !~ Regexp.new(/^$|^([1-9]|[1-9][0-9]|1[0-9][0-9]|2[0-4][0-9]|25[0-5]).([0-9]|[1-9][0-9]|1[0-9][0-9]|2[0-4][0-9]|25[0-5]).([0-9]|[1-9][0-9]|1[0-9][0-9]|2[0-4][0-9]|25[0-5]).([0-9]|[1-9][0-9]|1[0-9][0-9]|2[0-4][0-9]|25[0-5])\/([0-9]|[1-2][0-9]|3[0-2])$/) return false if !@l3_out_network_name.nil? && @l3_out_network_name !~ Regexp.new(/^$|^[a-zA-Z0-9][a-zA-Z0-9\-_]*[a-zA-Z0-9]$/) return false if !@l3_out_policy_name.nil? && @l3_out_policy_name !~ Regexp.new(/^$|^[a-zA-Z0-9][a-zA-Z0-9\-_]*[a-zA-Z0-9]$/) return false if !@l3_out_tenant.nil? && @l3_out_tenant !~ Regexp.new(/^$|^[a-zA-Z0-9][a-zA-Z0-9\-_]*[a-zA-Z0-9]$/) return false if !@nested_vmm_domain.nil? && @nested_vmm_domain !~ Regexp.new(/^$|^[a-zA-Z0-9][a-zA-Z0-9\-_]*[a-zA-Z0-9]$/) return false if !@node_svc_subnet_start.nil? && @node_svc_subnet_start !~ Regexp.new(/^$|^([1-9]|[1-9][0-9]|1[0-9][0-9]|2[0-4][0-9]|25[0-5]).([0-9]|[1-9][0-9]|1[0-9][0-9]|2[0-4][0-9]|25[0-5]).([0-9]|[1-9][0-9]|1[0-9][0-9]|2[0-4][0-9]|25[0-5]).([0-9]|[1-9][0-9]|1[0-9][0-9]|2[0-4][0-9]|25[0-5])\/([0-9]|[1-2][0-9]|3[0-2])$/) return false if !@opflex_multicast_address_range.nil? && @opflex_multicast_address_range !~ Regexp.new(/^$|^([1-9]|[1-9][0-9]|1[0-9][0-9]|2[0-4][0-9]|25[0-5]).([0-9]|[1-9][0-9]|1[0-9][0-9]|2[0-4][0-9]|25[0-5]).([0-9]|[1-9][0-9]|1[0-9][0-9]|2[0-4][0-9]|25[0-5]).([0-9]|[1-9][0-9]|1[0-9][0-9]|2[0-4][0-9]|25[0-5])\/([0-9]|[1-2][0-9]|3[0-2])$/) return false if !@pod_subnet_start.nil? && @pod_subnet_start !~ Regexp.new(/^$|^([1-9]|[1-9][0-9]|1[0-9][0-9]|2[0-4][0-9]|25[0-5]).([0-9]|[1-9][0-9]|1[0-9][0-9]|2[0-4][0-9]|25[0-5]).([0-9]|[1-9][0-9]|1[0-9][0-9]|2[0-4][0-9]|25[0-5]).([0-9]|[1-9][0-9]|1[0-9][0-9]|2[0-4][0-9]|25[0-5])\/([0-9]|[1-2][0-9]|3[0-2])$/) return false if !@svc_subnet_start.nil? && @svc_subnet_start !~ Regexp.new(/^$|^([1-9]|[1-9][0-9]|1[0-9][0-9]|2[0-4][0-9]|25[0-5]).([0-9]|[1-9][0-9]|1[0-9][0-9]|2[0-4][0-9]|25[0-5]).([0-9]|[1-9][0-9]|1[0-9][0-9]|2[0-4][0-9]|25[0-5]).([0-9]|[1-9][0-9]|1[0-9][0-9]|2[0-4][0-9]|25[0-5])\/([0-9]|[1-2][0-9]|3[0-2])$/) return false if !@vrf.nil? && @vrf !~ Regexp.new(/^$|^[a-zA-Z0-9][a-zA-Z0-9\-_]*[a-zA-Z0-9]$/) true && super end |