Method: IntersightClient::MemoryPersistentMemoryConfiguration#class_id
- Defined in:
- lib/intersight_client/models/memory_persistent_memory_configuration.rb
#class_id ⇒ Object
The fully-qualified name of the instantiated, concrete type. This property is used as a discriminator to identify the type of the payload when marshaling and unmarshaling data.
20 21 22 |
# File 'lib/intersight_client/models/memory_persistent_memory_configuration.rb', line 20 def class_id @class_id end |