Class: IntersightClient::NiatelemetryNiaInventoryFabric
- Defined in:
- lib/intersight_client/models/niatelemetry_nia_inventory_fabric.rb
Overview
Inventory Object available for Fabric-scoped attributes.
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#anycast_gw_mac ⇒ Object
Returns the aycast gateway mac.
-
#bgp_established_interface_count ⇒ Object
Counts the number of BGP interfaces that are in established state.
-
#bgw_interface_up_count ⇒ Object
Count number of active interfaces on border gateways.
-
#border_gateway_spine_count ⇒ Object
Count number of border gateway spines in the fabric inventory.
-
#border_leaf_count ⇒ Object
Count number of border leafs in the fabric inventory.
-
#class_id ⇒ Object
The fully-qualified name of the instantiated, concrete type.
-
#dci_subnet_range ⇒ Object
Returns the dci subnet range.
-
#dci_subnet_target_mask ⇒ Object
Returns the dci subnet target mask.
-
#dcnmtracker_enabled ⇒ Object
Returns the value of the dcnmtrackerEnabled field.
-
#ebgp_evpn_link_up_count ⇒ Object
Count number of ebgp evpn active interfaces.
-
#fabric_id ⇒ Object
Uniquely identifies a fabric.
-
#fabric_name ⇒ Object
Returns the value of the Name of a fabric.
-
#is_bgw_present ⇒ Object
Checks if border gateway is present in the fabric inventory.
-
#is_ngoam_enabled ⇒ Object
Returns if ngoam is enabled.
-
#is_scheduled_back_up_enabled ⇒ Object
Returns if the scheduled backup is enabled.
-
#leaf_count ⇒ Object
Returns total number of leafs in the fabric.
-
#logical_links ⇒ Object
Returns the value of attribute logical_links.
-
#nxos_vni_bw_sites_count ⇒ Object
Returns the count of vnis between sites.
-
#nxos_vrf_bw_sites_count ⇒ Object
Returns the count of vrfs between sites.
-
#nxos_vrf_count ⇒ Object
Returns the value of the nxosVrfCount field.
-
#object_type ⇒ Object
The fully-qualified name of the instantiated, concrete type.
-
#registered_device ⇒ Object
Returns the value of attribute registered_device.
-
#serial ⇒ Object
Serial number of device being inventoried.
-
#site_name ⇒ Object
Name of fabric domain of the controller.
-
#spine_count ⇒ Object
Returns total number of spines in the fabric.
-
#vlan_vni_mappings ⇒ Object
VLAN to VNI mappings configured in the DCNM.
-
#vni_ip_count ⇒ Object
Count number of IP addresses configured in the DCNM networks.
Attributes inherited from MoBaseMo
#account_moid, #ancestors, #create_time, #display_names, #domain_group_moid, #mod_time, #moid, #owners, #parent, #permission_resources, #shared_scope, #tags, #version_context
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns the key-value map of all the JSON attributes this model knows about, including the ones defined in its parent(s).
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about, including the ones defined in its parent(s).
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_all_of ⇒ Object
List of class defined in allOf (OpenAPI v3).
-
.openapi_discriminator_name ⇒ Object
discriminator's property name in OpenAPI v3.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ NiatelemetryNiaInventoryFabric
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ NiatelemetryNiaInventoryFabric
Initializes the object
218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 |
# File 'lib/intersight_client/models/niatelemetry_nia_inventory_fabric.rb', line 218 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `IntersightClient::NiatelemetryNiaInventoryFabric` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `#{self.class.name}`. Please check the name to make sure it's valid. List of attributes: " + self.class.acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } # call parent's initialize super(attributes) if attributes.key?(:'class_id') self.class_id = attributes[:'class_id'] else self.class_id = 'niatelemetry.NiaInventoryFabric' end if attributes.key?(:'object_type') self.object_type = attributes[:'object_type'] else self.object_type = 'niatelemetry.NiaInventoryFabric' end if attributes.key?(:'anycast_gw_mac') self.anycast_gw_mac = attributes[:'anycast_gw_mac'] end if attributes.key?(:'bgp_established_interface_count') self.bgp_established_interface_count = attributes[:'bgp_established_interface_count'] end if attributes.key?(:'bgw_interface_up_count') self.bgw_interface_up_count = attributes[:'bgw_interface_up_count'] end if attributes.key?(:'border_gateway_spine_count') self.border_gateway_spine_count = attributes[:'border_gateway_spine_count'] end if attributes.key?(:'border_leaf_count') self.border_leaf_count = attributes[:'border_leaf_count'] end if attributes.key?(:'dci_subnet_range') self.dci_subnet_range = attributes[:'dci_subnet_range'] end if attributes.key?(:'dci_subnet_target_mask') self.dci_subnet_target_mask = attributes[:'dci_subnet_target_mask'] end if attributes.key?(:'dcnmtracker_enabled') self.dcnmtracker_enabled = attributes[:'dcnmtracker_enabled'] end if attributes.key?(:'ebgp_evpn_link_up_count') self.ebgp_evpn_link_up_count = attributes[:'ebgp_evpn_link_up_count'] end if attributes.key?(:'fabric_id') self.fabric_id = attributes[:'fabric_id'] end if attributes.key?(:'fabric_name') self.fabric_name = attributes[:'fabric_name'] end if attributes.key?(:'is_bgw_present') self.is_bgw_present = attributes[:'is_bgw_present'] end if attributes.key?(:'is_ngoam_enabled') self.is_ngoam_enabled = attributes[:'is_ngoam_enabled'] end if attributes.key?(:'is_scheduled_back_up_enabled') self.is_scheduled_back_up_enabled = attributes[:'is_scheduled_back_up_enabled'] end if attributes.key?(:'leaf_count') self.leaf_count = attributes[:'leaf_count'] end if attributes.key?(:'logical_links') if (value = attributes[:'logical_links']).is_a?(Array) self.logical_links = value end end if attributes.key?(:'nxos_vni_bw_sites_count') self.nxos_vni_bw_sites_count = attributes[:'nxos_vni_bw_sites_count'] end if attributes.key?(:'nxos_vrf_bw_sites_count') self.nxos_vrf_bw_sites_count = attributes[:'nxos_vrf_bw_sites_count'] end if attributes.key?(:'nxos_vrf_count') self.nxos_vrf_count = attributes[:'nxos_vrf_count'] end if attributes.key?(:'serial') self.serial = attributes[:'serial'] end if attributes.key?(:'site_name') self.site_name = attributes[:'site_name'] end if attributes.key?(:'spine_count') self.spine_count = attributes[:'spine_count'] end if attributes.key?(:'vlan_vni_mappings') self.vlan_vni_mappings = attributes[:'vlan_vni_mappings'] end if attributes.key?(:'vni_ip_count') self.vni_ip_count = attributes[:'vni_ip_count'] end if attributes.key?(:'registered_device') self.registered_device = attributes[:'registered_device'] end end |
Instance Attribute Details
#anycast_gw_mac ⇒ Object
Returns the aycast gateway mac.
26 27 28 |
# File 'lib/intersight_client/models/niatelemetry_nia_inventory_fabric.rb', line 26 def anycast_gw_mac @anycast_gw_mac end |
#bgp_established_interface_count ⇒ Object
Counts the number of BGP interfaces that are in established state.
29 30 31 |
# File 'lib/intersight_client/models/niatelemetry_nia_inventory_fabric.rb', line 29 def bgp_established_interface_count @bgp_established_interface_count end |
#bgw_interface_up_count ⇒ Object
Count number of active interfaces on border gateways.
32 33 34 |
# File 'lib/intersight_client/models/niatelemetry_nia_inventory_fabric.rb', line 32 def bgw_interface_up_count @bgw_interface_up_count end |
#border_gateway_spine_count ⇒ Object
Count number of border gateway spines in the fabric inventory.
35 36 37 |
# File 'lib/intersight_client/models/niatelemetry_nia_inventory_fabric.rb', line 35 def border_gateway_spine_count @border_gateway_spine_count end |
#border_leaf_count ⇒ Object
Count number of border leafs in the fabric inventory.
38 39 40 |
# File 'lib/intersight_client/models/niatelemetry_nia_inventory_fabric.rb', line 38 def border_leaf_count @border_leaf_count end |
#class_id ⇒ Object
The fully-qualified name of the instantiated, concrete type. This property is used as a discriminator to identify the type of the payload when marshaling and unmarshaling data.
20 21 22 |
# File 'lib/intersight_client/models/niatelemetry_nia_inventory_fabric.rb', line 20 def class_id @class_id end |
#dci_subnet_range ⇒ Object
Returns the dci subnet range.
41 42 43 |
# File 'lib/intersight_client/models/niatelemetry_nia_inventory_fabric.rb', line 41 def dci_subnet_range @dci_subnet_range end |
#dci_subnet_target_mask ⇒ Object
Returns the dci subnet target mask.
44 45 46 |
# File 'lib/intersight_client/models/niatelemetry_nia_inventory_fabric.rb', line 44 def dci_subnet_target_mask @dci_subnet_target_mask end |
#dcnmtracker_enabled ⇒ Object
Returns the value of the dcnmtrackerEnabled field.
47 48 49 |
# File 'lib/intersight_client/models/niatelemetry_nia_inventory_fabric.rb', line 47 def dcnmtracker_enabled @dcnmtracker_enabled end |
#ebgp_evpn_link_up_count ⇒ Object
Count number of ebgp evpn active interfaces.
50 51 52 |
# File 'lib/intersight_client/models/niatelemetry_nia_inventory_fabric.rb', line 50 def ebgp_evpn_link_up_count @ebgp_evpn_link_up_count end |
#fabric_id ⇒ Object
Uniquely identifies a fabric.
53 54 55 |
# File 'lib/intersight_client/models/niatelemetry_nia_inventory_fabric.rb', line 53 def fabric_id @fabric_id end |
#fabric_name ⇒ Object
Returns the value of the Name of a fabric.
56 57 58 |
# File 'lib/intersight_client/models/niatelemetry_nia_inventory_fabric.rb', line 56 def fabric_name @fabric_name end |
#is_bgw_present ⇒ Object
Checks if border gateway is present in the fabric inventory.
59 60 61 |
# File 'lib/intersight_client/models/niatelemetry_nia_inventory_fabric.rb', line 59 def is_bgw_present @is_bgw_present end |
#is_ngoam_enabled ⇒ Object
Returns if ngoam is enabled.
62 63 64 |
# File 'lib/intersight_client/models/niatelemetry_nia_inventory_fabric.rb', line 62 def is_ngoam_enabled @is_ngoam_enabled end |
#is_scheduled_back_up_enabled ⇒ Object
Returns if the scheduled backup is enabled.
65 66 67 |
# File 'lib/intersight_client/models/niatelemetry_nia_inventory_fabric.rb', line 65 def is_scheduled_back_up_enabled @is_scheduled_back_up_enabled end |
#leaf_count ⇒ Object
Returns total number of leafs in the fabric.
68 69 70 |
# File 'lib/intersight_client/models/niatelemetry_nia_inventory_fabric.rb', line 68 def leaf_count @leaf_count end |
#logical_links ⇒ Object
Returns the value of attribute logical_links.
70 71 72 |
# File 'lib/intersight_client/models/niatelemetry_nia_inventory_fabric.rb', line 70 def logical_links @logical_links end |
#nxos_vni_bw_sites_count ⇒ Object
Returns the count of vnis between sites.
73 74 75 |
# File 'lib/intersight_client/models/niatelemetry_nia_inventory_fabric.rb', line 73 def nxos_vni_bw_sites_count @nxos_vni_bw_sites_count end |
#nxos_vrf_bw_sites_count ⇒ Object
Returns the count of vrfs between sites.
76 77 78 |
# File 'lib/intersight_client/models/niatelemetry_nia_inventory_fabric.rb', line 76 def nxos_vrf_bw_sites_count @nxos_vrf_bw_sites_count end |
#nxos_vrf_count ⇒ Object
Returns the value of the nxosVrfCount field.
79 80 81 |
# File 'lib/intersight_client/models/niatelemetry_nia_inventory_fabric.rb', line 79 def nxos_vrf_count @nxos_vrf_count end |
#object_type ⇒ Object
The fully-qualified name of the instantiated, concrete type. The value should be the same as the 'ClassId' property.
23 24 25 |
# File 'lib/intersight_client/models/niatelemetry_nia_inventory_fabric.rb', line 23 def object_type @object_type end |
#registered_device ⇒ Object
Returns the value of attribute registered_device.
96 97 98 |
# File 'lib/intersight_client/models/niatelemetry_nia_inventory_fabric.rb', line 96 def registered_device @registered_device end |
#serial ⇒ Object
Serial number of device being inventoried. The serial number is unique per device.
82 83 84 |
# File 'lib/intersight_client/models/niatelemetry_nia_inventory_fabric.rb', line 82 def serial @serial end |
#site_name ⇒ Object
Name of fabric domain of the controller.
85 86 87 |
# File 'lib/intersight_client/models/niatelemetry_nia_inventory_fabric.rb', line 85 def site_name @site_name end |
#spine_count ⇒ Object
Returns total number of spines in the fabric.
88 89 90 |
# File 'lib/intersight_client/models/niatelemetry_nia_inventory_fabric.rb', line 88 def spine_count @spine_count end |
#vlan_vni_mappings ⇒ Object
VLAN to VNI mappings configured in the DCNM.
91 92 93 |
# File 'lib/intersight_client/models/niatelemetry_nia_inventory_fabric.rb', line 91 def vlan_vni_mappings @vlan_vni_mappings end |
#vni_ip_count ⇒ Object
Count number of IP addresses configured in the DCNM networks.
94 95 96 |
# File 'lib/intersight_client/models/niatelemetry_nia_inventory_fabric.rb', line 94 def vni_ip_count @vni_ip_count end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns the key-value map of all the JSON attributes this model knows about, including the ones defined in its parent(s)
159 160 161 |
# File 'lib/intersight_client/models/niatelemetry_nia_inventory_fabric.rb', line 159 def self.acceptable_attribute_map attribute_map.merge(superclass.acceptable_attribute_map) end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about, including the ones defined in its parent(s)
154 155 156 |
# File 'lib/intersight_client/models/niatelemetry_nia_inventory_fabric.rb', line 154 def self.acceptable_attributes attribute_map.values.concat(superclass.acceptable_attributes) end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 |
# File 'lib/intersight_client/models/niatelemetry_nia_inventory_fabric.rb', line 121 def self.attribute_map { :'class_id' => :'ClassId', :'object_type' => :'ObjectType', :'anycast_gw_mac' => :'AnycastGwMac', :'bgp_established_interface_count' => :'BgpEstablishedInterfaceCount', :'bgw_interface_up_count' => :'BgwInterfaceUpCount', :'border_gateway_spine_count' => :'BorderGatewaySpineCount', :'border_leaf_count' => :'BorderLeafCount', :'dci_subnet_range' => :'DciSubnetRange', :'dci_subnet_target_mask' => :'DciSubnetTargetMask', :'dcnmtracker_enabled' => :'DcnmtrackerEnabled', :'ebgp_evpn_link_up_count' => :'EbgpEvpnLinkUpCount', :'fabric_id' => :'FabricId', :'fabric_name' => :'FabricName', :'is_bgw_present' => :'IsBgwPresent', :'is_ngoam_enabled' => :'IsNgoamEnabled', :'is_scheduled_back_up_enabled' => :'IsScheduledBackUpEnabled', :'leaf_count' => :'LeafCount', :'logical_links' => :'LogicalLinks', :'nxos_vni_bw_sites_count' => :'NxosVniBwSitesCount', :'nxos_vrf_bw_sites_count' => :'NxosVrfBwSitesCount', :'nxos_vrf_count' => :'NxosVrfCount', :'serial' => :'Serial', :'site_name' => :'SiteName', :'spine_count' => :'SpineCount', :'vlan_vni_mappings' => :'VlanVniMappings', :'vni_ip_count' => :'VniIpCount', :'registered_device' => :'RegisteredDevice' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
445 446 447 |
# File 'lib/intersight_client/models/niatelemetry_nia_inventory_fabric.rb', line 445 def self.build_from_hash(attributes) new.build_from_hash(attributes) end |
.openapi_all_of ⇒ Object
List of class defined in allOf (OpenAPI v3)
204 205 206 207 208 209 |
# File 'lib/intersight_client/models/niatelemetry_nia_inventory_fabric.rb', line 204 def self.openapi_all_of [ :'MoBaseMo', :'NiatelemetryNiaInventoryFabricAllOf' ] end |
.openapi_discriminator_name ⇒ Object
discriminator's property name in OpenAPI v3
212 213 214 |
# File 'lib/intersight_client/models/niatelemetry_nia_inventory_fabric.rb', line 212 def self.openapi_discriminator_name :'ClassId' end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
197 198 199 200 201 |
# File 'lib/intersight_client/models/niatelemetry_nia_inventory_fabric.rb', line 197 def self.openapi_nullable Set.new([ :'logical_links', ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 |
# File 'lib/intersight_client/models/niatelemetry_nia_inventory_fabric.rb', line 164 def self.openapi_types { :'class_id' => :'String', :'object_type' => :'String', :'anycast_gw_mac' => :'String', :'bgp_established_interface_count' => :'Integer', :'bgw_interface_up_count' => :'Integer', :'border_gateway_spine_count' => :'Integer', :'border_leaf_count' => :'Integer', :'dci_subnet_range' => :'String', :'dci_subnet_target_mask' => :'String', :'dcnmtracker_enabled' => :'Boolean', :'ebgp_evpn_link_up_count' => :'Integer', :'fabric_id' => :'String', :'fabric_name' => :'String', :'is_bgw_present' => :'Boolean', :'is_ngoam_enabled' => :'Boolean', :'is_scheduled_back_up_enabled' => :'Boolean', :'leaf_count' => :'Integer', :'logical_links' => :'Array<NiatelemetryLogicalLink>', :'nxos_vni_bw_sites_count' => :'Integer', :'nxos_vrf_bw_sites_count' => :'Integer', :'nxos_vrf_count' => :'Integer', :'serial' => :'String', :'site_name' => :'String', :'spine_count' => :'Integer', :'vlan_vni_mappings' => :'String', :'vni_ip_count' => :'Integer', :'registered_device' => :'AssetDeviceRegistrationRelationship' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 |
# File 'lib/intersight_client/models/niatelemetry_nia_inventory_fabric.rb', line 398 def ==(o) return true if self.equal?(o) self.class == o.class && class_id == o.class_id && object_type == o.object_type && anycast_gw_mac == o.anycast_gw_mac && bgp_established_interface_count == o.bgp_established_interface_count && bgw_interface_up_count == o.bgw_interface_up_count && border_gateway_spine_count == o.border_gateway_spine_count && border_leaf_count == o.border_leaf_count && dci_subnet_range == o.dci_subnet_range && dci_subnet_target_mask == o.dci_subnet_target_mask && dcnmtracker_enabled == o.dcnmtracker_enabled && ebgp_evpn_link_up_count == o.ebgp_evpn_link_up_count && fabric_id == o.fabric_id && fabric_name == o.fabric_name && is_bgw_present == o.is_bgw_present && is_ngoam_enabled == o.is_ngoam_enabled && is_scheduled_back_up_enabled == o.is_scheduled_back_up_enabled && leaf_count == o.leaf_count && logical_links == o.logical_links && nxos_vni_bw_sites_count == o.nxos_vni_bw_sites_count && nxos_vrf_bw_sites_count == o.nxos_vrf_bw_sites_count && nxos_vrf_count == o.nxos_vrf_count && serial == o.serial && site_name == o.site_name && spine_count == o.spine_count && vlan_vni_mappings == o.vlan_vni_mappings && vni_ip_count == o.vni_ip_count && registered_device == o.registered_device && super(o) end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
476 477 478 479 480 481 482 483 484 485 486 487 488 489 490 491 492 493 494 495 496 497 498 499 500 501 502 503 504 505 506 507 508 509 510 511 512 513 |
# File 'lib/intersight_client/models/niatelemetry_nia_inventory_fabric.rb', line 476 def _deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = IntersightClient.const_get(type) klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
547 548 549 550 551 552 553 554 555 556 557 558 559 |
# File 'lib/intersight_client/models/niatelemetry_nia_inventory_fabric.rb', line 547 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
452 453 454 455 456 457 458 459 460 461 462 463 464 465 466 467 468 469 470 |
# File 'lib/intersight_client/models/niatelemetry_nia_inventory_fabric.rb', line 452 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) super(attributes) NiatelemetryNiaInventoryFabric.openapi_types.each_pair do |key, type| if attributes[NiatelemetryNiaInventoryFabric.attribute_map[key]].nil? && NiatelemetryNiaInventoryFabric.openapi_nullable.include?(key) self.send("#{key}=", nil) elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[NiatelemetryNiaInventoryFabric.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[NiatelemetryNiaInventoryFabric.attribute_map[key]].map { |v| _deserialize($1, v) }) end elsif !attributes[NiatelemetryNiaInventoryFabric.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[NiatelemetryNiaInventoryFabric.attribute_map[key]])) end end self end |
#eql?(o) ⇒ Boolean
432 433 434 |
# File 'lib/intersight_client/models/niatelemetry_nia_inventory_fabric.rb', line 432 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
438 439 440 |
# File 'lib/intersight_client/models/niatelemetry_nia_inventory_fabric.rb', line 438 def hash [class_id, object_type, anycast_gw_mac, bgp_established_interface_count, bgw_interface_up_count, border_gateway_spine_count, border_leaf_count, dci_subnet_range, dci_subnet_target_mask, dcnmtracker_enabled, ebgp_evpn_link_up_count, fabric_id, fabric_name, is_bgw_present, is_ngoam_enabled, is_scheduled_back_up_enabled, leaf_count, logical_links, nxos_vni_bw_sites_count, nxos_vrf_bw_sites_count, nxos_vrf_count, serial, site_name, spine_count, vlan_vni_mappings, vni_ip_count, registered_device].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
351 352 353 354 355 356 357 358 359 360 361 362 |
# File 'lib/intersight_client/models/niatelemetry_nia_inventory_fabric.rb', line 351 def list_invalid_properties invalid_properties = super if @class_id.nil? invalid_properties.push('invalid value for "class_id", class_id cannot be nil.') end if @object_type.nil? invalid_properties.push('invalid value for "object_type", object_type cannot be nil.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
523 524 525 |
# File 'lib/intersight_client/models/niatelemetry_nia_inventory_fabric.rb', line 523 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
529 530 531 532 533 534 535 536 537 538 539 540 541 |
# File 'lib/intersight_client/models/niatelemetry_nia_inventory_fabric.rb', line 529 def to_hash hash = super NiatelemetryNiaInventoryFabric.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = NiatelemetryNiaInventoryFabric.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
517 518 519 |
# File 'lib/intersight_client/models/niatelemetry_nia_inventory_fabric.rb', line 517 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
366 367 368 369 370 371 372 373 374 |
# File 'lib/intersight_client/models/niatelemetry_nia_inventory_fabric.rb', line 366 def valid? return false if @class_id.nil? class_id_validator = EnumAttributeValidator.new('String', ["niatelemetry.NiaInventoryFabric"]) return false unless class_id_validator.valid?(@class_id) return false if @object_type.nil? object_type_validator = EnumAttributeValidator.new('String', ["niatelemetry.NiaInventoryFabric"]) return false unless object_type_validator.valid?(@object_type) true && super end |