Class: IntersightClient::StorageDriveGroupAllOf
- Inherits:
-
Object
- Object
- IntersightClient::StorageDriveGroupAllOf
- Defined in:
- lib/intersight_client/models/storage_drive_group_all_of.rb
Overview
Definition of the list of properties defined in ‘storage.DriveGroup’, excluding properties defined in parent classes.
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#automatic_drive_group ⇒ Object
Returns the value of attribute automatic_drive_group.
-
#class_id ⇒ Object
The fully-qualified name of the instantiated, concrete type.
-
#manual_drive_group ⇒ Object
Returns the value of attribute manual_drive_group.
-
#name ⇒ Object
The name of the drive group.
-
#object_type ⇒ Object
The fully-qualified name of the instantiated, concrete type.
-
#raid_level ⇒ Object
The supported RAID level for the disk group.
-
#storage_policy ⇒ Object
Returns the value of attribute storage_policy.
-
#type ⇒ Object
Type of drive selection to be used for this drive group.
-
#virtual_drives ⇒ Object
Returns the value of attribute virtual_drives.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns the key-value map of all the JSON attributes this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ StorageDriveGroupAllOf
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ StorageDriveGroupAllOf
Initializes the object
115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 |
# File 'lib/intersight_client/models/storage_drive_group_all_of.rb', line 115 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `IntersightClient::StorageDriveGroupAllOf` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `#{self.class.name}`. Please check the name to make sure it's valid. List of attributes: " + self.class.acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'class_id') self.class_id = attributes[:'class_id'] else self.class_id = 'storage.DriveGroup' end if attributes.key?(:'object_type') self.object_type = attributes[:'object_type'] else self.object_type = 'storage.DriveGroup' end if attributes.key?(:'automatic_drive_group') self.automatic_drive_group = attributes[:'automatic_drive_group'] end if attributes.key?(:'manual_drive_group') self.manual_drive_group = attributes[:'manual_drive_group'] end if attributes.key?(:'name') self.name = attributes[:'name'] end if attributes.key?(:'raid_level') self.raid_level = attributes[:'raid_level'] else self.raid_level = 'Raid0' end if attributes.key?(:'type') self.type = attributes[:'type'] else self.type = TYPE::N0 end if attributes.key?(:'virtual_drives') if (value = attributes[:'virtual_drives']).is_a?(Array) self.virtual_drives = value end end if attributes.key?(:'storage_policy') self.storage_policy = attributes[:'storage_policy'] end end |
Instance Attribute Details
#automatic_drive_group ⇒ Object
Returns the value of attribute automatic_drive_group.
25 26 27 |
# File 'lib/intersight_client/models/storage_drive_group_all_of.rb', line 25 def automatic_drive_group @automatic_drive_group end |
#class_id ⇒ Object
The fully-qualified name of the instantiated, concrete type. This property is used as a discriminator to identify the type of the payload when marshaling and unmarshaling data.
20 21 22 |
# File 'lib/intersight_client/models/storage_drive_group_all_of.rb', line 20 def class_id @class_id end |
#manual_drive_group ⇒ Object
Returns the value of attribute manual_drive_group.
27 28 29 |
# File 'lib/intersight_client/models/storage_drive_group_all_of.rb', line 27 def manual_drive_group @manual_drive_group end |
#name ⇒ Object
The name of the drive group. The name can be between 1 and 15 alphanumeric characters. Spaces or any special characters other than - (hyphen), _ (underscore), : (colon), and . (period) are not allowed.
30 31 32 |
# File 'lib/intersight_client/models/storage_drive_group_all_of.rb', line 30 def name @name end |
#object_type ⇒ Object
The fully-qualified name of the instantiated, concrete type. The value should be the same as the ‘ClassId’ property.
23 24 25 |
# File 'lib/intersight_client/models/storage_drive_group_all_of.rb', line 23 def object_type @object_type end |
#raid_level ⇒ Object
The supported RAID level for the disk group. * Raid0 - RAID 0 Stripe Raid Level. * Raid1 - RAID 1 Mirror Raid Level. * Raid5 - RAID 5 Mirror Raid Level. * Raid6 - RAID 6 Mirror Raid Level. * Raid10 - RAID 10 Mirror Raid Level. * Raid50 - RAID 50 Mirror Raid Level. * Raid60 - RAID 60 Mirror Raid Level.
33 34 35 |
# File 'lib/intersight_client/models/storage_drive_group_all_of.rb', line 33 def raid_level @raid_level end |
#storage_policy ⇒ Object
Returns the value of attribute storage_policy.
40 41 42 |
# File 'lib/intersight_client/models/storage_drive_group_all_of.rb', line 40 def storage_policy @storage_policy end |
#type ⇒ Object
Type of drive selection to be used for this drive group. * 0 - Drives are selected manually by the user. * 1 - Drives are selected automatically based on the RAID and virtual drive configuration.
36 37 38 |
# File 'lib/intersight_client/models/storage_drive_group_all_of.rb', line 36 def type @type end |
#virtual_drives ⇒ Object
Returns the value of attribute virtual_drives.
38 39 40 |
# File 'lib/intersight_client/models/storage_drive_group_all_of.rb', line 38 def virtual_drives @virtual_drives end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns the key-value map of all the JSON attributes this model knows about
85 86 87 |
# File 'lib/intersight_client/models/storage_drive_group_all_of.rb', line 85 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
80 81 82 |
# File 'lib/intersight_client/models/storage_drive_group_all_of.rb', line 80 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
65 66 67 68 69 70 71 72 73 74 75 76 77 |
# File 'lib/intersight_client/models/storage_drive_group_all_of.rb', line 65 def self.attribute_map { :'class_id' => :'ClassId', :'object_type' => :'ObjectType', :'automatic_drive_group' => :'AutomaticDriveGroup', :'manual_drive_group' => :'ManualDriveGroup', :'name' => :'Name', :'raid_level' => :'RaidLevel', :'type' => :'Type', :'virtual_drives' => :'VirtualDrives', :'storage_policy' => :'StoragePolicy' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
294 295 296 |
# File 'lib/intersight_client/models/storage_drive_group_all_of.rb', line 294 def self.build_from_hash(attributes) new.build_from_hash(attributes) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
105 106 107 108 109 110 111 |
# File 'lib/intersight_client/models/storage_drive_group_all_of.rb', line 105 def self.openapi_nullable Set.new([ :'automatic_drive_group', :'manual_drive_group', :'virtual_drives', ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
90 91 92 93 94 95 96 97 98 99 100 101 102 |
# File 'lib/intersight_client/models/storage_drive_group_all_of.rb', line 90 def self.openapi_types { :'class_id' => :'String', :'object_type' => :'String', :'automatic_drive_group' => :'StorageAutomaticDriveGroup', :'manual_drive_group' => :'StorageManualDriveGroup', :'name' => :'String', :'raid_level' => :'String', :'type' => :'Integer', :'virtual_drives' => :'Array<StorageVirtualDriveConfiguration>', :'storage_policy' => :'StorageStoragePolicyRelationship' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
265 266 267 268 269 270 271 272 273 274 275 276 277 |
# File 'lib/intersight_client/models/storage_drive_group_all_of.rb', line 265 def ==(o) return true if self.equal?(o) self.class == o.class && class_id == o.class_id && object_type == o.object_type && automatic_drive_group == o.automatic_drive_group && manual_drive_group == o.manual_drive_group && name == o.name && raid_level == o.raid_level && type == o.type && virtual_drives == o.virtual_drives && storage_policy == o.storage_policy end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 |
# File 'lib/intersight_client/models/storage_drive_group_all_of.rb', line 324 def _deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = IntersightClient.const_get(type) klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
395 396 397 398 399 400 401 402 403 404 405 406 407 |
# File 'lib/intersight_client/models/storage_drive_group_all_of.rb', line 395 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 |
# File 'lib/intersight_client/models/storage_drive_group_all_of.rb', line 301 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) StorageDriveGroupAllOf.openapi_types.each_pair do |key, type| if attributes[StorageDriveGroupAllOf.attribute_map[key]].nil? && StorageDriveGroupAllOf.openapi_nullable.include?(key) self.send("#{key}=", nil) elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[StorageDriveGroupAllOf.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[StorageDriveGroupAllOf.attribute_map[key]].map { |v| _deserialize($1, v) }) end elsif !attributes[StorageDriveGroupAllOf.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[StorageDriveGroupAllOf.attribute_map[key]])) end end self end |
#eql?(o) ⇒ Boolean
281 282 283 |
# File 'lib/intersight_client/models/storage_drive_group_all_of.rb', line 281 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
287 288 289 |
# File 'lib/intersight_client/models/storage_drive_group_all_of.rb', line 287 def hash [class_id, object_type, automatic_drive_group, manual_drive_group, name, raid_level, type, virtual_drives, storage_policy].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 |
# File 'lib/intersight_client/models/storage_drive_group_all_of.rb', line 177 def list_invalid_properties invalid_properties = Array.new if @class_id.nil? invalid_properties.push('invalid value for "class_id", class_id cannot be nil.') end if @object_type.nil? invalid_properties.push('invalid value for "object_type", object_type cannot be nil.') end pattern = Regexp.new(/[-.:_a-zA-Z0-9]{1,15}/) if !@name.nil? && @name !~ pattern invalid_properties.push("invalid value for \"name\", must conform to the pattern #{pattern}.") end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
371 372 373 |
# File 'lib/intersight_client/models/storage_drive_group_all_of.rb', line 371 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
377 378 379 380 381 382 383 384 385 386 387 388 389 |
# File 'lib/intersight_client/models/storage_drive_group_all_of.rb', line 377 def to_hash hash = {} StorageDriveGroupAllOf.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = StorageDriveGroupAllOf.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
365 366 367 |
# File 'lib/intersight_client/models/storage_drive_group_all_of.rb', line 365 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
197 198 199 200 201 202 203 204 205 206 207 208 209 210 |
# File 'lib/intersight_client/models/storage_drive_group_all_of.rb', line 197 def valid? return false if @class_id.nil? class_id_validator = EnumAttributeValidator.new('String', ["storage.DriveGroup"]) return false unless class_id_validator.valid?(@class_id) return false if @object_type.nil? object_type_validator = EnumAttributeValidator.new('String', ["storage.DriveGroup"]) return false unless object_type_validator.valid?(@object_type) return false if !@name.nil? && @name !~ Regexp.new(/[-.:_a-zA-Z0-9]{1,15}/) raid_level_validator = EnumAttributeValidator.new('String', ["Raid0", "Raid1", "Raid5", "Raid6", "Raid10", "Raid50", "Raid60"]) return false unless raid_level_validator.valid?(@raid_level) type_validator = EnumAttributeValidator.new('Integer', [0, 1]) return false unless type_validator.valid?(@type) true end |