Class: IntersightClient::VirtualizationVmwareVirtualSwitch
- Inherits:
-
VirtualizationBaseVirtualSwitch
- Object
- MoBaseMo
- VirtualizationBaseSourceDevice
- VirtualizationBaseSwitch
- VirtualizationBaseVirtualSwitch
- IntersightClient::VirtualizationVmwareVirtualSwitch
- Defined in:
- lib/intersight_client/models/virtualization_vmware_virtual_switch.rb
Overview
The VMware Virtual Switch object is represented here.
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#class_id ⇒ Object
The fully-qualified name of the instantiated, concrete type.
-
#forged_transmits ⇒ Object
If forgedTransmits property value is set to reject, outbound frames with a source MAC address different from the one set on the adapter are dropped.
-
#host ⇒ Object
Returns the value of attribute host.
-
#mac_address_changes ⇒ Object
If macAddressChanges property value is set to reject and the MAC address of the adapter is changed to a value other than the one specified in .vmx configuration file, the switch drops all inbound frames to the adapter.
-
#mtu ⇒ Object
Maximum transmission unit configured on a virtual switch.
-
#nic_teaming_and_failover ⇒ Object
Returns the value of attribute nic_teaming_and_failover.
-
#num_networks ⇒ Object
Number of networks available on this virtual switch.
-
#num_physical_network_interfaces ⇒ Object
Number of physical network interfaces connected with this virtual switch.
-
#object_type ⇒ Object
The fully-qualified name of the instantiated, concrete type.
-
#promiscuous_mode ⇒ Object
If promiscuousMode property value is set to reject, the virtual switch forwards only frames that are addressed to the adapter.
Attributes inherited from VirtualizationBaseSwitch
Attributes inherited from VirtualizationBaseSourceDevice
Attributes inherited from MoBaseMo
#account_moid, #ancestors, #create_time, #display_names, #domain_group_moid, #mod_time, #moid, #owners, #parent, #permission_resources, #shared_scope, #tags, #version_context
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns the key-value map of all the JSON attributes this model knows about, including the ones defined in its parent(s).
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about, including the ones defined in its parent(s).
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_all_of ⇒ Object
List of class defined in allOf (OpenAPI v3).
-
.openapi_discriminator_name ⇒ Object
discriminator’s property name in OpenAPI v3.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ VirtualizationVmwareVirtualSwitch
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ VirtualizationVmwareVirtualSwitch
Initializes the object
133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 |
# File 'lib/intersight_client/models/virtualization_vmware_virtual_switch.rb', line 133 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `IntersightClient::VirtualizationVmwareVirtualSwitch` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `#{self.class.name}`. Please check the name to make sure it's valid. List of attributes: " + self.class.acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } # call parent's initialize super(attributes) if attributes.key?(:'class_id') self.class_id = attributes[:'class_id'] else self.class_id = 'virtualization.VmwareVirtualSwitch' end if attributes.key?(:'object_type') self.object_type = attributes[:'object_type'] else self.object_type = 'virtualization.VmwareVirtualSwitch' end if attributes.key?(:'forged_transmits') self.forged_transmits = attributes[:'forged_transmits'] else self.forged_transmits = 'Reject' end if attributes.key?(:'mac_address_changes') self.mac_address_changes = attributes[:'mac_address_changes'] else self.mac_address_changes = 'Reject' end if attributes.key?(:'mtu') self.mtu = attributes[:'mtu'] end if attributes.key?(:'nic_teaming_and_failover') self.nic_teaming_and_failover = attributes[:'nic_teaming_and_failover'] end if attributes.key?(:'num_networks') self.num_networks = attributes[:'num_networks'] end if attributes.key?(:'num_physical_network_interfaces') self.num_physical_network_interfaces = attributes[:'num_physical_network_interfaces'] end if attributes.key?(:'promiscuous_mode') self.promiscuous_mode = attributes[:'promiscuous_mode'] else self.promiscuous_mode = 'Reject' end if attributes.key?(:'host') self.host = attributes[:'host'] end end |
Instance Attribute Details
#class_id ⇒ Object
The fully-qualified name of the instantiated, concrete type. This property is used as a discriminator to identify the type of the payload when marshaling and unmarshaling data.
20 21 22 |
# File 'lib/intersight_client/models/virtualization_vmware_virtual_switch.rb', line 20 def class_id @class_id end |
#forged_transmits ⇒ Object
If forgedTransmits property value is set to reject, outbound frames with a source MAC address different from the one set on the adapter are dropped. If property value is set to accept, the switch does not perform filtering and permits all outbound frames. * Reject - Indicates that the security policy is rejected. * Accept - Indicates that the security policy is accepted.
26 27 28 |
# File 'lib/intersight_client/models/virtualization_vmware_virtual_switch.rb', line 26 def forged_transmits @forged_transmits end |
#host ⇒ Object
Returns the value of attribute host.
45 46 47 |
# File 'lib/intersight_client/models/virtualization_vmware_virtual_switch.rb', line 45 def host @host end |
#mac_address_changes ⇒ Object
If macAddressChanges property value is set to reject and the MAC address of the adapter is changed to a value other than the one specified in .vmx configuration file, the switch drops all inbound frames to the adapter. If property value is set to accept and the MAC address is changed, the switch allows frames to the new MAC address to pass. * Reject - Indicates that the security policy is rejected. * Accept - Indicates that the security policy is accepted.
29 30 31 |
# File 'lib/intersight_client/models/virtualization_vmware_virtual_switch.rb', line 29 def mac_address_changes @mac_address_changes end |
#mtu ⇒ Object
Maximum transmission unit configured on a virtual switch.
32 33 34 |
# File 'lib/intersight_client/models/virtualization_vmware_virtual_switch.rb', line 32 def mtu @mtu end |
#nic_teaming_and_failover ⇒ Object
Returns the value of attribute nic_teaming_and_failover.
34 35 36 |
# File 'lib/intersight_client/models/virtualization_vmware_virtual_switch.rb', line 34 def nic_teaming_and_failover @nic_teaming_and_failover end |
#num_networks ⇒ Object
Number of networks available on this virtual switch.
37 38 39 |
# File 'lib/intersight_client/models/virtualization_vmware_virtual_switch.rb', line 37 def num_networks @num_networks end |
#num_physical_network_interfaces ⇒ Object
Number of physical network interfaces connected with this virtual switch.
40 41 42 |
# File 'lib/intersight_client/models/virtualization_vmware_virtual_switch.rb', line 40 def num_physical_network_interfaces @num_physical_network_interfaces end |
#object_type ⇒ Object
The fully-qualified name of the instantiated, concrete type. The value should be the same as the ‘ClassId’ property.
23 24 25 |
# File 'lib/intersight_client/models/virtualization_vmware_virtual_switch.rb', line 23 def object_type @object_type end |
#promiscuous_mode ⇒ Object
If promiscuousMode property value is set to reject, the virtual switch forwards only frames that are addressed to the adapter. If property value is set to accept, the virtual switch forwards all frames to the adapter in compliance with the active VLAN policy for the port to which it is connected. * Reject - Indicates that the security policy is rejected. * Accept - Indicates that the security policy is accepted.
43 44 45 |
# File 'lib/intersight_client/models/virtualization_vmware_virtual_switch.rb', line 43 def promiscuous_mode @promiscuous_mode end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns the key-value map of all the JSON attributes this model knows about, including the ones defined in its parent(s)
91 92 93 |
# File 'lib/intersight_client/models/virtualization_vmware_virtual_switch.rb', line 91 def self.acceptable_attribute_map attribute_map.merge(superclass.acceptable_attribute_map) end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about, including the ones defined in its parent(s)
86 87 88 |
# File 'lib/intersight_client/models/virtualization_vmware_virtual_switch.rb', line 86 def self.acceptable_attributes attribute_map.values.concat(superclass.acceptable_attributes) end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
70 71 72 73 74 75 76 77 78 79 80 81 82 83 |
# File 'lib/intersight_client/models/virtualization_vmware_virtual_switch.rb', line 70 def self.attribute_map { :'class_id' => :'ClassId', :'object_type' => :'ObjectType', :'forged_transmits' => :'ForgedTransmits', :'mac_address_changes' => :'MacAddressChanges', :'mtu' => :'Mtu', :'nic_teaming_and_failover' => :'NicTeamingAndFailover', :'num_networks' => :'NumNetworks', :'num_physical_network_interfaces' => :'NumPhysicalNetworkInterfaces', :'promiscuous_mode' => :'PromiscuousMode', :'host' => :'Host' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
315 316 317 |
# File 'lib/intersight_client/models/virtualization_vmware_virtual_switch.rb', line 315 def self.build_from_hash(attributes) new.build_from_hash(attributes) end |
.openapi_all_of ⇒ Object
List of class defined in allOf (OpenAPI v3)
119 120 121 122 123 124 |
# File 'lib/intersight_client/models/virtualization_vmware_virtual_switch.rb', line 119 def self.openapi_all_of [ :'VirtualizationBaseVirtualSwitch', :'VirtualizationVmwareVirtualSwitchAllOf' ] end |
.openapi_discriminator_name ⇒ Object
discriminator’s property name in OpenAPI v3
127 128 129 |
# File 'lib/intersight_client/models/virtualization_vmware_virtual_switch.rb', line 127 def self.openapi_discriminator_name :'ClassId' end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
112 113 114 115 116 |
# File 'lib/intersight_client/models/virtualization_vmware_virtual_switch.rb', line 112 def self.openapi_nullable Set.new([ :'nic_teaming_and_failover', ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
96 97 98 99 100 101 102 103 104 105 106 107 108 109 |
# File 'lib/intersight_client/models/virtualization_vmware_virtual_switch.rb', line 96 def self.openapi_types { :'class_id' => :'String', :'object_type' => :'String', :'forged_transmits' => :'String', :'mac_address_changes' => :'String', :'mtu' => :'Integer', :'nic_teaming_and_failover' => :'VirtualizationVmwareTeamingAndFailover', :'num_networks' => :'Integer', :'num_physical_network_interfaces' => :'Integer', :'promiscuous_mode' => :'String', :'host' => :'VirtualizationVmwareHostRelationship' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
285 286 287 288 289 290 291 292 293 294 295 296 297 298 |
# File 'lib/intersight_client/models/virtualization_vmware_virtual_switch.rb', line 285 def ==(o) return true if self.equal?(o) self.class == o.class && class_id == o.class_id && object_type == o.object_type && forged_transmits == o.forged_transmits && mac_address_changes == o.mac_address_changes && mtu == o.mtu && nic_teaming_and_failover == o.nic_teaming_and_failover && num_networks == o.num_networks && num_physical_network_interfaces == o.num_physical_network_interfaces && promiscuous_mode == o.promiscuous_mode && host == o.host && super(o) end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 |
# File 'lib/intersight_client/models/virtualization_vmware_virtual_switch.rb', line 346 def _deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = IntersightClient.const_get(type) klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
417 418 419 420 421 422 423 424 425 426 427 428 429 |
# File 'lib/intersight_client/models/virtualization_vmware_virtual_switch.rb', line 417 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 |
# File 'lib/intersight_client/models/virtualization_vmware_virtual_switch.rb', line 322 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) super(attributes) VirtualizationVmwareVirtualSwitch.openapi_types.each_pair do |key, type| if attributes[VirtualizationVmwareVirtualSwitch.attribute_map[key]].nil? && VirtualizationVmwareVirtualSwitch.openapi_nullable.include?(key) self.send("#{key}=", nil) elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[VirtualizationVmwareVirtualSwitch.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[VirtualizationVmwareVirtualSwitch.attribute_map[key]].map { |v| _deserialize($1, v) }) end elsif !attributes[VirtualizationVmwareVirtualSwitch.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[VirtualizationVmwareVirtualSwitch.attribute_map[key]])) end end self end |
#eql?(o) ⇒ Boolean
302 303 304 |
# File 'lib/intersight_client/models/virtualization_vmware_virtual_switch.rb', line 302 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
308 309 310 |
# File 'lib/intersight_client/models/virtualization_vmware_virtual_switch.rb', line 308 def hash [class_id, object_type, forged_transmits, mac_address_changes, mtu, nic_teaming_and_failover, num_networks, num_physical_network_interfaces, promiscuous_mode, host].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
202 203 204 205 206 207 208 209 210 211 212 213 |
# File 'lib/intersight_client/models/virtualization_vmware_virtual_switch.rb', line 202 def list_invalid_properties invalid_properties = super if @class_id.nil? invalid_properties.push('invalid value for "class_id", class_id cannot be nil.') end if @object_type.nil? invalid_properties.push('invalid value for "object_type", object_type cannot be nil.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
393 394 395 |
# File 'lib/intersight_client/models/virtualization_vmware_virtual_switch.rb', line 393 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
399 400 401 402 403 404 405 406 407 408 409 410 411 |
# File 'lib/intersight_client/models/virtualization_vmware_virtual_switch.rb', line 399 def to_hash hash = super VirtualizationVmwareVirtualSwitch.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = VirtualizationVmwareVirtualSwitch.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
387 388 389 |
# File 'lib/intersight_client/models/virtualization_vmware_virtual_switch.rb', line 387 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 |
# File 'lib/intersight_client/models/virtualization_vmware_virtual_switch.rb', line 217 def valid? return false if @class_id.nil? class_id_validator = EnumAttributeValidator.new('String', ["virtualization.VmwareVirtualSwitch"]) return false unless class_id_validator.valid?(@class_id) return false if @object_type.nil? object_type_validator = EnumAttributeValidator.new('String', ["virtualization.VmwareVirtualSwitch"]) return false unless object_type_validator.valid?(@object_type) forged_transmits_validator = EnumAttributeValidator.new('String', ["Reject", "Accept"]) return false unless forged_transmits_validator.valid?(@forged_transmits) mac_address_changes_validator = EnumAttributeValidator.new('String', ["Reject", "Accept"]) return false unless mac_address_changes_validator.valid?(@mac_address_changes) promiscuous_mode_validator = EnumAttributeValidator.new('String', ["Reject", "Accept"]) return false unless promiscuous_mode_validator.valid?(@promiscuous_mode) true && super end |