Class: IntersightClient::WorkflowSolutionActionInstance
- Defined in:
- lib/intersight_client/models/workflow_solution_action_instance.rb
Overview
Solution action instance which represents one action on a solution instance.
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#action ⇒ Object
Name of the action that needs to be performed on the solution instance.
-
#action_workflow_info ⇒ Object
Returns the value of attribute action_workflow_info.
-
#class_id ⇒ Object
The fully-qualified name of the instantiated, concrete type.
-
#end_time ⇒ Object
The time when the action was stopped or completed execution last time.
-
#input ⇒ Object
Inputs for a solution action and the format is specified by input definition of the solution action definition.
-
#last_action ⇒ Object
The last action that was issued on the action definition workflows is saved in this property.
-
#name ⇒ Object
Name for the action instance is created in the system by appending name of the solution instance to the name of the action definition.
-
#object_type ⇒ Object
The fully-qualified name of the instantiated, concrete type.
-
#solution_action_definition ⇒ Object
Returns the value of attribute solution_action_definition.
-
#solution_definition ⇒ Object
Returns the value of attribute solution_definition.
-
#solution_instance ⇒ Object
Returns the value of attribute solution_instance.
-
#start_time ⇒ Object
The time when the action was started for execution last time.
-
#status ⇒ Object
State of the solution action instance.
-
#stop_workflow_info ⇒ Object
Returns the value of attribute stop_workflow_info.
-
#validation_workflow_info ⇒ Object
Returns the value of attribute validation_workflow_info.
Attributes inherited from MoBaseMo
#account_moid, #ancestors, #create_time, #display_names, #domain_group_moid, #mod_time, #moid, #owners, #parent, #permission_resources, #shared_scope, #tags, #version_context
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns the key-value map of all the JSON attributes this model knows about, including the ones defined in its parent(s).
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about, including the ones defined in its parent(s).
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_all_of ⇒ Object
List of class defined in allOf (OpenAPI v3).
-
.openapi_discriminator_name ⇒ Object
discriminator’s property name in OpenAPI v3.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ WorkflowSolutionActionInstance
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ WorkflowSolutionActionInstance
Initializes the object
154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 |
# File 'lib/intersight_client/models/workflow_solution_action_instance.rb', line 154 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `IntersightClient::WorkflowSolutionActionInstance` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `#{self.class.name}`. Please check the name to make sure it's valid. List of attributes: " + self.class.acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } # call parent's initialize super(attributes) if attributes.key?(:'class_id') self.class_id = attributes[:'class_id'] else self.class_id = 'workflow.SolutionActionInstance' end if attributes.key?(:'object_type') self.object_type = attributes[:'object_type'] else self.object_type = 'workflow.SolutionActionInstance' end if attributes.key?(:'action') self.action = attributes[:'action'] else self.action = 'None' end if attributes.key?(:'end_time') self.end_time = attributes[:'end_time'] end if attributes.key?(:'input') self.input = attributes[:'input'] end if attributes.key?(:'last_action') self.last_action = attributes[:'last_action'] else self.last_action = 'None' end if attributes.key?(:'name') self.name = attributes[:'name'] end if attributes.key?(:'start_time') self.start_time = attributes[:'start_time'] end if attributes.key?(:'status') self.status = attributes[:'status'] else self.status = 'NotStarted' end if attributes.key?(:'action_workflow_info') self.action_workflow_info = attributes[:'action_workflow_info'] end if attributes.key?(:'solution_action_definition') self.solution_action_definition = attributes[:'solution_action_definition'] end if attributes.key?(:'solution_definition') self.solution_definition = attributes[:'solution_definition'] end if attributes.key?(:'solution_instance') self.solution_instance = attributes[:'solution_instance'] end if attributes.key?(:'stop_workflow_info') self.stop_workflow_info = attributes[:'stop_workflow_info'] end if attributes.key?(:'validation_workflow_info') self.validation_workflow_info = attributes[:'validation_workflow_info'] end end |
Instance Attribute Details
#action ⇒ Object
Name of the action that needs to be performed on the solution instance. * None - No action is set, this is the default value for action field. * Validate - Validation the action instance inputs and run the validation workflows. * Start - Start a new execution of the action instance. * Retry - Retry the solution action instance from the beginning. * RetryFailed - Retry the workflow that has failed from the failure point. * Cancel - Cancel the core workflow that is in running or waiting state. This action can be used when the workflows are stuck and not progressing. * Stop - Stop the action instance which is in progress and didn’t complete successfully. Use this action to clear the state and then delete the action instance. A completed action cannot be stopped.
26 27 28 |
# File 'lib/intersight_client/models/workflow_solution_action_instance.rb', line 26 def action @action end |
#action_workflow_info ⇒ Object
Returns the value of attribute action_workflow_info.
46 47 48 |
# File 'lib/intersight_client/models/workflow_solution_action_instance.rb', line 46 def action_workflow_info @action_workflow_info end |
#class_id ⇒ Object
The fully-qualified name of the instantiated, concrete type. This property is used as a discriminator to identify the type of the payload when marshaling and unmarshaling data.
20 21 22 |
# File 'lib/intersight_client/models/workflow_solution_action_instance.rb', line 20 def class_id @class_id end |
#end_time ⇒ Object
The time when the action was stopped or completed execution last time.
29 30 31 |
# File 'lib/intersight_client/models/workflow_solution_action_instance.rb', line 29 def end_time @end_time end |
#input ⇒ Object
Inputs for a solution action and the format is specified by input definition of the solution action definition.
32 33 34 |
# File 'lib/intersight_client/models/workflow_solution_action_instance.rb', line 32 def input @input end |
#last_action ⇒ Object
The last action that was issued on the action definition workflows is saved in this property. * None - No action is set, this is the default value for action field. * Validate - Validation the action instance inputs and run the validation workflows. * Start - Start a new execution of the action instance. * Retry - Retry the solution action instance from the beginning. * RetryFailed - Retry the workflow that has failed from the failure point. * Cancel - Cancel the core workflow that is in running or waiting state. This action can be used when the workflows are stuck and not progressing. * Stop - Stop the action instance which is in progress and didn’t complete successfully. Use this action to clear the state and then delete the action instance. A completed action cannot be stopped.
35 36 37 |
# File 'lib/intersight_client/models/workflow_solution_action_instance.rb', line 35 def last_action @last_action end |
#name ⇒ Object
Name for the action instance is created in the system by appending name of the solution instance to the name of the action definition.
38 39 40 |
# File 'lib/intersight_client/models/workflow_solution_action_instance.rb', line 38 def name @name end |
#object_type ⇒ Object
The fully-qualified name of the instantiated, concrete type. The value should be the same as the ‘ClassId’ property.
23 24 25 |
# File 'lib/intersight_client/models/workflow_solution_action_instance.rb', line 23 def object_type @object_type end |
#solution_action_definition ⇒ Object
Returns the value of attribute solution_action_definition.
48 49 50 |
# File 'lib/intersight_client/models/workflow_solution_action_instance.rb', line 48 def solution_action_definition @solution_action_definition end |
#solution_definition ⇒ Object
Returns the value of attribute solution_definition.
50 51 52 |
# File 'lib/intersight_client/models/workflow_solution_action_instance.rb', line 50 def solution_definition @solution_definition end |
#solution_instance ⇒ Object
Returns the value of attribute solution_instance.
52 53 54 |
# File 'lib/intersight_client/models/workflow_solution_action_instance.rb', line 52 def solution_instance @solution_instance end |
#start_time ⇒ Object
The time when the action was started for execution last time.
41 42 43 |
# File 'lib/intersight_client/models/workflow_solution_action_instance.rb', line 41 def start_time @start_time end |
#status ⇒ Object
State of the solution action instance. * NotStarted - Solution action is not yet started and it is in a draft mode. A solution action instance can be deleted in this state. * Validating - A validate action has been triggered on the action and until it completes the start action cannot be issued. * InProgress - An action is in progress and until that action has reached a final state, another action cannot be started. * Failed - The action on the solution failed and can be retried. * Completed - The action on the solution completed successfully. * Stopping - The stop action is running on the action instance.
44 45 46 |
# File 'lib/intersight_client/models/workflow_solution_action_instance.rb', line 44 def status @status end |
#stop_workflow_info ⇒ Object
Returns the value of attribute stop_workflow_info.
54 55 56 |
# File 'lib/intersight_client/models/workflow_solution_action_instance.rb', line 54 def stop_workflow_info @stop_workflow_info end |
#validation_workflow_info ⇒ Object
Returns the value of attribute validation_workflow_info.
56 57 58 |
# File 'lib/intersight_client/models/workflow_solution_action_instance.rb', line 56 def validation_workflow_info @validation_workflow_info end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns the key-value map of all the JSON attributes this model knows about, including the ones defined in its parent(s)
107 108 109 |
# File 'lib/intersight_client/models/workflow_solution_action_instance.rb', line 107 def self.acceptable_attribute_map attribute_map.merge(superclass.acceptable_attribute_map) end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about, including the ones defined in its parent(s)
102 103 104 |
# File 'lib/intersight_client/models/workflow_solution_action_instance.rb', line 102 def self.acceptable_attributes attribute_map.values.concat(superclass.acceptable_attributes) end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 |
# File 'lib/intersight_client/models/workflow_solution_action_instance.rb', line 81 def self.attribute_map { :'class_id' => :'ClassId', :'object_type' => :'ObjectType', :'action' => :'Action', :'end_time' => :'EndTime', :'input' => :'Input', :'last_action' => :'LastAction', :'name' => :'Name', :'start_time' => :'StartTime', :'status' => :'Status', :'action_workflow_info' => :'ActionWorkflowInfo', :'solution_action_definition' => :'SolutionActionDefinition', :'solution_definition' => :'SolutionDefinition', :'solution_instance' => :'SolutionInstance', :'stop_workflow_info' => :'StopWorkflowInfo', :'validation_workflow_info' => :'ValidationWorkflowInfo' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
361 362 363 |
# File 'lib/intersight_client/models/workflow_solution_action_instance.rb', line 361 def self.build_from_hash(attributes) new.build_from_hash(attributes) end |
.openapi_all_of ⇒ Object
List of class defined in allOf (OpenAPI v3)
140 141 142 143 144 145 |
# File 'lib/intersight_client/models/workflow_solution_action_instance.rb', line 140 def self.openapi_all_of [ :'MoBaseMo', :'WorkflowSolutionActionInstanceAllOf' ] end |
.openapi_discriminator_name ⇒ Object
discriminator’s property name in OpenAPI v3
148 149 150 |
# File 'lib/intersight_client/models/workflow_solution_action_instance.rb', line 148 def self.openapi_discriminator_name :'ClassId' end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
133 134 135 136 137 |
# File 'lib/intersight_client/models/workflow_solution_action_instance.rb', line 133 def self.openapi_nullable Set.new([ :'input', ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 |
# File 'lib/intersight_client/models/workflow_solution_action_instance.rb', line 112 def self.openapi_types { :'class_id' => :'String', :'object_type' => :'String', :'action' => :'String', :'end_time' => :'Time', :'input' => :'Object', :'last_action' => :'String', :'name' => :'String', :'start_time' => :'Time', :'status' => :'String', :'action_workflow_info' => :'WorkflowWorkflowInfoRelationship', :'solution_action_definition' => :'WorkflowSolutionActionDefinitionRelationship', :'solution_definition' => :'WorkflowSolutionDefinitionRelationship', :'solution_instance' => :'WorkflowSolutionInstanceRelationship', :'stop_workflow_info' => :'WorkflowWorkflowInfoRelationship', :'validation_workflow_info' => :'WorkflowWorkflowInfoRelationship' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 |
# File 'lib/intersight_client/models/workflow_solution_action_instance.rb', line 326 def ==(o) return true if self.equal?(o) self.class == o.class && class_id == o.class_id && object_type == o.object_type && action == o.action && end_time == o.end_time && input == o.input && last_action == o.last_action && name == o.name && start_time == o.start_time && status == o.status && action_workflow_info == o.action_workflow_info && solution_action_definition == o.solution_action_definition && solution_definition == o.solution_definition && solution_instance == o.solution_instance && stop_workflow_info == o.stop_workflow_info && validation_workflow_info == o.validation_workflow_info && super(o) end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 |
# File 'lib/intersight_client/models/workflow_solution_action_instance.rb', line 392 def _deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = IntersightClient.const_get(type) klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
463 464 465 466 467 468 469 470 471 472 473 474 475 |
# File 'lib/intersight_client/models/workflow_solution_action_instance.rb', line 463 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 |
# File 'lib/intersight_client/models/workflow_solution_action_instance.rb', line 368 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) super(attributes) WorkflowSolutionActionInstance.openapi_types.each_pair do |key, type| if attributes[WorkflowSolutionActionInstance.attribute_map[key]].nil? && WorkflowSolutionActionInstance.openapi_nullable.include?(key) self.send("#{key}=", nil) elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[WorkflowSolutionActionInstance.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[WorkflowSolutionActionInstance.attribute_map[key]].map { |v| _deserialize($1, v) }) end elsif !attributes[WorkflowSolutionActionInstance.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[WorkflowSolutionActionInstance.attribute_map[key]])) end end self end |
#eql?(o) ⇒ Boolean
348 349 350 |
# File 'lib/intersight_client/models/workflow_solution_action_instance.rb', line 348 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
354 355 356 |
# File 'lib/intersight_client/models/workflow_solution_action_instance.rb', line 354 def hash [class_id, object_type, action, end_time, input, last_action, name, start_time, status, action_workflow_info, solution_action_definition, solution_definition, solution_instance, stop_workflow_info, validation_workflow_info].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
243 244 245 246 247 248 249 250 251 252 253 254 |
# File 'lib/intersight_client/models/workflow_solution_action_instance.rb', line 243 def list_invalid_properties invalid_properties = super if @class_id.nil? invalid_properties.push('invalid value for "class_id", class_id cannot be nil.') end if @object_type.nil? invalid_properties.push('invalid value for "object_type", object_type cannot be nil.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
439 440 441 |
# File 'lib/intersight_client/models/workflow_solution_action_instance.rb', line 439 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
445 446 447 448 449 450 451 452 453 454 455 456 457 |
# File 'lib/intersight_client/models/workflow_solution_action_instance.rb', line 445 def to_hash hash = super WorkflowSolutionActionInstance.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = WorkflowSolutionActionInstance.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
433 434 435 |
# File 'lib/intersight_client/models/workflow_solution_action_instance.rb', line 433 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 |
# File 'lib/intersight_client/models/workflow_solution_action_instance.rb', line 258 def valid? return false if @class_id.nil? class_id_validator = EnumAttributeValidator.new('String', ["workflow.SolutionActionInstance"]) return false unless class_id_validator.valid?(@class_id) return false if @object_type.nil? object_type_validator = EnumAttributeValidator.new('String', ["workflow.SolutionActionInstance"]) return false unless object_type_validator.valid?(@object_type) action_validator = EnumAttributeValidator.new('String', ["None", "Validate", "Start", "Retry", "RetryFailed", "Cancel", "Stop"]) return false unless action_validator.valid?(@action) last_action_validator = EnumAttributeValidator.new('String', ["None", "Validate", "Start", "Retry", "RetryFailed", "Cancel", "Stop"]) return false unless last_action_validator.valid?(@last_action) status_validator = EnumAttributeValidator.new('String', ["NotStarted", "Validating", "InProgress", "Failed", "Completed", "Stopping"]) return false unless status_validator.valid?(@status) true && super end |